#    Licensed to the Apache Software Foundation (ASF) under one
#    or more contributor license agreements.  See the NOTICE file
#    distributed with this work for additional information
#    regarding copyright ownership.  The ASF licenses this file
#    to you under the Apache License, Version 2.0 (the
#    "License"); you may not use this file except in compliance
#    with the License.  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing,
#    software distributed under the License is distributed on an
#    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#    KIND, either express or implied.  See the License for the
#    specific language governing permissions and limitations
#    under the License.


from ctypes import *
from tempfile import NamedTemporaryFile
import weakref, sys

class FILE(Structure):
    pass

# PyFile_AsFile converts Python files into regular "FILE *" objects
PyFile_AsFile = pythonapi.PyFile_AsFile
PyFile_AsFile.argtypes = [py_object]
PyFile_AsFile.restype = POINTER(FILE)

# A friendly wrapper for exceptions
class SubversionException(Exception):
    def __init__(self, err, message=None, inherited=False):
        if isinstance(err, (int, long)):
            err = svn_error_create(err, None, message)

        self._as_parameter_ = err

        # Get a nice error message with line numbers and everything 
        f = NamedTemporaryFile()
        svn_handle_error2(err, PyFile_AsFile(f.file), 0, "")
        f.seek(0)
        self.value = f.read()
        f.close()

        # Save off the message and apr_err stuff
        self.message = err[0].message
        self.apr_err = err[0].apr_err
        self.child = None
        if err[0].child:
            self.child = SubversionException(err[0].child, None, True)

        if not inherited:
            # Cleanup the error when we die
            self.weakself = weakref.ref(self, lambda x: svn_error_clear(err))

    def __str__(self):
        return self.value

# If a error is returned from a Subversion function,
# raise an exception 
def SVN_ERR(ret):
    if ret:
        err = cast(ret, POINTER(svn_error_t))
        raise SubversionException(err)
    return ret

# If a error is returned from a Subversion function,
# raise an exception
def _svn_errcheck(result, func, args):
    return SVN_ERR(result)

# As of ctypes 1.0, ctypes does not support custom error-checking
# functions on callbacks, nor does it support custom datatypes on
# callbacks, so ctypesgen sets the return values for callbacks
# to c_void_p.
#
# Callback functions, therefore, won't have their errors checked
# automatically. Users who call these functions should wrap
# their function call using SVN_ERR so as to ensure that any
# exceptions are thrown appropriately.


###########################
r"""Wrapper for svn_auth.h

Generated with:
/usr/bin/ctypesgen-3 --cpp /usr/bin/cpp -DNDEBUG -DQT_NO_DEBUG -DLINUX -D_REENTRANT -D_GNU_SOURCE -DQT_DBUS_LIB -DQT_GUI_LIB -DQT_CORE_LIB -I/usr/include/apr -DLINUX -D_REENTRANT -D_GNU_SOURCE -I/usr/include/apr-util -I/usr/include -I/usr/include/apr -I/tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include -L/usr/libx32 -L/usr/libx32 -lapr-1 -L/usr/libx32 -L/usr/libx32 -laprutil-1 -lsvn_subr-1 -lsvn_diff-1 -lsvn_delta-1 -lsvn_fs-1 -lsvn_repos-1 -lsvn_wc-1 -lsvn_ra-1 -lsvn_client-1 /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_auth.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_base64.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_cache_config.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_checksum.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_client.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_cmdline.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_compat.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_config.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_ctype.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_dav.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_delta.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_diff.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_dirent_uri.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_dso.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_error.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_error_codes.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_fs.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_hash.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_io.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_iter.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_md5.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_mergeinfo.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_nls.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_opt.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_opt_impl.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_path.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_pools.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_props.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_quoprint.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_ra.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_ra_svn.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_repos.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_sorts.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_string.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_subst.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_time.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_types.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_types_impl.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_user.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_utf.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_version.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_wc.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_x509.h /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/builddir/../subversion/include/svn_xml.h /usr/include/apr/apr_allocator.h /usr/include/apr/apr_atomic.h /usr/include/apr/apr_cstr.h /usr/include/apr/apr_dso.h /usr/include/apr/apr_encode.h /usr/include/apr/apr_env.h /usr/include/apr/apr_errno.h /usr/include/apr/apr_escape.h /usr/include/apr/apr_file_info.h /usr/include/apr/apr_file_io.h /usr/include/apr/apr_fnmatch.h /usr/include/apr/apr_general.h /usr/include/apr/apr_getopt.h /usr/include/apr/apr_global_mutex.h /usr/include/apr/apr_hash.h /usr/include/apr/apr_inherit.h /usr/include/apr/apr_lib.h /usr/include/apr/apr_mmap.h /usr/include/apr/apr_network_io.h /usr/include/apr/apr_perms_set.h /usr/include/apr/apr_poll.h /usr/include/apr/apr_pools.h /usr/include/apr/apr_portable.h /usr/include/apr/apr_proc_mutex.h /usr/include/apr/apr_random.h /usr/include/apr/apr_ring.h /usr/include/apr/apr_shm.h /usr/include/apr/apr_signal.h /usr/include/apr/apr_skiplist.h /usr/include/apr/apr_strings.h /usr/include/apr/apr_support.h /usr/include/apr/apr_tables.h /usr/include/apr/apr_thread_cond.h /usr/include/apr/apr_thread_mutex.h /usr/include/apr/apr_thread_proc.h /usr/include/apr/apr_thread_rwlock.h /usr/include/apr/apr_time.h /usr/include/apr/apr_user.h /usr/include/apr/apr_version.h /usr/include/apr/apr_want.h /usr/include/apr-util/apr_anylock.h /usr/include/apr-util/apr_base64.h /usr/include/apr-util/apr_buckets.h /usr/include/apr-util/apr_crypto.h /usr/include/apr-util/apr_date.h /usr/include/apr-util/apr_dbd.h /usr/include/apr-util/apr_dbm.h /usr/include/apr-util/apr_hooks.h /usr/include/apr-util/apr_ldap.h /usr/include/apr-util/apr_ldap_init.h /usr/include/apr-util/apr_ldap_option.h /usr/include/apr-util/apr_ldap_rebind.h /usr/include/apr-util/apr_ldap_url.h /usr/include/apr-util/apr_md4.h /usr/include/apr-util/apr_md5.h /usr/include/apr-util/apr_memcache.h /usr/include/apr-util/apr_optional.h /usr/include/apr-util/apr_optional_hooks.h /usr/include/apr-util/apr_queue.h /usr/include/apr-util/apr_redis.h /usr/include/apr-util/apr_reslist.h /usr/include/apr-util/apr_rmm.h /usr/include/apr-util/apr_sdbm.h /usr/include/apr-util/apr_sha1.h /usr/include/apr-util/apr_siphash.h /usr/include/apr-util/apr_strmatch.h /usr/include/apr-util/apr_thread_pool.h /usr/include/apr-util/apr_uri.h /usr/include/apr-util/apr_uuid.h /usr/include/apr-util/apr_xlate.h /usr/include/apr-util/apr_xml.h /usr/include/apr-util/apu_errno.h /usr/include/apr-util/apu_version.h /usr/include/apr-util/apu_want.h -o subversion/bindings/ctypes-python/svn_all.py --no-macro-warnings

Do not modify this file.
"""

__docformat__ = "restructuredtext"

# Begin preamble for Python

import ctypes
import sys
from ctypes import *  # noqa: F401, F403

_int_types = (ctypes.c_int16, ctypes.c_int32)
if hasattr(ctypes, "c_int64"):
    # Some builds of ctypes apparently do not have ctypes.c_int64
    # defined; it's a pretty good bet that these builds do not
    # have 64-bit pointers.
    _int_types += (ctypes.c_int64,)
for t in _int_types:
    if ctypes.sizeof(t) == ctypes.sizeof(ctypes.c_size_t):
        c_ptrdiff_t = t
del t
del _int_types



class UserString:
    def __init__(self, seq):
        if isinstance(seq, bytes):
            self.data = seq
        elif isinstance(seq, UserString):
            self.data = seq.data[:]
        else:
            self.data = str(seq).encode()

    def __bytes__(self):
        return self.data

    def __str__(self):
        return self.data.decode()

    def __repr__(self):
        return repr(self.data)

    def __int__(self):
        return int(self.data.decode())

    def __long__(self):
        return int(self.data.decode())

    def __float__(self):
        return float(self.data.decode())

    def __complex__(self):
        return complex(self.data.decode())

    def __hash__(self):
        return hash(self.data)

    def __le__(self, string):
        if isinstance(string, UserString):
            return self.data <= string.data
        else:
            return self.data <= string

    def __lt__(self, string):
        if isinstance(string, UserString):
            return self.data < string.data
        else:
            return self.data < string

    def __ge__(self, string):
        if isinstance(string, UserString):
            return self.data >= string.data
        else:
            return self.data >= string

    def __gt__(self, string):
        if isinstance(string, UserString):
            return self.data > string.data
        else:
            return self.data > string

    def __eq__(self, string):
        if isinstance(string, UserString):
            return self.data == string.data
        else:
            return self.data == string

    def __ne__(self, string):
        if isinstance(string, UserString):
            return self.data != string.data
        else:
            return self.data != string

    def __contains__(self, char):
        return char in self.data

    def __len__(self):
        return len(self.data)

    def __getitem__(self, index):
        return self.__class__(self.data[index])

    def __getslice__(self, start, end):
        start = max(start, 0)
        end = max(end, 0)
        return self.__class__(self.data[start:end])

    def __add__(self, other):
        if isinstance(other, UserString):
            return self.__class__(self.data + other.data)
        elif isinstance(other, bytes):
            return self.__class__(self.data + other)
        else:
            return self.__class__(self.data + str(other).encode())

    def __radd__(self, other):
        if isinstance(other, bytes):
            return self.__class__(other + self.data)
        else:
            return self.__class__(str(other).encode() + self.data)

    def __mul__(self, n):
        return self.__class__(self.data * n)

    __rmul__ = __mul__

    def __mod__(self, args):
        return self.__class__(self.data % args)

    # the following methods are defined in alphabetical order:
    def capitalize(self):
        return self.__class__(self.data.capitalize())

    def center(self, width, *args):
        return self.__class__(self.data.center(width, *args))

    def count(self, sub, start=0, end=sys.maxsize):
        return self.data.count(sub, start, end)

    def decode(self, encoding=None, errors=None):  # XXX improve this?
        if encoding:
            if errors:
                return self.__class__(self.data.decode(encoding, errors))
            else:
                return self.__class__(self.data.decode(encoding))
        else:
            return self.__class__(self.data.decode())

    def encode(self, encoding=None, errors=None):  # XXX improve this?
        if encoding:
            if errors:
                return self.__class__(self.data.encode(encoding, errors))
            else:
                return self.__class__(self.data.encode(encoding))
        else:
            return self.__class__(self.data.encode())

    def endswith(self, suffix, start=0, end=sys.maxsize):
        return self.data.endswith(suffix, start, end)

    def expandtabs(self, tabsize=8):
        return self.__class__(self.data.expandtabs(tabsize))

    def find(self, sub, start=0, end=sys.maxsize):
        return self.data.find(sub, start, end)

    def index(self, sub, start=0, end=sys.maxsize):
        return self.data.index(sub, start, end)

    def isalpha(self):
        return self.data.isalpha()

    def isalnum(self):
        return self.data.isalnum()

    def isdecimal(self):
        return self.data.isdecimal()

    def isdigit(self):
        return self.data.isdigit()

    def islower(self):
        return self.data.islower()

    def isnumeric(self):
        return self.data.isnumeric()

    def isspace(self):
        return self.data.isspace()

    def istitle(self):
        return self.data.istitle()

    def isupper(self):
        return self.data.isupper()

    def join(self, seq):
        return self.data.join(seq)

    def ljust(self, width, *args):
        return self.__class__(self.data.ljust(width, *args))

    def lower(self):
        return self.__class__(self.data.lower())

    def lstrip(self, chars=None):
        return self.__class__(self.data.lstrip(chars))

    def partition(self, sep):
        return self.data.partition(sep)

    def replace(self, old, new, maxsplit=-1):
        return self.__class__(self.data.replace(old, new, maxsplit))

    def rfind(self, sub, start=0, end=sys.maxsize):
        return self.data.rfind(sub, start, end)

    def rindex(self, sub, start=0, end=sys.maxsize):
        return self.data.rindex(sub, start, end)

    def rjust(self, width, *args):
        return self.__class__(self.data.rjust(width, *args))

    def rpartition(self, sep):
        return self.data.rpartition(sep)

    def rstrip(self, chars=None):
        return self.__class__(self.data.rstrip(chars))

    def split(self, sep=None, maxsplit=-1):
        return self.data.split(sep, maxsplit)

    def rsplit(self, sep=None, maxsplit=-1):
        return self.data.rsplit(sep, maxsplit)

    def splitlines(self, keepends=0):
        return self.data.splitlines(keepends)

    def startswith(self, prefix, start=0, end=sys.maxsize):
        return self.data.startswith(prefix, start, end)

    def strip(self, chars=None):
        return self.__class__(self.data.strip(chars))

    def swapcase(self):
        return self.__class__(self.data.swapcase())

    def title(self):
        return self.__class__(self.data.title())

    def translate(self, *args):
        return self.__class__(self.data.translate(*args))

    def upper(self):
        return self.__class__(self.data.upper())

    def zfill(self, width):
        return self.__class__(self.data.zfill(width))


class MutableString(UserString):
    """mutable string objects

    Python strings are immutable objects.  This has the advantage, that
    strings may be used as dictionary keys.  If this property isn't needed
    and you insist on changing string values in place instead, you may cheat
    and use MutableString.

    But the purpose of this class is an educational one: to prevent
    people from inventing their own mutable string class derived
    from UserString and than forget thereby to remove (override) the
    __hash__ method inherited from UserString.  This would lead to
    errors that would be very hard to track down.

    A faster and better solution is to rewrite your program using lists."""

    def __init__(self, string=""):
        self.data = string

    def __hash__(self):
        raise TypeError("unhashable type (it is mutable)")

    def __setitem__(self, index, sub):
        if index < 0:
            index += len(self.data)
        if index < 0 or index >= len(self.data):
            raise IndexError
        self.data = self.data[:index] + sub + self.data[index + 1 :]

    def __delitem__(self, index):
        if index < 0:
            index += len(self.data)
        if index < 0 or index >= len(self.data):
            raise IndexError
        self.data = self.data[:index] + self.data[index + 1 :]

    def __setslice__(self, start, end, sub):
        start = max(start, 0)
        end = max(end, 0)
        if isinstance(sub, UserString):
            self.data = self.data[:start] + sub.data + self.data[end:]
        elif isinstance(sub, bytes):
            self.data = self.data[:start] + sub + self.data[end:]
        else:
            self.data = self.data[:start] + str(sub).encode() + self.data[end:]

    def __delslice__(self, start, end):
        start = max(start, 0)
        end = max(end, 0)
        self.data = self.data[:start] + self.data[end:]

    def immutable(self):
        return UserString(self.data)

    def __iadd__(self, other):
        if isinstance(other, UserString):
            self.data += other.data
        elif isinstance(other, bytes):
            self.data += other
        else:
            self.data += str(other).encode()
        return self

    def __imul__(self, n):
        self.data *= n
        return self


class String(MutableString, ctypes.Union):

    _fields_ = [("raw", ctypes.POINTER(ctypes.c_char)), ("data", ctypes.c_char_p)]

    def __init__(self, obj=b""):
        if isinstance(obj, (bytes, UserString)):
            self.data = bytes(obj)
        else:
            self.raw = obj

    def __len__(self):
        return self.data and len(self.data) or 0

    def from_param(cls, obj):
        # Convert None or 0
        if obj is None or obj == 0:
            return cls(ctypes.POINTER(ctypes.c_char)())

        # Convert from String
        elif isinstance(obj, String):
            return obj

        # Convert from bytes
        elif isinstance(obj, bytes):
            return cls(obj)

        # Convert from str
        elif isinstance(obj, str):
            return cls(obj.encode())

        # Convert from c_char_p
        elif isinstance(obj, ctypes.c_char_p):
            return obj

        # Convert from POINTER(ctypes.c_char)
        elif isinstance(obj, ctypes.POINTER(ctypes.c_char)):
            return obj

        # Convert from raw pointer
        elif isinstance(obj, int):
            return cls(ctypes.cast(obj, ctypes.POINTER(ctypes.c_char)))

        # Convert from ctypes.c_char array
        elif isinstance(obj, ctypes.c_char * len(obj)):
            return obj

        # Convert from object
        else:
            return String.from_param(obj._as_parameter_)

    from_param = classmethod(from_param)


def ReturnString(obj, func=None, arguments=None):
    return String.from_param(obj)


# As of ctypes 1.0, ctypes does not support custom error-checking
# functions on callbacks, nor does it support custom datatypes on
# callbacks, so we must ensure that all callbacks return
# primitive datatypes.
#
# Non-primitive return values wrapped with UNCHECKED won't be
# typechecked, and will be converted to ctypes.c_void_p.
def UNCHECKED(type):
    if hasattr(type, "_type_") and isinstance(type._type_, str) and type._type_ != "P":
        return type
    else:
        return ctypes.c_void_p


# ctypes doesn't have direct support for variadic functions, so we have to write
# our own wrapper class
class _variadic_function(object):
    def __init__(self, func, restype, argtypes, errcheck):
        self.func = func
        self.func.restype = restype
        self.argtypes = argtypes
        if errcheck:
            self.func.errcheck = errcheck

    def _as_parameter_(self):
        # So we can pass this variadic function as a function pointer
        return self.func

    def __call__(self, *args):
        fixed_args = []
        i = 0
        for argtype in self.argtypes:
            # Typecheck what we can
            fixed_args.append(argtype.from_param(args[i]))
            i += 1
        return self.func(*fixed_args + list(args[i:]))


def ord_if_char(value):
    """
    Simple helper used for casts to simple builtin types:  if the argument is a
    string type, it will be converted to it's ordinal value.

    This function will raise an exception if the argument is string with more
    than one characters.
    """
    return ord(value) if (isinstance(value, bytes) or isinstance(value, str)) else value

# End preamble

_libs = {}
_libdirs = ['/usr/libx32', '/usr/libx32', '/usr/libx32', '/usr/libx32']

# Begin loader

"""
Load libraries - appropriately for all our supported platforms
"""
# ----------------------------------------------------------------------------
# Copyright (c) 2008 David James
# Copyright (c) 2006-2008 Alex Holkner
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of pyglet nor the names of its
#    contributors may be used to endorse or promote products
#    derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# ----------------------------------------------------------------------------

import ctypes
import ctypes.util
import glob
import os.path
import platform
import re
import sys


def _environ_path(name):
    """Split an environment variable into a path-like list elements"""
    if name in os.environ:
        return os.environ[name].split(":")
    return []


class LibraryLoader:
    """
    A base class For loading of libraries ;-)
    Subclasses load libraries for specific platforms.
    """

    # library names formatted specifically for platforms
    name_formats = ["%s"]

    class Lookup:
        """Looking up calling conventions for a platform"""

        mode = ctypes.DEFAULT_MODE

        def __init__(self, path):
            super(LibraryLoader.Lookup, self).__init__()
            self.access = dict(cdecl=ctypes.CDLL(path, self.mode))

        def get(self, name, calling_convention="cdecl"):
            """Return the given name according to the selected calling convention"""
            if calling_convention not in self.access:
                raise LookupError(
                    "Unknown calling convention '{}' for function '{}'".format(
                        calling_convention, name
                    )
                )
            return getattr(self.access[calling_convention], name)

        def has(self, name, calling_convention="cdecl"):
            """Return True if this given calling convention finds the given 'name'"""
            if calling_convention not in self.access:
                return False
            return hasattr(self.access[calling_convention], name)

        def __getattr__(self, name):
            return getattr(self.access["cdecl"], name)

    def __init__(self):
        self.other_dirs = []

    def __call__(self, libname):
        """Given the name of a library, load it."""
        paths = self.getpaths(libname)

        for path in paths:
            # noinspection PyBroadException
            try:
                return self.Lookup(path)
            except Exception:  # pylint: disable=broad-except
                pass

        raise ImportError("Could not load %s." % libname)

    def getpaths(self, libname):
        """Return a list of paths where the library might be found."""
        if os.path.isabs(libname):
            yield libname
        else:
            # search through a prioritized series of locations for the library

            # we first search any specific directories identified by user
            for dir_i in self.other_dirs:
                for fmt in self.name_formats:
                    # dir_i should be absolute already
                    yield os.path.join(dir_i, fmt % libname)

            # check if this code is even stored in a physical file
            try:
                this_file = __file__
            except NameError:
                this_file = None

            # then we search the directory where the generated python interface is stored
            if this_file is not None:
                for fmt in self.name_formats:
                    yield os.path.abspath(os.path.join(os.path.dirname(__file__), fmt % libname))

            # now, use the ctypes tools to try to find the library
            for fmt in self.name_formats:
                path = ctypes.util.find_library(fmt % libname)
                if path:
                    yield path

            # then we search all paths identified as platform-specific lib paths
            for path in self.getplatformpaths(libname):
                yield path

            # Finally, we'll try the users current working directory
            for fmt in self.name_formats:
                yield os.path.abspath(os.path.join(os.path.curdir, fmt % libname))

    def getplatformpaths(self, _libname):  # pylint: disable=no-self-use
        """Return all the library paths available in this platform"""
        return []


# Darwin (Mac OS X)


class DarwinLibraryLoader(LibraryLoader):
    """Library loader for MacOS"""

    name_formats = [
        "lib%s.dylib",
        "lib%s.so",
        "lib%s.bundle",
        "%s.dylib",
        "%s.so",
        "%s.bundle",
        "%s",
    ]

    class Lookup(LibraryLoader.Lookup):
        """
        Looking up library files for this platform (Darwin aka MacOS)
        """

        # Darwin requires dlopen to be called with mode RTLD_GLOBAL instead
        # of the default RTLD_LOCAL.  Without this, you end up with
        # libraries not being loadable, resulting in "Symbol not found"
        # errors
        mode = ctypes.RTLD_GLOBAL

    def getplatformpaths(self, libname):
        if os.path.pathsep in libname:
            names = [libname]
        else:
            names = [fmt % libname for fmt in self.name_formats]

        for directory in self.getdirs(libname):
            for name in names:
                yield os.path.join(directory, name)

    @staticmethod
    def getdirs(libname):
        """Implements the dylib search as specified in Apple documentation:

        http://developer.apple.com/documentation/DeveloperTools/Conceptual/
            DynamicLibraries/Articles/DynamicLibraryUsageGuidelines.html

        Before commencing the standard search, the method first checks
        the bundle's ``Frameworks`` directory if the application is running
        within a bundle (OS X .app).
        """

        dyld_fallback_library_path = _environ_path("DYLD_FALLBACK_LIBRARY_PATH")
        if not dyld_fallback_library_path:
            dyld_fallback_library_path = [
                os.path.expanduser("~/lib"),
                "/usr/local/lib",
                "/usr/lib",
            ]

        dirs = []

        if "/" in libname:
            dirs.extend(_environ_path("DYLD_LIBRARY_PATH"))
        else:
            dirs.extend(_environ_path("LD_LIBRARY_PATH"))
            dirs.extend(_environ_path("DYLD_LIBRARY_PATH"))
            dirs.extend(_environ_path("LD_RUN_PATH"))

        if hasattr(sys, "frozen") and getattr(sys, "frozen") == "macosx_app":
            dirs.append(os.path.join(os.environ["RESOURCEPATH"], "..", "Frameworks"))

        dirs.extend(dyld_fallback_library_path)

        return dirs


# Posix


class PosixLibraryLoader(LibraryLoader):
    """Library loader for POSIX-like systems (including Linux)"""

    _ld_so_cache = None

    _include = re.compile(r"^\s*include\s+(?P<pattern>.*)")

    name_formats = ["lib%s.so", "%s.so", "%s"]

    class _Directories(dict):
        """Deal with directories"""

        def __init__(self):
            dict.__init__(self)
            self.order = 0

        def add(self, directory):
            """Add a directory to our current set of directories"""
            if len(directory) > 1:
                directory = directory.rstrip(os.path.sep)
            # only adds and updates order if exists and not already in set
            if not os.path.exists(directory):
                return
            order = self.setdefault(directory, self.order)
            if order == self.order:
                self.order += 1

        def extend(self, directories):
            """Add a list of directories to our set"""
            for a_dir in directories:
                self.add(a_dir)

        def ordered(self):
            """Sort the list of directories"""
            return (i[0] for i in sorted(self.items(), key=lambda d: d[1]))

    def _get_ld_so_conf_dirs(self, conf, dirs):
        """
        Recursive function to help parse all ld.so.conf files, including proper
        handling of the `include` directive.
        """

        try:
            with open(conf) as fileobj:
                for dirname in fileobj:
                    dirname = dirname.strip()
                    if not dirname:
                        continue

                    match = self._include.match(dirname)
                    if not match:
                        dirs.add(dirname)
                    else:
                        for dir2 in glob.glob(match.group("pattern")):
                            self._get_ld_so_conf_dirs(dir2, dirs)
        except IOError:
            pass

    def _create_ld_so_cache(self):
        # Recreate search path followed by ld.so.  This is going to be
        # slow to build, and incorrect (ld.so uses ld.so.cache, which may
        # not be up-to-date).  Used only as fallback for distros without
        # /sbin/ldconfig.
        #
        # We assume the DT_RPATH and DT_RUNPATH binary sections are omitted.

        directories = self._Directories()
        for name in (
            "LD_LIBRARY_PATH",
            "SHLIB_PATH",  # HP-UX
            "LIBPATH",  # OS/2, AIX
            "LIBRARY_PATH",  # BE/OS
        ):
            if name in os.environ:
                directories.extend(os.environ[name].split(os.pathsep))

        self._get_ld_so_conf_dirs("/etc/ld.so.conf", directories)

        bitage = platform.architecture()[0]

        unix_lib_dirs_list = []
        if bitage.startswith("64"):
            # prefer 64 bit if that is our arch
            unix_lib_dirs_list += ["/lib64", "/usr/lib64"]
        elif bitage.startswith("32") and platform.machine() == "x86_64":
            unix_lib_dirs_list += ["/libx32", "/usr/libx32"]

        # must include standard libs, since those paths are also used by 64 bit
        # installs
        unix_lib_dirs_list += ["/lib", "/usr/lib"]
        if sys.platform.startswith("linux"):
            # Try and support multiarch work in Ubuntu
            # https://wiki.ubuntu.com/MultiarchSpec
            if bitage.startswith("32"):
                # Assume Intel/AMD x86 compat
                unix_lib_dirs_list += ["/lib/i386-linux-gnu", "/usr/lib/i386-linux-gnu"]
            elif bitage.startswith("64"):
                # Assume Intel/AMD x86 compatible
                unix_lib_dirs_list += [
                    "/lib/x86_64-linux-gnu",
                    "/usr/lib/x86_64-linux-gnu",
                ]
            else:
                # guess...
                unix_lib_dirs_list += glob.glob("/lib/*linux-gnu")
        directories.extend(unix_lib_dirs_list)

        cache = {}
        lib_re = re.compile(r"lib(.*)\.s[ol]")
        # ext_re = re.compile(r"\.s[ol]$")
        for our_dir in directories.ordered():
            try:
                for path in glob.glob("%s/*.s[ol]*" % our_dir):
                    file = os.path.basename(path)

                    # Index by filename
                    cache_i = cache.setdefault(file, set())
                    cache_i.add(path)

                    # Index by library name
                    match = lib_re.match(file)
                    if match:
                        library = match.group(1)
                        cache_i = cache.setdefault(library, set())
                        cache_i.add(path)
            except OSError:
                pass

        self._ld_so_cache = cache

    def getplatformpaths(self, libname):
        if self._ld_so_cache is None:
            self._create_ld_so_cache()

        result = self._ld_so_cache.get(libname, set())
        for i in result:
            # we iterate through all found paths for library, since we may have
            # actually found multiple architectures or other library types that
            # may not load
            yield i


# Windows


class WindowsLibraryLoader(LibraryLoader):
    """Library loader for Microsoft Windows"""

    name_formats = ["%s.dll", "lib%s.dll", "%slib.dll", "%s"]

    class Lookup(LibraryLoader.Lookup):
        """Lookup class for Windows libraries..."""

        def __init__(self, path):
            super(WindowsLibraryLoader.Lookup, self).__init__(path)
            self.access["stdcall"] = ctypes.windll.LoadLibrary(path)


# Platform switching

# If your value of sys.platform does not appear in this dict, please contact
# the Ctypesgen maintainers.

loaderclass = {
    "darwin": DarwinLibraryLoader,
    "cygwin": WindowsLibraryLoader,
    "win32": WindowsLibraryLoader,
    "msys": WindowsLibraryLoader,
}

load_library = loaderclass.get(sys.platform, PosixLibraryLoader)()


def add_library_search_dirs(other_dirs):
    """
    Add libraries to search paths.
    If library paths are relative, convert them to absolute with respect to this
    file's directory
    """
    for path in other_dirs:
        if not os.path.isabs(path):
            path = os.path.abspath(path)
        load_library.other_dirs.append(path)


del loaderclass

# End loader

add_library_search_dirs(['/usr/libx32', '/usr/libx32', '/usr/libx32', '/usr/libx32'])

# Begin libraries
_libs["apr-1"] = load_library("apr-1")
_libs["aprutil-1"] = load_library("aprutil-1")
_libs["svn_subr-1"] = load_library("svn_subr-1")
_libs["svn_diff-1"] = load_library("svn_diff-1")
_libs["svn_delta-1"] = load_library("svn_delta-1")
_libs["svn_fs-1"] = load_library("svn_fs-1")
_libs["svn_repos-1"] = load_library("svn_repos-1")
_libs["svn_wc-1"] = load_library("svn_wc-1")
_libs["svn_ra-1"] = load_library("svn_ra-1")
_libs["svn_client-1"] = load_library("svn_client-1")

# 10 libraries
# End libraries

# No modules

__uint8_t = c_ubyte# /usr/include/bits/types.h: 38

__uint16_t = c_ushort# /usr/include/bits/types.h: 40

__uint32_t = c_uint# /usr/include/bits/types.h: 42

__uint64_t = c_ulonglong# /usr/include/bits/types.h: 48

__dev_t = __uint64_t# /usr/include/bits/types.h: 145

__uid_t = c_uint# /usr/include/bits/types.h: 146

__gid_t = c_uint# /usr/include/bits/types.h: 147

__ino_t = __uint64_t# /usr/include/bits/types.h: 148

__off_t = c_int64# /usr/include/bits/types.h: 152

__off64_t = c_int64# /usr/include/bits/types.h: 153

__pid_t = c_int# /usr/include/bits/types.h: 154

__rlim_t = __uint64_t# /usr/include/bits/types.h: 157

__time_t = c_int64# /usr/include/bits/types.h: 160

__suseconds_t = c_int64# /usr/include/bits/types.h: 162

__socklen_t = c_uint# /usr/include/bits/types.h: 210

ino_t = __ino_t# /usr/include/sys/types.h: 47

dev_t = __dev_t# /usr/include/sys/types.h: 59

gid_t = __gid_t# /usr/include/sys/types.h: 64

uid_t = __uid_t# /usr/include/sys/types.h: 79

off_t = __off_t# /usr/include/sys/types.h: 85

pid_t = __pid_t# /usr/include/sys/types.h: 97

time_t = __time_t# /usr/include/bits/types/time_t.h: 10

# /usr/include/bits/types/struct_timeval.h: 8
class struct_timeval(Structure):
    pass

struct_timeval.__slots__ = [
    'tv_sec',
    'tv_usec',
]
struct_timeval._fields_ = [
    ('tv_sec', __time_t),
    ('tv_usec', __suseconds_t),
]

# /usr/include/bits/thread-shared-types.h: 51
class struct___pthread_internal_list(Structure):
    pass

struct___pthread_internal_list.__slots__ = [
    '__prev',
    '__next',
]
struct___pthread_internal_list._fields_ = [
    ('__prev', POINTER(struct___pthread_internal_list)),
    ('__next', POINTER(struct___pthread_internal_list)),
]

__pthread_list_t = struct___pthread_internal_list# /usr/include/bits/thread-shared-types.h: 55

# /usr/include/bits/struct_mutex.h: 22
class struct___pthread_mutex_s(Structure):
    pass

struct___pthread_mutex_s.__slots__ = [
    '__lock',
    '__count',
    '__owner',
    '__nusers',
    '__kind',
    '__spins',
    '__elision',
    '__list',
]
struct___pthread_mutex_s._fields_ = [
    ('__lock', c_int),
    ('__count', c_uint),
    ('__owner', c_int),
    ('__nusers', c_uint),
    ('__kind', c_int),
    ('__spins', c_short),
    ('__elision', c_short),
    ('__list', __pthread_list_t),
]

pthread_t = c_ulong# /usr/include/bits/pthreadtypes.h: 27

pthread_key_t = c_uint# /usr/include/bits/pthreadtypes.h: 49

# /usr/include/bits/pthreadtypes.h: 72
class union_anon_9(Union):
    pass

union_anon_9.__slots__ = [
    '__data',
    '__size',
    '__align',
]
union_anon_9._fields_ = [
    ('__data', struct___pthread_mutex_s),
    ('__size', c_char * int(32)),
    ('__align', c_long),
]

pthread_mutex_t = union_anon_9# /usr/include/bits/pthreadtypes.h: 72

# /usr/include/bits/types/struct_iovec.h: 26
class struct_iovec(Structure):
    pass

struct_iovec.__slots__ = [
    'iov_base',
    'iov_len',
]
struct_iovec._fields_ = [
    ('iov_base', POINTER(None)),
    ('iov_len', c_size_t),
]

socklen_t = __socklen_t# /usr/include/bits/socket.h: 33

sa_family_t = c_ushort# /usr/include/bits/sockaddr.h: 28

# /usr/include/bits/socket.h: 184
class struct_sockaddr(Structure):
    pass

struct_sockaddr.__slots__ = [
    'sa_family',
    'sa_data',
]
struct_sockaddr._fields_ = [
    ('sa_family', sa_family_t),
    ('sa_data', c_char * int(14)),
]

# /usr/include/bits/socket.h: 197
class struct_sockaddr_storage(Structure):
    pass

struct_sockaddr_storage.__slots__ = [
    'ss_family',
    '__ss_padding',
    '__ss_align',
]
struct_sockaddr_storage._fields_ = [
    ('ss_family', sa_family_t),
    ('__ss_padding', c_char * int(((128 - sizeof(c_ushort)) - sizeof(c_ulong)))),
    ('__ss_align', c_ulong),
]

uint8_t = __uint8_t# /usr/include/bits/stdint-uintn.h: 24

uint16_t = __uint16_t# /usr/include/bits/stdint-uintn.h: 25

uint32_t = __uint32_t# /usr/include/bits/stdint-uintn.h: 26

uint64_t = __uint64_t# /usr/include/bits/stdint-uintn.h: 27

# /usr/include/signal.h: 119
if _libs["apr-1"].has("killpg", "cdecl"):
    killpg = _libs["apr-1"].get("killpg", "cdecl")
    killpg.argtypes = [__pid_t, c_int]
    killpg.restype = c_int

apr_byte_t = c_ubyte# /usr/include/apr/apr.h: 337

apr_int16_t = c_short# /usr/include/apr/apr.h: 339

apr_uint16_t = c_ushort# /usr/include/apr/apr.h: 340

apr_int32_t = c_int# /usr/include/apr/apr.h: 342

apr_uint32_t = c_uint# /usr/include/apr/apr.h: 343

apr_uint64_t = uint64_t# /usr/include/apr/apr.h: 381

apr_size_t = c_size_t# /usr/include/apr/apr.h: 388

apr_ssize_t = c_ptrdiff_t# /usr/include/apr/apr.h: 389

apr_off_t = off_t# /usr/include/apr/apr.h: 390

apr_socklen_t = socklen_t# /usr/include/apr/apr.h: 391

apr_ino_t = ino_t# /usr/include/apr/apr.h: 392

# /usr/include/errno.h: 37
if _libs["apr-1"].has("__errno_location", "cdecl"):
    __errno_location = _libs["apr-1"].get("__errno_location", "cdecl")
    __errno_location.argtypes = []
    __errno_location.restype = POINTER(c_int)

apr_status_t = c_int# /usr/include/apr/apr_errno.h: 44

# /usr/include/apr/apr_errno.h: 52
if _libs["apr-1"].has("apr_strerror", "cdecl"):
    apr_strerror = _libs["apr-1"].get("apr_strerror", "cdecl")
    apr_strerror.argtypes = [apr_status_t, String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_strerror.restype = ReturnString
    else:
        apr_strerror.restype = String
        apr_strerror.errcheck = ReturnString

apr_signum_t = c_int# /usr/include/apr/apr_general.h: 68

# /usr/include/apr/apr_general.h: 184
if _libs["apr-1"].has("apr_initialize", "cdecl"):
    apr_initialize = _libs["apr-1"].get("apr_initialize", "cdecl")
    apr_initialize.argtypes = []
    apr_initialize.restype = apr_status_t

# /usr/include/apr/apr_general.h: 198
if _libs["apr-1"].has("apr_app_initialize", "cdecl"):
    apr_app_initialize = _libs["apr-1"].get("apr_app_initialize", "cdecl")
    apr_app_initialize.argtypes = [POINTER(c_int), POINTER(POINTER(POINTER(c_char))), POINTER(POINTER(POINTER(c_char)))]
    apr_app_initialize.restype = apr_status_t

# /usr/include/apr/apr_general.h: 213
if _libs["apr-1"].has("apr_terminate", "cdecl"):
    apr_terminate = _libs["apr-1"].get("apr_terminate", "cdecl")
    apr_terminate.argtypes = []
    apr_terminate.restype = None

# /usr/include/apr/apr_general.h: 224
if _libs["apr-1"].has("apr_terminate2", "cdecl"):
    apr_terminate2 = _libs["apr-1"].get("apr_terminate2", "cdecl")
    apr_terminate2.argtypes = []
    apr_terminate2.restype = None

# /usr/include/apr/apr_general.h: 241
if _libs["apr-1"].has("apr_generate_random_bytes", "cdecl"):
    apr_generate_random_bytes = _libs["apr-1"].get("apr_generate_random_bytes", "cdecl")
    apr_generate_random_bytes.argtypes = [POINTER(c_ubyte), apr_size_t]
    apr_generate_random_bytes.restype = apr_status_t

# /usr/include/string.h: 61
if _libs["apr-1"].has("memset", "cdecl"):
    memset = _libs["apr-1"].get("memset", "cdecl")
    memset.argtypes = [POINTER(None), c_int, c_size_t]
    memset.restype = POINTER(c_ubyte)
    memset.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_pools.h: 60
class struct_apr_pool_t(Structure):
    pass

apr_pool_t = struct_apr_pool_t# /usr/include/apr/apr_pools.h: 60

apr_abortfunc_t = CFUNCTYPE(UNCHECKED(c_int), c_int)# /usr/include/apr/apr_pools.h: 148

# /usr/include/apr/apr_pools.h: 164
if _libs["apr-1"].has("apr_pool_initialize", "cdecl"):
    apr_pool_initialize = _libs["apr-1"].get("apr_pool_initialize", "cdecl")
    apr_pool_initialize.argtypes = []
    apr_pool_initialize.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 172
if _libs["apr-1"].has("apr_pool_terminate", "cdecl"):
    apr_pool_terminate = _libs["apr-1"].get("apr_pool_terminate", "cdecl")
    apr_pool_terminate.argtypes = []
    apr_pool_terminate.restype = None

# /usr/include/apr/apr_allocator.h: 41
class struct_apr_allocator_t(Structure):
    pass

apr_allocator_t = struct_apr_allocator_t# /usr/include/apr/apr_allocator.h: 41

# /usr/include/apr/apr_allocator.h: 54
class struct_apr_memnode_t(Structure):
    pass

apr_memnode_t = struct_apr_memnode_t# /usr/include/apr/apr_allocator.h: 43

struct_apr_memnode_t.__slots__ = [
    'next',
    'ref',
    'index',
    'free_index',
    'first_avail',
    'endp',
]
struct_apr_memnode_t._fields_ = [
    ('next', POINTER(apr_memnode_t)),
    ('ref', POINTER(POINTER(apr_memnode_t))),
    ('index', apr_uint32_t),
    ('free_index', apr_uint32_t),
    ('first_avail', String),
    ('endp', String),
]

# /usr/include/apr/apr_allocator.h: 74
if _libs["apr-1"].has("apr_allocator_create", "cdecl"):
    apr_allocator_create = _libs["apr-1"].get("apr_allocator_create", "cdecl")
    apr_allocator_create.argtypes = [POINTER(POINTER(apr_allocator_t))]
    apr_allocator_create.restype = apr_status_t

# /usr/include/apr/apr_allocator.h: 83
if _libs["apr-1"].has("apr_allocator_destroy", "cdecl"):
    apr_allocator_destroy = _libs["apr-1"].get("apr_allocator_destroy", "cdecl")
    apr_allocator_destroy.argtypes = [POINTER(apr_allocator_t)]
    apr_allocator_destroy.restype = None

# /usr/include/apr/apr_allocator.h: 92
if _libs["apr-1"].has("apr_allocator_alloc", "cdecl"):
    apr_allocator_alloc = _libs["apr-1"].get("apr_allocator_alloc", "cdecl")
    apr_allocator_alloc.argtypes = [POINTER(apr_allocator_t), apr_size_t]
    apr_allocator_alloc.restype = POINTER(apr_memnode_t)

# /usr/include/apr/apr_allocator.h: 103
if _libs["apr-1"].has("apr_allocator_free", "cdecl"):
    apr_allocator_free = _libs["apr-1"].get("apr_allocator_free", "cdecl")
    apr_allocator_free.argtypes = [POINTER(apr_allocator_t), POINTER(apr_memnode_t)]
    apr_allocator_free.restype = None

# /usr/include/apr/apr_allocator.h: 114
if _libs["apr-1"].has("apr_allocator_align", "cdecl"):
    apr_allocator_align = _libs["apr-1"].get("apr_allocator_align", "cdecl")
    apr_allocator_align.argtypes = [POINTER(apr_allocator_t), apr_size_t]
    apr_allocator_align.restype = apr_size_t

# /usr/include/apr/apr_allocator.h: 130
if _libs["apr-1"].has("apr_allocator_owner_set", "cdecl"):
    apr_allocator_owner_set = _libs["apr-1"].get("apr_allocator_owner_set", "cdecl")
    apr_allocator_owner_set.argtypes = [POINTER(apr_allocator_t), POINTER(apr_pool_t)]
    apr_allocator_owner_set.restype = None

# /usr/include/apr/apr_allocator.h: 138
if _libs["apr-1"].has("apr_allocator_owner_get", "cdecl"):
    apr_allocator_owner_get = _libs["apr-1"].get("apr_allocator_owner_get", "cdecl")
    apr_allocator_owner_get.argtypes = [POINTER(apr_allocator_t)]
    apr_allocator_owner_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_allocator.h: 147
if _libs["apr-1"].has("apr_allocator_max_free_set", "cdecl"):
    apr_allocator_max_free_set = _libs["apr-1"].get("apr_allocator_max_free_set", "cdecl")
    apr_allocator_max_free_set.argtypes = [POINTER(apr_allocator_t), apr_size_t]
    apr_allocator_max_free_set.restype = None

# /usr/include/apr/apr_thread_mutex.h: 41
class struct_apr_thread_mutex_t(Structure):
    pass

apr_thread_mutex_t = struct_apr_thread_mutex_t# /usr/include/apr/apr_thread_mutex.h: 41

# /usr/include/apr/apr_time.h: 39
try:
    apr_month_snames = ((c_char * int(4)) * int(12)).in_dll(_libs["apr-1"], "apr_month_snames")
except:
    pass

# /usr/include/apr/apr_time.h: 41
try:
    apr_day_snames = ((c_char * int(4)) * int(7)).in_dll(_libs["apr-1"], "apr_day_snames")
except:
    pass

apr_time_t = c_int64# /usr/include/apr/apr_time.h: 45

apr_interval_time_t = c_int64# /usr/include/apr/apr_time.h: 55

apr_short_interval_time_t = apr_int32_t# /usr/include/apr/apr_time.h: 57

# /usr/include/apr/apr_time.h: 87
if _libs["apr-1"].has("apr_time_now", "cdecl"):
    apr_time_now = _libs["apr-1"].get("apr_time_now", "cdecl")
    apr_time_now.argtypes = []
    apr_time_now.restype = apr_time_t

# /usr/include/apr/apr_time.h: 97
class struct_apr_time_exp_t(Structure):
    pass

apr_time_exp_t = struct_apr_time_exp_t# /usr/include/apr/apr_time.h: 90

struct_apr_time_exp_t.__slots__ = [
    'tm_usec',
    'tm_sec',
    'tm_min',
    'tm_hour',
    'tm_mday',
    'tm_mon',
    'tm_year',
    'tm_wday',
    'tm_yday',
    'tm_isdst',
    'tm_gmtoff',
]
struct_apr_time_exp_t._fields_ = [
    ('tm_usec', apr_int32_t),
    ('tm_sec', apr_int32_t),
    ('tm_min', apr_int32_t),
    ('tm_hour', apr_int32_t),
    ('tm_mday', apr_int32_t),
    ('tm_mon', apr_int32_t),
    ('tm_year', apr_int32_t),
    ('tm_wday', apr_int32_t),
    ('tm_yday', apr_int32_t),
    ('tm_isdst', apr_int32_t),
    ('tm_gmtoff', apr_int32_t),
]

# /usr/include/apr/apr_time.h: 130
if _libs["apr-1"].has("apr_time_ansi_put", "cdecl"):
    apr_time_ansi_put = _libs["apr-1"].get("apr_time_ansi_put", "cdecl")
    apr_time_ansi_put.argtypes = [POINTER(apr_time_t), time_t]
    apr_time_ansi_put.restype = apr_status_t

# /usr/include/apr/apr_time.h: 140
if _libs["apr-1"].has("apr_time_exp_tz", "cdecl"):
    apr_time_exp_tz = _libs["apr-1"].get("apr_time_exp_tz", "cdecl")
    apr_time_exp_tz.argtypes = [POINTER(apr_time_exp_t), apr_time_t, apr_int32_t]
    apr_time_exp_tz.restype = apr_status_t

# /usr/include/apr/apr_time.h: 149
if _libs["apr-1"].has("apr_time_exp_gmt", "cdecl"):
    apr_time_exp_gmt = _libs["apr-1"].get("apr_time_exp_gmt", "cdecl")
    apr_time_exp_gmt.argtypes = [POINTER(apr_time_exp_t), apr_time_t]
    apr_time_exp_gmt.restype = apr_status_t

# /usr/include/apr/apr_time.h: 157
if _libs["apr-1"].has("apr_time_exp_lt", "cdecl"):
    apr_time_exp_lt = _libs["apr-1"].get("apr_time_exp_lt", "cdecl")
    apr_time_exp_lt.argtypes = [POINTER(apr_time_exp_t), apr_time_t]
    apr_time_exp_lt.restype = apr_status_t

# /usr/include/apr/apr_time.h: 166
if _libs["apr-1"].has("apr_time_exp_get", "cdecl"):
    apr_time_exp_get = _libs["apr-1"].get("apr_time_exp_get", "cdecl")
    apr_time_exp_get.argtypes = [POINTER(apr_time_t), POINTER(apr_time_exp_t)]
    apr_time_exp_get.restype = apr_status_t

# /usr/include/apr/apr_time.h: 175
if _libs["apr-1"].has("apr_time_exp_gmt_get", "cdecl"):
    apr_time_exp_gmt_get = _libs["apr-1"].get("apr_time_exp_gmt_get", "cdecl")
    apr_time_exp_gmt_get.argtypes = [POINTER(apr_time_t), POINTER(apr_time_exp_t)]
    apr_time_exp_gmt_get.restype = apr_status_t

# /usr/include/apr/apr_time.h: 183
if _libs["apr-1"].has("apr_sleep", "cdecl"):
    apr_sleep = _libs["apr-1"].get("apr_sleep", "cdecl")
    apr_sleep.argtypes = [apr_interval_time_t]
    apr_sleep.restype = None

# /usr/include/apr/apr_time.h: 195
if _libs["apr-1"].has("apr_rfc822_date", "cdecl"):
    apr_rfc822_date = _libs["apr-1"].get("apr_rfc822_date", "cdecl")
    apr_rfc822_date.argtypes = [String, apr_time_t]
    apr_rfc822_date.restype = apr_status_t

# /usr/include/apr/apr_time.h: 209
if _libs["apr-1"].has("apr_ctime", "cdecl"):
    apr_ctime = _libs["apr-1"].get("apr_ctime", "cdecl")
    apr_ctime.argtypes = [String, apr_time_t]
    apr_ctime.restype = apr_status_t

# /usr/include/apr/apr_time.h: 219
if _libs["apr-1"].has("apr_strftime", "cdecl"):
    apr_strftime = _libs["apr-1"].get("apr_strftime", "cdecl")
    apr_strftime.argtypes = [String, POINTER(apr_size_t), apr_size_t, String, POINTER(apr_time_exp_t)]
    apr_strftime.restype = apr_status_t

# /usr/include/apr/apr_time.h: 229
if _libs["apr-1"].has("apr_time_clock_hires", "cdecl"):
    apr_time_clock_hires = _libs["apr-1"].get("apr_time_clock_hires", "cdecl")
    apr_time_clock_hires.argtypes = [POINTER(apr_pool_t)]
    apr_time_clock_hires.restype = None

# /usr/include/apr/apr_thread_mutex.h: 67
if _libs["apr-1"].has("apr_thread_mutex_create", "cdecl"):
    apr_thread_mutex_create = _libs["apr-1"].get("apr_thread_mutex_create", "cdecl")
    apr_thread_mutex_create.argtypes = [POINTER(POINTER(apr_thread_mutex_t)), c_uint, POINTER(apr_pool_t)]
    apr_thread_mutex_create.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 75
if _libs["apr-1"].has("apr_thread_mutex_lock", "cdecl"):
    apr_thread_mutex_lock = _libs["apr-1"].get("apr_thread_mutex_lock", "cdecl")
    apr_thread_mutex_lock.argtypes = [POINTER(apr_thread_mutex_t)]
    apr_thread_mutex_lock.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 84
if _libs["apr-1"].has("apr_thread_mutex_trylock", "cdecl"):
    apr_thread_mutex_trylock = _libs["apr-1"].get("apr_thread_mutex_trylock", "cdecl")
    apr_thread_mutex_trylock.argtypes = [POINTER(apr_thread_mutex_t)]
    apr_thread_mutex_trylock.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 94
if _libs["apr-1"].has("apr_thread_mutex_timedlock", "cdecl"):
    apr_thread_mutex_timedlock = _libs["apr-1"].get("apr_thread_mutex_timedlock", "cdecl")
    apr_thread_mutex_timedlock.argtypes = [POINTER(apr_thread_mutex_t), apr_interval_time_t]
    apr_thread_mutex_timedlock.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 101
if _libs["apr-1"].has("apr_thread_mutex_unlock", "cdecl"):
    apr_thread_mutex_unlock = _libs["apr-1"].get("apr_thread_mutex_unlock", "cdecl")
    apr_thread_mutex_unlock.argtypes = [POINTER(apr_thread_mutex_t)]
    apr_thread_mutex_unlock.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 107
if _libs["apr-1"].has("apr_thread_mutex_destroy", "cdecl"):
    apr_thread_mutex_destroy = _libs["apr-1"].get("apr_thread_mutex_destroy", "cdecl")
    apr_thread_mutex_destroy.argtypes = [POINTER(apr_thread_mutex_t)]
    apr_thread_mutex_destroy.restype = apr_status_t

# /usr/include/apr/apr_thread_mutex.h: 113
if _libs["apr-1"].has("apr_thread_mutex_pool_get", "cdecl"):
    apr_thread_mutex_pool_get = _libs["apr-1"].get("apr_thread_mutex_pool_get", "cdecl")
    apr_thread_mutex_pool_get.argtypes = [POINTER(apr_thread_mutex_t)]
    apr_thread_mutex_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_allocator.h: 159
if _libs["apr-1"].has("apr_allocator_mutex_set", "cdecl"):
    apr_allocator_mutex_set = _libs["apr-1"].get("apr_allocator_mutex_set", "cdecl")
    apr_allocator_mutex_set.argtypes = [POINTER(apr_allocator_t), POINTER(apr_thread_mutex_t)]
    apr_allocator_mutex_set.restype = None

# /usr/include/apr/apr_allocator.h: 167
if _libs["apr-1"].has("apr_allocator_mutex_get", "cdecl"):
    apr_allocator_mutex_get = _libs["apr-1"].get("apr_allocator_mutex_get", "cdecl")
    apr_allocator_mutex_get.argtypes = [POINTER(apr_allocator_t)]
    apr_allocator_mutex_get.restype = POINTER(apr_thread_mutex_t)

# /usr/include/apr/apr_pools.h: 196
if _libs["apr-1"].has("apr_pool_create_ex", "cdecl"):
    apr_pool_create_ex = _libs["apr-1"].get("apr_pool_create_ex", "cdecl")
    apr_pool_create_ex.argtypes = [POINTER(POINTER(apr_pool_t)), POINTER(apr_pool_t), apr_abortfunc_t, POINTER(apr_allocator_t)]
    apr_pool_create_ex.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 206
if _libs["apr-1"].has("apr_pool_create_core_ex", "cdecl"):
    apr_pool_create_core_ex = _libs["apr-1"].get("apr_pool_create_core_ex", "cdecl")
    apr_pool_create_core_ex.argtypes = [POINTER(POINTER(apr_pool_t)), apr_abortfunc_t, POINTER(apr_allocator_t)]
    apr_pool_create_core_ex.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 226
if _libs["apr-1"].has("apr_pool_create_unmanaged_ex", "cdecl"):
    apr_pool_create_unmanaged_ex = _libs["apr-1"].get("apr_pool_create_unmanaged_ex", "cdecl")
    apr_pool_create_unmanaged_ex.argtypes = [POINTER(POINTER(apr_pool_t)), apr_abortfunc_t, POINTER(apr_allocator_t)]
    apr_pool_create_unmanaged_ex.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 247
if _libs["apr-1"].has("apr_pool_create_ex_debug", "cdecl"):
    apr_pool_create_ex_debug = _libs["apr-1"].get("apr_pool_create_ex_debug", "cdecl")
    apr_pool_create_ex_debug.argtypes = [POINTER(POINTER(apr_pool_t)), POINTER(apr_pool_t), apr_abortfunc_t, POINTER(apr_allocator_t), String]
    apr_pool_create_ex_debug.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 264
if _libs["apr-1"].has("apr_pool_create_core_ex_debug", "cdecl"):
    apr_pool_create_core_ex_debug = _libs["apr-1"].get("apr_pool_create_core_ex_debug", "cdecl")
    apr_pool_create_core_ex_debug.argtypes = [POINTER(POINTER(apr_pool_t)), apr_abortfunc_t, POINTER(apr_allocator_t), String]
    apr_pool_create_core_ex_debug.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 284
if _libs["apr-1"].has("apr_pool_create_unmanaged_ex_debug", "cdecl"):
    apr_pool_create_unmanaged_ex_debug = _libs["apr-1"].get("apr_pool_create_unmanaged_ex_debug", "cdecl")
    apr_pool_create_unmanaged_ex_debug.argtypes = [POINTER(POINTER(apr_pool_t)), apr_abortfunc_t, POINTER(apr_allocator_t), String]
    apr_pool_create_unmanaged_ex_debug.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 354
if _libs["apr-1"].has("apr_pool_allocator_get", "cdecl"):
    apr_pool_allocator_get = _libs["apr-1"].get("apr_pool_allocator_get", "cdecl")
    apr_pool_allocator_get.argtypes = [POINTER(apr_pool_t)]
    apr_pool_allocator_get.restype = POINTER(apr_allocator_t)

# /usr/include/apr/apr_pools.h: 365
if _libs["apr-1"].has("apr_pool_clear", "cdecl"):
    apr_pool_clear = _libs["apr-1"].get("apr_pool_clear", "cdecl")
    apr_pool_clear.argtypes = [POINTER(apr_pool_t)]
    apr_pool_clear.restype = None

# /usr/include/apr/apr_pools.h: 380
if _libs["apr-1"].has("apr_pool_clear_debug", "cdecl"):
    apr_pool_clear_debug = _libs["apr-1"].get("apr_pool_clear_debug", "cdecl")
    apr_pool_clear_debug.argtypes = [POINTER(apr_pool_t), String]
    apr_pool_clear_debug.restype = None

# /usr/include/apr/apr_pools.h: 395
if _libs["apr-1"].has("apr_pool_destroy", "cdecl"):
    apr_pool_destroy = _libs["apr-1"].get("apr_pool_destroy", "cdecl")
    apr_pool_destroy.argtypes = [POINTER(apr_pool_t)]
    apr_pool_destroy.restype = None

# /usr/include/apr/apr_pools.h: 410
if _libs["apr-1"].has("apr_pool_destroy_debug", "cdecl"):
    apr_pool_destroy_debug = _libs["apr-1"].get("apr_pool_destroy_debug", "cdecl")
    apr_pool_destroy_debug.argtypes = [POINTER(apr_pool_t), String]
    apr_pool_destroy_debug.restype = None

# /usr/include/apr/apr_pools.h: 430
if _libs["apr-1"].has("apr_palloc", "cdecl"):
    apr_palloc = _libs["apr-1"].get("apr_palloc", "cdecl")
    apr_palloc.argtypes = [POINTER(apr_pool_t), apr_size_t]
    apr_palloc.restype = POINTER(c_ubyte)
    apr_palloc.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_pools.h: 444
if _libs["apr-1"].has("apr_palloc_debug", "cdecl"):
    apr_palloc_debug = _libs["apr-1"].get("apr_palloc_debug", "cdecl")
    apr_palloc_debug.argtypes = [POINTER(apr_pool_t), apr_size_t, String]
    apr_palloc_debug.restype = POINTER(c_ubyte)
    apr_palloc_debug.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_pools.h: 476
if _libs["apr-1"].has("apr_pcalloc_debug", "cdecl"):
    apr_pcalloc_debug = _libs["apr-1"].get("apr_pcalloc_debug", "cdecl")
    apr_pcalloc_debug.argtypes = [POINTER(apr_pool_t), apr_size_t, String]
    apr_pcalloc_debug.restype = POINTER(c_ubyte)
    apr_pcalloc_debug.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_pools.h: 498
if _libs["apr-1"].has("apr_pool_abort_set", "cdecl"):
    apr_pool_abort_set = _libs["apr-1"].get("apr_pool_abort_set", "cdecl")
    apr_pool_abort_set.argtypes = [apr_abortfunc_t, POINTER(apr_pool_t)]
    apr_pool_abort_set.restype = None

# /usr/include/apr/apr_pools.h: 507
if _libs["apr-1"].has("apr_pool_abort_get", "cdecl"):
    apr_pool_abort_get = _libs["apr-1"].get("apr_pool_abort_get", "cdecl")
    apr_pool_abort_get.argtypes = [POINTER(apr_pool_t)]
    apr_pool_abort_get.restype = apr_abortfunc_t

# /usr/include/apr/apr_pools.h: 515
if _libs["apr-1"].has("apr_pool_parent_get", "cdecl"):
    apr_pool_parent_get = _libs["apr-1"].get("apr_pool_parent_get", "cdecl")
    apr_pool_parent_get.argtypes = [POINTER(apr_pool_t)]
    apr_pool_parent_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_pools.h: 529
if _libs["apr-1"].has("apr_pool_is_ancestor", "cdecl"):
    apr_pool_is_ancestor = _libs["apr-1"].get("apr_pool_is_ancestor", "cdecl")
    apr_pool_is_ancestor.argtypes = [POINTER(apr_pool_t), POINTER(apr_pool_t)]
    apr_pool_is_ancestor.restype = c_int

# /usr/include/apr/apr_pools.h: 536
if _libs["apr-1"].has("apr_pool_tag", "cdecl"):
    apr_pool_tag = _libs["apr-1"].get("apr_pool_tag", "cdecl")
    apr_pool_tag.argtypes = [POINTER(apr_pool_t), String]
    apr_pool_tag.restype = None

# /usr/include/apr/apr_pools.h: 563
if _libs["apr-1"].has("apr_pool_userdata_set", "cdecl"):
    apr_pool_userdata_set = _libs["apr-1"].get("apr_pool_userdata_set", "cdecl")
    apr_pool_userdata_set.argtypes = [POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), POINTER(apr_pool_t)]
    apr_pool_userdata_set.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 588
if _libs["apr-1"].has("apr_pool_userdata_setn", "cdecl"):
    apr_pool_userdata_setn = _libs["apr-1"].get("apr_pool_userdata_setn", "cdecl")
    apr_pool_userdata_setn.argtypes = [POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), POINTER(apr_pool_t)]
    apr_pool_userdata_setn.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 600
if _libs["apr-1"].has("apr_pool_userdata_get", "cdecl"):
    apr_pool_userdata_get = _libs["apr-1"].get("apr_pool_userdata_get", "cdecl")
    apr_pool_userdata_get.argtypes = [POINTER(POINTER(None)), String, POINTER(apr_pool_t)]
    apr_pool_userdata_get.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 628
if _libs["apr-1"].has("apr_pool_cleanup_register", "cdecl"):
    apr_pool_cleanup_register = _libs["apr-1"].get("apr_pool_cleanup_register", "cdecl")
    apr_pool_cleanup_register.argtypes = [POINTER(apr_pool_t), POINTER(None), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_pool_cleanup_register.restype = None

# /usr/include/apr/apr_pools.h: 646
if _libs["apr-1"].has("apr_pool_pre_cleanup_register", "cdecl"):
    apr_pool_pre_cleanup_register = _libs["apr-1"].get("apr_pool_pre_cleanup_register", "cdecl")
    apr_pool_pre_cleanup_register.argtypes = [POINTER(apr_pool_t), POINTER(None), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_pool_pre_cleanup_register.restype = None

# /usr/include/apr/apr_pools.h: 663
if _libs["apr-1"].has("apr_pool_cleanup_kill", "cdecl"):
    apr_pool_cleanup_kill = _libs["apr-1"].get("apr_pool_cleanup_kill", "cdecl")
    apr_pool_cleanup_kill.argtypes = [POINTER(apr_pool_t), POINTER(None), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_pool_cleanup_kill.restype = None

# /usr/include/apr/apr_pools.h: 679
if _libs["apr-1"].has("apr_pool_child_cleanup_set", "cdecl"):
    apr_pool_child_cleanup_set = _libs["apr-1"].get("apr_pool_child_cleanup_set", "cdecl")
    apr_pool_child_cleanup_set.argtypes = [POINTER(apr_pool_t), POINTER(None), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_pool_child_cleanup_set.restype = None

# /usr/include/apr/apr_pools.h: 696
if _libs["apr-1"].has("apr_pool_cleanup_run", "cdecl"):
    apr_pool_cleanup_run = _libs["apr-1"].get("apr_pool_cleanup_run", "cdecl")
    apr_pool_cleanup_run.argtypes = [POINTER(apr_pool_t), POINTER(None), CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_pool_cleanup_run.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 707
if _libs["apr-1"].has("apr_pool_cleanup_null", "cdecl"):
    apr_pool_cleanup_null = _libs["apr-1"].get("apr_pool_cleanup_null", "cdecl")
    apr_pool_cleanup_null.argtypes = [POINTER(None)]
    apr_pool_cleanup_null.restype = apr_status_t

# /usr/include/apr/apr_pools.h: 715
if _libs["apr-1"].has("apr_pool_cleanup_for_exec", "cdecl"):
    apr_pool_cleanup_for_exec = _libs["apr-1"].get("apr_pool_cleanup_for_exec", "cdecl")
    apr_pool_cleanup_for_exec.argtypes = []
    apr_pool_cleanup_for_exec.restype = None

# /usr/include/apr/apr_hash.h: 52
class struct_apr_hash_t(Structure):
    pass

apr_hash_t = struct_apr_hash_t# /usr/include/apr/apr_hash.h: 52

# /usr/include/apr/apr_hash.h: 57
class struct_apr_hash_index_t(Structure):
    pass

apr_hash_index_t = struct_apr_hash_index_t# /usr/include/apr/apr_hash.h: 57

apr_hashfunc_t = CFUNCTYPE(UNCHECKED(c_uint), String, POINTER(apr_ssize_t))# /usr/include/apr/apr_hash.h: 65

# /usr/include/apr/apr_hash.h: 70
if _libs["apr-1"].has("apr_hashfunc_default", "cdecl"):
    apr_hashfunc_default = _libs["apr-1"].get("apr_hashfunc_default", "cdecl")
    apr_hashfunc_default.argtypes = [String, POINTER(apr_ssize_t)]
    apr_hashfunc_default.restype = c_uint

# /usr/include/apr/apr_hash.h: 78
if _libs["apr-1"].has("apr_hash_make", "cdecl"):
    apr_hash_make = _libs["apr-1"].get("apr_hash_make", "cdecl")
    apr_hash_make.argtypes = [POINTER(apr_pool_t)]
    apr_hash_make.restype = POINTER(apr_hash_t)

# /usr/include/apr/apr_hash.h: 86
if _libs["apr-1"].has("apr_hash_make_custom", "cdecl"):
    apr_hash_make_custom = _libs["apr-1"].get("apr_hash_make_custom", "cdecl")
    apr_hash_make_custom.argtypes = [POINTER(apr_pool_t), apr_hashfunc_t]
    apr_hash_make_custom.restype = POINTER(apr_hash_t)

# /usr/include/apr/apr_hash.h: 96
if _libs["apr-1"].has("apr_hash_copy", "cdecl"):
    apr_hash_copy = _libs["apr-1"].get("apr_hash_copy", "cdecl")
    apr_hash_copy.argtypes = [POINTER(apr_pool_t), POINTER(apr_hash_t)]
    apr_hash_copy.restype = POINTER(apr_hash_t)

# /usr/include/apr/apr_hash.h: 108
if _libs["apr-1"].has("apr_hash_set", "cdecl"):
    apr_hash_set = _libs["apr-1"].get("apr_hash_set", "cdecl")
    apr_hash_set.argtypes = [POINTER(apr_hash_t), POINTER(None), apr_ssize_t, POINTER(None)]
    apr_hash_set.restype = None

# /usr/include/apr/apr_hash.h: 118
if _libs["apr-1"].has("apr_hash_get", "cdecl"):
    apr_hash_get = _libs["apr-1"].get("apr_hash_get", "cdecl")
    apr_hash_get.argtypes = [POINTER(apr_hash_t), POINTER(None), apr_ssize_t]
    apr_hash_get.restype = POINTER(c_ubyte)
    apr_hash_get.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_hash.h: 148
if _libs["apr-1"].has("apr_hash_first", "cdecl"):
    apr_hash_first = _libs["apr-1"].get("apr_hash_first", "cdecl")
    apr_hash_first.argtypes = [POINTER(apr_pool_t), POINTER(apr_hash_t)]
    apr_hash_first.restype = POINTER(apr_hash_index_t)

# /usr/include/apr/apr_hash.h: 156
if _libs["apr-1"].has("apr_hash_next", "cdecl"):
    apr_hash_next = _libs["apr-1"].get("apr_hash_next", "cdecl")
    apr_hash_next.argtypes = [POINTER(apr_hash_index_t)]
    apr_hash_next.restype = POINTER(apr_hash_index_t)

# /usr/include/apr/apr_hash.h: 167
if _libs["apr-1"].has("apr_hash_this", "cdecl"):
    apr_hash_this = _libs["apr-1"].get("apr_hash_this", "cdecl")
    apr_hash_this.argtypes = [POINTER(apr_hash_index_t), POINTER(POINTER(None)), POINTER(apr_ssize_t), POINTER(POINTER(None))]
    apr_hash_this.restype = None

# /usr/include/apr/apr_hash.h: 175
if _libs["apr-1"].has("apr_hash_this_key", "cdecl"):
    apr_hash_this_key = _libs["apr-1"].get("apr_hash_this_key", "cdecl")
    apr_hash_this_key.argtypes = [POINTER(apr_hash_index_t)]
    apr_hash_this_key.restype = POINTER(c_ubyte)
    apr_hash_this_key.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_hash.h: 182
if _libs["apr-1"].has("apr_hash_this_key_len", "cdecl"):
    apr_hash_this_key_len = _libs["apr-1"].get("apr_hash_this_key_len", "cdecl")
    apr_hash_this_key_len.argtypes = [POINTER(apr_hash_index_t)]
    apr_hash_this_key_len.restype = apr_ssize_t

# /usr/include/apr/apr_hash.h: 189
if _libs["apr-1"].has("apr_hash_this_val", "cdecl"):
    apr_hash_this_val = _libs["apr-1"].get("apr_hash_this_val", "cdecl")
    apr_hash_this_val.argtypes = [POINTER(apr_hash_index_t)]
    apr_hash_this_val.restype = POINTER(c_ubyte)
    apr_hash_this_val.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_hash.h: 196
if _libs["apr-1"].has("apr_hash_count", "cdecl"):
    apr_hash_count = _libs["apr-1"].get("apr_hash_count", "cdecl")
    apr_hash_count.argtypes = [POINTER(apr_hash_t)]
    apr_hash_count.restype = c_uint

# /usr/include/apr/apr_hash.h: 202
if _libs["apr-1"].has("apr_hash_clear", "cdecl"):
    apr_hash_clear = _libs["apr-1"].get("apr_hash_clear", "cdecl")
    apr_hash_clear.argtypes = [POINTER(apr_hash_t)]
    apr_hash_clear.restype = None

# /usr/include/apr/apr_hash.h: 213
if _libs["apr-1"].has("apr_hash_overlay", "cdecl"):
    apr_hash_overlay = _libs["apr-1"].get("apr_hash_overlay", "cdecl")
    apr_hash_overlay.argtypes = [POINTER(apr_pool_t), POINTER(apr_hash_t), POINTER(apr_hash_t)]
    apr_hash_overlay.restype = POINTER(apr_hash_t)

# /usr/include/apr/apr_hash.h: 231
if _libs["apr-1"].has("apr_hash_merge", "cdecl"):
    apr_hash_merge = _libs["apr-1"].get("apr_hash_merge", "cdecl")
    apr_hash_merge.argtypes = [POINTER(apr_pool_t), POINTER(apr_hash_t), POINTER(apr_hash_t), CFUNCTYPE(UNCHECKED(POINTER(c_ubyte)), POINTER(apr_pool_t), POINTER(None), apr_ssize_t, POINTER(None), POINTER(None), POINTER(None)), POINTER(None)]
    apr_hash_merge.restype = POINTER(apr_hash_t)

apr_hash_do_callback_fn_t = CFUNCTYPE(UNCHECKED(c_int), POINTER(None), POINTER(None), apr_ssize_t, POINTER(None))# /usr/include/apr/apr_hash.h: 253

# /usr/include/apr/apr_hash.h: 269
if _libs["apr-1"].has("apr_hash_do", "cdecl"):
    apr_hash_do = _libs["apr-1"].get("apr_hash_do", "cdecl")
    apr_hash_do.argtypes = [POINTER(apr_hash_do_callback_fn_t), POINTER(None), POINTER(apr_hash_t)]
    apr_hash_do.restype = c_int

# /usr/include/apr/apr_hash.h: 275
if _libs["apr-1"].has("apr_hash_pool_get", "cdecl"):
    apr_hash_pool_get = _libs["apr-1"].get("apr_hash_pool_get", "cdecl")
    apr_hash_pool_get.argtypes = [POINTER(apr_hash_t)]
    apr_hash_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_tables.h: 56
class struct_apr_table_t(Structure):
    pass

apr_table_t = struct_apr_table_t# /usr/include/apr/apr_tables.h: 56

# /usr/include/apr/apr_tables.h: 62
class struct_apr_array_header_t(Structure):
    pass

apr_array_header_t = struct_apr_array_header_t# /usr/include/apr/apr_tables.h: 59

struct_apr_array_header_t.__slots__ = [
    'pool',
    'elt_size',
    'nelts',
    'nalloc',
    'elts',
]
struct_apr_array_header_t._fields_ = [
    ('pool', POINTER(apr_pool_t)),
    ('elt_size', c_int),
    ('nelts', c_int),
    ('nalloc', c_int),
    ('elts', String),
]

# /usr/include/apr/apr_tables.h: 81
class struct_apr_table_entry_t(Structure):
    pass

apr_table_entry_t = struct_apr_table_entry_t# /usr/include/apr/apr_tables.h: 78

struct_apr_table_entry_t.__slots__ = [
    'key',
    'val',
    'key_checksum',
]
struct_apr_table_entry_t._fields_ = [
    ('key', String),
    ('val', String),
    ('key_checksum', apr_uint32_t),
]

# /usr/include/apr/apr_tables.h: 98
if _libs["apr-1"].has("apr_table_elts", "cdecl"):
    apr_table_elts = _libs["apr-1"].get("apr_table_elts", "cdecl")
    apr_table_elts.argtypes = [POINTER(apr_table_t)]
    apr_table_elts.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_tables.h: 105
if _libs["apr-1"].has("apr_is_empty_table", "cdecl"):
    apr_is_empty_table = _libs["apr-1"].get("apr_is_empty_table", "cdecl")
    apr_is_empty_table.argtypes = [POINTER(apr_table_t)]
    apr_is_empty_table.restype = c_int

# /usr/include/apr/apr_tables.h: 112
if _libs["apr-1"].has("apr_is_empty_array", "cdecl"):
    apr_is_empty_array = _libs["apr-1"].get("apr_is_empty_array", "cdecl")
    apr_is_empty_array.argtypes = [POINTER(apr_array_header_t)]
    apr_is_empty_array.restype = c_int

# /usr/include/apr/apr_tables.h: 121
if _libs["apr-1"].has("apr_array_make", "cdecl"):
    apr_array_make = _libs["apr-1"].get("apr_array_make", "cdecl")
    apr_array_make.argtypes = [POINTER(apr_pool_t), c_int, c_int]
    apr_array_make.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_tables.h: 131
if _libs["apr-1"].has("apr_array_push", "cdecl"):
    apr_array_push = _libs["apr-1"].get("apr_array_push", "cdecl")
    apr_array_push.argtypes = [POINTER(apr_array_header_t)]
    apr_array_push.restype = POINTER(c_ubyte)
    apr_array_push.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_tables.h: 158
if _libs["apr-1"].has("apr_array_pop", "cdecl"):
    apr_array_pop = _libs["apr-1"].get("apr_array_pop", "cdecl")
    apr_array_pop.argtypes = [POINTER(apr_array_header_t)]
    apr_array_pop.restype = POINTER(c_ubyte)
    apr_array_pop.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_tables.h: 166
if _libs["apr-1"].has("apr_array_clear", "cdecl"):
    apr_array_clear = _libs["apr-1"].get("apr_array_clear", "cdecl")
    apr_array_clear.argtypes = [POINTER(apr_array_header_t)]
    apr_array_clear.restype = None

# /usr/include/apr/apr_tables.h: 174
if _libs["apr-1"].has("apr_array_cat", "cdecl"):
    apr_array_cat = _libs["apr-1"].get("apr_array_cat", "cdecl")
    apr_array_cat.argtypes = [POINTER(apr_array_header_t), POINTER(apr_array_header_t)]
    apr_array_cat.restype = None

# /usr/include/apr/apr_tables.h: 186
if _libs["apr-1"].has("apr_array_copy", "cdecl"):
    apr_array_copy = _libs["apr-1"].get("apr_array_copy", "cdecl")
    apr_array_copy.argtypes = [POINTER(apr_pool_t), POINTER(apr_array_header_t)]
    apr_array_copy.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_tables.h: 196
if _libs["apr-1"].has("apr_array_copy_hdr", "cdecl"):
    apr_array_copy_hdr = _libs["apr-1"].get("apr_array_copy_hdr", "cdecl")
    apr_array_copy_hdr.argtypes = [POINTER(apr_pool_t), POINTER(apr_array_header_t)]
    apr_array_copy_hdr.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_tables.h: 206
if _libs["apr-1"].has("apr_array_append", "cdecl"):
    apr_array_append = _libs["apr-1"].get("apr_array_append", "cdecl")
    apr_array_append.argtypes = [POINTER(apr_pool_t), POINTER(apr_array_header_t), POINTER(apr_array_header_t)]
    apr_array_append.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_tables.h: 221
if _libs["apr-1"].has("apr_array_pstrcat", "cdecl"):
    apr_array_pstrcat = _libs["apr-1"].get("apr_array_pstrcat", "cdecl")
    apr_array_pstrcat.argtypes = [POINTER(apr_pool_t), POINTER(apr_array_header_t), c_char]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_array_pstrcat.restype = ReturnString
    else:
        apr_array_pstrcat.restype = String
        apr_array_pstrcat.errcheck = ReturnString

# /usr/include/apr/apr_tables.h: 232
if _libs["apr-1"].has("apr_table_make", "cdecl"):
    apr_table_make = _libs["apr-1"].get("apr_table_make", "cdecl")
    apr_table_make.argtypes = [POINTER(apr_pool_t), c_int]
    apr_table_make.restype = POINTER(apr_table_t)

# /usr/include/apr/apr_tables.h: 241
if _libs["apr-1"].has("apr_table_copy", "cdecl"):
    apr_table_copy = _libs["apr-1"].get("apr_table_copy", "cdecl")
    apr_table_copy.argtypes = [POINTER(apr_pool_t), POINTER(apr_table_t)]
    apr_table_copy.restype = POINTER(apr_table_t)

# /usr/include/apr/apr_tables.h: 252
if _libs["apr-1"].has("apr_table_clone", "cdecl"):
    apr_table_clone = _libs["apr-1"].get("apr_table_clone", "cdecl")
    apr_table_clone.argtypes = [POINTER(apr_pool_t), POINTER(apr_table_t)]
    apr_table_clone.restype = POINTER(apr_table_t)

# /usr/include/apr/apr_tables.h: 259
if _libs["apr-1"].has("apr_table_clear", "cdecl"):
    apr_table_clear = _libs["apr-1"].get("apr_table_clear", "cdecl")
    apr_table_clear.argtypes = [POINTER(apr_table_t)]
    apr_table_clear.restype = None

# /usr/include/apr/apr_tables.h: 268
if _libs["apr-1"].has("apr_table_get", "cdecl"):
    apr_table_get = _libs["apr-1"].get("apr_table_get", "cdecl")
    apr_table_get.argtypes = [POINTER(apr_table_t), String]
    apr_table_get.restype = c_char_p

# /usr/include/apr/apr_tables.h: 279
if _libs["apr-1"].has("apr_table_getm", "cdecl"):
    apr_table_getm = _libs["apr-1"].get("apr_table_getm", "cdecl")
    apr_table_getm.argtypes = [POINTER(apr_pool_t), POINTER(apr_table_t), String]
    apr_table_getm.restype = c_char_p

# /usr/include/apr/apr_tables.h: 291
if _libs["apr-1"].has("apr_table_set", "cdecl"):
    apr_table_set = _libs["apr-1"].get("apr_table_set", "cdecl")
    apr_table_set.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_set.restype = None

# /usr/include/apr/apr_tables.h: 304
if _libs["apr-1"].has("apr_table_setn", "cdecl"):
    apr_table_setn = _libs["apr-1"].get("apr_table_setn", "cdecl")
    apr_table_setn.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_setn.restype = None

# /usr/include/apr/apr_tables.h: 312
if _libs["apr-1"].has("apr_table_unset", "cdecl"):
    apr_table_unset = _libs["apr-1"].get("apr_table_unset", "cdecl")
    apr_table_unset.argtypes = [POINTER(apr_table_t), String]
    apr_table_unset.restype = None

# /usr/include/apr/apr_tables.h: 323
if _libs["apr-1"].has("apr_table_merge", "cdecl"):
    apr_table_merge = _libs["apr-1"].get("apr_table_merge", "cdecl")
    apr_table_merge.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_merge.restype = None

# /usr/include/apr/apr_tables.h: 335
if _libs["apr-1"].has("apr_table_mergen", "cdecl"):
    apr_table_mergen = _libs["apr-1"].get("apr_table_mergen", "cdecl")
    apr_table_mergen.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_mergen.restype = None

# /usr/include/apr/apr_tables.h: 347
if _libs["apr-1"].has("apr_table_add", "cdecl"):
    apr_table_add = _libs["apr-1"].get("apr_table_add", "cdecl")
    apr_table_add.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_add.restype = None

# /usr/include/apr/apr_tables.h: 360
if _libs["apr-1"].has("apr_table_addn", "cdecl"):
    apr_table_addn = _libs["apr-1"].get("apr_table_addn", "cdecl")
    apr_table_addn.argtypes = [POINTER(apr_table_t), String, String]
    apr_table_addn.restype = None

# /usr/include/apr/apr_tables.h: 370
if _libs["apr-1"].has("apr_table_overlay", "cdecl"):
    apr_table_overlay = _libs["apr-1"].get("apr_table_overlay", "cdecl")
    apr_table_overlay.argtypes = [POINTER(apr_pool_t), POINTER(apr_table_t), POINTER(apr_table_t)]
    apr_table_overlay.restype = POINTER(apr_table_t)

apr_table_do_callback_fn_t = CFUNCTYPE(UNCHECKED(c_int), POINTER(None), String, String)# /usr/include/apr/apr_tables.h: 385

# /usr/include/apr/apr_tables.h: 407
if _libs["apr-1"].has("apr_table_do", "cdecl"):
    _func = _libs["apr-1"].get("apr_table_do", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_table_do_callback_fn_t), POINTER(None), POINTER(apr_table_t)]
    apr_table_do = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr/apr_tables.h: 433
if _libs["apr-1"].has("apr_table_vdo", "cdecl"):
    apr_table_vdo = _libs["apr-1"].get("apr_table_vdo", "cdecl")
    apr_table_vdo.argtypes = [POINTER(apr_table_do_callback_fn_t), POINTER(None), POINTER(apr_table_t), c_void_p]
    apr_table_vdo.restype = c_int

# /usr/include/apr/apr_tables.h: 485
if _libs["apr-1"].has("apr_table_overlap", "cdecl"):
    apr_table_overlap = _libs["apr-1"].get("apr_table_overlap", "cdecl")
    apr_table_overlap.argtypes = [POINTER(apr_table_t), POINTER(apr_table_t), c_uint]
    apr_table_overlap.restype = None

# /usr/include/apr/apr_tables.h: 499
if _libs["apr-1"].has("apr_table_compress", "cdecl"):
    apr_table_compress = _libs["apr-1"].get("apr_table_compress", "cdecl")
    apr_table_compress.argtypes = [POINTER(apr_table_t), c_uint]
    apr_table_compress.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 180
class struct_svn_error_t(Structure):
    pass

enum_svn_node_kind_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_file = (svn_node_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_dir = (svn_node_file + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_unknown = (svn_node_dir + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_symlink = (svn_node_unknown + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

svn_node_kind_t = enum_svn_node_kind_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 70

enum_svn_tristate_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 90

svn_tristate_false = 2# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 90

svn_tristate_true = (svn_tristate_false + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 90

svn_tristate_unknown = (svn_tristate_true + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 90

svn_tristate_t = enum_svn_tristate_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 90

svn_revnum_t = c_long# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 95

enum_svn_depth_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_unknown = (-2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_exclude = (-1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_empty = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_files = 1# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_immediates = 2# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_infinity = 3# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

svn_depth_t = enum_svn_depth_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 151

# /usr/include/stdlib.h: 108
if _libs["apr-1"].has("atol", "cdecl"):
    atol = _libs["apr-1"].get("atol", "cdecl")
    atol.argtypes = [String]
    atol.restype = c_long

# /usr/include/apr/apr_version.h: 144
class struct_anon_57(Structure):
    pass

struct_anon_57.__slots__ = [
    'major',
    'minor',
    'patch',
    'is_dev',
]
struct_anon_57._fields_ = [
    ('major', c_int),
    ('minor', c_int),
    ('patch', c_int),
    ('is_dev', c_int),
]

apr_version_t = struct_anon_57# /usr/include/apr/apr_version.h: 144

# /usr/include/apr/apr_version.h: 152
if _libs["apr-1"].has("apr_version", "cdecl"):
    apr_version = _libs["apr-1"].get("apr_version", "cdecl")
    apr_version.argtypes = [POINTER(apr_version_t)]
    apr_version.restype = None

# /usr/include/apr/apr_version.h: 155
if _libs["apr-1"].has("apr_version_string", "cdecl"):
    apr_version_string = _libs["apr-1"].get("apr_version_string", "cdecl")
    apr_version_string.argtypes = []
    apr_version_string.restype = c_char_p

# /usr/include/apr/apr_strings.h: 76
if _libs["apr-1"].has("apr_strnatcmp", "cdecl"):
    apr_strnatcmp = _libs["apr-1"].get("apr_strnatcmp", "cdecl")
    apr_strnatcmp.argtypes = [String, String]
    apr_strnatcmp.restype = c_int

# /usr/include/apr/apr_strings.h: 87
if _libs["apr-1"].has("apr_strnatcasecmp", "cdecl"):
    apr_strnatcasecmp = _libs["apr-1"].get("apr_strnatcasecmp", "cdecl")
    apr_strnatcasecmp.argtypes = [String, String]
    apr_strnatcasecmp.restype = c_int

# /usr/include/apr/apr_strings.h: 95
if _libs["apr-1"].has("apr_pstrdup", "cdecl"):
    apr_pstrdup = _libs["apr-1"].get("apr_pstrdup", "cdecl")
    apr_pstrdup.argtypes = [POINTER(apr_pool_t), String]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_pstrdup.restype = ReturnString
    else:
        apr_pstrdup.restype = String
        apr_pstrdup.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 109
if _libs["apr-1"].has("apr_pstrmemdup", "cdecl"):
    apr_pstrmemdup = _libs["apr-1"].get("apr_pstrmemdup", "cdecl")
    apr_pstrmemdup.argtypes = [POINTER(apr_pool_t), String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_pstrmemdup.restype = ReturnString
    else:
        apr_pstrmemdup.restype = String
        apr_pstrmemdup.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 125
if _libs["apr-1"].has("apr_pstrndup", "cdecl"):
    apr_pstrndup = _libs["apr-1"].get("apr_pstrndup", "cdecl")
    apr_pstrndup.argtypes = [POINTER(apr_pool_t), String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_pstrndup.restype = ReturnString
    else:
        apr_pstrndup.restype = String
        apr_pstrndup.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 135
if _libs["apr-1"].has("apr_pmemdup", "cdecl"):
    apr_pmemdup = _libs["apr-1"].get("apr_pmemdup", "cdecl")
    apr_pmemdup.argtypes = [POINTER(apr_pool_t), POINTER(None), apr_size_t]
    apr_pmemdup.restype = POINTER(c_ubyte)
    apr_pmemdup.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_strings.h: 147
if _libs["apr-1"].has("apr_pstrcat", "cdecl"):
    _func = _libs["apr-1"].get("apr_pstrcat", "cdecl")
    _restype = String
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t)]
    apr_pstrcat = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr/apr_strings.h: 161
if _libs["apr-1"].has("apr_pstrcatv", "cdecl"):
    apr_pstrcatv = _libs["apr-1"].get("apr_pstrcatv", "cdecl")
    apr_pstrcatv.argtypes = [POINTER(apr_pool_t), POINTER(struct_iovec), apr_size_t, POINTER(apr_size_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_pstrcatv.restype = ReturnString
    else:
        apr_pstrcatv.restype = String
        apr_pstrcatv.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 172
if _libs["apr-1"].has("apr_pvsprintf", "cdecl"):
    apr_pvsprintf = _libs["apr-1"].get("apr_pvsprintf", "cdecl")
    apr_pvsprintf.argtypes = [POINTER(apr_pool_t), String, c_void_p]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_pvsprintf.restype = ReturnString
    else:
        apr_pvsprintf.restype = String
        apr_pvsprintf.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 182
if _libs["apr-1"].has("apr_psprintf", "cdecl"):
    _func = _libs["apr-1"].get("apr_psprintf", "cdecl")
    _restype = String
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    apr_psprintf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr/apr_strings.h: 207
if _libs["apr-1"].has("apr_cpystrn", "cdecl"):
    apr_cpystrn = _libs["apr-1"].get("apr_cpystrn", "cdecl")
    apr_cpystrn.argtypes = [String, String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_cpystrn.restype = ReturnString
    else:
        apr_cpystrn.restype = String
        apr_cpystrn.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 217
if _libs["apr-1"].has("apr_collapse_spaces", "cdecl"):
    apr_collapse_spaces = _libs["apr-1"].get("apr_collapse_spaces", "cdecl")
    apr_collapse_spaces.argtypes = [String, String]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_collapse_spaces.restype = ReturnString
    else:
        apr_collapse_spaces.restype = String
        apr_collapse_spaces.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 226
if _libs["apr-1"].has("apr_tokenize_to_argv", "cdecl"):
    apr_tokenize_to_argv = _libs["apr-1"].get("apr_tokenize_to_argv", "cdecl")
    apr_tokenize_to_argv.argtypes = [String, POINTER(POINTER(POINTER(c_char))), POINTER(apr_pool_t)]
    apr_tokenize_to_argv.restype = apr_status_t

# /usr/include/apr/apr_strings.h: 247
if _libs["apr-1"].has("apr_strtok", "cdecl"):
    apr_strtok = _libs["apr-1"].get("apr_strtok", "cdecl")
    apr_strtok.argtypes = [String, String, POINTER(POINTER(c_char))]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_strtok.restype = ReturnString
    else:
        apr_strtok.restype = String
        apr_strtok.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 279
if _libs["apr-1"].has("apr_snprintf", "cdecl"):
    _func = _libs["apr-1"].get("apr_snprintf", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [String, apr_size_t, String]
    apr_snprintf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr/apr_strings.h: 291
if _libs["apr-1"].has("apr_vsnprintf", "cdecl"):
    apr_vsnprintf = _libs["apr-1"].get("apr_vsnprintf", "cdecl")
    apr_vsnprintf.argtypes = [String, apr_size_t, String, c_void_p]
    apr_vsnprintf.restype = c_int

# /usr/include/apr/apr_strings.h: 301
if _libs["apr-1"].has("apr_itoa", "cdecl"):
    apr_itoa = _libs["apr-1"].get("apr_itoa", "cdecl")
    apr_itoa.argtypes = [POINTER(apr_pool_t), c_int]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_itoa.restype = ReturnString
    else:
        apr_itoa.restype = String
        apr_itoa.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 309
if _libs["apr-1"].has("apr_ltoa", "cdecl"):
    apr_ltoa = _libs["apr-1"].get("apr_ltoa", "cdecl")
    apr_ltoa.argtypes = [POINTER(apr_pool_t), c_long]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_ltoa.restype = ReturnString
    else:
        apr_ltoa.restype = String
        apr_ltoa.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 317
if _libs["apr-1"].has("apr_off_t_toa", "cdecl"):
    apr_off_t_toa = _libs["apr-1"].get("apr_off_t_toa", "cdecl")
    apr_off_t_toa.argtypes = [POINTER(apr_pool_t), apr_off_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_off_t_toa.restype = ReturnString
    else:
        apr_off_t_toa.restype = String
        apr_off_t_toa.errcheck = ReturnString

# /usr/include/apr/apr_strings.h: 335
if _libs["apr-1"].has("apr_strtoff", "cdecl"):
    apr_strtoff = _libs["apr-1"].get("apr_strtoff", "cdecl")
    apr_strtoff.argtypes = [POINTER(apr_off_t), String, POINTER(POINTER(c_char)), c_int]
    apr_strtoff.restype = apr_status_t

# /usr/include/apr/apr_strings.h: 353
if _libs["apr-1"].has("apr_strtoi64", "cdecl"):
    apr_strtoi64 = _libs["apr-1"].get("apr_strtoi64", "cdecl")
    apr_strtoi64.argtypes = [String, POINTER(POINTER(c_char)), c_int]
    apr_strtoi64.restype = c_int64

# /usr/include/apr/apr_strings.h: 362
if _libs["apr-1"].has("apr_atoi64", "cdecl"):
    apr_atoi64 = _libs["apr-1"].get("apr_atoi64", "cdecl")
    apr_atoi64.argtypes = [String]
    apr_atoi64.restype = c_int64

# /usr/include/apr/apr_strings.h: 372
if _libs["apr-1"].has("apr_strfsize", "cdecl"):
    apr_strfsize = _libs["apr-1"].get("apr_strfsize", "cdecl")
    apr_strfsize.argtypes = [apr_off_t, String]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_strfsize.restype = ReturnString
    else:
        apr_strfsize.restype = String
        apr_strfsize.errcheck = ReturnString

svn_boolean_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 141

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 159
class struct_svn__null_pointer_constant_stdarg_sentinel_t(Structure):
    pass

struct_svn_error_t.__slots__ = [
    'apr_err',
    'message',
    'child',
    'pool',
    'file',
    'line',
]
struct_svn_error_t._fields_ = [
    ('apr_err', apr_status_t),
    ('message', String),
    ('child', POINTER(struct_svn_error_t)),
    ('pool', POINTER(apr_pool_t)),
    ('file', String),
    ('line', c_long),
]

svn_error_t = struct_svn_error_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 222

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 147
class struct_svn_version_t(Structure):
    pass

svn_version_t = struct_svn_version_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 228

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 317
if _libs["svn_subr-1"].has("svn_node_kind_to_word", "cdecl"):
    svn_node_kind_to_word = _libs["svn_subr-1"].get("svn_node_kind_to_word", "cdecl")
    svn_node_kind_to_word.argtypes = [svn_node_kind_t]
    svn_node_kind_to_word.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 327
if _libs["svn_subr-1"].has("svn_node_kind_from_word", "cdecl"):
    svn_node_kind_from_word = _libs["svn_subr-1"].get("svn_node_kind_from_word", "cdecl")
    svn_node_kind_from_word.argtypes = [String]
    svn_node_kind_from_word.restype = svn_node_kind_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 337
if _libs["svn_subr-1"].has("svn_tristate__to_word", "cdecl"):
    svn_tristate__to_word = _libs["svn_subr-1"].get("svn_tristate__to_word", "cdecl")
    svn_tristate__to_word.argtypes = [svn_tristate_t]
    svn_tristate__to_word.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 347
if _libs["svn_subr-1"].has("svn_tristate__from_word", "cdecl"):
    svn_tristate__from_word = _libs["svn_subr-1"].get("svn_tristate__from_word", "cdecl")
    svn_tristate__from_word.argtypes = [String]
    svn_tristate__from_word.restype = svn_tristate_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 415
if _libs["svn_subr-1"].has("svn_revnum_parse", "cdecl"):
    svn_revnum_parse = _libs["svn_subr-1"].get("svn_revnum_parse", "cdecl")
    svn_revnum_parse.argtypes = [POINTER(svn_revnum_t), String, POINTER(POINTER(c_char))]
    svn_revnum_parse.restype = POINTER(svn_error_t)
    svn_revnum_parse.errcheck = _svn_errcheck

svn_filesize_t = c_int64# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 434

enum_svn_recurse_kind = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 452

svn_nonrecursive = 1# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 452

svn_recursive = (svn_nonrecursive + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 452

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 466
if _libs["svn_subr-1"].has("svn_depth_to_word", "cdecl"):
    svn_depth_to_word = _libs["svn_subr-1"].get("svn_depth_to_word", "cdecl")
    svn_depth_to_word.argtypes = [svn_depth_t]
    svn_depth_to_word.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 476
if _libs["svn_subr-1"].has("svn_depth_from_word", "cdecl"):
    svn_depth_from_word = _libs["svn_subr-1"].get("svn_depth_from_word", "cdecl")
    svn_depth_from_word.argtypes = [String]
    svn_depth_from_word.restype = svn_depth_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 584
class struct_svn_dirent_t(Structure):
    pass

struct_svn_dirent_t.__slots__ = [
    'kind',
    'size',
    'has_props',
    'created_rev',
    'time',
    'last_author',
]
struct_svn_dirent_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('size', svn_filesize_t),
    ('has_props', svn_boolean_t),
    ('created_rev', svn_revnum_t),
    ('time', apr_time_t),
    ('last_author', String),
]

svn_dirent_t = struct_svn_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 584

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 590
if _libs["svn_subr-1"].has("svn_dirent_dup", "cdecl"):
    svn_dirent_dup = _libs["svn_subr-1"].get("svn_dirent_dup", "cdecl")
    svn_dirent_dup.argtypes = [POINTER(svn_dirent_t), POINTER(apr_pool_t)]
    svn_dirent_dup.restype = POINTER(svn_dirent_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 600
if _libs["svn_subr-1"].has("svn_dirent_create", "cdecl"):
    svn_dirent_create = _libs["svn_subr-1"].get("svn_dirent_create", "cdecl")
    svn_dirent_create.argtypes = [POINTER(apr_pool_t)]
    svn_dirent_create.restype = POINTER(svn_dirent_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 707
class struct_svn_commit_info_t(Structure):
    pass

struct_svn_commit_info_t.__slots__ = [
    'revision',
    'date',
    'author',
    'post_commit_err',
    'repos_root',
]
struct_svn_commit_info_t._fields_ = [
    ('revision', svn_revnum_t),
    ('date', String),
    ('author', String),
    ('post_commit_err', String),
    ('repos_root', String),
]

svn_commit_info_t = struct_svn_commit_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 707

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 723
if _libs["svn_subr-1"].has("svn_create_commit_info", "cdecl"):
    svn_create_commit_info = _libs["svn_subr-1"].get("svn_create_commit_info", "cdecl")
    svn_create_commit_info.argtypes = [POINTER(apr_pool_t)]
    svn_create_commit_info.restype = POINTER(svn_commit_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 731
if _libs["svn_subr-1"].has("svn_commit_info_dup", "cdecl"):
    svn_commit_info_dup = _libs["svn_subr-1"].get("svn_commit_info_dup", "cdecl")
    svn_commit_info_dup.argtypes = [POINTER(svn_commit_info_t), POINTER(apr_pool_t)]
    svn_commit_info_dup.restype = POINTER(svn_commit_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 771
class struct_svn_log_changed_path2_t(Structure):
    pass

struct_svn_log_changed_path2_t.__slots__ = [
    'action',
    'copyfrom_path',
    'copyfrom_rev',
    'node_kind',
    'text_modified',
    'props_modified',
]
struct_svn_log_changed_path2_t._fields_ = [
    ('action', c_char),
    ('copyfrom_path', String),
    ('copyfrom_rev', svn_revnum_t),
    ('node_kind', svn_node_kind_t),
    ('text_modified', svn_tristate_t),
    ('props_modified', svn_tristate_t),
]

svn_log_changed_path2_t = struct_svn_log_changed_path2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 771

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 783
if _libs["svn_subr-1"].has("svn_log_changed_path2_create", "cdecl"):
    svn_log_changed_path2_create = _libs["svn_subr-1"].get("svn_log_changed_path2_create", "cdecl")
    svn_log_changed_path2_create.argtypes = [POINTER(apr_pool_t)]
    svn_log_changed_path2_create.restype = POINTER(svn_log_changed_path2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 791
if _libs["svn_subr-1"].has("svn_log_changed_path2_dup", "cdecl"):
    svn_log_changed_path2_dup = _libs["svn_subr-1"].get("svn_log_changed_path2_dup", "cdecl")
    svn_log_changed_path2_dup.argtypes = [POINTER(svn_log_changed_path2_t), POINTER(apr_pool_t)]
    svn_log_changed_path2_dup.restype = POINTER(svn_log_changed_path2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 812
class struct_svn_log_changed_path_t(Structure):
    pass

struct_svn_log_changed_path_t.__slots__ = [
    'action',
    'copyfrom_path',
    'copyfrom_rev',
]
struct_svn_log_changed_path_t._fields_ = [
    ('action', c_char),
    ('copyfrom_path', String),
    ('copyfrom_rev', svn_revnum_t),
]

svn_log_changed_path_t = struct_svn_log_changed_path_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 812

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 821
if _libs["svn_subr-1"].has("svn_log_changed_path_dup", "cdecl"):
    svn_log_changed_path_dup = _libs["svn_subr-1"].get("svn_log_changed_path_dup", "cdecl")
    svn_log_changed_path_dup.argtypes = [POINTER(svn_log_changed_path_t), POINTER(apr_pool_t)]
    svn_log_changed_path_dup.restype = POINTER(svn_log_changed_path_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 910
class struct_svn_log_entry_t(Structure):
    pass

struct_svn_log_entry_t.__slots__ = [
    'changed_paths',
    'revision',
    'revprops',
    'has_children',
    'changed_paths2',
    'non_inheritable',
    'subtractive_merge',
]
struct_svn_log_entry_t._fields_ = [
    ('changed_paths', POINTER(apr_hash_t)),
    ('revision', svn_revnum_t),
    ('revprops', POINTER(apr_hash_t)),
    ('has_children', svn_boolean_t),
    ('changed_paths2', POINTER(apr_hash_t)),
    ('non_inheritable', svn_boolean_t),
    ('subtractive_merge', svn_boolean_t),
]

svn_log_entry_t = struct_svn_log_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 910

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 921
if _libs["svn_subr-1"].has("svn_log_entry_create", "cdecl"):
    svn_log_entry_create = _libs["svn_subr-1"].get("svn_log_entry_create", "cdecl")
    svn_log_entry_create.argtypes = [POINTER(apr_pool_t)]
    svn_log_entry_create.restype = POINTER(svn_log_entry_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 932
if _libs["svn_subr-1"].has("svn_log_entry_dup", "cdecl"):
    svn_log_entry_dup = _libs["svn_subr-1"].get("svn_log_entry_dup", "cdecl")
    svn_log_entry_dup.argtypes = [POINTER(svn_log_entry_t), POINTER(apr_pool_t)]
    svn_log_entry_dup.restype = POINTER(svn_log_entry_t)

svn_log_entry_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_log_entry_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 967

svn_log_message_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_hash_t), svn_revnum_t, String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 978

svn_commit_callback2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_commit_info_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1001

svn_commit_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), svn_revnum_t, String, String, POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1011

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1066
if _libs["svn_subr-1"].has("svn_mime_type_validate", "cdecl"):
    svn_mime_type_validate = _libs["svn_subr-1"].get("svn_mime_type_validate", "cdecl")
    svn_mime_type_validate.argtypes = [String, POINTER(apr_pool_t)]
    svn_mime_type_validate.restype = POINTER(svn_error_t)
    svn_mime_type_validate.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1076
if _libs["svn_subr-1"].has("svn_mime_type_is_binary", "cdecl"):
    svn_mime_type_is_binary = _libs["svn_subr-1"].get("svn_mime_type_is_binary", "cdecl")
    svn_mime_type_is_binary.argtypes = [String]
    svn_mime_type_is_binary.restype = svn_boolean_t

svn_cancel_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1085

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1118
class struct_svn_lock_t(Structure):
    pass

struct_svn_lock_t.__slots__ = [
    'path',
    'token',
    'owner',
    'comment',
    'is_dav_comment',
    'creation_date',
    'expiration_date',
]
struct_svn_lock_t._fields_ = [
    ('path', String),
    ('token', String),
    ('owner', String),
    ('comment', String),
    ('is_dav_comment', svn_boolean_t),
    ('creation_date', apr_time_t),
    ('expiration_date', apr_time_t),
]

svn_lock_t = struct_svn_lock_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1118

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1129
if _libs["svn_subr-1"].has("svn_lock_create", "cdecl"):
    svn_lock_create = _libs["svn_subr-1"].get("svn_lock_create", "cdecl")
    svn_lock_create.argtypes = [POINTER(apr_pool_t)]
    svn_lock_create.restype = POINTER(svn_lock_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1137
if _libs["svn_subr-1"].has("svn_lock_dup", "cdecl"):
    svn_lock_dup = _libs["svn_subr-1"].get("svn_lock_dup", "cdecl")
    svn_lock_dup.argtypes = [POINTER(svn_lock_t), POINTER(apr_pool_t)]
    svn_lock_dup.restype = POINTER(svn_lock_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1147
if _libs["svn_subr-1"].has("svn_uuid_generate", "cdecl"):
    svn_uuid_generate = _libs["svn_subr-1"].get("svn_uuid_generate", "cdecl")
    svn_uuid_generate.argtypes = [POINTER(apr_pool_t)]
    svn_uuid_generate.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1173
class struct_svn_merge_range_t(Structure):
    pass

struct_svn_merge_range_t.__slots__ = [
    'start',
    'end',
    'inheritable',
]
struct_svn_merge_range_t._fields_ = [
    ('start', svn_revnum_t),
    ('end', svn_revnum_t),
    ('inheritable', svn_boolean_t),
]

svn_merge_range_t = struct_svn_merge_range_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1173

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1180
if _libs["svn_subr-1"].has("svn_merge_range_dup", "cdecl"):
    svn_merge_range_dup = _libs["svn_subr-1"].get("svn_merge_range_dup", "cdecl")
    svn_merge_range_dup.argtypes = [POINTER(svn_merge_range_t), POINTER(apr_pool_t)]
    svn_merge_range_dup.restype = POINTER(svn_merge_range_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1190
if _libs["svn_subr-1"].has("svn_merge_range_contains_rev", "cdecl"):
    svn_merge_range_contains_rev = _libs["svn_subr-1"].get("svn_merge_range_contains_rev", "cdecl")
    svn_merge_range_contains_rev.argtypes = [POINTER(svn_merge_range_t), svn_revnum_t]
    svn_merge_range_contains_rev.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1215
class struct_svn_location_segment_t(Structure):
    pass

struct_svn_location_segment_t.__slots__ = [
    'range_start',
    'range_end',
    'path',
]
struct_svn_location_segment_t._fields_ = [
    ('range_start', svn_revnum_t),
    ('range_end', svn_revnum_t),
    ('path', String),
]

svn_location_segment_t = struct_svn_location_segment_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1215

svn_location_segment_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_location_segment_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1223

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1233
if _libs["svn_subr-1"].has("svn_location_segment_dup", "cdecl"):
    svn_location_segment_dup = _libs["svn_subr-1"].get("svn_location_segment_dup", "cdecl")
    svn_location_segment_dup.argtypes = [POINTER(svn_location_segment_t), POINTER(apr_pool_t)]
    svn_location_segment_dup.restype = POINTER(svn_location_segment_t)

svn_linenum_t = c_ulong# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1245

# /usr/include/bits/types/struct_FILE.h: 50
class struct__IO_FILE(Structure):
    pass


# /usr/include/bits/types/struct_FILE.h: 37
class struct__IO_marker(Structure):
    pass

# /usr/include/bits/types/struct_FILE.h: 38
class struct__IO_codecvt(Structure):
    pass

# /usr/include/bits/types/struct_FILE.h: 39
class struct__IO_wide_data(Structure):
    pass

_IO_lock_t = None# /usr/include/bits/types/struct_FILE.h: 44

struct__IO_FILE.__slots__ = [
    '_flags',
    '_IO_read_ptr',
    '_IO_read_end',
    '_IO_read_base',
    '_IO_write_base',
    '_IO_write_ptr',
    '_IO_write_end',
    '_IO_buf_base',
    '_IO_buf_end',
    '_IO_save_base',
    '_IO_backup_base',
    '_IO_save_end',
    '_markers',
    '_chain',
    '_fileno',
    '_flags2',
    '_short_backupbuf',
    '_old_offset',
    '_cur_column',
    '_vtable_offset',
    '_shortbuf',
    '_lock',
    '_offset',
    '_codecvt',
    '_wide_data',
    '_freeres_list',
    '_freeres_buf',
    '_prevchain',
    '_mode',
    '_unused2',
]
struct__IO_FILE._fields_ = [
    ('_flags', c_int),
    ('_IO_read_ptr', String),
    ('_IO_read_end', String),
    ('_IO_read_base', String),
    ('_IO_write_base', String),
    ('_IO_write_ptr', String),
    ('_IO_write_end', String),
    ('_IO_buf_base', String),
    ('_IO_buf_end', String),
    ('_IO_save_base', String),
    ('_IO_backup_base', String),
    ('_IO_save_end', String),
    ('_markers', POINTER(struct__IO_marker)),
    ('_chain', POINTER(struct__IO_FILE)),
    ('_fileno', c_int),
    ('_flags2', c_int, 24),
    ('_short_backupbuf', c_char * int(1)),
    ('_old_offset', __off_t),
    ('_cur_column', c_ushort),
    ('_vtable_offset', c_char),
    ('_shortbuf', c_char * int(1)),
    ('_lock', POINTER(_IO_lock_t)),
    ('_offset', __off64_t),
    ('_codecvt', POINTER(struct__IO_codecvt)),
    ('_wide_data', POINTER(struct__IO_wide_data)),
    ('_freeres_list', POINTER(struct__IO_FILE)),
    ('_freeres_buf', POINTER(None)),
    ('_prevchain', POINTER(POINTER(struct__IO_FILE))),
    ('_mode', c_int),
    ('_unused2', c_char * int(((15 * sizeof(c_int)) - (5 * sizeof(POINTER(None)))))),
]

enum_svn_errno_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_WARNING = (((20000 + 50000) + 50000) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_CONTAINING_POOL = ((((20000 + 50000) + 50000) + (1 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_FILENAME = ((((20000 + 50000) + 50000) + (1 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_URL = ((((20000 + 50000) + 50000) + (1 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_DATE = ((((20000 + 50000) + 50000) + (1 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_MIME_TYPE = ((((20000 + 50000) + 50000) + (1 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_PROPERTY_VALUE = ((((20000 + 50000) + 50000) + (1 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_VERSION_FILE_FORMAT = ((((20000 + 50000) + 50000) + (1 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_RELATIVE_PATH = ((((20000 + 50000) + 50000) + (1 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_UUID = ((((20000 + 50000) + 50000) + (1 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_CONFIG_VALUE = ((((20000 + 50000) + 50000) + (1 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_SERVER_SPECIFICATION = ((((20000 + 50000) + 50000) + (1 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_CHECKSUM_KIND = ((((20000 + 50000) + 50000) + (1 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_CHECKSUM_PARSE = ((((20000 + 50000) + 50000) + (1 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_TOKEN = ((((20000 + 50000) + 50000) + (1 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_CHANGELIST_NAME = ((((20000 + 50000) + 50000) + (1 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_ATOMIC = ((((20000 + 50000) + 50000) + (1 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_COMPRESSION_METHOD = ((((20000 + 50000) + 50000) + (1 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_PROPERTY_VALUE_EOL = ((((20000 + 50000) + 50000) + (1 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_ATTRIB_NOT_FOUND = ((((20000 + 50000) + 50000) + (2 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_MISSING_ANCESTRY = ((((20000 + 50000) + 50000) + (2 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_UNKNOWN_ENCODING = ((((20000 + 50000) + 50000) + (2 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_MALFORMED = ((((20000 + 50000) + 50000) + (2 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_UNESCAPABLE_DATA = ((((20000 + 50000) + 50000) + (2 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_XML_UNEXPECTED_ELEMENT = ((((20000 + 50000) + 50000) + (2 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_INCONSISTENT_EOL = ((((20000 + 50000) + 50000) + (3 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_UNKNOWN_EOL = ((((20000 + 50000) + 50000) + (3 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_CORRUPT_EOL = ((((20000 + 50000) + 50000) + (3 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_UNIQUE_NAMES_EXHAUSTED = ((((20000 + 50000) + 50000) + (3 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_PIPE_FRAME_ERROR = ((((20000 + 50000) + 50000) + (3 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_PIPE_READ_ERROR = ((((20000 + 50000) + 50000) + (3 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_WRITE_ERROR = ((((20000 + 50000) + 50000) + (3 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_IO_PIPE_WRITE_ERROR = ((((20000 + 50000) + 50000) + (3 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_STREAM_UNEXPECTED_EOF = ((((20000 + 50000) + 50000) + (4 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_STREAM_MALFORMED_DATA = ((((20000 + 50000) + 50000) + (4 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_STREAM_UNRECOGNIZED_DATA = ((((20000 + 50000) + 50000) + (4 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_STREAM_SEEK_NOT_SUPPORTED = ((((20000 + 50000) + 50000) + (4 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_STREAM_NOT_SUPPORTED = ((((20000 + 50000) + 50000) + (4 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_NODE_UNKNOWN_KIND = ((((20000 + 50000) + 50000) + (5 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_NODE_UNEXPECTED_KIND = ((((20000 + 50000) + 50000) + (5 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_NOT_FOUND = ((((20000 + 50000) + 50000) + (6 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_EXISTS = ((((20000 + 50000) + 50000) + (6 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_MISSING_REVISION = ((((20000 + 50000) + 50000) + (6 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_MISSING_URL = ((((20000 + 50000) + 50000) + (6 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_ATTRIBUTE_INVALID = ((((20000 + 50000) + 50000) + (6 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ENTRY_FORBIDDEN = ((((20000 + 50000) + 50000) + (6 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_OBSTRUCTED_UPDATE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_UNWIND_MISMATCH = ((((20000 + 50000) + 50000) + (7 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_UNWIND_EMPTY = ((((20000 + 50000) + 50000) + (7 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_UNWIND_NOT_EMPTY = ((((20000 + 50000) + 50000) + (7 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_LOCKED = ((((20000 + 50000) + 50000) + (7 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_LOCKED = ((((20000 + 50000) + 50000) + (7 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_LOCK = ((((20000 + 50000) + 50000) + (7 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_WORKING_COPY = ((((20000 + 50000) + 50000) + (7 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_DIRECTORY = SVN_ERR_WC_NOT_WORKING_COPY# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_FILE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_BAD_ADM_LOG = ((((20000 + 50000) + 50000) + (7 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_PATH_NOT_FOUND = ((((20000 + 50000) + 50000) + (7 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_UP_TO_DATE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_LEFT_LOCAL_MOD = ((((20000 + 50000) + 50000) + (7 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_SCHEDULE_CONFLICT = ((((20000 + 50000) + 50000) + (7 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_PATH_FOUND = ((((20000 + 50000) + 50000) + (7 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_FOUND_CONFLICT = ((((20000 + 50000) + 50000) + (7 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CORRUPT = ((((20000 + 50000) + 50000) + (7 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CORRUPT_TEXT_BASE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NODE_KIND_CHANGE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 18)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_OP_ON_CWD = ((((20000 + 50000) + 50000) + (7 * 5000)) + 19)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_BAD_ADM_LOG_START = ((((20000 + 50000) + 50000) + (7 * 5000)) + 20)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_UNSUPPORTED_FORMAT = ((((20000 + 50000) + 50000) + (7 * 5000)) + 21)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_BAD_PATH = ((((20000 + 50000) + 50000) + (7 * 5000)) + 22)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_SCHEDULE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 23)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_RELOCATION = ((((20000 + 50000) + 50000) + (7 * 5000)) + 24)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_SWITCH = ((((20000 + 50000) + 50000) + (7 * 5000)) + 25)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_MISMATCHED_CHANGELIST = ((((20000 + 50000) + 50000) + (7 * 5000)) + 26)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CONFLICT_RESOLVER_FAILURE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 27)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_COPYFROM_PATH_NOT_FOUND = ((((20000 + 50000) + 50000) + (7 * 5000)) + 28)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CHANGELIST_MOVE = ((((20000 + 50000) + 50000) + (7 * 5000)) + 29)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CANNOT_DELETE_FILE_EXTERNAL = ((((20000 + 50000) + 50000) + (7 * 5000)) + 30)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CANNOT_MOVE_FILE_EXTERNAL = ((((20000 + 50000) + 50000) + (7 * 5000)) + 31)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_DB_ERROR = ((((20000 + 50000) + 50000) + (7 * 5000)) + 32)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_MISSING = ((((20000 + 50000) + 50000) + (7 * 5000)) + 33)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_NOT_SYMLINK = ((((20000 + 50000) + 50000) + (7 * 5000)) + 34)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_PATH_UNEXPECTED_STATUS = ((((20000 + 50000) + 50000) + (7 * 5000)) + 35)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_UPGRADE_REQUIRED = ((((20000 + 50000) + 50000) + (7 * 5000)) + 36)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_CLEANUP_REQUIRED = ((((20000 + 50000) + 50000) + (7 * 5000)) + 37)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_INVALID_OPERATION_DEPTH = ((((20000 + 50000) + 50000) + (7 * 5000)) + 38)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_PATH_ACCESS_DENIED = ((((20000 + 50000) + 50000) + (7 * 5000)) + 39)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_MIXED_REVISIONS = ((((20000 + 50000) + 50000) + (7 * 5000)) + 40)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_WC_DUPLICATE_EXTERNALS_TARGET = ((((20000 + 50000) + 50000) + (7 * 5000)) + 41)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_GENERAL = ((((20000 + 50000) + 50000) + (8 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CLEANUP = ((((20000 + 50000) + 50000) + (8 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_ALREADY_OPEN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_OPEN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CORRUPT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_PATH_SYNTAX = ((((20000 + 50000) + 50000) + (8 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_REVISION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_TRANSACTION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_ENTRY = ((((20000 + 50000) + 50000) + (8 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_REPRESENTATION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_STRING = ((((20000 + 50000) + 50000) + (8 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_COPY = ((((20000 + 50000) + 50000) + (8 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_TRANSACTION_NOT_MUTABLE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_FOUND = ((((20000 + 50000) + 50000) + (8 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_ID_NOT_FOUND = ((((20000 + 50000) + 50000) + (8 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_ID = ((((20000 + 50000) + 50000) + (8 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_DIRECTORY = ((((20000 + 50000) + 50000) + (8 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_FILE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_SINGLE_PATH_COMPONENT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 18)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_MUTABLE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 19)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_ALREADY_EXISTS = ((((20000 + 50000) + 50000) + (8 * 5000)) + 20)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_ROOT_DIR = ((((20000 + 50000) + 50000) + (8 * 5000)) + 21)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_TXN_ROOT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 22)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NOT_REVISION_ROOT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 23)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CONFLICT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 24)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REP_CHANGED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 25)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REP_NOT_MUTABLE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 26)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_MALFORMED_SKEL = ((((20000 + 50000) + 50000) + (8 * 5000)) + 27)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_TXN_OUT_OF_DATE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 28)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_BERKELEY_DB = ((((20000 + 50000) + 50000) + (8 * 5000)) + 29)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_BERKELEY_DB_DEADLOCK = ((((20000 + 50000) + 50000) + (8 * 5000)) + 30)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_TRANSACTION_DEAD = ((((20000 + 50000) + 50000) + (8 * 5000)) + 31)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_TRANSACTION_NOT_DEAD = ((((20000 + 50000) + 50000) + (8 * 5000)) + 32)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_UNKNOWN_FS_TYPE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 33)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_USER = ((((20000 + 50000) + 50000) + (8 * 5000)) + 34)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_PATH_ALREADY_LOCKED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 35)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_PATH_NOT_LOCKED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 36)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_BAD_LOCK_TOKEN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 37)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_LOCK_TOKEN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 38)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_LOCK_OWNER_MISMATCH = ((((20000 + 50000) + 50000) + (8 * 5000)) + 39)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_LOCK = ((((20000 + 50000) + 50000) + (8 * 5000)) + 40)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_LOCK_EXPIRED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 41)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_OUT_OF_DATE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 42)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_UNSUPPORTED_FORMAT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 43)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REP_BEING_WRITTEN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 44)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_TXN_NAME_TOO_LONG = ((((20000 + 50000) + 50000) + (8 * 5000)) + 45)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_NODE_ORIGIN = ((((20000 + 50000) + 50000) + (8 * 5000)) + 46)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_UNSUPPORTED_UPGRADE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 47)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_NO_SUCH_CHECKSUM_REP = ((((20000 + 50000) + 50000) + (8 * 5000)) + 48)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_PROP_BASEVALUE_MISMATCH = ((((20000 + 50000) + 50000) + (8 * 5000)) + 49)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INCORRECT_EDITOR_COMPLETION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 50)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_PACKED_REVPROP_READ_FAILURE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 51)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REVPROP_CACHE_INIT_FAILURE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 52)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_MALFORMED_TXN_ID = ((((20000 + 50000) + 50000) + (8 * 5000)) + 53)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INDEX_CORRUPTION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 54)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INDEX_REVISION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 55)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INDEX_OVERFLOW = ((((20000 + 50000) + 50000) + (8 * 5000)) + 56)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CONTAINER_INDEX = ((((20000 + 50000) + 50000) + (8 * 5000)) + 57)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INDEX_INCONSISTENT = ((((20000 + 50000) + 50000) + (8 * 5000)) + 58)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_LOCK_OPERATION_FAILED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 59)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_UNSUPPORTED_TYPE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 60)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CONTAINER_SIZE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 61)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_MALFORMED_NODEREV_ID = ((((20000 + 50000) + 50000) + (8 * 5000)) + 62)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_INVALID_GENERATION = ((((20000 + 50000) + 50000) + (8 * 5000)) + 63)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CORRUPT_REVPROP_MANIFEST = ((((20000 + 50000) + 50000) + (8 * 5000)) + 64)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_CORRUPT_PROPLIST = ((((20000 + 50000) + 50000) + (8 * 5000)) + 65)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_AMBIGUOUS_CHECKSUM_REP = ((((20000 + 50000) + 50000) + (8 * 5000)) + 67)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_UNRECOGNIZED_IOCTL_CODE = ((((20000 + 50000) + 50000) + (8 * 5000)) + 68)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REP_SHARING_NOT_ALLOWED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 69)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_FS_REP_SHARING_NOT_SUPPORTED = ((((20000 + 50000) + 50000) + (8 * 5000)) + 70)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_LOCKED = ((((20000 + 50000) + 50000) + (9 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_HOOK_FAILURE = ((((20000 + 50000) + 50000) + (9 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_BAD_ARGS = ((((20000 + 50000) + 50000) + (9 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_NO_DATA_FOR_REPORT = ((((20000 + 50000) + 50000) + (9 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_BAD_REVISION_REPORT = ((((20000 + 50000) + 50000) + (9 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_UNSUPPORTED_VERSION = ((((20000 + 50000) + 50000) + (9 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_DISABLED_FEATURE = ((((20000 + 50000) + 50000) + (9 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_POST_COMMIT_HOOK_FAILED = ((((20000 + 50000) + 50000) + (9 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_POST_LOCK_HOOK_FAILED = ((((20000 + 50000) + 50000) + (9 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_POST_UNLOCK_HOOK_FAILED = ((((20000 + 50000) + 50000) + (9 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REPOS_UNSUPPORTED_UPGRADE = ((((20000 + 50000) + 50000) + (9 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_ILLEGAL_URL = ((((20000 + 50000) + 50000) + (10 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_NOT_AUTHORIZED = ((((20000 + 50000) + 50000) + (10 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_UNKNOWN_AUTH = ((((20000 + 50000) + 50000) + (10 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_NOT_IMPLEMENTED = ((((20000 + 50000) + 50000) + (10 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_OUT_OF_DATE = ((((20000 + 50000) + 50000) + (10 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_NO_REPOS_UUID = ((((20000 + 50000) + 50000) + (10 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_UNSUPPORTED_ABI_VERSION = ((((20000 + 50000) + 50000) + (10 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_NOT_LOCKED = ((((20000 + 50000) + 50000) + (10 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_PARTIAL_REPLAY_NOT_SUPPORTED = ((((20000 + 50000) + 50000) + (10 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_UUID_MISMATCH = ((((20000 + 50000) + 50000) + (10 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_REPOS_ROOT_URL_MISMATCH = ((((20000 + 50000) + 50000) + (10 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SESSION_URL_MISMATCH = ((((20000 + 50000) + 50000) + (10 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_CANNOT_CREATE_TUNNEL = ((((20000 + 50000) + 50000) + (10 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_CANNOT_CREATE_SESSION = ((((20000 + 50000) + 50000) + (10 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_SOCK_INIT = ((((20000 + 50000) + 50000) + (11 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_CREATING_REQUEST = ((((20000 + 50000) + 50000) + (11 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_REQUEST_FAILED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_OPTIONS_REQ_FAILED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_PROPS_NOT_FOUND = ((((20000 + 50000) + 50000) + (11 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_ALREADY_EXISTS = ((((20000 + 50000) + 50000) + (11 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_INVALID_CONFIG_VALUE = ((((20000 + 50000) + 50000) + (11 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_PATH_NOT_FOUND = ((((20000 + 50000) + 50000) + (11 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_PROPPATCH_FAILED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_MALFORMED_DATA = ((((20000 + 50000) + 50000) + (11 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_RESPONSE_HEADER_BADNESS = ((((20000 + 50000) + 50000) + (11 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_RELOCATED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_CONN_TIMEOUT = ((((20000 + 50000) + 50000) + (11 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_FORBIDDEN = ((((20000 + 50000) + 50000) + (11 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_PRECONDITION_FAILED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_DAV_METHOD_NOT_ALLOWED = ((((20000 + 50000) + 50000) + (11 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_LOCAL_REPOS_NOT_FOUND = ((((20000 + 50000) + 50000) + (12 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_LOCAL_REPOS_OPEN_FAILED = ((((20000 + 50000) + 50000) + (12 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_INVALID_HEADER = ((((20000 + 50000) + 50000) + (13 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_CORRUPT_WINDOW = ((((20000 + 50000) + 50000) + (13 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_BACKWARD_VIEW = ((((20000 + 50000) + 50000) + (13 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_INVALID_OPS = ((((20000 + 50000) + 50000) + (13 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_UNEXPECTED_END = ((((20000 + 50000) + 50000) + (13 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SVNDIFF_INVALID_COMPRESSED_DATA = ((((20000 + 50000) + 50000) + (13 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_APMOD_MISSING_PATH_TO_FS = ((((20000 + 50000) + 50000) + (14 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_APMOD_MALFORMED_URI = ((((20000 + 50000) + 50000) + (14 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_APMOD_ACTIVITY_NOT_FOUND = ((((20000 + 50000) + 50000) + (14 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_APMOD_BAD_BASELINE = ((((20000 + 50000) + 50000) + (14 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_APMOD_CONNECTION_ABORTED = ((((20000 + 50000) + 50000) + (14 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_VERSIONED_PATH_REQUIRED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_RA_ACCESS_REQUIRED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_BAD_REVISION = ((((20000 + 50000) + 50000) + (15 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_DUPLICATE_COMMIT_URL = ((((20000 + 50000) + 50000) + (15 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_IS_BINARY_FILE = ((((20000 + 50000) + 50000) + (15 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_INVALID_EXTERNALS_DESCRIPTION = ((((20000 + 50000) + 50000) + (15 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_MODIFIED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_IS_DIRECTORY = ((((20000 + 50000) + 50000) + (15 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_REVISION_RANGE = ((((20000 + 50000) + 50000) + (15 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_INVALID_RELOCATION = ((((20000 + 50000) + 50000) + (15 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_REVISION_AUTHOR_CONTAINS_NEWLINE = ((((20000 + 50000) + 50000) + (15 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_PROPERTY_NAME = ((((20000 + 50000) + 50000) + (15 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_UNRELATED_RESOURCES = ((((20000 + 50000) + 50000) + (15 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_MISSING_LOCK_TOKEN = ((((20000 + 50000) + 50000) + (15 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_MULTIPLE_SOURCES_DISALLOWED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_NO_VERSIONED_PARENT = ((((20000 + 50000) + 50000) + (15 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_NOT_READY_TO_MERGE = ((((20000 + 50000) + 50000) + (15 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_FILE_EXTERNAL_OVERWRITE_VERSIONED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_PATCH_BAD_STRIP_COUNT = ((((20000 + 50000) + 50000) + (15 * 5000)) + 18)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_CYCLE_DETECTED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 19)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_MERGE_UPDATE_REQUIRED = ((((20000 + 50000) + 50000) + (15 * 5000)) + 20)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_INVALID_MERGEINFO_NO_MERGETRACKING = ((((20000 + 50000) + 50000) + (15 * 5000)) + 21)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_NO_LOCK_TOKEN = ((((20000 + 50000) + 50000) + (15 * 5000)) + 22)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_FORBIDDEN_BY_SERVER = ((((20000 + 50000) + 50000) + (15 * 5000)) + 23)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CLIENT_CONFLICT_OPTION_NOT_APPLICABLE = ((((20000 + 50000) + 50000) + (15 * 5000)) + 24)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BASE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_PLUGIN_LOAD_FAILURE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_MALFORMED_FILE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_INCOMPLETE_DATA = ((((20000 + 50000) + 50000) + (16 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_INCORRECT_PARAMS = ((((20000 + 50000) + 50000) + (16 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UNVERSIONED_RESOURCE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_TEST_FAILED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UNSUPPORTED_FEATURE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_BAD_PROP_KIND = ((((20000 + 50000) + 50000) + (16 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ILLEGAL_TARGET = ((((20000 + 50000) + 50000) + (16 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_DELTA_MD5_CHECKSUM_ABSENT = ((((20000 + 50000) + 50000) + (16 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_DIR_NOT_EMPTY = ((((20000 + 50000) + 50000) + (16 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_EXTERNAL_PROGRAM = ((((20000 + 50000) + 50000) + (16 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SWIG_PY_EXCEPTION_SET = ((((20000 + 50000) + 50000) + (16 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CHECKSUM_MISMATCH = ((((20000 + 50000) + 50000) + (16 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CANCELLED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_INVALID_DIFF_OPTION = ((((20000 + 50000) + 50000) + (16 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_PROPERTY_NOT_FOUND = ((((20000 + 50000) + 50000) + (16 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_NO_AUTH_FILE_PATH = ((((20000 + 50000) + 50000) + (16 * 5000)) + 18)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_VERSION_MISMATCH = ((((20000 + 50000) + 50000) + (16 * 5000)) + 19)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_MERGEINFO_PARSE_ERROR = ((((20000 + 50000) + 50000) + (16 * 5000)) + 20)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CEASE_INVOCATION = ((((20000 + 50000) + 50000) + (16 * 5000)) + 21)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_REVNUM_PARSE_FAILURE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 22)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ITER_BREAK = ((((20000 + 50000) + 50000) + (16 * 5000)) + 23)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UNKNOWN_CHANGELIST = ((((20000 + 50000) + 50000) + (16 * 5000)) + 24)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RESERVED_FILENAME_SPECIFIED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 25)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UNKNOWN_CAPABILITY = ((((20000 + 50000) + 50000) + (16 * 5000)) + 26)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_TEST_SKIPPED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 27)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_NO_APR_MEMCACHE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 28)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ATOMIC_INIT_FAILURE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 29)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_ERROR = ((((20000 + 50000) + 50000) + (16 * 5000)) + 30)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_READONLY = ((((20000 + 50000) + 50000) + (16 * 5000)) + 31)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_UNSUPPORTED_SCHEMA = ((((20000 + 50000) + 50000) + (16 * 5000)) + 32)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_BUSY = ((((20000 + 50000) + 50000) + (16 * 5000)) + 33)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_RESETTING_FOR_ROLLBACK = ((((20000 + 50000) + 50000) + (16 * 5000)) + 34)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_CONSTRAINT = ((((20000 + 50000) + 50000) + (16 * 5000)) + 35)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_TOO_MANY_MEMCACHED_SERVERS = ((((20000 + 50000) + 50000) + (16 * 5000)) + 36)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_MALFORMED_VERSION_STRING = ((((20000 + 50000) + 50000) + (16 * 5000)) + 37)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CORRUPTED_ATOMIC_STORAGE = ((((20000 + 50000) + 50000) + (16 * 5000)) + 38)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UTF8PROC_ERROR = ((((20000 + 50000) + 50000) + (16 * 5000)) + 39)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_UTF8_GLOB = ((((20000 + 50000) + 50000) + (16 * 5000)) + 40)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CORRUPT_PACKED_DATA = ((((20000 + 50000) + 50000) + (16 * 5000)) + 41)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_COMPOSED_ERROR = ((((20000 + 50000) + 50000) + (16 * 5000)) + 42)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_INVALID_INPUT = ((((20000 + 50000) + 50000) + (16 * 5000)) + 43)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_SQLITE_ROLLBACK_FAILED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 44)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_LZ4_COMPRESSION_FAILED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 45)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_LZ4_DECOMPRESSION_FAILED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 46)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CANONICALIZATION_FAILED = ((((20000 + 50000) + 50000) + (16 * 5000)) + 47)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_ARG_PARSING_ERROR = ((((20000 + 50000) + 50000) + (17 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_INSUFFICIENT_ARGS = ((((20000 + 50000) + 50000) + (17 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_MUTUALLY_EXCLUSIVE_ARGS = ((((20000 + 50000) + 50000) + (17 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_ADM_DIR_RESERVED = ((((20000 + 50000) + 50000) + (17 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_LOG_MESSAGE_IS_VERSIONED_FILE = ((((20000 + 50000) + 50000) + (17 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_LOG_MESSAGE_IS_PATHNAME = ((((20000 + 50000) + 50000) + (17 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_COMMIT_IN_ADDED_DIR = ((((20000 + 50000) + 50000) + (17 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_NO_EXTERNAL_EDITOR = ((((20000 + 50000) + 50000) + (17 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_BAD_LOG_MESSAGE = ((((20000 + 50000) + 50000) + (17 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_UNNECESSARY_LOG_MESSAGE = ((((20000 + 50000) + 50000) + (17 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_NO_EXTERNAL_MERGE_TOOL = ((((20000 + 50000) + 50000) + (17 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_ERROR_PROCESSING_EXTERNALS = ((((20000 + 50000) + 50000) + (17 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_CL_REPOS_VERIFY_FAILED = ((((20000 + 50000) + 50000) + (17 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_CMD_ERR = ((((20000 + 50000) + 50000) + (18 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_UNKNOWN_CMD = ((((20000 + 50000) + 50000) + (18 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_CONNECTION_CLOSED = ((((20000 + 50000) + 50000) + (18 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_IO_ERROR = ((((20000 + 50000) + 50000) + (18 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_MALFORMED_DATA = ((((20000 + 50000) + 50000) + (18 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_REPOS_NOT_FOUND = ((((20000 + 50000) + 50000) + (18 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_BAD_VERSION = ((((20000 + 50000) + 50000) + (18 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_NO_MECHANISMS = ((((20000 + 50000) + 50000) + (18 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_EDIT_ABORTED = ((((20000 + 50000) + 50000) + (18 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_REQUEST_SIZE = ((((20000 + 50000) + 50000) + (18 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SVN_RESPONSE_SIZE = ((((20000 + 50000) + 50000) + (18 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHN_CREDS_UNAVAILABLE = ((((20000 + 50000) + 50000) + (19 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHN_NO_PROVIDER = ((((20000 + 50000) + 50000) + (19 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHN_PROVIDERS_EXHAUSTED = ((((20000 + 50000) + 50000) + (19 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHN_CREDS_NOT_SAVED = ((((20000 + 50000) + 50000) + (19 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHN_FAILED = ((((20000 + 50000) + 50000) + (19 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHZ_ROOT_UNREADABLE = ((((20000 + 50000) + 50000) + (20 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHZ_UNREADABLE = ((((20000 + 50000) + 50000) + (20 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHZ_PARTIALLY_READABLE = ((((20000 + 50000) + 50000) + (20 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHZ_INVALID_CONFIG = ((((20000 + 50000) + 50000) + (20 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_AUTHZ_UNWRITABLE = ((((20000 + 50000) + 50000) + (20 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_DIFF_DATASOURCE_MODIFIED = ((((20000 + 50000) + 50000) + (21 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_DIFF_UNEXPECTED_DATA = ((((20000 + 50000) + 50000) + (21 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SERF_SSPI_INITIALISATION_FAILED = ((((20000 + 50000) + 50000) + (22 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SERF_SSL_CERT_UNTRUSTED = ((((20000 + 50000) + 50000) + (22 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SERF_GSSAPI_INITIALISATION_FAILED = ((((20000 + 50000) + 50000) + (22 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SERF_WRAPPED_ERROR = ((((20000 + 50000) + 50000) + (22 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_RA_SERF_STREAM_BUCKET_READ_ERROR = ((((20000 + 50000) + 50000) + (22 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASSERTION_FAIL = ((((20000 + 50000) + 50000) + (23 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASSERTION_ONLY_TRACING_LINKS = ((((20000 + 50000) + 50000) + (23 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASN1_OUT_OF_DATA = ((((20000 + 50000) + 50000) + (24 * 5000)) + 0)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASN1_UNEXPECTED_TAG = ((((20000 + 50000) + 50000) + (24 * 5000)) + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASN1_INVALID_LENGTH = ((((20000 + 50000) + 50000) + (24 * 5000)) + 2)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASN1_LENGTH_MISMATCH = ((((20000 + 50000) + 50000) + (24 * 5000)) + 3)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_ASN1_INVALID_DATA = ((((20000 + 50000) + 50000) + (24 * 5000)) + 4)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_FEATURE_UNAVAILABLE = ((((20000 + 50000) + 50000) + (24 * 5000)) + 5)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_PEM = ((((20000 + 50000) + 50000) + (24 * 5000)) + 6)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_FORMAT = ((((20000 + 50000) + 50000) + (24 * 5000)) + 7)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_VERSION = ((((20000 + 50000) + 50000) + (24 * 5000)) + 8)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_SERIAL = ((((20000 + 50000) + 50000) + (24 * 5000)) + 9)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_ALG = ((((20000 + 50000) + 50000) + (24 * 5000)) + 10)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_NAME = ((((20000 + 50000) + 50000) + (24 * 5000)) + 11)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_DATE = ((((20000 + 50000) + 50000) + (24 * 5000)) + 12)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_PUBKEY = ((((20000 + 50000) + 50000) + (24 * 5000)) + 13)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_SIGNATURE = ((((20000 + 50000) + 50000) + (24 * 5000)) + 14)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_INVALID_EXTENSIONS = ((((20000 + 50000) + 50000) + (24 * 5000)) + 15)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_UNKNOWN_VERSION = ((((20000 + 50000) + 50000) + (24 * 5000)) + 16)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_UNKNOWN_PK_ALG = ((((20000 + 50000) + 50000) + (24 * 5000)) + 17)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_SIG_MISMATCH = ((((20000 + 50000) + 50000) + (24 * 5000)) + 18)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_X509_CERT_VERIFY_FAILED = ((((20000 + 50000) + 50000) + (24 * 5000)) + 19)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

SVN_ERR_LAST = (SVN_ERR_X509_CERT_VERIFY_FAILED + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

svn_errno_t = enum_svn_errno_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 1794

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 63
if _libs["svn_subr-1"].has("svn_strerror", "cdecl"):
    svn_strerror = _libs["svn_subr-1"].get("svn_strerror", "cdecl")
    svn_strerror.argtypes = [apr_status_t, String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_strerror.restype = ReturnString
    else:
        svn_strerror.restype = String
        svn_strerror.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 95
if _libs["svn_subr-1"].has("svn_error_symbolic_name", "cdecl"):
    svn_error_symbolic_name = _libs["svn_subr-1"].get("svn_error_symbolic_name", "cdecl")
    svn_error_symbolic_name.argtypes = [apr_status_t]
    svn_error_symbolic_name.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 108
if _libs["svn_subr-1"].has("svn_err_best_message", "cdecl"):
    svn_err_best_message = _libs["svn_subr-1"].get("svn_err_best_message", "cdecl")
    svn_err_best_message.argtypes = [POINTER(svn_error_t), String, apr_size_t]
    svn_err_best_message.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 138
if _libs["svn_subr-1"].has("svn_error_create", "cdecl"):
    svn_error_create = _libs["svn_subr-1"].get("svn_error_create", "cdecl")
    svn_error_create.argtypes = [apr_status_t, POINTER(svn_error_t), String]
    svn_error_create.restype = POINTER(svn_error_t)
    svn_error_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 147
if _libs["svn_subr-1"].has("svn_error_createf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_error_createf", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [apr_status_t, POINTER(svn_error_t), String]
    svn_error_createf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 162
if _libs["svn_subr-1"].has("svn_error_wrap_apr", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_error_wrap_apr", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [apr_status_t, String]
    svn_error_wrap_apr = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 173
if _libs["svn_subr-1"].has("svn_error_quick_wrap", "cdecl"):
    svn_error_quick_wrap = _libs["svn_subr-1"].get("svn_error_quick_wrap", "cdecl")
    svn_error_quick_wrap.argtypes = [POINTER(svn_error_t), String]
    svn_error_quick_wrap.restype = POINTER(svn_error_t)
    svn_error_quick_wrap.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 181
if _libs["svn_subr-1"].has("svn_error_quick_wrapf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_error_quick_wrapf", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_error_t), String]
    svn_error_quick_wrapf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 198
if _libs["svn_subr-1"].has("svn_error_compose_create", "cdecl"):
    svn_error_compose_create = _libs["svn_subr-1"].get("svn_error_compose_create", "cdecl")
    svn_error_compose_create.argtypes = [POINTER(svn_error_t), POINTER(svn_error_t)]
    svn_error_compose_create.restype = POINTER(svn_error_t)
    svn_error_compose_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 211
if _libs["svn_subr-1"].has("svn_error_compose", "cdecl"):
    svn_error_compose = _libs["svn_subr-1"].get("svn_error_compose", "cdecl")
    svn_error_compose.argtypes = [POINTER(svn_error_t), POINTER(svn_error_t)]
    svn_error_compose.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 221
if _libs["svn_subr-1"].has("svn_error_root_cause", "cdecl"):
    svn_error_root_cause = _libs["svn_subr-1"].get("svn_error_root_cause", "cdecl")
    svn_error_root_cause.argtypes = [POINTER(svn_error_t)]
    svn_error_root_cause.restype = POINTER(svn_error_t)
    svn_error_root_cause.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 232
if _libs["svn_subr-1"].has("svn_error_find_cause", "cdecl"):
    svn_error_find_cause = _libs["svn_subr-1"].get("svn_error_find_cause", "cdecl")
    svn_error_find_cause.argtypes = [POINTER(svn_error_t), apr_status_t]
    svn_error_find_cause.restype = POINTER(svn_error_t)
    svn_error_find_cause.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 239
if _libs["svn_subr-1"].has("svn_error_dup", "cdecl"):
    svn_error_dup = _libs["svn_subr-1"].get("svn_error_dup", "cdecl")
    svn_error_dup.argtypes = [POINTER(svn_error_t)]
    svn_error_dup.restype = POINTER(svn_error_t)
    svn_error_dup.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 252
if _libs["svn_subr-1"].has("svn_error_clear", "cdecl"):
    svn_error_clear = _libs["svn_subr-1"].get("svn_error_clear", "cdecl")
    svn_error_clear.argtypes = [POINTER(svn_error_t)]
    svn_error_clear.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 292
if _libs["svn_subr-1"].has("svn_handle_error2", "cdecl"):
    svn_handle_error2 = _libs["svn_subr-1"].get("svn_handle_error2", "cdecl")
    svn_handle_error2.argtypes = [POINTER(svn_error_t), POINTER(FILE), svn_boolean_t, String]
    svn_handle_error2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 303
if _libs["svn_subr-1"].has("svn_handle_error", "cdecl"):
    svn_handle_error = _libs["svn_subr-1"].get("svn_handle_error", "cdecl")
    svn_handle_error.argtypes = [POINTER(svn_error_t), POINTER(FILE), svn_boolean_t]
    svn_handle_error.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 319
if _libs["svn_subr-1"].has("svn_handle_warning2", "cdecl"):
    svn_handle_warning2 = _libs["svn_subr-1"].get("svn_handle_warning2", "cdecl")
    svn_handle_warning2.argtypes = [POINTER(FILE), POINTER(svn_error_t), String]
    svn_handle_warning2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 329
if _libs["svn_subr-1"].has("svn_handle_warning", "cdecl"):
    svn_handle_warning = _libs["svn_subr-1"].get("svn_handle_warning", "cdecl")
    svn_handle_warning.argtypes = [POINTER(FILE), POINTER(svn_error_t)]
    svn_handle_warning.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 394
if _libs["svn_subr-1"].has("svn_error_purge_tracing", "cdecl"):
    svn_error_purge_tracing = _libs["svn_subr-1"].get("svn_error_purge_tracing", "cdecl")
    svn_error_purge_tracing.argtypes = [POINTER(svn_error_t)]
    svn_error_purge_tracing.restype = POINTER(svn_error_t)
    svn_error_purge_tracing.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 621
if _libs["svn_subr-1"].has("svn_error__malfunction", "cdecl"):
    svn_error__malfunction = _libs["svn_subr-1"].get("svn_error__malfunction", "cdecl")
    svn_error__malfunction.argtypes = [svn_boolean_t, String, c_int, String]
    svn_error__malfunction.restype = POINTER(svn_error_t)
    svn_error__malfunction.errcheck = _svn_errcheck

svn_error_malfunction_handler_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), svn_boolean_t, String, c_int, String)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 648

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 663
if _libs["svn_subr-1"].has("svn_error_set_malfunction_handler", "cdecl"):
    svn_error_set_malfunction_handler = _libs["svn_subr-1"].get("svn_error_set_malfunction_handler", "cdecl")
    svn_error_set_malfunction_handler.argtypes = [svn_error_malfunction_handler_t]
    svn_error_set_malfunction_handler.restype = svn_error_malfunction_handler_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 668
if _libs["svn_subr-1"].has("svn_error_get_malfunction_handler", "cdecl"):
    svn_error_get_malfunction_handler = _libs["svn_subr-1"].get("svn_error_get_malfunction_handler", "cdecl")
    svn_error_get_malfunction_handler.argtypes = []
    svn_error_get_malfunction_handler.restype = svn_error_malfunction_handler_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 678
if _libs["svn_subr-1"].has("svn_error_raise_on_malfunction", "cdecl"):
    svn_error_raise_on_malfunction = _libs["svn_subr-1"].get("svn_error_raise_on_malfunction", "cdecl")
    svn_error_raise_on_malfunction.argtypes = [svn_boolean_t, String, c_int, String]
    svn_error_raise_on_malfunction.restype = POINTER(svn_error_t)
    svn_error_raise_on_malfunction.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 690
if _libs["svn_subr-1"].has("svn_error_abort_on_malfunction", "cdecl"):
    svn_error_abort_on_malfunction = _libs["svn_subr-1"].get("svn_error_abort_on_malfunction", "cdecl")
    svn_error_abort_on_malfunction.argtypes = [svn_boolean_t, String, c_int, String]
    svn_error_abort_on_malfunction.restype = POINTER(svn_error_t)
    svn_error_abort_on_malfunction.errcheck = _svn_errcheck

apr_uid_t = uid_t# /usr/include/apr/apr_user.h: 45

apr_gid_t = gid_t# /usr/include/apr/apr_user.h: 54

# /usr/include/apr/apr_user.h: 66
if _libs["apr-1"].has("apr_uid_current", "cdecl"):
    apr_uid_current = _libs["apr-1"].get("apr_uid_current", "cdecl")
    apr_uid_current.argtypes = [POINTER(apr_uid_t), POINTER(apr_gid_t), POINTER(apr_pool_t)]
    apr_uid_current.restype = apr_status_t

# /usr/include/apr/apr_user.h: 77
if _libs["apr-1"].has("apr_uid_name_get", "cdecl"):
    apr_uid_name_get = _libs["apr-1"].get("apr_uid_name_get", "cdecl")
    apr_uid_name_get.argtypes = [POINTER(POINTER(c_char)), apr_uid_t, POINTER(apr_pool_t)]
    apr_uid_name_get.restype = apr_status_t

# /usr/include/apr/apr_user.h: 88
if _libs["apr-1"].has("apr_uid_get", "cdecl"):
    apr_uid_get = _libs["apr-1"].get("apr_uid_get", "cdecl")
    apr_uid_get.argtypes = [POINTER(apr_uid_t), POINTER(apr_gid_t), String, POINTER(apr_pool_t)]
    apr_uid_get.restype = apr_status_t

# /usr/include/apr/apr_user.h: 98
if _libs["apr-1"].has("apr_uid_homepath_get", "cdecl"):
    apr_uid_homepath_get = _libs["apr-1"].get("apr_uid_homepath_get", "cdecl")
    apr_uid_homepath_get.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    apr_uid_homepath_get.restype = apr_status_t

# /usr/include/apr/apr_user.h: 123
if _libs["apr-1"].has("apr_gid_name_get", "cdecl"):
    apr_gid_name_get = _libs["apr-1"].get("apr_gid_name_get", "cdecl")
    apr_gid_name_get.argtypes = [POINTER(POINTER(c_char)), apr_gid_t, POINTER(apr_pool_t)]
    apr_gid_name_get.restype = apr_status_t

# /usr/include/apr/apr_user.h: 133
if _libs["apr-1"].has("apr_gid_get", "cdecl"):
    apr_gid_get = _libs["apr-1"].get("apr_gid_get", "cdecl")
    apr_gid_get.argtypes = [POINTER(apr_gid_t), String, POINTER(apr_pool_t)]
    apr_gid_get.restype = apr_status_t

enum_anon_60 = c_int# /usr/include/apr/apr_file_info.h: 72

APR_NOFILE = 0# /usr/include/apr/apr_file_info.h: 72

APR_REG = (APR_NOFILE + 1)# /usr/include/apr/apr_file_info.h: 72

APR_DIR = (APR_REG + 1)# /usr/include/apr/apr_file_info.h: 72

APR_CHR = (APR_DIR + 1)# /usr/include/apr/apr_file_info.h: 72

APR_BLK = (APR_CHR + 1)# /usr/include/apr/apr_file_info.h: 72

APR_PIPE = (APR_BLK + 1)# /usr/include/apr/apr_file_info.h: 72

APR_LNK = (APR_PIPE + 1)# /usr/include/apr/apr_file_info.h: 72

APR_SOCK = (APR_LNK + 1)# /usr/include/apr/apr_file_info.h: 72

APR_UNKFILE = 127# /usr/include/apr/apr_file_info.h: 72

apr_filetype_e = enum_anon_60# /usr/include/apr/apr_file_info.h: 72

# /usr/include/apr/apr_file_info.h: 121
class struct_apr_dir_t(Structure):
    pass

apr_dir_t = struct_apr_dir_t# /usr/include/apr/apr_file_info.h: 121

apr_fileperms_t = apr_int32_t# /usr/include/apr/apr_file_info.h: 125

apr_dev_t = dev_t# /usr/include/apr/apr_file_info.h: 135

# /usr/include/apr/apr_file_info.h: 174
class struct_apr_finfo_t(Structure):
    pass

apr_finfo_t = struct_apr_finfo_t# /usr/include/apr/apr_file_info.h: 143

# /usr/include/apr/apr_file_info.h: 212
class struct_apr_file_t(Structure):
    pass

struct_apr_finfo_t.__slots__ = [
    'pool',
    'valid',
    'protection',
    'filetype',
    'user',
    'group',
    'inode',
    'device',
    'nlink',
    'size',
    'csize',
    'atime',
    'mtime',
    'ctime',
    'fname',
    'name',
    'filehand',
]
struct_apr_finfo_t._fields_ = [
    ('pool', POINTER(apr_pool_t)),
    ('valid', apr_int32_t),
    ('protection', apr_fileperms_t),
    ('filetype', apr_filetype_e),
    ('user', apr_uid_t),
    ('group', apr_gid_t),
    ('inode', apr_ino_t),
    ('device', apr_dev_t),
    ('nlink', apr_int32_t),
    ('size', apr_off_t),
    ('csize', apr_off_t),
    ('atime', apr_time_t),
    ('mtime', apr_time_t),
    ('ctime', apr_time_t),
    ('fname', String),
    ('name', String),
    ('filehand', POINTER(struct_apr_file_t)),
]

# /usr/include/apr/apr_file_info.h: 229
if _libs["apr-1"].has("apr_stat", "cdecl"):
    apr_stat = _libs["apr-1"].get("apr_stat", "cdecl")
    apr_stat.argtypes = [POINTER(apr_finfo_t), String, apr_int32_t, POINTER(apr_pool_t)]
    apr_stat.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 244
if _libs["apr-1"].has("apr_dir_open", "cdecl"):
    apr_dir_open = _libs["apr-1"].get("apr_dir_open", "cdecl")
    apr_dir_open.argtypes = [POINTER(POINTER(apr_dir_t)), String, POINTER(apr_pool_t)]
    apr_dir_open.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 252
if _libs["apr-1"].has("apr_dir_close", "cdecl"):
    apr_dir_close = _libs["apr-1"].get("apr_dir_close", "cdecl")
    apr_dir_close.argtypes = [POINTER(apr_dir_t)]
    apr_dir_close.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 267
if _libs["apr-1"].has("apr_dir_read", "cdecl"):
    apr_dir_read = _libs["apr-1"].get("apr_dir_read", "cdecl")
    apr_dir_read.argtypes = [POINTER(apr_finfo_t), apr_int32_t, POINTER(apr_dir_t)]
    apr_dir_read.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 274
if _libs["apr-1"].has("apr_dir_rewind", "cdecl"):
    apr_dir_rewind = _libs["apr-1"].get("apr_dir_rewind", "cdecl")
    apr_dir_rewind.argtypes = [POINTER(apr_dir_t)]
    apr_dir_rewind.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 336
if _libs["apr-1"].has("apr_filepath_root", "cdecl"):
    apr_filepath_root = _libs["apr-1"].get("apr_filepath_root", "cdecl")
    apr_filepath_root.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), apr_int32_t, POINTER(apr_pool_t)]
    apr_filepath_root.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 354
if _libs["apr-1"].has("apr_filepath_merge", "cdecl"):
    apr_filepath_merge = _libs["apr-1"].get("apr_filepath_merge", "cdecl")
    apr_filepath_merge.argtypes = [POINTER(POINTER(c_char)), String, String, apr_int32_t, POINTER(apr_pool_t)]
    apr_filepath_merge.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 369
if _libs["apr-1"].has("apr_filepath_list_split", "cdecl"):
    apr_filepath_list_split = _libs["apr-1"].get("apr_filepath_list_split", "cdecl")
    apr_filepath_list_split.argtypes = [POINTER(POINTER(apr_array_header_t)), String, POINTER(apr_pool_t)]
    apr_filepath_list_split.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 382
if _libs["apr-1"].has("apr_filepath_list_merge", "cdecl"):
    apr_filepath_list_merge = _libs["apr-1"].get("apr_filepath_list_merge", "cdecl")
    apr_filepath_list_merge.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    apr_filepath_list_merge.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 393
if _libs["apr-1"].has("apr_filepath_get", "cdecl"):
    apr_filepath_get = _libs["apr-1"].get("apr_filepath_get", "cdecl")
    apr_filepath_get.argtypes = [POINTER(POINTER(c_char)), apr_int32_t, POINTER(apr_pool_t)]
    apr_filepath_get.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 401
if _libs["apr-1"].has("apr_filepath_set", "cdecl"):
    apr_filepath_set = _libs["apr-1"].get("apr_filepath_set", "cdecl")
    apr_filepath_set.argtypes = [String, POINTER(apr_pool_t)]
    apr_filepath_set.restype = apr_status_t

# /usr/include/apr/apr_file_info.h: 419
if _libs["apr-1"].has("apr_filepath_encoding", "cdecl"):
    apr_filepath_encoding = _libs["apr-1"].get("apr_filepath_encoding", "cdecl")
    apr_filepath_encoding.argtypes = [POINTER(c_int), POINTER(apr_pool_t)]
    apr_filepath_encoding.restype = apr_status_t

apr_fileattrs_t = apr_uint32_t# /usr/include/apr/apr_file_io.h: 180

apr_seek_where_t = c_int# /usr/include/apr/apr_file_io.h: 183

apr_file_t = struct_apr_file_t# /usr/include/apr/apr_file_io.h: 188

# /usr/include/apr/apr_file_io.h: 250
if _libs["apr-1"].has("apr_file_open", "cdecl"):
    apr_file_open = _libs["apr-1"].get("apr_file_open", "cdecl")
    apr_file_open.argtypes = [POINTER(POINTER(apr_file_t)), String, apr_int32_t, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_file_open.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 258
if _libs["apr-1"].has("apr_file_close", "cdecl"):
    apr_file_close = _libs["apr-1"].get("apr_file_close", "cdecl")
    apr_file_close.argtypes = [POINTER(apr_file_t)]
    apr_file_close.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 267
if _libs["apr-1"].has("apr_file_remove", "cdecl"):
    apr_file_remove = _libs["apr-1"].get("apr_file_remove", "cdecl")
    apr_file_remove.argtypes = [String, POINTER(apr_pool_t)]
    apr_file_remove.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 278
if _libs["apr-1"].has("apr_file_rename", "cdecl"):
    apr_file_rename = _libs["apr-1"].get("apr_file_rename", "cdecl")
    apr_file_rename.argtypes = [String, String, POINTER(apr_pool_t)]
    apr_file_rename.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 288
if _libs["apr-1"].has("apr_file_link", "cdecl"):
    apr_file_link = _libs["apr-1"].get("apr_file_link", "cdecl")
    apr_file_link.argtypes = [String, String]
    apr_file_link.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 303
if _libs["apr-1"].has("apr_file_copy", "cdecl"):
    apr_file_copy = _libs["apr-1"].get("apr_file_copy", "cdecl")
    apr_file_copy.argtypes = [String, String, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_file_copy.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 323
if _libs["apr-1"].has("apr_file_append", "cdecl"):
    apr_file_append = _libs["apr-1"].get("apr_file_append", "cdecl")
    apr_file_append.argtypes = [String, String, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_file_append.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 333
if _libs["apr-1"].has("apr_file_eof", "cdecl"):
    apr_file_eof = _libs["apr-1"].get("apr_file_eof", "cdecl")
    apr_file_eof.argtypes = [POINTER(apr_file_t)]
    apr_file_eof.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 350
if _libs["apr-1"].has("apr_file_open_stderr", "cdecl"):
    apr_file_open_stderr = _libs["apr-1"].get("apr_file_open_stderr", "cdecl")
    apr_file_open_stderr.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_pool_t)]
    apr_file_open_stderr.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 360
if _libs["apr-1"].has("apr_file_open_stdout", "cdecl"):
    apr_file_open_stdout = _libs["apr-1"].get("apr_file_open_stdout", "cdecl")
    apr_file_open_stdout.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_pool_t)]
    apr_file_open_stdout.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 370
if _libs["apr-1"].has("apr_file_open_stdin", "cdecl"):
    apr_file_open_stdin = _libs["apr-1"].get("apr_file_open_stdin", "cdecl")
    apr_file_open_stdin.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_pool_t)]
    apr_file_open_stdin.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 390
if _libs["apr-1"].has("apr_file_open_flags_stderr", "cdecl"):
    apr_file_open_flags_stderr = _libs["apr-1"].get("apr_file_open_flags_stderr", "cdecl")
    apr_file_open_flags_stderr.argtypes = [POINTER(POINTER(apr_file_t)), apr_int32_t, POINTER(apr_pool_t)]
    apr_file_open_flags_stderr.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 411
if _libs["apr-1"].has("apr_file_open_flags_stdout", "cdecl"):
    apr_file_open_flags_stdout = _libs["apr-1"].get("apr_file_open_flags_stdout", "cdecl")
    apr_file_open_flags_stdout.argtypes = [POINTER(POINTER(apr_file_t)), apr_int32_t, POINTER(apr_pool_t)]
    apr_file_open_flags_stdout.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 432
if _libs["apr-1"].has("apr_file_open_flags_stdin", "cdecl"):
    apr_file_open_flags_stdin = _libs["apr-1"].get("apr_file_open_flags_stdin", "cdecl")
    apr_file_open_flags_stdin.argtypes = [POINTER(POINTER(apr_file_t)), apr_int32_t, POINTER(apr_pool_t)]
    apr_file_open_flags_stdin.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 453
if _libs["apr-1"].has("apr_file_read", "cdecl"):
    apr_file_read = _libs["apr-1"].get("apr_file_read", "cdecl")
    apr_file_read.argtypes = [POINTER(apr_file_t), POINTER(None), POINTER(apr_size_t)]
    apr_file_read.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 471
if _libs["apr-1"].has("apr_file_write", "cdecl"):
    apr_file_write = _libs["apr-1"].get("apr_file_write", "cdecl")
    apr_file_write.argtypes = [POINTER(apr_file_t), POINTER(None), POINTER(apr_size_t)]
    apr_file_write.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 489
if _libs["apr-1"].has("apr_file_writev", "cdecl"):
    apr_file_writev = _libs["apr-1"].get("apr_file_writev", "cdecl")
    apr_file_writev.argtypes = [POINTER(apr_file_t), POINTER(struct_iovec), apr_size_t, POINTER(apr_size_t)]
    apr_file_writev.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 513
if _libs["apr-1"].has("apr_file_read_full", "cdecl"):
    apr_file_read_full = _libs["apr-1"].get("apr_file_read_full", "cdecl")
    apr_file_read_full.argtypes = [POINTER(apr_file_t), POINTER(None), apr_size_t, POINTER(apr_size_t)]
    apr_file_read_full.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 537
if _libs["apr-1"].has("apr_file_write_full", "cdecl"):
    apr_file_write_full = _libs["apr-1"].get("apr_file_write_full", "cdecl")
    apr_file_write_full.argtypes = [POINTER(apr_file_t), POINTER(None), apr_size_t, POINTER(apr_size_t)]
    apr_file_write_full.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 556
if _libs["apr-1"].has("apr_file_writev_full", "cdecl"):
    apr_file_writev_full = _libs["apr-1"].get("apr_file_writev_full", "cdecl")
    apr_file_writev_full.argtypes = [POINTER(apr_file_t), POINTER(struct_iovec), apr_size_t, POINTER(apr_size_t)]
    apr_file_writev_full.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 565
if _libs["apr-1"].has("apr_file_putc", "cdecl"):
    apr_file_putc = _libs["apr-1"].get("apr_file_putc", "cdecl")
    apr_file_putc.argtypes = [c_char, POINTER(apr_file_t)]
    apr_file_putc.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 572
if _libs["apr-1"].has("apr_file_getc", "cdecl"):
    apr_file_getc = _libs["apr-1"].get("apr_file_getc", "cdecl")
    apr_file_getc.argtypes = [String, POINTER(apr_file_t)]
    apr_file_getc.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 579
if _libs["apr-1"].has("apr_file_ungetc", "cdecl"):
    apr_file_ungetc = _libs["apr-1"].get("apr_file_ungetc", "cdecl")
    apr_file_ungetc.argtypes = [c_char, POINTER(apr_file_t)]
    apr_file_ungetc.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 589
if _libs["apr-1"].has("apr_file_gets", "cdecl"):
    apr_file_gets = _libs["apr-1"].get("apr_file_gets", "cdecl")
    apr_file_gets.argtypes = [String, c_int, POINTER(apr_file_t)]
    apr_file_gets.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 597
if _libs["apr-1"].has("apr_file_puts", "cdecl"):
    apr_file_puts = _libs["apr-1"].get("apr_file_puts", "cdecl")
    apr_file_puts.argtypes = [String, POINTER(apr_file_t)]
    apr_file_puts.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 603
if _libs["apr-1"].has("apr_file_flush", "cdecl"):
    apr_file_flush = _libs["apr-1"].get("apr_file_flush", "cdecl")
    apr_file_flush.argtypes = [POINTER(apr_file_t)]
    apr_file_flush.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 609
if _libs["apr-1"].has("apr_file_sync", "cdecl"):
    apr_file_sync = _libs["apr-1"].get("apr_file_sync", "cdecl")
    apr_file_sync.argtypes = [POINTER(apr_file_t)]
    apr_file_sync.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 615
if _libs["apr-1"].has("apr_file_datasync", "cdecl"):
    apr_file_datasync = _libs["apr-1"].get("apr_file_datasync", "cdecl")
    apr_file_datasync.argtypes = [POINTER(apr_file_t)]
    apr_file_datasync.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 624
if _libs["apr-1"].has("apr_file_dup", "cdecl"):
    apr_file_dup = _libs["apr-1"].get("apr_file_dup", "cdecl")
    apr_file_dup.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_file_t), POINTER(apr_pool_t)]
    apr_file_dup.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 636
if _libs["apr-1"].has("apr_file_dup2", "cdecl"):
    apr_file_dup2 = _libs["apr-1"].get("apr_file_dup2", "cdecl")
    apr_file_dup2.argtypes = [POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    apr_file_dup2.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 651
if _libs["apr-1"].has("apr_file_setaside", "cdecl"):
    apr_file_setaside = _libs["apr-1"].get("apr_file_setaside", "cdecl")
    apr_file_setaside.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_file_t), POINTER(apr_pool_t)]
    apr_file_setaside.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 666
if _libs["apr-1"].has("apr_file_buffer_set", "cdecl"):
    apr_file_buffer_set = _libs["apr-1"].get("apr_file_buffer_set", "cdecl")
    apr_file_buffer_set.argtypes = [POINTER(apr_file_t), String, apr_size_t]
    apr_file_buffer_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 674
if _libs["apr-1"].has("apr_file_buffer_size_get", "cdecl"):
    apr_file_buffer_size_get = _libs["apr-1"].get("apr_file_buffer_size_get", "cdecl")
    apr_file_buffer_size_get.argtypes = [POINTER(apr_file_t)]
    apr_file_buffer_size_get.restype = apr_size_t

# /usr/include/apr/apr_file_io.h: 687
if _libs["apr-1"].has("apr_file_seek", "cdecl"):
    apr_file_seek = _libs["apr-1"].get("apr_file_seek", "cdecl")
    apr_file_seek.argtypes = [POINTER(apr_file_t), apr_seek_where_t, POINTER(apr_off_t)]
    apr_file_seek.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 704
if _libs["apr-1"].has("apr_file_pipe_create", "cdecl"):
    apr_file_pipe_create = _libs["apr-1"].get("apr_file_pipe_create", "cdecl")
    apr_file_pipe_create.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(apr_file_t)), POINTER(apr_pool_t)]
    apr_file_pipe_create.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 728
if _libs["apr-1"].has("apr_file_pipe_create_ex", "cdecl"):
    apr_file_pipe_create_ex = _libs["apr-1"].get("apr_file_pipe_create_ex", "cdecl")
    apr_file_pipe_create_ex.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(apr_file_t)), apr_int32_t, POINTER(apr_pool_t)]
    apr_file_pipe_create_ex.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 754
if _libs["apr-1"].has("apr_file_pipe_create_pools", "cdecl"):
    apr_file_pipe_create_pools = _libs["apr-1"].get("apr_file_pipe_create_pools", "cdecl")
    apr_file_pipe_create_pools.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(apr_file_t)), apr_int32_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    apr_file_pipe_create_pools.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 766
if _libs["apr-1"].has("apr_file_namedpipe_create", "cdecl"):
    apr_file_namedpipe_create = _libs["apr-1"].get("apr_file_namedpipe_create", "cdecl")
    apr_file_namedpipe_create.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_file_namedpipe_create.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 775
if _libs["apr-1"].has("apr_file_pipe_timeout_get", "cdecl"):
    apr_file_pipe_timeout_get = _libs["apr-1"].get("apr_file_pipe_timeout_get", "cdecl")
    apr_file_pipe_timeout_get.argtypes = [POINTER(apr_file_t), POINTER(apr_interval_time_t)]
    apr_file_pipe_timeout_get.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 784
if _libs["apr-1"].has("apr_file_pipe_timeout_set", "cdecl"):
    apr_file_pipe_timeout_set = _libs["apr-1"].get("apr_file_pipe_timeout_set", "cdecl")
    apr_file_pipe_timeout_set.argtypes = [POINTER(apr_file_t), apr_interval_time_t]
    apr_file_pipe_timeout_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 798
if _libs["apr-1"].has("apr_file_lock", "cdecl"):
    apr_file_lock = _libs["apr-1"].get("apr_file_lock", "cdecl")
    apr_file_lock.argtypes = [POINTER(apr_file_t), c_int]
    apr_file_lock.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 804
if _libs["apr-1"].has("apr_file_unlock", "cdecl"):
    apr_file_unlock = _libs["apr-1"].get("apr_file_unlock", "cdecl")
    apr_file_unlock.argtypes = [POINTER(apr_file_t)]
    apr_file_unlock.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 813
if _libs["apr-1"].has("apr_file_name_get", "cdecl"):
    apr_file_name_get = _libs["apr-1"].get("apr_file_name_get", "cdecl")
    apr_file_name_get.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_file_t)]
    apr_file_name_get.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 822
if _libs["apr-1"].has("apr_file_data_get", "cdecl"):
    apr_file_data_get = _libs["apr-1"].get("apr_file_data_get", "cdecl")
    apr_file_data_get.argtypes = [POINTER(POINTER(None)), String, POINTER(apr_file_t)]
    apr_file_data_get.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 832
if _libs["apr-1"].has("apr_file_data_set", "cdecl"):
    apr_file_data_set = _libs["apr-1"].get("apr_file_data_set", "cdecl")
    apr_file_data_set.argtypes = [POINTER(apr_file_t), POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_file_data_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 843
if _libs["apr-1"].has("apr_file_printf", "cdecl"):
    _func = _libs["apr-1"].get("apr_file_printf", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_file_t), String]
    apr_file_printf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr/apr_file_io.h: 859
if _libs["apr-1"].has("apr_file_perms_set", "cdecl"):
    apr_file_perms_set = _libs["apr-1"].get("apr_file_perms_set", "cdecl")
    apr_file_perms_set.argtypes = [String, apr_fileperms_t]
    apr_file_perms_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 878
if _libs["apr-1"].has("apr_file_attrs_set", "cdecl"):
    apr_file_attrs_set = _libs["apr-1"].get("apr_file_attrs_set", "cdecl")
    apr_file_attrs_set.argtypes = [String, apr_fileattrs_t, apr_fileattrs_t, POINTER(apr_pool_t)]
    apr_file_attrs_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 891
if _libs["apr-1"].has("apr_file_mtime_set", "cdecl"):
    apr_file_mtime_set = _libs["apr-1"].get("apr_file_mtime_set", "cdecl")
    apr_file_mtime_set.argtypes = [String, apr_time_t, POINTER(apr_pool_t)]
    apr_file_mtime_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 901
if _libs["apr-1"].has("apr_dir_make", "cdecl"):
    apr_dir_make = _libs["apr-1"].get("apr_dir_make", "cdecl")
    apr_dir_make.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_dir_make.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 911
if _libs["apr-1"].has("apr_dir_make_recursive", "cdecl"):
    apr_dir_make_recursive = _libs["apr-1"].get("apr_dir_make_recursive", "cdecl")
    apr_dir_make_recursive.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_dir_make_recursive.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 922
if _libs["apr-1"].has("apr_dir_remove", "cdecl"):
    apr_dir_remove = _libs["apr-1"].get("apr_dir_remove", "cdecl")
    apr_dir_remove.argtypes = [String, POINTER(apr_pool_t)]
    apr_dir_remove.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 930
if _libs["apr-1"].has("apr_file_info_get", "cdecl"):
    apr_file_info_get = _libs["apr-1"].get("apr_file_info_get", "cdecl")
    apr_file_info_get.argtypes = [POINTER(apr_finfo_t), apr_int32_t, POINTER(apr_file_t)]
    apr_file_info_get.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 941
if _libs["apr-1"].has("apr_file_trunc", "cdecl"):
    apr_file_trunc = _libs["apr-1"].get("apr_file_trunc", "cdecl")
    apr_file_trunc.argtypes = [POINTER(apr_file_t), apr_off_t]
    apr_file_trunc.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 948
if _libs["apr-1"].has("apr_file_flags_get", "cdecl"):
    apr_file_flags_get = _libs["apr-1"].get("apr_file_flags_get", "cdecl")
    apr_file_flags_get.argtypes = [POINTER(apr_file_t)]
    apr_file_flags_get.restype = apr_int32_t

# /usr/include/apr/apr_file_io.h: 953
if _libs["apr-1"].has("apr_file_pool_get", "cdecl"):
    apr_file_pool_get = _libs["apr-1"].get("apr_file_pool_get", "cdecl")
    apr_file_pool_get.argtypes = [POINTER(apr_file_t)]
    apr_file_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_file_io.h: 959
if _libs["apr-1"].has("apr_file_inherit_set", "cdecl"):
    apr_file_inherit_set = _libs["apr-1"].get("apr_file_inherit_set", "cdecl")
    apr_file_inherit_set.argtypes = [POINTER(apr_file_t)]
    apr_file_inherit_set.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 964
if _libs["apr-1"].has("apr_file_inherit_unset", "cdecl"):
    apr_file_inherit_unset = _libs["apr-1"].get("apr_file_inherit_unset", "cdecl")
    apr_file_inherit_unset.argtypes = [POINTER(apr_file_t)]
    apr_file_inherit_unset.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 983
if _libs["apr-1"].has("apr_file_mktemp", "cdecl"):
    apr_file_mktemp = _libs["apr-1"].get("apr_file_mktemp", "cdecl")
    apr_file_mktemp.argtypes = [POINTER(POINTER(apr_file_t)), String, apr_int32_t, POINTER(apr_pool_t)]
    apr_file_mktemp.restype = apr_status_t

# /usr/include/apr/apr_file_io.h: 996
if _libs["apr-1"].has("apr_temp_dir_get", "cdecl"):
    apr_temp_dir_get = _libs["apr-1"].get("apr_temp_dir_get", "cdecl")
    apr_temp_dir_get.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    apr_temp_dir_get.restype = apr_status_t

apr_perms_setfn_t = CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None), apr_fileperms_t, apr_uid_t, apr_gid_t)# /usr/include/apr/apr_perms_set.h: 42

rlim_t = __rlim_t# /usr/include/bits/resource.h: 131

# /usr/include/bits/resource.h: 139
class struct_rlimit(Structure):
    pass

struct_rlimit.__slots__ = [
    'rlim_cur',
    'rlim_max',
]
struct_rlimit._fields_ = [
    ('rlim_cur', rlim_t),
    ('rlim_max', rlim_t),
]

enum_anon_75 = c_int# /usr/include/apr/apr_thread_proc.h: 54

APR_SHELLCMD = 0# /usr/include/apr/apr_thread_proc.h: 54

APR_PROGRAM = (APR_SHELLCMD + 1)# /usr/include/apr/apr_thread_proc.h: 54

APR_PROGRAM_ENV = (APR_PROGRAM + 1)# /usr/include/apr/apr_thread_proc.h: 54

APR_PROGRAM_PATH = (APR_PROGRAM_ENV + 1)# /usr/include/apr/apr_thread_proc.h: 54

APR_SHELLCMD_ENV = (APR_PROGRAM_PATH + 1)# /usr/include/apr/apr_thread_proc.h: 54

apr_cmdtype_e = enum_anon_75# /usr/include/apr/apr_thread_proc.h: 54

enum_anon_76 = c_int# /usr/include/apr/apr_thread_proc.h: 59

APR_WAIT = 0# /usr/include/apr/apr_thread_proc.h: 59

APR_NOWAIT = (APR_WAIT + 1)# /usr/include/apr/apr_thread_proc.h: 59

apr_wait_how_e = enum_anon_76# /usr/include/apr/apr_thread_proc.h: 59

enum_anon_77 = c_int# /usr/include/apr/apr_thread_proc.h: 70

APR_PROC_EXIT = 1# /usr/include/apr/apr_thread_proc.h: 70

APR_PROC_SIGNAL = 2# /usr/include/apr/apr_thread_proc.h: 70

APR_PROC_SIGNAL_CORE = 4# /usr/include/apr/apr_thread_proc.h: 70

apr_exit_why_e = enum_anon_77# /usr/include/apr/apr_thread_proc.h: 70

# /usr/include/apr/apr_thread_proc.h: 162
class struct_apr_proc_t(Structure):
    pass

struct_apr_proc_t.__slots__ = [
    'pid',
    'in',
    'out',
    'err',
]
struct_apr_proc_t._fields_ = [
    ('pid', pid_t),
    ('in', POINTER(apr_file_t)),
    ('out', POINTER(apr_file_t)),
    ('err', POINTER(apr_file_t)),
]

apr_proc_t = struct_apr_proc_t# /usr/include/apr/apr_thread_proc.h: 162

apr_child_errfn_t = CFUNCTYPE(UNCHECKED(None), POINTER(apr_pool_t), apr_status_t, String)# /usr/include/apr/apr_thread_proc.h: 174

# /usr/include/apr/apr_thread_proc.h: 178
class struct_apr_thread_t(Structure):
    pass

apr_thread_t = struct_apr_thread_t# /usr/include/apr/apr_thread_proc.h: 178

# /usr/include/apr/apr_thread_proc.h: 181
class struct_apr_threadattr_t(Structure):
    pass

apr_threadattr_t = struct_apr_threadattr_t# /usr/include/apr/apr_thread_proc.h: 181

# /usr/include/apr/apr_thread_proc.h: 184
class struct_apr_procattr_t(Structure):
    pass

apr_procattr_t = struct_apr_procattr_t# /usr/include/apr/apr_thread_proc.h: 184

# /usr/include/apr/apr_thread_proc.h: 187
class struct_apr_thread_once_t(Structure):
    pass

apr_thread_once_t = struct_apr_thread_once_t# /usr/include/apr/apr_thread_proc.h: 187

# /usr/include/apr/apr_thread_proc.h: 190
class struct_apr_threadkey_t(Structure):
    pass

apr_threadkey_t = struct_apr_threadkey_t# /usr/include/apr/apr_thread_proc.h: 190

# /usr/include/apr/apr_thread_proc.h: 193
class struct_apr_other_child_rec_t(Structure):
    pass

apr_other_child_rec_t = struct_apr_other_child_rec_t# /usr/include/apr/apr_thread_proc.h: 193

apr_thread_start_t = CFUNCTYPE(UNCHECKED(POINTER(c_ubyte)), POINTER(apr_thread_t), POINTER(None))# /usr/include/apr/apr_thread_proc.h: 198

enum_anon_78 = c_int# /usr/include/apr/apr_thread_proc.h: 208

APR_KILL_NEVER = 0# /usr/include/apr/apr_thread_proc.h: 208

APR_KILL_ALWAYS = (APR_KILL_NEVER + 1)# /usr/include/apr/apr_thread_proc.h: 208

APR_KILL_AFTER_TIMEOUT = (APR_KILL_ALWAYS + 1)# /usr/include/apr/apr_thread_proc.h: 208

APR_JUST_WAIT = (APR_KILL_AFTER_TIMEOUT + 1)# /usr/include/apr/apr_thread_proc.h: 208

APR_KILL_ONLY_ONCE = (APR_JUST_WAIT + 1)# /usr/include/apr/apr_thread_proc.h: 208

apr_kill_conditions_e = enum_anon_78# /usr/include/apr/apr_thread_proc.h: 208

# /usr/include/apr/apr_thread_proc.h: 219
if _libs["apr-1"].has("apr_threadattr_create", "cdecl"):
    apr_threadattr_create = _libs["apr-1"].get("apr_threadattr_create", "cdecl")
    apr_threadattr_create.argtypes = [POINTER(POINTER(apr_threadattr_t)), POINTER(apr_pool_t)]
    apr_threadattr_create.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 227
if _libs["apr-1"].has("apr_threadattr_detach_set", "cdecl"):
    apr_threadattr_detach_set = _libs["apr-1"].get("apr_threadattr_detach_set", "cdecl")
    apr_threadattr_detach_set.argtypes = [POINTER(apr_threadattr_t), apr_int32_t]
    apr_threadattr_detach_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 236
if _libs["apr-1"].has("apr_threadattr_detach_get", "cdecl"):
    apr_threadattr_detach_get = _libs["apr-1"].get("apr_threadattr_detach_get", "cdecl")
    apr_threadattr_detach_get.argtypes = [POINTER(apr_threadattr_t)]
    apr_threadattr_detach_get.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 243
if _libs["apr-1"].has("apr_threadattr_stacksize_set", "cdecl"):
    apr_threadattr_stacksize_set = _libs["apr-1"].get("apr_threadattr_stacksize_set", "cdecl")
    apr_threadattr_stacksize_set.argtypes = [POINTER(apr_threadattr_t), apr_size_t]
    apr_threadattr_stacksize_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 256
if _libs["apr-1"].has("apr_threadattr_guardsize_set", "cdecl"):
    apr_threadattr_guardsize_set = _libs["apr-1"].get("apr_threadattr_guardsize_set", "cdecl")
    apr_threadattr_guardsize_set.argtypes = [POINTER(apr_threadattr_t), apr_size_t]
    apr_threadattr_guardsize_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 267
if _libs["apr-1"].has("apr_thread_create", "cdecl"):
    apr_thread_create = _libs["apr-1"].get("apr_thread_create", "cdecl")
    apr_thread_create.argtypes = [POINTER(POINTER(apr_thread_t)), POINTER(apr_threadattr_t), apr_thread_start_t, POINTER(None), POINTER(apr_pool_t)]
    apr_thread_create.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 277
if _libs["apr-1"].has("apr_thread_exit", "cdecl"):
    apr_thread_exit = _libs["apr-1"].get("apr_thread_exit", "cdecl")
    apr_thread_exit.argtypes = [POINTER(apr_thread_t), apr_status_t]
    apr_thread_exit.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 285
if _libs["apr-1"].has("apr_thread_join", "cdecl"):
    apr_thread_join = _libs["apr-1"].get("apr_thread_join", "cdecl")
    apr_thread_join.argtypes = [POINTER(apr_status_t), POINTER(apr_thread_t)]
    apr_thread_join.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 291
if _libs["apr-1"].has("apr_thread_yield", "cdecl"):
    apr_thread_yield = _libs["apr-1"].get("apr_thread_yield", "cdecl")
    apr_thread_yield.argtypes = []
    apr_thread_yield.restype = None

# /usr/include/apr/apr_thread_proc.h: 299
if _libs["apr-1"].has("apr_thread_once_init", "cdecl"):
    apr_thread_once_init = _libs["apr-1"].get("apr_thread_once_init", "cdecl")
    apr_thread_once_init.argtypes = [POINTER(POINTER(apr_thread_once_t)), POINTER(apr_pool_t)]
    apr_thread_once_init.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 311
if _libs["apr-1"].has("apr_thread_once", "cdecl"):
    apr_thread_once = _libs["apr-1"].get("apr_thread_once", "cdecl")
    apr_thread_once.argtypes = [POINTER(apr_thread_once_t), CFUNCTYPE(UNCHECKED(None), )]
    apr_thread_once.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 318
if _libs["apr-1"].has("apr_thread_detach", "cdecl"):
    apr_thread_detach = _libs["apr-1"].get("apr_thread_detach", "cdecl")
    apr_thread_detach.argtypes = [POINTER(apr_thread_t)]
    apr_thread_detach.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 326
if _libs["apr-1"].has("apr_thread_data_get", "cdecl"):
    apr_thread_data_get = _libs["apr-1"].get("apr_thread_data_get", "cdecl")
    apr_thread_data_get.argtypes = [POINTER(POINTER(None)), String, POINTER(apr_thread_t)]
    apr_thread_data_get.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 336
if _libs["apr-1"].has("apr_thread_data_set", "cdecl"):
    apr_thread_data_set = _libs["apr-1"].get("apr_thread_data_set", "cdecl")
    apr_thread_data_set.argtypes = [POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), POINTER(apr_thread_t)]
    apr_thread_data_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 346
if _libs["apr-1"].has("apr_threadkey_private_create", "cdecl"):
    apr_threadkey_private_create = _libs["apr-1"].get("apr_threadkey_private_create", "cdecl")
    apr_threadkey_private_create.argtypes = [POINTER(POINTER(apr_threadkey_t)), CFUNCTYPE(UNCHECKED(None), POINTER(None)), POINTER(apr_pool_t)]
    apr_threadkey_private_create.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 355
if _libs["apr-1"].has("apr_threadkey_private_get", "cdecl"):
    apr_threadkey_private_get = _libs["apr-1"].get("apr_threadkey_private_get", "cdecl")
    apr_threadkey_private_get.argtypes = [POINTER(POINTER(None)), POINTER(apr_threadkey_t)]
    apr_threadkey_private_get.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 363
if _libs["apr-1"].has("apr_threadkey_private_set", "cdecl"):
    apr_threadkey_private_set = _libs["apr-1"].get("apr_threadkey_private_set", "cdecl")
    apr_threadkey_private_set.argtypes = [POINTER(None), POINTER(apr_threadkey_t)]
    apr_threadkey_private_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 370
if _libs["apr-1"].has("apr_threadkey_private_delete", "cdecl"):
    apr_threadkey_private_delete = _libs["apr-1"].get("apr_threadkey_private_delete", "cdecl")
    apr_threadkey_private_delete.argtypes = [POINTER(apr_threadkey_t)]
    apr_threadkey_private_delete.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 378
if _libs["apr-1"].has("apr_threadkey_data_get", "cdecl"):
    apr_threadkey_data_get = _libs["apr-1"].get("apr_threadkey_data_get", "cdecl")
    apr_threadkey_data_get.argtypes = [POINTER(POINTER(None)), String, POINTER(apr_threadkey_t)]
    apr_threadkey_data_get.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 388
if _libs["apr-1"].has("apr_threadkey_data_set", "cdecl"):
    apr_threadkey_data_set = _libs["apr-1"].get("apr_threadkey_data_set", "cdecl")
    apr_threadkey_data_set.argtypes = [POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None)), POINTER(apr_threadkey_t)]
    apr_threadkey_data_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 399
if _libs["apr-1"].has("apr_procattr_create", "cdecl"):
    apr_procattr_create = _libs["apr-1"].get("apr_procattr_create", "cdecl")
    apr_procattr_create.argtypes = [POINTER(POINTER(apr_procattr_t)), POINTER(apr_pool_t)]
    apr_procattr_create.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 416
if _libs["apr-1"].has("apr_procattr_io_set", "cdecl"):
    apr_procattr_io_set = _libs["apr-1"].get("apr_procattr_io_set", "cdecl")
    apr_procattr_io_set.argtypes = [POINTER(apr_procattr_t), apr_int32_t, apr_int32_t, apr_int32_t]
    apr_procattr_io_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 435
if _libs["apr-1"].has("apr_procattr_child_in_set", "cdecl"):
    apr_procattr_child_in_set = _libs["apr-1"].get("apr_procattr_child_in_set", "cdecl")
    apr_procattr_child_in_set.argtypes = [POINTER(struct_apr_procattr_t), POINTER(apr_file_t), POINTER(apr_file_t)]
    apr_procattr_child_in_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 452
if _libs["apr-1"].has("apr_procattr_child_out_set", "cdecl"):
    apr_procattr_child_out_set = _libs["apr-1"].get("apr_procattr_child_out_set", "cdecl")
    apr_procattr_child_out_set.argtypes = [POINTER(struct_apr_procattr_t), POINTER(apr_file_t), POINTER(apr_file_t)]
    apr_procattr_child_out_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 469
if _libs["apr-1"].has("apr_procattr_child_err_set", "cdecl"):
    apr_procattr_child_err_set = _libs["apr-1"].get("apr_procattr_child_err_set", "cdecl")
    apr_procattr_child_err_set.argtypes = [POINTER(struct_apr_procattr_t), POINTER(apr_file_t), POINTER(apr_file_t)]
    apr_procattr_child_err_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 480
if _libs["apr-1"].has("apr_procattr_dir_set", "cdecl"):
    apr_procattr_dir_set = _libs["apr-1"].get("apr_procattr_dir_set", "cdecl")
    apr_procattr_dir_set.argtypes = [POINTER(apr_procattr_t), String]
    apr_procattr_dir_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 494
if _libs["apr-1"].has("apr_procattr_cmdtype_set", "cdecl"):
    apr_procattr_cmdtype_set = _libs["apr-1"].get("apr_procattr_cmdtype_set", "cdecl")
    apr_procattr_cmdtype_set.argtypes = [POINTER(apr_procattr_t), apr_cmdtype_e]
    apr_procattr_cmdtype_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 502
if _libs["apr-1"].has("apr_procattr_detach_set", "cdecl"):
    apr_procattr_detach_set = _libs["apr-1"].get("apr_procattr_detach_set", "cdecl")
    apr_procattr_detach_set.argtypes = [POINTER(apr_procattr_t), apr_int32_t]
    apr_procattr_detach_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 518
if _libs["apr-1"].has("apr_procattr_limit_set", "cdecl"):
    apr_procattr_limit_set = _libs["apr-1"].get("apr_procattr_limit_set", "cdecl")
    apr_procattr_limit_set.argtypes = [POINTER(apr_procattr_t), apr_int32_t, POINTER(struct_rlimit)]
    apr_procattr_limit_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 534
if _libs["apr-1"].has("apr_procattr_child_errfn_set", "cdecl"):
    apr_procattr_child_errfn_set = _libs["apr-1"].get("apr_procattr_child_errfn_set", "cdecl")
    apr_procattr_child_errfn_set.argtypes = [POINTER(apr_procattr_t), POINTER(apr_child_errfn_t)]
    apr_procattr_child_errfn_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 549
if _libs["apr-1"].has("apr_procattr_error_check_set", "cdecl"):
    apr_procattr_error_check_set = _libs["apr-1"].get("apr_procattr_error_check_set", "cdecl")
    apr_procattr_error_check_set.argtypes = [POINTER(apr_procattr_t), apr_int32_t]
    apr_procattr_error_check_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 559
if _libs["apr-1"].has("apr_procattr_addrspace_set", "cdecl"):
    apr_procattr_addrspace_set = _libs["apr-1"].get("apr_procattr_addrspace_set", "cdecl")
    apr_procattr_addrspace_set.argtypes = [POINTER(apr_procattr_t), apr_int32_t]
    apr_procattr_addrspace_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 570
if _libs["apr-1"].has("apr_procattr_user_set", "cdecl"):
    apr_procattr_user_set = _libs["apr-1"].get("apr_procattr_user_set", "cdecl")
    apr_procattr_user_set.argtypes = [POINTER(apr_procattr_t), String, String]
    apr_procattr_user_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 579
if _libs["apr-1"].has("apr_procattr_group_set", "cdecl"):
    apr_procattr_group_set = _libs["apr-1"].get("apr_procattr_group_set", "cdecl")
    apr_procattr_group_set.argtypes = [POINTER(apr_procattr_t), String]
    apr_procattr_group_set.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 590
if _libs["apr-1"].has("apr_procattr_perms_set_register", "cdecl"):
    apr_procattr_perms_set_register = _libs["apr-1"].get("apr_procattr_perms_set_register", "cdecl")
    apr_procattr_perms_set_register.argtypes = [POINTER(apr_procattr_t), POINTER(apr_perms_setfn_t), POINTER(None), apr_fileperms_t]
    apr_procattr_perms_set_register.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 604
if _libs["apr-1"].has("apr_proc_fork", "cdecl"):
    apr_proc_fork = _libs["apr-1"].get("apr_proc_fork", "cdecl")
    apr_proc_fork.argtypes = [POINTER(apr_proc_t), POINTER(apr_pool_t)]
    apr_proc_fork.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 623
if _libs["apr-1"].has("apr_proc_create", "cdecl"):
    apr_proc_create = _libs["apr-1"].get("apr_proc_create", "cdecl")
    apr_proc_create.argtypes = [POINTER(apr_proc_t), String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_procattr_t), POINTER(apr_pool_t)]
    apr_proc_create.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 656
if _libs["apr-1"].has("apr_proc_wait", "cdecl"):
    apr_proc_wait = _libs["apr-1"].get("apr_proc_wait", "cdecl")
    apr_proc_wait.argtypes = [POINTER(apr_proc_t), POINTER(c_int), POINTER(apr_exit_why_e), apr_wait_how_e]
    apr_proc_wait.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 686
if _libs["apr-1"].has("apr_proc_wait_all_procs", "cdecl"):
    apr_proc_wait_all_procs = _libs["apr-1"].get("apr_proc_wait_all_procs", "cdecl")
    apr_proc_wait_all_procs.argtypes = [POINTER(apr_proc_t), POINTER(c_int), POINTER(apr_exit_why_e), apr_wait_how_e, POINTER(apr_pool_t)]
    apr_proc_wait_all_procs.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 701
if _libs["apr-1"].has("apr_proc_detach", "cdecl"):
    apr_proc_detach = _libs["apr-1"].get("apr_proc_detach", "cdecl")
    apr_proc_detach.argtypes = [c_int]
    apr_proc_detach.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 720
if _libs["apr-1"].has("apr_proc_other_child_register", "cdecl"):
    apr_proc_other_child_register = _libs["apr-1"].get("apr_proc_other_child_register", "cdecl")
    apr_proc_other_child_register.argtypes = [POINTER(apr_proc_t), CFUNCTYPE(UNCHECKED(None), c_int, POINTER(None), c_int), POINTER(None), POINTER(apr_file_t), POINTER(apr_pool_t)]
    apr_proc_other_child_register.restype = None

# /usr/include/apr/apr_thread_proc.h: 736
if _libs["apr-1"].has("apr_proc_other_child_unregister", "cdecl"):
    apr_proc_other_child_unregister = _libs["apr-1"].get("apr_proc_other_child_unregister", "cdecl")
    apr_proc_other_child_unregister.argtypes = [POINTER(None)]
    apr_proc_other_child_unregister.restype = None

# /usr/include/apr/apr_thread_proc.h: 758
if _libs["apr-1"].has("apr_proc_other_child_alert", "cdecl"):
    apr_proc_other_child_alert = _libs["apr-1"].get("apr_proc_other_child_alert", "cdecl")
    apr_proc_other_child_alert.argtypes = [POINTER(apr_proc_t), c_int, c_int]
    apr_proc_other_child_alert.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 769
if _libs["apr-1"].has("apr_proc_other_child_refresh", "cdecl"):
    apr_proc_other_child_refresh = _libs["apr-1"].get("apr_proc_other_child_refresh", "cdecl")
    apr_proc_other_child_refresh.argtypes = [POINTER(apr_other_child_rec_t), c_int]
    apr_proc_other_child_refresh.restype = None

# /usr/include/apr/apr_thread_proc.h: 778
if _libs["apr-1"].has("apr_proc_other_child_refresh_all", "cdecl"):
    apr_proc_other_child_refresh_all = _libs["apr-1"].get("apr_proc_other_child_refresh_all", "cdecl")
    apr_proc_other_child_refresh_all.argtypes = [c_int]
    apr_proc_other_child_refresh_all.restype = None

# /usr/include/apr/apr_thread_proc.h: 785
if _libs["apr-1"].has("apr_proc_kill", "cdecl"):
    apr_proc_kill = _libs["apr-1"].get("apr_proc_kill", "cdecl")
    apr_proc_kill.argtypes = [POINTER(apr_proc_t), c_int]
    apr_proc_kill.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 800
if _libs["apr-1"].has("apr_pool_note_subprocess", "cdecl"):
    apr_pool_note_subprocess = _libs["apr-1"].get("apr_pool_note_subprocess", "cdecl")
    apr_pool_note_subprocess.argtypes = [POINTER(apr_pool_t), POINTER(apr_proc_t), apr_kill_conditions_e]
    apr_pool_note_subprocess.restype = None

# /usr/include/apr/apr_thread_proc.h: 811
if _libs["apr-1"].has("apr_setup_signal_thread", "cdecl"):
    apr_setup_signal_thread = _libs["apr-1"].get("apr_setup_signal_thread", "cdecl")
    apr_setup_signal_thread.argtypes = []
    apr_setup_signal_thread.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 827
if _libs["apr-1"].has("apr_signal_thread", "cdecl"):
    apr_signal_thread = _libs["apr-1"].get("apr_signal_thread", "cdecl")
    apr_signal_thread.argtypes = [CFUNCTYPE(UNCHECKED(c_int), c_int)]
    apr_signal_thread.restype = apr_status_t

# /usr/include/apr/apr_thread_proc.h: 835
if _libs["apr-1"].has("apr_thread_pool_get", "cdecl"):
    apr_thread_pool_get = _libs["apr-1"].get("apr_thread_pool_get", "cdecl")
    apr_thread_pool_get.argtypes = [POINTER(apr_thread_t)]
    apr_thread_pool_get.restype = POINTER(apr_pool_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 100
class struct_svn_string_t(Structure):
    pass

struct_svn_string_t.__slots__ = [
    'data',
    'len',
]
struct_svn_string_t._fields_ = [
    ('data', String),
    ('len', apr_size_t),
]

svn_string_t = struct_svn_string_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 100

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 120
class struct_svn_stringbuf_t(Structure):
    pass

struct_svn_stringbuf_t.__slots__ = [
    'pool',
    'data',
    'len',
    'blocksize',
]
struct_svn_stringbuf_t._fields_ = [
    ('pool', POINTER(apr_pool_t)),
    ('data', String),
    ('len', apr_size_t),
    ('blocksize', apr_size_t),
]

svn_stringbuf_t = struct_svn_stringbuf_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 120

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 130
if _libs["svn_subr-1"].has("svn_string_create", "cdecl"):
    svn_string_create = _libs["svn_subr-1"].get("svn_string_create", "cdecl")
    svn_string_create.argtypes = [String, POINTER(apr_pool_t)]
    svn_string_create.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 137
if _libs["svn_subr-1"].has("svn_string_create_empty", "cdecl"):
    svn_string_create_empty = _libs["svn_subr-1"].get("svn_string_create_empty", "cdecl")
    svn_string_create_empty.argtypes = [POINTER(apr_pool_t)]
    svn_string_create_empty.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 146
if _libs["svn_subr-1"].has("svn_string_ncreate", "cdecl"):
    svn_string_ncreate = _libs["svn_subr-1"].get("svn_string_ncreate", "cdecl")
    svn_string_ncreate.argtypes = [String, apr_size_t, POINTER(apr_pool_t)]
    svn_string_ncreate.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 151
if _libs["svn_subr-1"].has("svn_string_create_from_buf", "cdecl"):
    svn_string_create_from_buf = _libs["svn_subr-1"].get("svn_string_create_from_buf", "cdecl")
    svn_string_create_from_buf.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_string_create_from_buf.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 157
if _libs["svn_subr-1"].has("svn_string_createf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_string_createf", "cdecl")
    _restype = POINTER(svn_string_t)
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    svn_string_createf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 165
if _libs["svn_subr-1"].has("svn_string_createv", "cdecl"):
    svn_string_createv = _libs["svn_subr-1"].get("svn_string_createv", "cdecl")
    svn_string_createv.argtypes = [POINTER(apr_pool_t), String, c_void_p]
    svn_string_createv.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 171
if _libs["svn_subr-1"].has("svn_string_isempty", "cdecl"):
    svn_string_isempty = _libs["svn_subr-1"].get("svn_string_isempty", "cdecl")
    svn_string_isempty.argtypes = [POINTER(svn_string_t)]
    svn_string_isempty.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 178
if _libs["svn_subr-1"].has("svn_string_dup", "cdecl"):
    svn_string_dup = _libs["svn_subr-1"].get("svn_string_dup", "cdecl")
    svn_string_dup.argtypes = [POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_string_dup.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 183
if _libs["svn_subr-1"].has("svn_string_compare", "cdecl"):
    svn_string_compare = _libs["svn_subr-1"].get("svn_string_compare", "cdecl")
    svn_string_compare.argtypes = [POINTER(svn_string_t), POINTER(svn_string_t)]
    svn_string_compare.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 189
if _libs["svn_subr-1"].has("svn_string_first_non_whitespace", "cdecl"):
    svn_string_first_non_whitespace = _libs["svn_subr-1"].get("svn_string_first_non_whitespace", "cdecl")
    svn_string_first_non_whitespace.argtypes = [POINTER(svn_string_t)]
    svn_string_first_non_whitespace.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 195
if _libs["svn_subr-1"].has("svn_string_find_char_backward", "cdecl"):
    svn_string_find_char_backward = _libs["svn_subr-1"].get("svn_string_find_char_backward", "cdecl")
    svn_string_find_char_backward.argtypes = [POINTER(svn_string_t), c_char]
    svn_string_find_char_backward.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 208
if _libs["svn_subr-1"].has("svn_stringbuf_create", "cdecl"):
    svn_stringbuf_create = _libs["svn_subr-1"].get("svn_stringbuf_create", "cdecl")
    svn_stringbuf_create.argtypes = [String, POINTER(apr_pool_t)]
    svn_stringbuf_create.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 217
if _libs["svn_subr-1"].has("svn_stringbuf_ncreate", "cdecl"):
    svn_stringbuf_ncreate = _libs["svn_subr-1"].get("svn_stringbuf_ncreate", "cdecl")
    svn_stringbuf_ncreate.argtypes = [String, apr_size_t, POINTER(apr_pool_t)]
    svn_stringbuf_ncreate.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 224
if _libs["svn_subr-1"].has("svn_stringbuf_create_empty", "cdecl"):
    svn_stringbuf_create_empty = _libs["svn_subr-1"].get("svn_stringbuf_create_empty", "cdecl")
    svn_stringbuf_create_empty.argtypes = [POINTER(apr_pool_t)]
    svn_stringbuf_create_empty.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 235
if _libs["svn_subr-1"].has("svn_stringbuf_create_ensure", "cdecl"):
    svn_stringbuf_create_ensure = _libs["svn_subr-1"].get("svn_stringbuf_create_ensure", "cdecl")
    svn_stringbuf_create_ensure.argtypes = [apr_size_t, POINTER(apr_pool_t)]
    svn_stringbuf_create_ensure.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 240
if _libs["svn_subr-1"].has("svn_stringbuf_create_from_string", "cdecl"):
    svn_stringbuf_create_from_string = _libs["svn_subr-1"].get("svn_stringbuf_create_from_string", "cdecl")
    svn_stringbuf_create_from_string.argtypes = [POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_stringbuf_create_from_string.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 249
if _libs["svn_subr-1"].has("svn_stringbuf_create_wrap", "cdecl"):
    svn_stringbuf_create_wrap = _libs["svn_subr-1"].get("svn_stringbuf_create_wrap", "cdecl")
    svn_stringbuf_create_wrap.argtypes = [String, POINTER(apr_pool_t)]
    svn_stringbuf_create_wrap.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 255
if _libs["svn_subr-1"].has("svn_stringbuf_createf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_stringbuf_createf", "cdecl")
    _restype = POINTER(svn_stringbuf_t)
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    svn_stringbuf_createf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 263
if _libs["svn_subr-1"].has("svn_stringbuf_createv", "cdecl"):
    svn_stringbuf_createv = _libs["svn_subr-1"].get("svn_stringbuf_createv", "cdecl")
    svn_stringbuf_createv.argtypes = [POINTER(apr_pool_t), String, c_void_p]
    svn_stringbuf_createv.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 279
if _libs["svn_subr-1"].has("svn_stringbuf_ensure", "cdecl"):
    svn_stringbuf_ensure = _libs["svn_subr-1"].get("svn_stringbuf_ensure", "cdecl")
    svn_stringbuf_ensure.argtypes = [POINTER(svn_stringbuf_t), apr_size_t]
    svn_stringbuf_ensure.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 283
if _libs["svn_subr-1"].has("svn_stringbuf_set", "cdecl"):
    svn_stringbuf_set = _libs["svn_subr-1"].get("svn_stringbuf_set", "cdecl")
    svn_stringbuf_set.argtypes = [POINTER(svn_stringbuf_t), String]
    svn_stringbuf_set.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 287
if _libs["svn_subr-1"].has("svn_stringbuf_setempty", "cdecl"):
    svn_stringbuf_setempty = _libs["svn_subr-1"].get("svn_stringbuf_setempty", "cdecl")
    svn_stringbuf_setempty.argtypes = [POINTER(svn_stringbuf_t)]
    svn_stringbuf_setempty.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 291
if _libs["svn_subr-1"].has("svn_stringbuf_isempty", "cdecl"):
    svn_stringbuf_isempty = _libs["svn_subr-1"].get("svn_stringbuf_isempty", "cdecl")
    svn_stringbuf_isempty.argtypes = [POINTER(svn_stringbuf_t)]
    svn_stringbuf_isempty.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 295
if _libs["svn_subr-1"].has("svn_stringbuf_chop", "cdecl"):
    svn_stringbuf_chop = _libs["svn_subr-1"].get("svn_stringbuf_chop", "cdecl")
    svn_stringbuf_chop.argtypes = [POINTER(svn_stringbuf_t), apr_size_t]
    svn_stringbuf_chop.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 303
if _libs["svn_subr-1"].has("svn_stringbuf_leftchop", "cdecl"):
    svn_stringbuf_leftchop = _libs["svn_subr-1"].get("svn_stringbuf_leftchop", "cdecl")
    svn_stringbuf_leftchop.argtypes = [POINTER(svn_stringbuf_t), apr_size_t]
    svn_stringbuf_leftchop.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 307
if _libs["svn_subr-1"].has("svn_stringbuf_fillchar", "cdecl"):
    svn_stringbuf_fillchar = _libs["svn_subr-1"].get("svn_stringbuf_fillchar", "cdecl")
    svn_stringbuf_fillchar.argtypes = [POINTER(svn_stringbuf_t), c_ubyte]
    svn_stringbuf_fillchar.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 320
if _libs["svn_subr-1"].has("svn_stringbuf_appendbyte", "cdecl"):
    svn_stringbuf_appendbyte = _libs["svn_subr-1"].get("svn_stringbuf_appendbyte", "cdecl")
    svn_stringbuf_appendbyte.argtypes = [POINTER(svn_stringbuf_t), c_char]
    svn_stringbuf_appendbyte.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 330
if _libs["svn_subr-1"].has("svn_stringbuf_appendbytes", "cdecl"):
    svn_stringbuf_appendbytes = _libs["svn_subr-1"].get("svn_stringbuf_appendbytes", "cdecl")
    svn_stringbuf_appendbytes.argtypes = [POINTER(svn_stringbuf_t), String, apr_size_t]
    svn_stringbuf_appendbytes.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 340
if _libs["svn_subr-1"].has("svn_stringbuf_appendfill", "cdecl"):
    svn_stringbuf_appendfill = _libs["svn_subr-1"].get("svn_stringbuf_appendfill", "cdecl")
    svn_stringbuf_appendfill.argtypes = [POINTER(svn_stringbuf_t), c_char, apr_size_t]
    svn_stringbuf_appendfill.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 349
if _libs["svn_subr-1"].has("svn_stringbuf_appendstr", "cdecl"):
    svn_stringbuf_appendstr = _libs["svn_subr-1"].get("svn_stringbuf_appendstr", "cdecl")
    svn_stringbuf_appendstr.argtypes = [POINTER(svn_stringbuf_t), POINTER(svn_stringbuf_t)]
    svn_stringbuf_appendstr.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 357
if _libs["svn_subr-1"].has("svn_stringbuf_appendcstr", "cdecl"):
    svn_stringbuf_appendcstr = _libs["svn_subr-1"].get("svn_stringbuf_appendcstr", "cdecl")
    svn_stringbuf_appendcstr.argtypes = [POINTER(svn_stringbuf_t), String]
    svn_stringbuf_appendcstr.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 375
if _libs["svn_subr-1"].has("svn_stringbuf_insert", "cdecl"):
    svn_stringbuf_insert = _libs["svn_subr-1"].get("svn_stringbuf_insert", "cdecl")
    svn_stringbuf_insert.argtypes = [POINTER(svn_stringbuf_t), apr_size_t, String, apr_size_t]
    svn_stringbuf_insert.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 390
if _libs["svn_subr-1"].has("svn_stringbuf_remove", "cdecl"):
    svn_stringbuf_remove = _libs["svn_subr-1"].get("svn_stringbuf_remove", "cdecl")
    svn_stringbuf_remove.argtypes = [POINTER(svn_stringbuf_t), apr_size_t, apr_size_t]
    svn_stringbuf_remove.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 409
if _libs["svn_subr-1"].has("svn_stringbuf_replace", "cdecl"):
    svn_stringbuf_replace = _libs["svn_subr-1"].get("svn_stringbuf_replace", "cdecl")
    svn_stringbuf_replace.argtypes = [POINTER(svn_stringbuf_t), apr_size_t, apr_size_t, String, apr_size_t]
    svn_stringbuf_replace.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 421
if _libs["svn_subr-1"].has("svn_stringbuf_replace_all", "cdecl"):
    svn_stringbuf_replace_all = _libs["svn_subr-1"].get("svn_stringbuf_replace_all", "cdecl")
    svn_stringbuf_replace_all.argtypes = [POINTER(svn_stringbuf_t), String, String]
    svn_stringbuf_replace_all.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 426
if _libs["svn_subr-1"].has("svn_stringbuf_dup", "cdecl"):
    svn_stringbuf_dup = _libs["svn_subr-1"].get("svn_stringbuf_dup", "cdecl")
    svn_stringbuf_dup.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_stringbuf_dup.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 431
if _libs["svn_subr-1"].has("svn_stringbuf_compare", "cdecl"):
    svn_stringbuf_compare = _libs["svn_subr-1"].get("svn_stringbuf_compare", "cdecl")
    svn_stringbuf_compare.argtypes = [POINTER(svn_stringbuf_t), POINTER(svn_stringbuf_t)]
    svn_stringbuf_compare.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 438
if _libs["svn_subr-1"].has("svn_stringbuf_first_non_whitespace", "cdecl"):
    svn_stringbuf_first_non_whitespace = _libs["svn_subr-1"].get("svn_stringbuf_first_non_whitespace", "cdecl")
    svn_stringbuf_first_non_whitespace.argtypes = [POINTER(svn_stringbuf_t)]
    svn_stringbuf_first_non_whitespace.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 442
if _libs["svn_subr-1"].has("svn_stringbuf_strip_whitespace", "cdecl"):
    svn_stringbuf_strip_whitespace = _libs["svn_subr-1"].get("svn_stringbuf_strip_whitespace", "cdecl")
    svn_stringbuf_strip_whitespace.argtypes = [POINTER(svn_stringbuf_t)]
    svn_stringbuf_strip_whitespace.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 448
if _libs["svn_subr-1"].has("svn_stringbuf_find_char_backward", "cdecl"):
    svn_stringbuf_find_char_backward = _libs["svn_subr-1"].get("svn_stringbuf_find_char_backward", "cdecl")
    svn_stringbuf_find_char_backward.argtypes = [POINTER(svn_stringbuf_t), c_char]
    svn_stringbuf_find_char_backward.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 452
if _libs["svn_subr-1"].has("svn_string_compare_stringbuf", "cdecl"):
    svn_string_compare_stringbuf = _libs["svn_subr-1"].get("svn_string_compare_stringbuf", "cdecl")
    svn_string_compare_stringbuf.argtypes = [POINTER(svn_string_t), POINTER(svn_stringbuf_t)]
    svn_string_compare_stringbuf.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 477
if _libs["svn_subr-1"].has("svn_cstring_split", "cdecl"):
    svn_cstring_split = _libs["svn_subr-1"].get("svn_cstring_split", "cdecl")
    svn_cstring_split.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cstring_split.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 488
if _libs["svn_subr-1"].has("svn_cstring_split_append", "cdecl"):
    svn_cstring_split_append = _libs["svn_subr-1"].get("svn_cstring_split_append", "cdecl")
    svn_cstring_split_append.argtypes = [POINTER(apr_array_header_t), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cstring_split_append.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 499
if _libs["svn_subr-1"].has("svn_cstring_match_glob_list", "cdecl"):
    svn_cstring_match_glob_list = _libs["svn_subr-1"].get("svn_cstring_match_glob_list", "cdecl")
    svn_cstring_match_glob_list.argtypes = [String, POINTER(apr_array_header_t)]
    svn_cstring_match_glob_list.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 506
if _libs["svn_subr-1"].has("svn_cstring_match_list", "cdecl"):
    svn_cstring_match_list = _libs["svn_subr-1"].get("svn_cstring_match_list", "cdecl")
    svn_cstring_match_list.argtypes = [String, POINTER(apr_array_header_t)]
    svn_cstring_match_list.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 519
if _libs["svn_subr-1"].has("svn_cstring_tokenize", "cdecl"):
    svn_cstring_tokenize = _libs["svn_subr-1"].get("svn_cstring_tokenize", "cdecl")
    svn_cstring_tokenize.argtypes = [String, POINTER(POINTER(c_char))]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_cstring_tokenize.restype = ReturnString
    else:
        svn_cstring_tokenize.restype = String
        svn_cstring_tokenize.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 529
if _libs["svn_subr-1"].has("svn_cstring_count_newlines", "cdecl"):
    svn_cstring_count_newlines = _libs["svn_subr-1"].get("svn_cstring_count_newlines", "cdecl")
    svn_cstring_count_newlines.argtypes = [String]
    svn_cstring_count_newlines.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 540
if _libs["svn_subr-1"].has("svn_cstring_join2", "cdecl"):
    svn_cstring_join2 = _libs["svn_subr-1"].get("svn_cstring_join2", "cdecl")
    svn_cstring_join2.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_cstring_join2.restype = ReturnString
    else:
        svn_cstring_join2.restype = String
        svn_cstring_join2.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 554
if _libs["svn_subr-1"].has("svn_cstring_join", "cdecl"):
    svn_cstring_join = _libs["svn_subr-1"].get("svn_cstring_join", "cdecl")
    svn_cstring_join.argtypes = [POINTER(apr_array_header_t), String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_cstring_join.restype = ReturnString
    else:
        svn_cstring_join.restype = String
        svn_cstring_join.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 570
if _libs["svn_subr-1"].has("svn_cstring_casecmp", "cdecl"):
    svn_cstring_casecmp = _libs["svn_subr-1"].get("svn_cstring_casecmp", "cdecl")
    svn_cstring_casecmp.argtypes = [String, String]
    svn_cstring_casecmp.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 591
if _libs["svn_subr-1"].has("svn_cstring_strtoi64", "cdecl"):
    svn_cstring_strtoi64 = _libs["svn_subr-1"].get("svn_cstring_strtoi64", "cdecl")
    svn_cstring_strtoi64.argtypes = [POINTER(c_int64), String, c_int64, c_int64, c_int]
    svn_cstring_strtoi64.restype = POINTER(svn_error_t)
    svn_cstring_strtoi64.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 605
if _libs["svn_subr-1"].has("svn_cstring_atoi64", "cdecl"):
    svn_cstring_atoi64 = _libs["svn_subr-1"].get("svn_cstring_atoi64", "cdecl")
    svn_cstring_atoi64.argtypes = [POINTER(c_int64), String]
    svn_cstring_atoi64.restype = POINTER(svn_error_t)
    svn_cstring_atoi64.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 617
if _libs["svn_subr-1"].has("svn_cstring_atoi", "cdecl"):
    svn_cstring_atoi = _libs["svn_subr-1"].get("svn_cstring_atoi", "cdecl")
    svn_cstring_atoi.argtypes = [POINTER(c_int), String]
    svn_cstring_atoi.restype = POINTER(svn_error_t)
    svn_cstring_atoi.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 643
if _libs["svn_subr-1"].has("svn_cstring_strtoui64", "cdecl"):
    svn_cstring_strtoui64 = _libs["svn_subr-1"].get("svn_cstring_strtoui64", "cdecl")
    svn_cstring_strtoui64.argtypes = [POINTER(apr_uint64_t), String, apr_uint64_t, apr_uint64_t, c_int]
    svn_cstring_strtoui64.restype = POINTER(svn_error_t)
    svn_cstring_strtoui64.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 658
if _libs["svn_subr-1"].has("svn_cstring_atoui64", "cdecl"):
    svn_cstring_atoui64 = _libs["svn_subr-1"].get("svn_cstring_atoui64", "cdecl")
    svn_cstring_atoui64.argtypes = [POINTER(apr_uint64_t), String]
    svn_cstring_atoui64.restype = POINTER(svn_error_t)
    svn_cstring_atoui64.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 671
if _libs["svn_subr-1"].has("svn_cstring_atoui", "cdecl"):
    svn_cstring_atoui = _libs["svn_subr-1"].get("svn_cstring_atoui", "cdecl")
    svn_cstring_atoui.argtypes = [POINTER(c_uint), String]
    svn_cstring_atoui.restype = POINTER(svn_error_t)
    svn_cstring_atoui.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 681
if _libs["svn_subr-1"].has("svn_cstring_skip_prefix", "cdecl"):
    svn_cstring_skip_prefix = _libs["svn_subr-1"].get("svn_cstring_skip_prefix", "cdecl")
    svn_cstring_skip_prefix.argtypes = [String, String]
    svn_cstring_skip_prefix.restype = c_char_p

enum_svn_checksum_kind_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

svn_checksum_md5 = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

svn_checksum_sha1 = (svn_checksum_md5 + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

svn_checksum_fnv1a_32 = (svn_checksum_sha1 + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

svn_checksum_fnv1a_32x4 = (svn_checksum_fnv1a_32 + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

svn_checksum_kind_t = enum_svn_checksum_kind_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 62

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 77
class struct_svn_checksum_t(Structure):
    pass

struct_svn_checksum_t.__slots__ = [
    'digest',
    'kind',
]
struct_svn_checksum_t._fields_ = [
    ('digest', POINTER(c_ubyte)),
    ('kind', svn_checksum_kind_t),
]

svn_checksum_t = struct_svn_checksum_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 77

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 82
class struct_svn_checksum_ctx_t(Structure):
    pass

svn_checksum_ctx_t = struct_svn_checksum_ctx_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 82

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 89
if _libs["svn_subr-1"].has("svn_checksum_create", "cdecl"):
    svn_checksum_create = _libs["svn_subr-1"].get("svn_checksum_create", "cdecl")
    svn_checksum_create.argtypes = [svn_checksum_kind_t, POINTER(apr_pool_t)]
    svn_checksum_create.restype = POINTER(svn_checksum_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 98
if _libs["svn_subr-1"].has("svn_checksum_clear", "cdecl"):
    svn_checksum_clear = _libs["svn_subr-1"].get("svn_checksum_clear", "cdecl")
    svn_checksum_clear.argtypes = [POINTER(svn_checksum_t)]
    svn_checksum_clear.restype = POINTER(svn_error_t)
    svn_checksum_clear.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 108
if _libs["svn_subr-1"].has("svn_checksum_match", "cdecl"):
    svn_checksum_match = _libs["svn_subr-1"].get("svn_checksum_match", "cdecl")
    svn_checksum_match.argtypes = [POINTER(svn_checksum_t), POINTER(svn_checksum_t)]
    svn_checksum_match.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 118
if _libs["svn_subr-1"].has("svn_checksum_dup", "cdecl"):
    svn_checksum_dup = _libs["svn_subr-1"].get("svn_checksum_dup", "cdecl")
    svn_checksum_dup.argtypes = [POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_checksum_dup.restype = POINTER(svn_checksum_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 128
if _libs["svn_subr-1"].has("svn_checksum_to_cstring_display", "cdecl"):
    svn_checksum_to_cstring_display = _libs["svn_subr-1"].get("svn_checksum_to_cstring_display", "cdecl")
    svn_checksum_to_cstring_display.argtypes = [POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_checksum_to_cstring_display.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 141
if _libs["svn_subr-1"].has("svn_checksum_to_cstring", "cdecl"):
    svn_checksum_to_cstring = _libs["svn_subr-1"].get("svn_checksum_to_cstring", "cdecl")
    svn_checksum_to_cstring.argtypes = [POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_checksum_to_cstring.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 153
if _libs["svn_subr-1"].has("svn_checksum_serialize", "cdecl"):
    svn_checksum_serialize = _libs["svn_subr-1"].get("svn_checksum_serialize", "cdecl")
    svn_checksum_serialize.argtypes = [POINTER(svn_checksum_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_checksum_serialize.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 165
if _libs["svn_subr-1"].has("svn_checksum_deserialize", "cdecl"):
    svn_checksum_deserialize = _libs["svn_subr-1"].get("svn_checksum_deserialize", "cdecl")
    svn_checksum_deserialize.argtypes = [POINTER(POINTER(svn_checksum_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_checksum_deserialize.restype = POINTER(svn_error_t)
    svn_checksum_deserialize.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 184
if _libs["svn_subr-1"].has("svn_checksum_parse_hex", "cdecl"):
    svn_checksum_parse_hex = _libs["svn_subr-1"].get("svn_checksum_parse_hex", "cdecl")
    svn_checksum_parse_hex.argtypes = [POINTER(POINTER(svn_checksum_t)), svn_checksum_kind_t, String, POINTER(apr_pool_t)]
    svn_checksum_parse_hex.restype = POINTER(svn_error_t)
    svn_checksum_parse_hex.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 196
if _libs["svn_subr-1"].has("svn_checksum", "cdecl"):
    svn_checksum = _libs["svn_subr-1"].get("svn_checksum", "cdecl")
    svn_checksum.argtypes = [POINTER(POINTER(svn_checksum_t)), svn_checksum_kind_t, POINTER(None), apr_size_t, POINTER(apr_pool_t)]
    svn_checksum.restype = POINTER(svn_error_t)
    svn_checksum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 210
if _libs["svn_subr-1"].has("svn_checksum_empty_checksum", "cdecl"):
    svn_checksum_empty_checksum = _libs["svn_subr-1"].get("svn_checksum_empty_checksum", "cdecl")
    svn_checksum_empty_checksum.argtypes = [svn_checksum_kind_t, POINTER(apr_pool_t)]
    svn_checksum_empty_checksum.restype = POINTER(svn_checksum_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 221
if _libs["svn_subr-1"].has("svn_checksum_ctx_create", "cdecl"):
    svn_checksum_ctx_create = _libs["svn_subr-1"].get("svn_checksum_ctx_create", "cdecl")
    svn_checksum_ctx_create.argtypes = [svn_checksum_kind_t, POINTER(apr_pool_t)]
    svn_checksum_ctx_create.restype = POINTER(svn_checksum_ctx_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 231
if _libs["svn_subr-1"].has("svn_checksum_ctx_reset", "cdecl"):
    svn_checksum_ctx_reset = _libs["svn_subr-1"].get("svn_checksum_ctx_reset", "cdecl")
    svn_checksum_ctx_reset.argtypes = [POINTER(svn_checksum_ctx_t)]
    svn_checksum_ctx_reset.restype = POINTER(svn_error_t)
    svn_checksum_ctx_reset.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 240
if _libs["svn_subr-1"].has("svn_checksum_update", "cdecl"):
    svn_checksum_update = _libs["svn_subr-1"].get("svn_checksum_update", "cdecl")
    svn_checksum_update.argtypes = [POINTER(svn_checksum_ctx_t), POINTER(None), apr_size_t]
    svn_checksum_update.restype = POINTER(svn_error_t)
    svn_checksum_update.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 252
if _libs["svn_subr-1"].has("svn_checksum_final", "cdecl"):
    svn_checksum_final = _libs["svn_subr-1"].get("svn_checksum_final", "cdecl")
    svn_checksum_final.argtypes = [POINTER(POINTER(svn_checksum_t)), POINTER(svn_checksum_ctx_t), POINTER(apr_pool_t)]
    svn_checksum_final.restype = POINTER(svn_error_t)
    svn_checksum_final.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 264
if _libs["svn_subr-1"].has("svn_checksum_size", "cdecl"):
    svn_checksum_size = _libs["svn_subr-1"].get("svn_checksum_size", "cdecl")
    svn_checksum_size.argtypes = [POINTER(svn_checksum_t)]
    svn_checksum_size.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 273
if _libs["svn_subr-1"].has("svn_checksum_is_empty_checksum", "cdecl"):
    svn_checksum_is_empty_checksum = _libs["svn_subr-1"].get("svn_checksum_is_empty_checksum", "cdecl")
    svn_checksum_is_empty_checksum.argtypes = [POINTER(svn_checksum_t)]
    svn_checksum_is_empty_checksum.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 289
if _libs["svn_subr-1"].has("svn_checksum_mismatch_err", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_checksum_mismatch_err", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_checksum_t), POINTER(svn_checksum_t), POINTER(apr_pool_t), String]
    svn_checksum_mismatch_err = _variadic_function(_func,_restype,_argtypes,_errcheck)

enum_svn_io_file_del_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 66

svn_io_file_del_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 66

svn_io_file_del_on_close = (svn_io_file_del_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 66

svn_io_file_del_on_pool_cleanup = (svn_io_file_del_on_close + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 66

svn_io_file_del_t = enum_svn_io_file_del_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 66

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 98
class struct_svn_io_dirent2_t(Structure):
    pass

struct_svn_io_dirent2_t.__slots__ = [
    'kind',
    'special',
    'filesize',
    'mtime',
]
struct_svn_io_dirent2_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('special', svn_boolean_t),
    ('filesize', svn_filesize_t),
    ('mtime', apr_time_t),
]

svn_io_dirent2_t = struct_svn_io_dirent2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 98

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 105
if _libs["svn_subr-1"].has("svn_io_dirent2_create", "cdecl"):
    svn_io_dirent2_create = _libs["svn_subr-1"].get("svn_io_dirent2_create", "cdecl")
    svn_io_dirent2_create.argtypes = [POINTER(apr_pool_t)]
    svn_io_dirent2_create.restype = POINTER(svn_io_dirent2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 112
if _libs["svn_subr-1"].has("svn_io_dirent2_dup", "cdecl"):
    svn_io_dirent2_dup = _libs["svn_subr-1"].get("svn_io_dirent2_dup", "cdecl")
    svn_io_dirent2_dup.argtypes = [POINTER(svn_io_dirent2_t), POINTER(apr_pool_t)]
    svn_io_dirent2_dup.restype = POINTER(svn_io_dirent2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 132
class struct_svn_io_dirent_t(Structure):
    pass

struct_svn_io_dirent_t.__slots__ = [
    'kind',
    'special',
]
struct_svn_io_dirent_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('special', svn_boolean_t),
]

svn_io_dirent_t = struct_svn_io_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 132

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 153
if _libs["svn_subr-1"].has("svn_io_check_path", "cdecl"):
    svn_io_check_path = _libs["svn_subr-1"].get("svn_io_check_path", "cdecl")
    svn_io_check_path.argtypes = [String, POINTER(svn_node_kind_t), POINTER(apr_pool_t)]
    svn_io_check_path.restype = POINTER(svn_error_t)
    svn_io_check_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 164
if _libs["svn_subr-1"].has("svn_io_check_special_path", "cdecl"):
    svn_io_check_special_path = _libs["svn_subr-1"].get("svn_io_check_special_path", "cdecl")
    svn_io_check_special_path.argtypes = [String, POINTER(svn_node_kind_t), POINTER(svn_boolean_t), POINTER(apr_pool_t)]
    svn_io_check_special_path.restype = POINTER(svn_error_t)
    svn_io_check_special_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 172
if _libs["svn_subr-1"].has("svn_io_check_resolved_path", "cdecl"):
    svn_io_check_resolved_path = _libs["svn_subr-1"].get("svn_io_check_resolved_path", "cdecl")
    svn_io_check_resolved_path.argtypes = [String, POINTER(svn_node_kind_t), POINTER(apr_pool_t)]
    svn_io_check_resolved_path.restype = POINTER(svn_error_t)
    svn_io_check_resolved_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 230
if _libs["svn_subr-1"].has("svn_io_open_uniquely_named", "cdecl"):
    svn_io_open_uniquely_named = _libs["svn_subr-1"].get("svn_io_open_uniquely_named", "cdecl")
    svn_io_open_uniquely_named.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(c_char)), String, String, String, svn_io_file_del_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_open_uniquely_named.restype = POINTER(svn_error_t)
    svn_io_open_uniquely_named.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 267
if _libs["svn_subr-1"].has("svn_io_open_unique_file3", "cdecl"):
    svn_io_open_unique_file3 = _libs["svn_subr-1"].get("svn_io_open_unique_file3", "cdecl")
    svn_io_open_unique_file3.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(c_char)), String, svn_io_file_del_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_open_unique_file3.restype = POINTER(svn_error_t)
    svn_io_open_unique_file3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 284
if _libs["svn_subr-1"].has("svn_io_open_unique_file2", "cdecl"):
    svn_io_open_unique_file2 = _libs["svn_subr-1"].get("svn_io_open_unique_file2", "cdecl")
    svn_io_open_unique_file2.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(c_char)), String, String, svn_io_file_del_t, POINTER(apr_pool_t)]
    svn_io_open_unique_file2.restype = POINTER(svn_error_t)
    svn_io_open_unique_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 301
if _libs["svn_subr-1"].has("svn_io_open_unique_file", "cdecl"):
    svn_io_open_unique_file = _libs["svn_subr-1"].get("svn_io_open_unique_file", "cdecl")
    svn_io_open_unique_file.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(c_char)), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_open_unique_file.restype = POINTER(svn_error_t)
    svn_io_open_unique_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 316
if _libs["svn_subr-1"].has("svn_io_create_unique_link", "cdecl"):
    svn_io_create_unique_link = _libs["svn_subr-1"].get("svn_io_create_unique_link", "cdecl")
    svn_io_create_unique_link.argtypes = [POINTER(POINTER(c_char)), String, String, String, POINTER(apr_pool_t)]
    svn_io_create_unique_link.restype = POINTER(svn_error_t)
    svn_io_create_unique_link.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 330
if _libs["svn_subr-1"].has("svn_io_read_link", "cdecl"):
    svn_io_read_link = _libs["svn_subr-1"].get("svn_io_read_link", "cdecl")
    svn_io_read_link.argtypes = [POINTER(POINTER(svn_string_t)), String, POINTER(apr_pool_t)]
    svn_io_read_link.restype = POINTER(svn_error_t)
    svn_io_read_link.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 339
if _libs["svn_subr-1"].has("svn_io_temp_dir", "cdecl"):
    svn_io_temp_dir = _libs["svn_subr-1"].get("svn_io_temp_dir", "cdecl")
    svn_io_temp_dir.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_io_temp_dir.restype = POINTER(svn_error_t)
    svn_io_temp_dir.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 349
if _libs["svn_subr-1"].has("svn_io_copy_file", "cdecl"):
    svn_io_copy_file = _libs["svn_subr-1"].get("svn_io_copy_file", "cdecl")
    svn_io_copy_file.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_copy_file.restype = POINTER(svn_error_t)
    svn_io_copy_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 361
if _libs["svn_subr-1"].has("svn_io_copy_perms", "cdecl"):
    svn_io_copy_perms = _libs["svn_subr-1"].get("svn_io_copy_perms", "cdecl")
    svn_io_copy_perms.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_copy_perms.restype = POINTER(svn_error_t)
    svn_io_copy_perms.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 375
if _libs["svn_subr-1"].has("svn_io_copy_link", "cdecl"):
    svn_io_copy_link = _libs["svn_subr-1"].get("svn_io_copy_link", "cdecl")
    svn_io_copy_link.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_copy_link.restype = POINTER(svn_error_t)
    svn_io_copy_link.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 391
if _libs["svn_subr-1"].has("svn_io_copy_dir_recursively", "cdecl"):
    svn_io_copy_dir_recursively = _libs["svn_subr-1"].get("svn_io_copy_dir_recursively", "cdecl")
    svn_io_copy_dir_recursively.argtypes = [String, String, String, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_io_copy_dir_recursively.restype = POINTER(svn_error_t)
    svn_io_copy_dir_recursively.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 408
if _libs["svn_subr-1"].has("svn_io_make_dir_recursively", "cdecl"):
    svn_io_make_dir_recursively = _libs["svn_subr-1"].get("svn_io_make_dir_recursively", "cdecl")
    svn_io_make_dir_recursively.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_make_dir_recursively.restype = POINTER(svn_error_t)
    svn_io_make_dir_recursively.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 417
if _libs["svn_subr-1"].has("svn_io_dir_empty", "cdecl"):
    svn_io_dir_empty = _libs["svn_subr-1"].get("svn_io_dir_empty", "cdecl")
    svn_io_dir_empty.argtypes = [POINTER(svn_boolean_t), String, POINTER(apr_pool_t)]
    svn_io_dir_empty.restype = POINTER(svn_error_t)
    svn_io_dir_empty.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 426
if _libs["svn_subr-1"].has("svn_io_append_file", "cdecl"):
    svn_io_append_file = _libs["svn_subr-1"].get("svn_io_append_file", "cdecl")
    svn_io_append_file.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_append_file.restype = POINTER(svn_error_t)
    svn_io_append_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 444
if _libs["svn_subr-1"].has("svn_io_set_file_read_only", "cdecl"):
    svn_io_set_file_read_only = _libs["svn_subr-1"].get("svn_io_set_file_read_only", "cdecl")
    svn_io_set_file_read_only.argtypes = [String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_set_file_read_only.restype = POINTER(svn_error_t)
    svn_io_set_file_read_only.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 465
if _libs["svn_subr-1"].has("svn_io_set_file_read_write", "cdecl"):
    svn_io_set_file_read_write = _libs["svn_subr-1"].get("svn_io_set_file_read_write", "cdecl")
    svn_io_set_file_read_write.argtypes = [String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_set_file_read_write.restype = POINTER(svn_error_t)
    svn_io_set_file_read_write.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 494
if _libs["svn_subr-1"].has("svn_io_set_file_read_write_carefully", "cdecl"):
    svn_io_set_file_read_write_carefully = _libs["svn_subr-1"].get("svn_io_set_file_read_write_carefully", "cdecl")
    svn_io_set_file_read_write_carefully.argtypes = [String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_set_file_read_write_carefully.restype = POINTER(svn_error_t)
    svn_io_set_file_read_write_carefully.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 525
if _libs["svn_subr-1"].has("svn_io_set_file_executable", "cdecl"):
    svn_io_set_file_executable = _libs["svn_subr-1"].get("svn_io_set_file_executable", "cdecl")
    svn_io_set_file_executable.argtypes = [String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_set_file_executable.restype = POINTER(svn_error_t)
    svn_io_set_file_executable.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 537
if _libs["svn_subr-1"].has("svn_io_is_file_executable", "cdecl"):
    svn_io_is_file_executable = _libs["svn_subr-1"].get("svn_io_is_file_executable", "cdecl")
    svn_io_is_file_executable.argtypes = [POINTER(svn_boolean_t), String, POINTER(apr_pool_t)]
    svn_io_is_file_executable.restype = POINTER(svn_error_t)
    svn_io_is_file_executable.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 551
if _libs["svn_subr-1"].has("svn_io_read_length_line", "cdecl"):
    svn_io_read_length_line = _libs["svn_subr-1"].get("svn_io_read_length_line", "cdecl")
    svn_io_read_length_line.argtypes = [POINTER(apr_file_t), String, POINTER(apr_size_t), POINTER(apr_pool_t)]
    svn_io_read_length_line.restype = POINTER(svn_error_t)
    svn_io_read_length_line.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 564
if _libs["svn_subr-1"].has("svn_io_file_affected_time", "cdecl"):
    svn_io_file_affected_time = _libs["svn_subr-1"].get("svn_io_file_affected_time", "cdecl")
    svn_io_file_affected_time.argtypes = [POINTER(apr_time_t), String, POINTER(apr_pool_t)]
    svn_io_file_affected_time.restype = POINTER(svn_error_t)
    svn_io_file_affected_time.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 575
if _libs["svn_subr-1"].has("svn_io_set_file_affected_time", "cdecl"):
    svn_io_set_file_affected_time = _libs["svn_subr-1"].get("svn_io_set_file_affected_time", "cdecl")
    svn_io_set_file_affected_time.argtypes = [apr_time_t, String, POINTER(apr_pool_t)]
    svn_io_set_file_affected_time.restype = POINTER(svn_error_t)
    svn_io_set_file_affected_time.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 595
if _libs["svn_subr-1"].has("svn_io_sleep_for_timestamps", "cdecl"):
    svn_io_sleep_for_timestamps = _libs["svn_subr-1"].get("svn_io_sleep_for_timestamps", "cdecl")
    svn_io_sleep_for_timestamps.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_sleep_for_timestamps.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 606
if _libs["svn_subr-1"].has("svn_io_filesizes_different_p", "cdecl"):
    svn_io_filesizes_different_p = _libs["svn_subr-1"].get("svn_io_filesizes_different_p", "cdecl")
    svn_io_filesizes_different_p.argtypes = [POINTER(svn_boolean_t), String, String, POINTER(apr_pool_t)]
    svn_io_filesizes_different_p.restype = POINTER(svn_error_t)
    svn_io_filesizes_different_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 625
if _libs["svn_subr-1"].has("svn_io_filesizes_three_different_p", "cdecl"):
    svn_io_filesizes_three_different_p = _libs["svn_subr-1"].get("svn_io_filesizes_three_different_p", "cdecl")
    svn_io_filesizes_three_different_p.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, String, String, POINTER(apr_pool_t)]
    svn_io_filesizes_three_different_p.restype = POINTER(svn_error_t)
    svn_io_filesizes_three_different_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 639
if _libs["svn_subr-1"].has("svn_io_file_checksum2", "cdecl"):
    svn_io_file_checksum2 = _libs["svn_subr-1"].get("svn_io_file_checksum2", "cdecl")
    svn_io_file_checksum2.argtypes = [POINTER(POINTER(svn_checksum_t)), String, svn_checksum_kind_t, POINTER(apr_pool_t)]
    svn_io_file_checksum2.restype = POINTER(svn_error_t)
    svn_io_file_checksum2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 653
if _libs["svn_subr-1"].has("svn_io_file_checksum", "cdecl"):
    svn_io_file_checksum = _libs["svn_subr-1"].get("svn_io_file_checksum", "cdecl")
    svn_io_file_checksum.argtypes = [POINTER(c_ubyte), String, POINTER(apr_pool_t)]
    svn_io_file_checksum.restype = POINTER(svn_error_t)
    svn_io_file_checksum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 662
if _libs["svn_subr-1"].has("svn_io_files_contents_same_p", "cdecl"):
    svn_io_files_contents_same_p = _libs["svn_subr-1"].get("svn_io_files_contents_same_p", "cdecl")
    svn_io_files_contents_same_p.argtypes = [POINTER(svn_boolean_t), String, String, POINTER(apr_pool_t)]
    svn_io_files_contents_same_p.restype = POINTER(svn_error_t)
    svn_io_files_contents_same_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 676
if _libs["svn_subr-1"].has("svn_io_files_contents_three_same_p", "cdecl"):
    svn_io_files_contents_three_same_p = _libs["svn_subr-1"].get("svn_io_files_contents_three_same_p", "cdecl")
    svn_io_files_contents_three_same_p.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, String, String, POINTER(apr_pool_t)]
    svn_io_files_contents_three_same_p.restype = POINTER(svn_error_t)
    svn_io_files_contents_three_same_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 696
if _libs["svn_subr-1"].has("svn_io_file_create", "cdecl"):
    svn_io_file_create = _libs["svn_subr-1"].get("svn_io_file_create", "cdecl")
    svn_io_file_create.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_file_create.restype = POINTER(svn_error_t)
    svn_io_file_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 714
if _libs["svn_subr-1"].has("svn_io_file_create_bytes", "cdecl"):
    svn_io_file_create_bytes = _libs["svn_subr-1"].get("svn_io_file_create_bytes", "cdecl")
    svn_io_file_create_bytes.argtypes = [String, POINTER(None), apr_size_t, POINTER(apr_pool_t)]
    svn_io_file_create_bytes.restype = POINTER(svn_error_t)
    svn_io_file_create_bytes.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 729
if _libs["svn_subr-1"].has("svn_io_file_create_empty", "cdecl"):
    svn_io_file_create_empty = _libs["svn_subr-1"].get("svn_io_file_create_empty", "cdecl")
    svn_io_file_create_empty.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_file_create_empty.restype = POINTER(svn_error_t)
    svn_io_file_create_empty.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 742
if _libs["svn_subr-1"].has("svn_io_file_lock", "cdecl"):
    svn_io_file_lock = _libs["svn_subr-1"].get("svn_io_file_lock", "cdecl")
    svn_io_file_lock.argtypes = [String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_file_lock.restype = POINTER(svn_error_t)
    svn_io_file_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 759
if _libs["svn_subr-1"].has("svn_io_file_lock2", "cdecl"):
    svn_io_file_lock2 = _libs["svn_subr-1"].get("svn_io_file_lock2", "cdecl")
    svn_io_file_lock2.argtypes = [String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_file_lock2.restype = POINTER(svn_error_t)
    svn_io_file_lock2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 779
if _libs["svn_subr-1"].has("svn_io_lock_open_file", "cdecl"):
    svn_io_lock_open_file = _libs["svn_subr-1"].get("svn_io_lock_open_file", "cdecl")
    svn_io_lock_open_file.argtypes = [POINTER(apr_file_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_lock_open_file.restype = POINTER(svn_error_t)
    svn_io_lock_open_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 793
if _libs["svn_subr-1"].has("svn_io_unlock_open_file", "cdecl"):
    svn_io_unlock_open_file = _libs["svn_subr-1"].get("svn_io_unlock_open_file", "cdecl")
    svn_io_unlock_open_file.argtypes = [POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_unlock_open_file.restype = POINTER(svn_error_t)
    svn_io_unlock_open_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 809
if _libs["svn_subr-1"].has("svn_io_file_flush_to_disk", "cdecl"):
    svn_io_file_flush_to_disk = _libs["svn_subr-1"].get("svn_io_file_flush_to_disk", "cdecl")
    svn_io_file_flush_to_disk.argtypes = [POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_flush_to_disk.restype = POINTER(svn_error_t)
    svn_io_file_flush_to_disk.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 821
if _libs["svn_subr-1"].has("svn_io_dir_file_copy", "cdecl"):
    svn_io_dir_file_copy = _libs["svn_subr-1"].get("svn_io_dir_file_copy", "cdecl")
    svn_io_dir_file_copy.argtypes = [String, String, String, POINTER(apr_pool_t)]
    svn_io_dir_file_copy.restype = POINTER(svn_error_t)
    svn_io_dir_file_copy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 863
class struct_svn_stream_t(Structure):
    pass

svn_stream_t = struct_svn_stream_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 863

svn_read_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_size_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 868

svn_stream_skip_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_size_t)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 876

svn_write_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_size_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 880

svn_close_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 885

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 894
class struct_svn_stream_mark_t(Structure):
    pass

svn_stream_mark_t = struct_svn_stream_mark_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 894

svn_stream_mark_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_stream_mark_t)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 901

svn_stream_seek_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_stream_mark_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 910

svn_stream_data_available_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_boolean_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 918

svn_stream_readline_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_stringbuf_t)), String, POINTER(svn_boolean_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 926

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 933
if _libs["svn_subr-1"].has("svn_stream_create", "cdecl"):
    svn_stream_create = _libs["svn_subr-1"].get("svn_stream_create", "cdecl")
    svn_stream_create.argtypes = [POINTER(None), POINTER(apr_pool_t)]
    svn_stream_create.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 939
if _libs["svn_subr-1"].has("svn_stream_set_baton", "cdecl"):
    svn_stream_set_baton = _libs["svn_subr-1"].get("svn_stream_set_baton", "cdecl")
    svn_stream_set_baton.argtypes = [POINTER(svn_stream_t), POINTER(None)]
    svn_stream_set_baton.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 949
if _libs["svn_subr-1"].has("svn_stream_set_read2", "cdecl"):
    svn_stream_set_read2 = _libs["svn_subr-1"].get("svn_stream_set_read2", "cdecl")
    svn_stream_set_read2.argtypes = [POINTER(svn_stream_t), svn_read_fn_t, svn_read_fn_t]
    svn_stream_set_read2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 961
if _libs["svn_subr-1"].has("svn_stream_set_read", "cdecl"):
    svn_stream_set_read = _libs["svn_subr-1"].get("svn_stream_set_read", "cdecl")
    svn_stream_set_read.argtypes = [POINTER(svn_stream_t), svn_read_fn_t]
    svn_stream_set_read.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 969
if _libs["svn_subr-1"].has("svn_stream_set_skip", "cdecl"):
    svn_stream_set_skip = _libs["svn_subr-1"].get("svn_stream_set_skip", "cdecl")
    svn_stream_set_skip.argtypes = [POINTER(svn_stream_t), svn_stream_skip_fn_t]
    svn_stream_set_skip.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 974
if _libs["svn_subr-1"].has("svn_stream_set_write", "cdecl"):
    svn_stream_set_write = _libs["svn_subr-1"].get("svn_stream_set_write", "cdecl")
    svn_stream_set_write.argtypes = [POINTER(svn_stream_t), svn_write_fn_t]
    svn_stream_set_write.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 979
if _libs["svn_subr-1"].has("svn_stream_set_close", "cdecl"):
    svn_stream_set_close = _libs["svn_subr-1"].get("svn_stream_set_close", "cdecl")
    svn_stream_set_close.argtypes = [POINTER(svn_stream_t), svn_close_fn_t]
    svn_stream_set_close.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 987
if _libs["svn_subr-1"].has("svn_stream_set_mark", "cdecl"):
    svn_stream_set_mark = _libs["svn_subr-1"].get("svn_stream_set_mark", "cdecl")
    svn_stream_set_mark.argtypes = [POINTER(svn_stream_t), svn_stream_mark_fn_t]
    svn_stream_set_mark.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 995
if _libs["svn_subr-1"].has("svn_stream_set_seek", "cdecl"):
    svn_stream_set_seek = _libs["svn_subr-1"].get("svn_stream_set_seek", "cdecl")
    svn_stream_set_seek.argtypes = [POINTER(svn_stream_t), svn_stream_seek_fn_t]
    svn_stream_set_seek.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1003
if _libs["svn_subr-1"].has("svn_stream_set_data_available", "cdecl"):
    svn_stream_set_data_available = _libs["svn_subr-1"].get("svn_stream_set_data_available", "cdecl")
    svn_stream_set_data_available.argtypes = [POINTER(svn_stream_t), svn_stream_data_available_fn_t]
    svn_stream_set_data_available.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1011
if _libs["svn_subr-1"].has("svn_stream_set_readline", "cdecl"):
    svn_stream_set_readline = _libs["svn_subr-1"].get("svn_stream_set_readline", "cdecl")
    svn_stream_set_readline.argtypes = [POINTER(svn_stream_t), svn_stream_readline_fn_t]
    svn_stream_set_readline.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1015
if _libs["svn_subr-1"].has("svn_stream_empty", "cdecl"):
    svn_stream_empty = _libs["svn_subr-1"].get("svn_stream_empty", "cdecl")
    svn_stream_empty.argtypes = [POINTER(apr_pool_t)]
    svn_stream_empty.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1025
if _libs["svn_subr-1"].has("svn_stream_disown", "cdecl"):
    svn_stream_disown = _libs["svn_subr-1"].get("svn_stream_disown", "cdecl")
    svn_stream_disown.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_disown.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1040
if _libs["svn_subr-1"].has("svn_stream_open_readonly", "cdecl"):
    svn_stream_open_readonly = _libs["svn_subr-1"].get("svn_stream_open_readonly", "cdecl")
    svn_stream_open_readonly.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_stream_open_readonly.restype = POINTER(svn_error_t)
    svn_stream_open_readonly.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1059
if _libs["svn_subr-1"].has("svn_stream_open_writable", "cdecl"):
    svn_stream_open_writable = _libs["svn_subr-1"].get("svn_stream_open_writable", "cdecl")
    svn_stream_open_writable.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_stream_open_writable.restype = POINTER(svn_error_t)
    svn_stream_open_writable.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1084
if _libs["svn_subr-1"].has("svn_stream_open_unique", "cdecl"):
    svn_stream_open_unique = _libs["svn_subr-1"].get("svn_stream_open_unique", "cdecl")
    svn_stream_open_unique.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(POINTER(c_char)), String, svn_io_file_del_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_stream_open_unique.restype = POINTER(svn_error_t)
    svn_stream_open_unique.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1104
if _libs["svn_subr-1"].has("svn_stream_from_aprfile2", "cdecl"):
    svn_stream_from_aprfile2 = _libs["svn_subr-1"].get("svn_stream_from_aprfile2", "cdecl")
    svn_stream_from_aprfile2.argtypes = [POINTER(apr_file_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_stream_from_aprfile2.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1119
if _libs["svn_subr-1"].has("svn_stream_from_aprfile", "cdecl"):
    svn_stream_from_aprfile = _libs["svn_subr-1"].get("svn_stream_from_aprfile", "cdecl")
    svn_stream_from_aprfile.argtypes = [POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_stream_from_aprfile.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1135
if _libs["svn_subr-1"].has("svn_stream_for_stdin2", "cdecl"):
    svn_stream_for_stdin2 = _libs["svn_subr-1"].get("svn_stream_for_stdin2", "cdecl")
    svn_stream_for_stdin2.argtypes = [POINTER(POINTER(svn_stream_t)), svn_boolean_t, POINTER(apr_pool_t)]
    svn_stream_for_stdin2.restype = POINTER(svn_error_t)
    svn_stream_for_stdin2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1147
if _libs["svn_subr-1"].has("svn_stream_for_stdin", "cdecl"):
    svn_stream_for_stdin = _libs["svn_subr-1"].get("svn_stream_for_stdin", "cdecl")
    svn_stream_for_stdin.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(apr_pool_t)]
    svn_stream_for_stdin.restype = POINTER(svn_error_t)
    svn_stream_for_stdin.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1157
if _libs["svn_subr-1"].has("svn_stream_for_stderr", "cdecl"):
    svn_stream_for_stderr = _libs["svn_subr-1"].get("svn_stream_for_stderr", "cdecl")
    svn_stream_for_stderr.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(apr_pool_t)]
    svn_stream_for_stderr.restype = POINTER(svn_error_t)
    svn_stream_for_stderr.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1165
if _libs["svn_subr-1"].has("svn_stream_for_stdout", "cdecl"):
    svn_stream_for_stdout = _libs["svn_subr-1"].get("svn_stream_for_stdout", "cdecl")
    svn_stream_for_stdout.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(apr_pool_t)]
    svn_stream_for_stdout.restype = POINTER(svn_error_t)
    svn_stream_for_stdout.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1188
if _libs["svn_subr-1"].has("svn_stringbuf_from_stream", "cdecl"):
    svn_stringbuf_from_stream = _libs["svn_subr-1"].get("svn_stringbuf_from_stream", "cdecl")
    svn_stringbuf_from_stream.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_stream_t), apr_size_t, POINTER(apr_pool_t)]
    svn_stringbuf_from_stream.restype = POINTER(svn_error_t)
    svn_stringbuf_from_stream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1197
if _libs["svn_subr-1"].has("svn_stream_from_stringbuf", "cdecl"):
    svn_stream_from_stringbuf = _libs["svn_subr-1"].get("svn_stream_from_stringbuf", "cdecl")
    svn_stream_from_stringbuf.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_stream_from_stringbuf.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1204
if _libs["svn_subr-1"].has("svn_stream_from_string", "cdecl"):
    svn_stream_from_string = _libs["svn_subr-1"].get("svn_stream_from_string", "cdecl")
    svn_stream_from_string.argtypes = [POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_stream_from_string.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1215
if _libs["svn_subr-1"].has("svn_stream_buffered", "cdecl"):
    svn_stream_buffered = _libs["svn_subr-1"].get("svn_stream_buffered", "cdecl")
    svn_stream_buffered.argtypes = [POINTER(apr_pool_t)]
    svn_stream_buffered.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1228
if _libs["svn_subr-1"].has("svn_stream_compressed", "cdecl"):
    svn_stream_compressed = _libs["svn_subr-1"].get("svn_stream_compressed", "cdecl")
    svn_stream_compressed.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_compressed.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1254
if _libs["svn_subr-1"].has("svn_stream_checksummed2", "cdecl"):
    svn_stream_checksummed2 = _libs["svn_subr-1"].get("svn_stream_checksummed2", "cdecl")
    svn_stream_checksummed2.argtypes = [POINTER(svn_stream_t), POINTER(POINTER(svn_checksum_t)), POINTER(POINTER(svn_checksum_t)), svn_checksum_kind_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_stream_checksummed2.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1270
if _libs["svn_subr-1"].has("svn_stream_checksummed", "cdecl"):
    svn_stream_checksummed = _libs["svn_subr-1"].get("svn_stream_checksummed", "cdecl")
    svn_stream_checksummed.argtypes = [POINTER(svn_stream_t), POINTER(POINTER(c_ubyte)), POINTER(POINTER(c_ubyte)), svn_boolean_t, POINTER(apr_pool_t)]
    svn_stream_checksummed.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1288
if _libs["svn_subr-1"].has("svn_stream_contents_checksum", "cdecl"):
    svn_stream_contents_checksum = _libs["svn_subr-1"].get("svn_stream_contents_checksum", "cdecl")
    svn_stream_contents_checksum.argtypes = [POINTER(POINTER(svn_checksum_t)), POINTER(svn_stream_t), svn_checksum_kind_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_stream_contents_checksum.restype = POINTER(svn_error_t)
    svn_stream_contents_checksum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1300
if _libs["svn_subr-1"].has("svn_stream_read_full", "cdecl"):
    svn_stream_read_full = _libs["svn_subr-1"].get("svn_stream_read_full", "cdecl")
    svn_stream_read_full.argtypes = [POINTER(svn_stream_t), String, POINTER(apr_size_t)]
    svn_stream_read_full.restype = POINTER(svn_error_t)
    svn_stream_read_full.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1311
if _libs["svn_subr-1"].has("svn_stream_supports_partial_read", "cdecl"):
    svn_stream_supports_partial_read = _libs["svn_subr-1"].get("svn_stream_supports_partial_read", "cdecl")
    svn_stream_supports_partial_read.argtypes = [POINTER(svn_stream_t)]
    svn_stream_supports_partial_read.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1322
if _libs["svn_subr-1"].has("svn_stream_read2", "cdecl"):
    svn_stream_read2 = _libs["svn_subr-1"].get("svn_stream_read2", "cdecl")
    svn_stream_read2.argtypes = [POINTER(svn_stream_t), String, POINTER(apr_size_t)]
    svn_stream_read2.restype = POINTER(svn_error_t)
    svn_stream_read2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1337
if _libs["svn_subr-1"].has("svn_stream_read", "cdecl"):
    svn_stream_read = _libs["svn_subr-1"].get("svn_stream_read", "cdecl")
    svn_stream_read.argtypes = [POINTER(svn_stream_t), String, POINTER(apr_size_t)]
    svn_stream_read.restype = POINTER(svn_error_t)
    svn_stream_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1356
if _libs["svn_subr-1"].has("svn_stream_skip", "cdecl"):
    svn_stream_skip = _libs["svn_subr-1"].get("svn_stream_skip", "cdecl")
    svn_stream_skip.argtypes = [POINTER(svn_stream_t), apr_size_t]
    svn_stream_skip.restype = POINTER(svn_error_t)
    svn_stream_skip.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1361
if _libs["svn_subr-1"].has("svn_stream_write", "cdecl"):
    svn_stream_write = _libs["svn_subr-1"].get("svn_stream_write", "cdecl")
    svn_stream_write.argtypes = [POINTER(svn_stream_t), String, POINTER(apr_size_t)]
    svn_stream_write.restype = POINTER(svn_error_t)
    svn_stream_write.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1367
if _libs["svn_subr-1"].has("svn_stream_close", "cdecl"):
    svn_stream_close = _libs["svn_subr-1"].get("svn_stream_close", "cdecl")
    svn_stream_close.argtypes = [POINTER(svn_stream_t)]
    svn_stream_close.restype = POINTER(svn_error_t)
    svn_stream_close.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1377
if _libs["svn_subr-1"].has("svn_stream_reset", "cdecl"):
    svn_stream_reset = _libs["svn_subr-1"].get("svn_stream_reset", "cdecl")
    svn_stream_reset.argtypes = [POINTER(svn_stream_t)]
    svn_stream_reset.restype = POINTER(svn_error_t)
    svn_stream_reset.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1386
if _libs["svn_subr-1"].has("svn_stream_supports_mark", "cdecl"):
    svn_stream_supports_mark = _libs["svn_subr-1"].get("svn_stream_supports_mark", "cdecl")
    svn_stream_supports_mark.argtypes = [POINTER(svn_stream_t)]
    svn_stream_supports_mark.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1394
if _libs["svn_subr-1"].has("svn_stream_supports_reset", "cdecl"):
    svn_stream_supports_reset = _libs["svn_subr-1"].get("svn_stream_supports_reset", "cdecl")
    svn_stream_supports_reset.argtypes = [POINTER(svn_stream_t)]
    svn_stream_supports_reset.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1406
if _libs["svn_subr-1"].has("svn_stream_mark", "cdecl"):
    svn_stream_mark = _libs["svn_subr-1"].get("svn_stream_mark", "cdecl")
    svn_stream_mark.argtypes = [POINTER(svn_stream_t), POINTER(POINTER(svn_stream_mark_t)), POINTER(apr_pool_t)]
    svn_stream_mark.restype = POINTER(svn_error_t)
    svn_stream_mark.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1419
if _libs["svn_subr-1"].has("svn_stream_seek", "cdecl"):
    svn_stream_seek = _libs["svn_subr-1"].get("svn_stream_seek", "cdecl")
    svn_stream_seek.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_mark_t)]
    svn_stream_seek.restype = POINTER(svn_error_t)
    svn_stream_seek.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1432
if _libs["svn_subr-1"].has("svn_stream_data_available", "cdecl"):
    svn_stream_data_available = _libs["svn_subr-1"].get("svn_stream_data_available", "cdecl")
    svn_stream_data_available.argtypes = [POINTER(svn_stream_t), POINTER(svn_boolean_t)]
    svn_stream_data_available.restype = POINTER(svn_error_t)
    svn_stream_data_available.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1444
if _libs["svn_subr-1"].has("svn_stream_tee", "cdecl"):
    svn_stream_tee = _libs["svn_subr-1"].get("svn_stream_tee", "cdecl")
    svn_stream_tee.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_tee.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1454
if _libs["svn_subr-1"].has("svn_stream_puts", "cdecl"):
    svn_stream_puts = _libs["svn_subr-1"].get("svn_stream_puts", "cdecl")
    svn_stream_puts.argtypes = [POINTER(svn_stream_t), String]
    svn_stream_puts.restype = POINTER(svn_error_t)
    svn_stream_puts.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1461
if _libs["svn_subr-1"].has("svn_stream_printf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_stream_printf", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t), String]
    svn_stream_printf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1477
if _libs["svn_subr-1"].has("svn_stream_printf_from_utf8", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_stream_printf_from_utf8", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_stream_t), String, POINTER(apr_pool_t), String]
    svn_stream_printf_from_utf8 = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1493
if _libs["svn_subr-1"].has("svn_stream_readline", "cdecl"):
    svn_stream_readline = _libs["svn_subr-1"].get("svn_stream_readline", "cdecl")
    svn_stream_readline.argtypes = [POINTER(svn_stream_t), POINTER(POINTER(svn_stringbuf_t)), String, POINTER(svn_boolean_t), POINTER(apr_pool_t)]
    svn_stream_readline.restype = POINTER(svn_error_t)
    svn_stream_readline.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1514
if _libs["svn_subr-1"].has("svn_stream_copy3", "cdecl"):
    svn_stream_copy3 = _libs["svn_subr-1"].get("svn_stream_copy3", "cdecl")
    svn_stream_copy3.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_stream_copy3.restype = POINTER(svn_error_t)
    svn_stream_copy3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1528
if _libs["svn_subr-1"].has("svn_stream_copy2", "cdecl"):
    svn_stream_copy2 = _libs["svn_subr-1"].get("svn_stream_copy2", "cdecl")
    svn_stream_copy2.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_stream_copy2.restype = POINTER(svn_error_t)
    svn_stream_copy2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1543
if _libs["svn_subr-1"].has("svn_stream_copy", "cdecl"):
    svn_stream_copy = _libs["svn_subr-1"].get("svn_stream_copy", "cdecl")
    svn_stream_copy.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_copy.restype = POINTER(svn_error_t)
    svn_stream_copy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1559
if _libs["svn_subr-1"].has("svn_stream_contents_same2", "cdecl"):
    svn_stream_contents_same2 = _libs["svn_subr-1"].get("svn_stream_contents_same2", "cdecl")
    svn_stream_contents_same2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_contents_same2.restype = POINTER(svn_error_t)
    svn_stream_contents_same2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1573
if _libs["svn_subr-1"].has("svn_stream_contents_same", "cdecl"):
    svn_stream_contents_same = _libs["svn_subr-1"].get("svn_stream_contents_same", "cdecl")
    svn_stream_contents_same.argtypes = [POINTER(svn_boolean_t), POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_stream_contents_same.restype = POINTER(svn_error_t)
    svn_stream_contents_same.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1600
if _libs["svn_subr-1"].has("svn_string_from_stream2", "cdecl"):
    svn_string_from_stream2 = _libs["svn_subr-1"].get("svn_string_from_stream2", "cdecl")
    svn_string_from_stream2.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_stream_t), apr_size_t, POINTER(apr_pool_t)]
    svn_string_from_stream2.restype = POINTER(svn_error_t)
    svn_string_from_stream2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1612
if _libs["svn_subr-1"].has("svn_string_from_stream", "cdecl"):
    svn_string_from_stream = _libs["svn_subr-1"].get("svn_string_from_stream", "cdecl")
    svn_string_from_stream.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_stream_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_string_from_stream.restype = POINTER(svn_error_t)
    svn_string_from_stream.errcheck = _svn_errcheck

svn_stream_lazyopen_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_stream_t)), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1632

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1657
if _libs["svn_subr-1"].has("svn_stream_lazyopen_create", "cdecl"):
    svn_stream_lazyopen_create = _libs["svn_subr-1"].get("svn_stream_lazyopen_create", "cdecl")
    svn_stream_lazyopen_create.argtypes = [svn_stream_lazyopen_func_t, POINTER(None), svn_boolean_t, POINTER(apr_pool_t)]
    svn_stream_lazyopen_create.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1680
if _libs["svn_subr-1"].has("svn_stringbuf_from_file2", "cdecl"):
    svn_stringbuf_from_file2 = _libs["svn_subr-1"].get("svn_stringbuf_from_file2", "cdecl")
    svn_stringbuf_from_file2.argtypes = [POINTER(POINTER(svn_stringbuf_t)), String, POINTER(apr_pool_t)]
    svn_stringbuf_from_file2.restype = POINTER(svn_error_t)
    svn_stringbuf_from_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1692
if _libs["svn_subr-1"].has("svn_stringbuf_from_file", "cdecl"):
    svn_stringbuf_from_file = _libs["svn_subr-1"].get("svn_stringbuf_from_file", "cdecl")
    svn_stringbuf_from_file.argtypes = [POINTER(POINTER(svn_stringbuf_t)), String, POINTER(apr_pool_t)]
    svn_stringbuf_from_file.restype = POINTER(svn_error_t)
    svn_stringbuf_from_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1704
if _libs["svn_subr-1"].has("svn_stringbuf_from_aprfile", "cdecl"):
    svn_stringbuf_from_aprfile = _libs["svn_subr-1"].get("svn_stringbuf_from_aprfile", "cdecl")
    svn_stringbuf_from_aprfile.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_stringbuf_from_aprfile.restype = POINTER(svn_error_t)
    svn_stringbuf_from_aprfile.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1719
if _libs["svn_subr-1"].has("svn_io_remove_file2", "cdecl"):
    svn_io_remove_file2 = _libs["svn_subr-1"].get("svn_io_remove_file2", "cdecl")
    svn_io_remove_file2.argtypes = [String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_remove_file2.restype = POINTER(svn_error_t)
    svn_io_remove_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1729
if _libs["svn_subr-1"].has("svn_io_remove_file", "cdecl"):
    svn_io_remove_file = _libs["svn_subr-1"].get("svn_io_remove_file", "cdecl")
    svn_io_remove_file.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_remove_file.restype = POINTER(svn_error_t)
    svn_io_remove_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1742
if _libs["svn_subr-1"].has("svn_io_remove_dir2", "cdecl"):
    svn_io_remove_dir2 = _libs["svn_subr-1"].get("svn_io_remove_dir2", "cdecl")
    svn_io_remove_dir2.argtypes = [String, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_io_remove_dir2.restype = POINTER(svn_error_t)
    svn_io_remove_dir2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1755
if _libs["svn_subr-1"].has("svn_io_remove_dir", "cdecl"):
    svn_io_remove_dir = _libs["svn_subr-1"].get("svn_io_remove_dir", "cdecl")
    svn_io_remove_dir.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_remove_dir.restype = POINTER(svn_error_t)
    svn_io_remove_dir.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1770
if _libs["svn_subr-1"].has("svn_io_get_dir_filenames", "cdecl"):
    svn_io_get_dir_filenames = _libs["svn_subr-1"].get("svn_io_get_dir_filenames", "cdecl")
    svn_io_get_dir_filenames.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_io_get_dir_filenames.restype = POINTER(svn_error_t)
    svn_io_get_dir_filenames.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1790
if _libs["svn_subr-1"].has("svn_io_get_dirents3", "cdecl"):
    svn_io_get_dirents3 = _libs["svn_subr-1"].get("svn_io_get_dirents3", "cdecl")
    svn_io_get_dirents3.argtypes = [POINTER(POINTER(apr_hash_t)), String, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_get_dirents3.restype = POINTER(svn_error_t)
    svn_io_get_dirents3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1805
if _libs["svn_subr-1"].has("svn_io_get_dirents2", "cdecl"):
    svn_io_get_dirents2 = _libs["svn_subr-1"].get("svn_io_get_dirents2", "cdecl")
    svn_io_get_dirents2.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_io_get_dirents2.restype = POINTER(svn_error_t)
    svn_io_get_dirents2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1816
if _libs["svn_subr-1"].has("svn_io_get_dirents", "cdecl"):
    svn_io_get_dirents = _libs["svn_subr-1"].get("svn_io_get_dirents", "cdecl")
    svn_io_get_dirents.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_io_get_dirents.restype = POINTER(svn_error_t)
    svn_io_get_dirents.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1835
if _libs["svn_subr-1"].has("svn_io_stat_dirent2", "cdecl"):
    svn_io_stat_dirent2 = _libs["svn_subr-1"].get("svn_io_stat_dirent2", "cdecl")
    svn_io_stat_dirent2.argtypes = [POINTER(POINTER(svn_io_dirent2_t)), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_stat_dirent2.restype = POINTER(svn_error_t)
    svn_io_stat_dirent2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1851
if _libs["svn_subr-1"].has("svn_io_stat_dirent", "cdecl"):
    svn_io_stat_dirent = _libs["svn_subr-1"].get("svn_io_stat_dirent", "cdecl")
    svn_io_stat_dirent.argtypes = [POINTER(POINTER(svn_io_dirent2_t)), String, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_stat_dirent.restype = POINTER(svn_error_t)
    svn_io_stat_dirent.errcheck = _svn_errcheck

svn_io_walk_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_finfo_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1860

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1885
if _libs["svn_subr-1"].has("svn_io_dir_walk2", "cdecl"):
    svn_io_dir_walk2 = _libs["svn_subr-1"].get("svn_io_dir_walk2", "cdecl")
    svn_io_dir_walk2.argtypes = [String, apr_int32_t, svn_io_walk_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_io_dir_walk2.restype = POINTER(svn_error_t)
    svn_io_dir_walk2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1898
if _libs["svn_subr-1"].has("svn_io_dir_walk", "cdecl"):
    svn_io_dir_walk = _libs["svn_subr-1"].get("svn_io_dir_walk", "cdecl")
    svn_io_dir_walk.argtypes = [String, apr_int32_t, svn_io_walk_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_io_dir_walk.restype = POINTER(svn_error_t)
    svn_io_dir_walk.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1941
if _libs["svn_subr-1"].has("svn_io_start_cmd3", "cdecl"):
    svn_io_start_cmd3 = _libs["svn_subr-1"].get("svn_io_start_cmd3", "cdecl")
    svn_io_start_cmd3.argtypes = [POINTER(apr_proc_t), String, String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), svn_boolean_t, POINTER(apr_file_t), svn_boolean_t, POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_start_cmd3.restype = POINTER(svn_error_t)
    svn_io_start_cmd3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1963
if _libs["svn_subr-1"].has("svn_io_start_cmd2", "cdecl"):
    svn_io_start_cmd2 = _libs["svn_subr-1"].get("svn_io_start_cmd2", "cdecl")
    svn_io_start_cmd2.argtypes = [POINTER(apr_proc_t), String, String, POINTER(POINTER(c_char)), svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), svn_boolean_t, POINTER(apr_file_t), svn_boolean_t, POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_start_cmd2.restype = POINTER(svn_error_t)
    svn_io_start_cmd2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 1984
if _libs["svn_subr-1"].has("svn_io_start_cmd", "cdecl"):
    svn_io_start_cmd = _libs["svn_subr-1"].get("svn_io_start_cmd", "cdecl")
    svn_io_start_cmd.argtypes = [POINTER(apr_proc_t), String, String, POINTER(POINTER(c_char)), svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_start_cmd.restype = POINTER(svn_error_t)
    svn_io_start_cmd.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2011
if _libs["svn_subr-1"].has("svn_io_wait_for_cmd", "cdecl"):
    svn_io_wait_for_cmd = _libs["svn_subr-1"].get("svn_io_wait_for_cmd", "cdecl")
    svn_io_wait_for_cmd.argtypes = [POINTER(apr_proc_t), String, POINTER(c_int), POINTER(apr_exit_why_e), POINTER(apr_pool_t)]
    svn_io_wait_for_cmd.restype = POINTER(svn_error_t)
    svn_io_wait_for_cmd.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2022
if _libs["svn_subr-1"].has("svn_io_run_cmd", "cdecl"):
    svn_io_run_cmd = _libs["svn_subr-1"].get("svn_io_run_cmd", "cdecl")
    svn_io_run_cmd.argtypes = [String, String, POINTER(POINTER(c_char)), POINTER(c_int), POINTER(apr_exit_why_e), svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_run_cmd.restype = POINTER(svn_error_t)
    svn_io_run_cmd.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2054
if _libs["svn_subr-1"].has("svn_io_run_diff2", "cdecl"):
    svn_io_run_diff2 = _libs["svn_subr-1"].get("svn_io_run_diff2", "cdecl")
    svn_io_run_diff2.argtypes = [String, POINTER(POINTER(c_char)), c_int, String, String, String, String, POINTER(c_int), POINTER(apr_file_t), POINTER(apr_file_t), String, POINTER(apr_pool_t)]
    svn_io_run_diff2.restype = POINTER(svn_error_t)
    svn_io_run_diff2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2073
if _libs["svn_subr-1"].has("svn_io_run_diff", "cdecl"):
    svn_io_run_diff = _libs["svn_subr-1"].get("svn_io_run_diff", "cdecl")
    svn_io_run_diff.argtypes = [String, POINTER(POINTER(c_char)), c_int, String, String, String, String, POINTER(c_int), POINTER(apr_file_t), POINTER(apr_file_t), String, POINTER(apr_pool_t)]
    svn_io_run_diff.restype = POINTER(svn_error_t)
    svn_io_run_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2123
if _libs["svn_subr-1"].has("svn_io_run_diff3_3", "cdecl"):
    svn_io_run_diff3_3 = _libs["svn_subr-1"].get("svn_io_run_diff3_3", "cdecl")
    svn_io_run_diff3_3.argtypes = [POINTER(c_int), String, String, String, String, String, String, String, POINTER(apr_file_t), String, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_io_run_diff3_3.restype = POINTER(svn_error_t)
    svn_io_run_diff3_3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2144
if _libs["svn_subr-1"].has("svn_io_run_diff3_2", "cdecl"):
    svn_io_run_diff3_2 = _libs["svn_subr-1"].get("svn_io_run_diff3_2", "cdecl")
    svn_io_run_diff3_2.argtypes = [POINTER(c_int), String, String, String, String, String, String, String, POINTER(apr_file_t), String, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_io_run_diff3_2.restype = POINTER(svn_error_t)
    svn_io_run_diff3_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2163
if _libs["svn_subr-1"].has("svn_io_run_diff3", "cdecl"):
    svn_io_run_diff3 = _libs["svn_subr-1"].get("svn_io_run_diff3", "cdecl")
    svn_io_run_diff3.argtypes = [String, String, String, String, String, String, String, POINTER(apr_file_t), POINTER(c_int), String, POINTER(apr_pool_t)]
    svn_io_run_diff3.restype = POINTER(svn_error_t)
    svn_io_run_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2184
if _libs["svn_subr-1"].has("svn_io_parse_mimetypes_file", "cdecl"):
    svn_io_parse_mimetypes_file = _libs["svn_subr-1"].get("svn_io_parse_mimetypes_file", "cdecl")
    svn_io_parse_mimetypes_file.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_io_parse_mimetypes_file.restype = POINTER(svn_error_t)
    svn_io_parse_mimetypes_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2203
if _libs["svn_subr-1"].has("svn_io_detect_mimetype2", "cdecl"):
    svn_io_detect_mimetype2 = _libs["svn_subr-1"].get("svn_io_detect_mimetype2", "cdecl")
    svn_io_detect_mimetype2.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_io_detect_mimetype2.restype = POINTER(svn_error_t)
    svn_io_detect_mimetype2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2216
if _libs["svn_subr-1"].has("svn_io_detect_mimetype", "cdecl"):
    svn_io_detect_mimetype = _libs["svn_subr-1"].get("svn_io_detect_mimetype", "cdecl")
    svn_io_detect_mimetype.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_io_detect_mimetype.restype = POINTER(svn_error_t)
    svn_io_detect_mimetype.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2229
if _libs["svn_subr-1"].has("svn_io_is_binary_data", "cdecl"):
    svn_io_is_binary_data = _libs["svn_subr-1"].get("svn_io_is_binary_data", "cdecl")
    svn_io_is_binary_data.argtypes = [POINTER(None), apr_size_t]
    svn_io_is_binary_data.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2234
if _libs["svn_subr-1"].has("svn_io_file_open", "cdecl"):
    svn_io_file_open = _libs["svn_subr-1"].get("svn_io_file_open", "cdecl")
    svn_io_file_open.argtypes = [POINTER(POINTER(apr_file_t)), String, apr_int32_t, apr_fileperms_t, POINTER(apr_pool_t)]
    svn_io_file_open.restype = POINTER(svn_error_t)
    svn_io_file_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2243
if _libs["svn_subr-1"].has("svn_io_file_close", "cdecl"):
    svn_io_file_close = _libs["svn_subr-1"].get("svn_io_file_close", "cdecl")
    svn_io_file_close.argtypes = [POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_close.restype = POINTER(svn_error_t)
    svn_io_file_close.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2249
if _libs["svn_subr-1"].has("svn_io_file_getc", "cdecl"):
    svn_io_file_getc = _libs["svn_subr-1"].get("svn_io_file_getc", "cdecl")
    svn_io_file_getc.argtypes = [String, POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_getc.restype = POINTER(svn_error_t)
    svn_io_file_getc.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2258
if _libs["svn_subr-1"].has("svn_io_file_putc", "cdecl"):
    svn_io_file_putc = _libs["svn_subr-1"].get("svn_io_file_putc", "cdecl")
    svn_io_file_putc.argtypes = [c_char, POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_putc.restype = POINTER(svn_error_t)
    svn_io_file_putc.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2265
if _libs["svn_subr-1"].has("svn_io_file_info_get", "cdecl"):
    svn_io_file_info_get = _libs["svn_subr-1"].get("svn_io_file_info_get", "cdecl")
    svn_io_file_info_get.argtypes = [POINTER(apr_finfo_t), apr_int32_t, POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_info_get.restype = POINTER(svn_error_t)
    svn_io_file_info_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2280
if _libs["svn_subr-1"].has("svn_io_file_size_get", "cdecl"):
    svn_io_file_size_get = _libs["svn_subr-1"].get("svn_io_file_size_get", "cdecl")
    svn_io_file_size_get.argtypes = [POINTER(svn_filesize_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_size_get.restype = POINTER(svn_error_t)
    svn_io_file_size_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2289
if _libs["svn_subr-1"].has("svn_io_file_get_offset", "cdecl"):
    svn_io_file_get_offset = _libs["svn_subr-1"].get("svn_io_file_get_offset", "cdecl")
    svn_io_file_get_offset.argtypes = [POINTER(apr_off_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_get_offset.restype = POINTER(svn_error_t)
    svn_io_file_get_offset.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2295
if _libs["svn_subr-1"].has("svn_io_file_read", "cdecl"):
    svn_io_file_read = _libs["svn_subr-1"].get("svn_io_file_read", "cdecl")
    svn_io_file_read.argtypes = [POINTER(apr_file_t), POINTER(None), POINTER(apr_size_t), POINTER(apr_pool_t)]
    svn_io_file_read.restype = POINTER(svn_error_t)
    svn_io_file_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2309
if _libs["svn_subr-1"].has("svn_io_file_read_full2", "cdecl"):
    svn_io_file_read_full2 = _libs["svn_subr-1"].get("svn_io_file_read_full2", "cdecl")
    svn_io_file_read_full2.argtypes = [POINTER(apr_file_t), POINTER(None), apr_size_t, POINTER(apr_size_t), POINTER(svn_boolean_t), POINTER(apr_pool_t)]
    svn_io_file_read_full2.restype = POINTER(svn_error_t)
    svn_io_file_read_full2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2324
if _libs["svn_subr-1"].has("svn_io_file_read_full", "cdecl"):
    svn_io_file_read_full = _libs["svn_subr-1"].get("svn_io_file_read_full", "cdecl")
    svn_io_file_read_full.argtypes = [POINTER(apr_file_t), POINTER(None), apr_size_t, POINTER(apr_size_t), POINTER(apr_pool_t)]
    svn_io_file_read_full.restype = POINTER(svn_error_t)
    svn_io_file_read_full.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2333
if _libs["svn_subr-1"].has("svn_io_file_seek", "cdecl"):
    svn_io_file_seek = _libs["svn_subr-1"].get("svn_io_file_seek", "cdecl")
    svn_io_file_seek.argtypes = [POINTER(apr_file_t), apr_seek_where_t, POINTER(apr_off_t), POINTER(apr_pool_t)]
    svn_io_file_seek.restype = POINTER(svn_error_t)
    svn_io_file_seek.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2355
if _libs["svn_subr-1"].has("svn_io_file_aligned_seek", "cdecl"):
    svn_io_file_aligned_seek = _libs["svn_subr-1"].get("svn_io_file_aligned_seek", "cdecl")
    svn_io_file_aligned_seek.argtypes = [POINTER(apr_file_t), apr_off_t, POINTER(apr_off_t), apr_off_t, POINTER(apr_pool_t)]
    svn_io_file_aligned_seek.restype = POINTER(svn_error_t)
    svn_io_file_aligned_seek.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2363
if _libs["svn_subr-1"].has("svn_io_file_write", "cdecl"):
    svn_io_file_write = _libs["svn_subr-1"].get("svn_io_file_write", "cdecl")
    svn_io_file_write.argtypes = [POINTER(apr_file_t), POINTER(None), POINTER(apr_size_t), POINTER(apr_pool_t)]
    svn_io_file_write.restype = POINTER(svn_error_t)
    svn_io_file_write.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2372
if _libs["svn_subr-1"].has("svn_io_file_flush", "cdecl"):
    svn_io_file_flush = _libs["svn_subr-1"].get("svn_io_file_flush", "cdecl")
    svn_io_file_flush.argtypes = [POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_flush.restype = POINTER(svn_error_t)
    svn_io_file_flush.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2379
if _libs["svn_subr-1"].has("svn_io_file_write_full", "cdecl"):
    svn_io_file_write_full = _libs["svn_subr-1"].get("svn_io_file_write_full", "cdecl")
    svn_io_file_write_full.argtypes = [POINTER(apr_file_t), POINTER(None), apr_size_t, POINTER(apr_size_t), POINTER(apr_pool_t)]
    svn_io_file_write_full.restype = POINTER(svn_error_t)
    svn_io_file_write_full.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2404
if _libs["svn_subr-1"].has("svn_io_write_atomic2", "cdecl"):
    svn_io_write_atomic2 = _libs["svn_subr-1"].get("svn_io_write_atomic2", "cdecl")
    svn_io_write_atomic2.argtypes = [String, POINTER(None), apr_size_t, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_write_atomic2.restype = POINTER(svn_error_t)
    svn_io_write_atomic2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2420
if _libs["svn_subr-1"].has("svn_io_write_atomic", "cdecl"):
    svn_io_write_atomic = _libs["svn_subr-1"].get("svn_io_write_atomic", "cdecl")
    svn_io_write_atomic.argtypes = [String, POINTER(None), apr_size_t, String, POINTER(apr_pool_t)]
    svn_io_write_atomic.restype = POINTER(svn_error_t)
    svn_io_write_atomic.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2441
if _libs["svn_subr-1"].has("svn_io_write_unique", "cdecl"):
    svn_io_write_unique = _libs["svn_subr-1"].get("svn_io_write_unique", "cdecl")
    svn_io_write_unique.argtypes = [POINTER(POINTER(c_char)), String, POINTER(None), apr_size_t, svn_io_file_del_t, POINTER(apr_pool_t)]
    svn_io_write_unique.restype = POINTER(svn_error_t)
    svn_io_write_unique.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2451
if _libs["svn_subr-1"].has("svn_io_file_trunc", "cdecl"):
    svn_io_file_trunc = _libs["svn_subr-1"].get("svn_io_file_trunc", "cdecl")
    svn_io_file_trunc.argtypes = [POINTER(apr_file_t), apr_off_t, POINTER(apr_pool_t)]
    svn_io_file_trunc.restype = POINTER(svn_error_t)
    svn_io_file_trunc.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2458
if _libs["svn_subr-1"].has("svn_io_stat", "cdecl"):
    svn_io_stat = _libs["svn_subr-1"].get("svn_io_stat", "cdecl")
    svn_io_stat.argtypes = [POINTER(apr_finfo_t), String, apr_int32_t, POINTER(apr_pool_t)]
    svn_io_stat.restype = POINTER(svn_error_t)
    svn_io_stat.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2479
if _libs["svn_subr-1"].has("svn_io_file_rename2", "cdecl"):
    svn_io_file_rename2 = _libs["svn_subr-1"].get("svn_io_file_rename2", "cdecl")
    svn_io_file_rename2.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_io_file_rename2.restype = POINTER(svn_error_t)
    svn_io_file_rename2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2489
if _libs["svn_subr-1"].has("svn_io_file_rename", "cdecl"):
    svn_io_file_rename = _libs["svn_subr-1"].get("svn_io_file_rename", "cdecl")
    svn_io_file_rename.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_file_rename.restype = POINTER(svn_error_t)
    svn_io_file_rename.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2503
if _libs["svn_subr-1"].has("svn_io_file_move", "cdecl"):
    svn_io_file_move = _libs["svn_subr-1"].get("svn_io_file_move", "cdecl")
    svn_io_file_move.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_io_file_move.restype = POINTER(svn_error_t)
    svn_io_file_move.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2510
if _libs["svn_subr-1"].has("svn_io_dir_make", "cdecl"):
    svn_io_dir_make = _libs["svn_subr-1"].get("svn_io_dir_make", "cdecl")
    svn_io_dir_make.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    svn_io_dir_make.restype = POINTER(svn_error_t)
    svn_io_dir_make.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2517
if _libs["svn_subr-1"].has("svn_io_dir_make_hidden", "cdecl"):
    svn_io_dir_make_hidden = _libs["svn_subr-1"].get("svn_io_dir_make_hidden", "cdecl")
    svn_io_dir_make_hidden.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    svn_io_dir_make_hidden.restype = POINTER(svn_error_t)
    svn_io_dir_make_hidden.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2532
if _libs["svn_subr-1"].has("svn_io_dir_make_sgid", "cdecl"):
    svn_io_dir_make_sgid = _libs["svn_subr-1"].get("svn_io_dir_make_sgid", "cdecl")
    svn_io_dir_make_sgid.argtypes = [String, apr_fileperms_t, POINTER(apr_pool_t)]
    svn_io_dir_make_sgid.restype = POINTER(svn_error_t)
    svn_io_dir_make_sgid.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2538
if _libs["svn_subr-1"].has("svn_io_dir_open", "cdecl"):
    svn_io_dir_open = _libs["svn_subr-1"].get("svn_io_dir_open", "cdecl")
    svn_io_dir_open.argtypes = [POINTER(POINTER(apr_dir_t)), String, POINTER(apr_pool_t)]
    svn_io_dir_open.restype = POINTER(svn_error_t)
    svn_io_dir_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2547
if _libs["svn_subr-1"].has("svn_io_dir_close", "cdecl"):
    svn_io_dir_close = _libs["svn_subr-1"].get("svn_io_dir_close", "cdecl")
    svn_io_dir_close.argtypes = [POINTER(apr_dir_t)]
    svn_io_dir_close.restype = POINTER(svn_error_t)
    svn_io_dir_close.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2554
if _libs["svn_subr-1"].has("svn_io_dir_remove_nonrecursive", "cdecl"):
    svn_io_dir_remove_nonrecursive = _libs["svn_subr-1"].get("svn_io_dir_remove_nonrecursive", "cdecl")
    svn_io_dir_remove_nonrecursive.argtypes = [String, POINTER(apr_pool_t)]
    svn_io_dir_remove_nonrecursive.restype = POINTER(svn_error_t)
    svn_io_dir_remove_nonrecursive.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2564
if _libs["svn_subr-1"].has("svn_io_dir_read", "cdecl"):
    svn_io_dir_read = _libs["svn_subr-1"].get("svn_io_dir_read", "cdecl")
    svn_io_dir_read.argtypes = [POINTER(apr_finfo_t), apr_int32_t, POINTER(apr_dir_t), POINTER(apr_pool_t)]
    svn_io_dir_read.restype = POINTER(svn_error_t)
    svn_io_dir_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2575
if _libs["svn_subr-1"].has("svn_io_file_name_get", "cdecl"):
    svn_io_file_name_get = _libs["svn_subr-1"].get("svn_io_file_name_get", "cdecl")
    svn_io_file_name_get.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_io_file_name_get.restype = POINTER(svn_error_t)
    svn_io_file_name_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2593
if _libs["svn_subr-1"].has("svn_io_read_version_file", "cdecl"):
    svn_io_read_version_file = _libs["svn_subr-1"].get("svn_io_read_version_file", "cdecl")
    svn_io_read_version_file.argtypes = [POINTER(c_int), String, POINTER(apr_pool_t)]
    svn_io_read_version_file.restype = POINTER(svn_error_t)
    svn_io_read_version_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2603
if _libs["svn_subr-1"].has("svn_io_write_version_file", "cdecl"):
    svn_io_write_version_file = _libs["svn_subr-1"].get("svn_io_write_version_file", "cdecl")
    svn_io_write_version_file.argtypes = [String, c_int, POINTER(apr_pool_t)]
    svn_io_write_version_file.restype = POINTER(svn_error_t)
    svn_io_write_version_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 2629
if _libs["svn_subr-1"].has("svn_io_file_readline", "cdecl"):
    svn_io_file_readline = _libs["svn_subr-1"].get("svn_io_file_readline", "cdecl")
    svn_io_file_readline.argtypes = [POINTER(apr_file_t), POINTER(POINTER(svn_stringbuf_t)), POINTER(POINTER(c_char)), POINTER(svn_boolean_t), apr_size_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_io_file_readline.restype = POINTER(svn_error_t)
    svn_io_file_readline.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 54
class struct_svn_config_t(Structure):
    pass

svn_config_t = struct_svn_config_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 54

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 253
if _libs["svn_subr-1"].has("svn_config_get_config", "cdecl"):
    svn_config_get_config = _libs["svn_subr-1"].get("svn_config_get_config", "cdecl")
    svn_config_get_config.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_config_get_config.restype = POINTER(svn_error_t)
    svn_config_get_config.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 269
if _libs["svn_subr-1"].has("svn_config_create2", "cdecl"):
    svn_config_create2 = _libs["svn_subr-1"].get("svn_config_create2", "cdecl")
    svn_config_create2.argtypes = [POINTER(POINTER(svn_config_t)), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_create2.restype = POINTER(svn_error_t)
    svn_config_create2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 282
if _libs["svn_subr-1"].has("svn_config_create", "cdecl"):
    svn_config_create = _libs["svn_subr-1"].get("svn_config_create", "cdecl")
    svn_config_create.argtypes = [POINTER(POINTER(svn_config_t)), svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_create.restype = POINTER(svn_error_t)
    svn_config_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 301
if _libs["svn_subr-1"].has("svn_config_read3", "cdecl"):
    svn_config_read3 = _libs["svn_subr-1"].get("svn_config_read3", "cdecl")
    svn_config_read3.argtypes = [POINTER(POINTER(svn_config_t)), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_read3.restype = POINTER(svn_error_t)
    svn_config_read3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 316
if _libs["svn_subr-1"].has("svn_config_read2", "cdecl"):
    svn_config_read2 = _libs["svn_subr-1"].get("svn_config_read2", "cdecl")
    svn_config_read2.argtypes = [POINTER(POINTER(svn_config_t)), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_read2.restype = POINTER(svn_error_t)
    svn_config_read2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 329
if _libs["svn_subr-1"].has("svn_config_read", "cdecl"):
    svn_config_read = _libs["svn_subr-1"].get("svn_config_read", "cdecl")
    svn_config_read.argtypes = [POINTER(POINTER(svn_config_t)), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_read.restype = POINTER(svn_error_t)
    svn_config_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 347
if _libs["svn_subr-1"].has("svn_config_parse", "cdecl"):
    svn_config_parse = _libs["svn_subr-1"].get("svn_config_parse", "cdecl")
    svn_config_parse.argtypes = [POINTER(POINTER(svn_config_t)), POINTER(svn_stream_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_config_parse.restype = POINTER(svn_error_t)
    svn_config_parse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 360
if _libs["svn_subr-1"].has("svn_config_merge", "cdecl"):
    svn_config_merge = _libs["svn_subr-1"].get("svn_config_merge", "cdecl")
    svn_config_merge.argtypes = [POINTER(svn_config_t), String, svn_boolean_t]
    svn_config_merge.restype = POINTER(svn_error_t)
    svn_config_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 380
if _libs["svn_subr-1"].has("svn_config_get", "cdecl"):
    svn_config_get = _libs["svn_subr-1"].get("svn_config_get", "cdecl")
    svn_config_get.argtypes = [POINTER(svn_config_t), POINTER(POINTER(c_char)), String, String, String]
    svn_config_get.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 394
if _libs["svn_subr-1"].has("svn_config_set", "cdecl"):
    svn_config_set = _libs["svn_subr-1"].get("svn_config_set", "cdecl")
    svn_config_set.argtypes = [POINTER(svn_config_t), String, String, String]
    svn_config_set.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 405
if _libs["svn_subr-1"].has("svn_config_get_bool", "cdecl"):
    svn_config_get_bool = _libs["svn_subr-1"].get("svn_config_get_bool", "cdecl")
    svn_config_get_bool.argtypes = [POINTER(svn_config_t), POINTER(svn_boolean_t), String, String, svn_boolean_t]
    svn_config_get_bool.restype = POINTER(svn_error_t)
    svn_config_get_bool.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 417
if _libs["svn_subr-1"].has("svn_config_set_bool", "cdecl"):
    svn_config_set_bool = _libs["svn_subr-1"].get("svn_config_set_bool", "cdecl")
    svn_config_set_bool.argtypes = [POINTER(svn_config_t), String, String, svn_boolean_t]
    svn_config_set_bool.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 431
if _libs["svn_subr-1"].has("svn_config_get_int64", "cdecl"):
    svn_config_get_int64 = _libs["svn_subr-1"].get("svn_config_get_int64", "cdecl")
    svn_config_get_int64.argtypes = [POINTER(svn_config_t), POINTER(c_int64), String, String, c_int64]
    svn_config_get_int64.restype = POINTER(svn_error_t)
    svn_config_get_int64.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 446
if _libs["svn_subr-1"].has("svn_config_set_int64", "cdecl"):
    svn_config_set_int64 = _libs["svn_subr-1"].get("svn_config_set_int64", "cdecl")
    svn_config_set_int64.argtypes = [POINTER(svn_config_t), String, String, c_int64]
    svn_config_set_int64.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 467
if _libs["svn_subr-1"].has("svn_config_get_yes_no_ask", "cdecl"):
    svn_config_get_yes_no_ask = _libs["svn_subr-1"].get("svn_config_get_yes_no_ask", "cdecl")
    svn_config_get_yes_no_ask.argtypes = [POINTER(svn_config_t), POINTER(POINTER(c_char)), String, String, String]
    svn_config_get_yes_no_ask.restype = POINTER(svn_error_t)
    svn_config_get_yes_no_ask.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 487
if _libs["svn_subr-1"].has("svn_config_get_tristate", "cdecl"):
    svn_config_get_tristate = _libs["svn_subr-1"].get("svn_config_get_tristate", "cdecl")
    svn_config_get_tristate.argtypes = [POINTER(svn_config_t), POINTER(svn_tristate_t), String, String, String, svn_tristate_t]
    svn_config_get_tristate.restype = POINTER(svn_error_t)
    svn_config_get_tristate.errcheck = _svn_errcheck

svn_config_section_enumerator_t = CFUNCTYPE(UNCHECKED(svn_boolean_t), String, POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 502

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 512
if _libs["svn_subr-1"].has("svn_config_enumerate_sections", "cdecl"):
    svn_config_enumerate_sections = _libs["svn_subr-1"].get("svn_config_enumerate_sections", "cdecl")
    svn_config_enumerate_sections.argtypes = [POINTER(svn_config_t), svn_config_section_enumerator_t, POINTER(None)]
    svn_config_enumerate_sections.restype = c_int

svn_config_section_enumerator2_t = CFUNCTYPE(UNCHECKED(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 522

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 538
if _libs["svn_subr-1"].has("svn_config_enumerate_sections2", "cdecl"):
    svn_config_enumerate_sections2 = _libs["svn_subr-1"].get("svn_config_enumerate_sections2", "cdecl")
    svn_config_enumerate_sections2.argtypes = [POINTER(svn_config_t), svn_config_section_enumerator2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_config_enumerate_sections2.restype = c_int

svn_config_enumerator_t = CFUNCTYPE(UNCHECKED(svn_boolean_t), String, String, POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 548

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 559
if _libs["svn_subr-1"].has("svn_config_enumerate", "cdecl"):
    svn_config_enumerate = _libs["svn_subr-1"].get("svn_config_enumerate", "cdecl")
    svn_config_enumerate.argtypes = [POINTER(svn_config_t), String, svn_config_enumerator_t, POINTER(None)]
    svn_config_enumerate.restype = c_int

svn_config_enumerator2_t = CFUNCTYPE(UNCHECKED(svn_boolean_t), String, String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 571

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 595
if _libs["svn_subr-1"].has("svn_config_enumerate2", "cdecl"):
    svn_config_enumerate2 = _libs["svn_subr-1"].get("svn_config_enumerate2", "cdecl")
    svn_config_enumerate2.argtypes = [POINTER(svn_config_t), String, svn_config_enumerator2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_config_enumerate2.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 607
if _libs["svn_subr-1"].has("svn_config_has_section", "cdecl"):
    svn_config_has_section = _libs["svn_subr-1"].get("svn_config_has_section", "cdecl")
    svn_config_has_section.argtypes = [POINTER(svn_config_t), String]
    svn_config_has_section.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 615
if _libs["svn_subr-1"].has("svn_config_find_group", "cdecl"):
    svn_config_find_group = _libs["svn_subr-1"].get("svn_config_find_group", "cdecl")
    svn_config_find_group.argtypes = [POINTER(svn_config_t), String, String, POINTER(apr_pool_t)]
    svn_config_find_group.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 629
if _libs["svn_subr-1"].has("svn_config_get_server_setting", "cdecl"):
    svn_config_get_server_setting = _libs["svn_subr-1"].get("svn_config_get_server_setting", "cdecl")
    svn_config_get_server_setting.argtypes = [POINTER(svn_config_t), String, String, String]
    svn_config_get_server_setting.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 643
if _libs["svn_subr-1"].has("svn_config_get_server_setting_int", "cdecl"):
    svn_config_get_server_setting_int = _libs["svn_subr-1"].get("svn_config_get_server_setting_int", "cdecl")
    svn_config_get_server_setting_int.argtypes = [POINTER(svn_config_t), String, String, c_int64, POINTER(c_int64), POINTER(apr_pool_t)]
    svn_config_get_server_setting_int.restype = POINTER(svn_error_t)
    svn_config_get_server_setting_int.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 662
if _libs["svn_subr-1"].has("svn_config_get_server_setting_bool", "cdecl"):
    svn_config_get_server_setting_bool = _libs["svn_subr-1"].get("svn_config_get_server_setting_bool", "cdecl")
    svn_config_get_server_setting_bool.argtypes = [POINTER(svn_config_t), POINTER(svn_boolean_t), String, String, svn_boolean_t]
    svn_config_get_server_setting_bool.restype = POINTER(svn_error_t)
    svn_config_get_server_setting_bool.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 685
if _libs["svn_subr-1"].has("svn_config_ensure", "cdecl"):
    svn_config_ensure = _libs["svn_subr-1"].get("svn_config_ensure", "cdecl")
    svn_config_ensure.argtypes = [String, POINTER(apr_pool_t)]
    svn_config_ensure.restype = POINTER(svn_error_t)
    svn_config_ensure.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 775
if _libs["svn_subr-1"].has("svn_config_read_auth_data", "cdecl"):
    svn_config_read_auth_data = _libs["svn_subr-1"].get("svn_config_read_auth_data", "cdecl")
    svn_config_read_auth_data.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, String, POINTER(apr_pool_t)]
    svn_config_read_auth_data.restype = POINTER(svn_error_t)
    svn_config_read_auth_data.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 794
if _libs["svn_subr-1"].has("svn_config_write_auth_data", "cdecl"):
    svn_config_write_auth_data = _libs["svn_subr-1"].get("svn_config_write_auth_data", "cdecl")
    svn_config_write_auth_data.argtypes = [POINTER(apr_hash_t), String, String, String, POINTER(apr_pool_t)]
    svn_config_write_auth_data.restype = POINTER(svn_error_t)
    svn_config_write_auth_data.errcheck = _svn_errcheck

svn_config_auth_walk_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(None), String, String, POINTER(apr_hash_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 823

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 859
if _libs["svn_subr-1"].has("svn_config_walk_auth_data", "cdecl"):
    svn_config_walk_auth_data = _libs["svn_subr-1"].get("svn_config_walk_auth_data", "cdecl")
    svn_config_walk_auth_data.argtypes = [String, svn_config_auth_walk_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_config_walk_auth_data.restype = POINTER(svn_error_t)
    svn_config_walk_auth_data.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 883
if _libs["svn_subr-1"].has("svn_config_get_user_config_path", "cdecl"):
    svn_config_get_user_config_path = _libs["svn_subr-1"].get("svn_config_get_user_config_path", "cdecl")
    svn_config_get_user_config_path.argtypes = [POINTER(POINTER(c_char)), String, String, POINTER(apr_pool_t)]
    svn_config_get_user_config_path.restype = POINTER(svn_error_t)
    svn_config_get_user_config_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 894
if _libs["svn_subr-1"].has("svn_config_dup", "cdecl"):
    svn_config_dup = _libs["svn_subr-1"].get("svn_config_dup", "cdecl")
    svn_config_dup.argtypes = [POINTER(POINTER(svn_config_t)), POINTER(svn_config_t), POINTER(apr_pool_t)]
    svn_config_dup.restype = POINTER(svn_error_t)
    svn_config_dup.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 904
if _libs["svn_subr-1"].has("svn_config_copy_config", "cdecl"):
    svn_config_copy_config = _libs["svn_subr-1"].get("svn_config_copy_config", "cdecl")
    svn_config_copy_config.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_config_copy_config.restype = POINTER(svn_error_t)
    svn_config_copy_config.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 87
class struct_svn_auth_baton_t(Structure):
    pass

svn_auth_baton_t = struct_svn_auth_baton_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 87

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 90
class struct_svn_auth_iterstate_t(Structure):
    pass

svn_auth_iterstate_t = struct_svn_auth_iterstate_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 90

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 153
class struct_svn_auth_provider_t(Structure):
    pass

struct_svn_auth_provider_t.__slots__ = [
    'cred_kind',
    'first_credentials',
    'next_credentials',
    'save_credentials',
]
struct_svn_auth_provider_t._fields_ = [
    ('cred_kind', String),
    ('first_credentials', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(POINTER(None)), POINTER(None), POINTER(apr_hash_t), String, POINTER(apr_pool_t))),
    ('next_credentials', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(None), POINTER(None), POINTER(apr_hash_t), String, POINTER(apr_pool_t))),
    ('save_credentials', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(None), POINTER(None), POINTER(apr_hash_t), String, POINTER(apr_pool_t))),
]

svn_auth_provider_t = struct_svn_auth_provider_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 153

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 163
class struct_svn_auth_provider_object_t(Structure):
    pass

struct_svn_auth_provider_object_t.__slots__ = [
    'vtable',
    'provider_baton',
]
struct_svn_auth_provider_object_t._fields_ = [
    ('vtable', POINTER(svn_auth_provider_t)),
    ('provider_baton', POINTER(None)),
]

svn_auth_provider_object_t = struct_svn_auth_provider_object_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 163

svn_auth_simple_provider_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 166

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 200
class struct_svn_auth_cred_simple_t(Structure):
    pass

struct_svn_auth_cred_simple_t.__slots__ = [
    'username',
    'password',
    'may_save',
]
struct_svn_auth_cred_simple_t._fields_ = [
    ('username', String),
    ('password', String),
    ('may_save', svn_boolean_t),
]

svn_auth_cred_simple_t = struct_svn_auth_cred_simple_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 200

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 222
class struct_svn_auth_cred_username_t(Structure):
    pass

struct_svn_auth_cred_username_t.__slots__ = [
    'username',
    'may_save',
]
struct_svn_auth_cred_username_t._fields_ = [
    ('username', String),
    ('may_save', svn_boolean_t),
]

svn_auth_cred_username_t = struct_svn_auth_cred_username_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 222

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 248
class struct_svn_auth_cred_ssl_client_cert_t(Structure):
    pass

struct_svn_auth_cred_ssl_client_cert_t.__slots__ = [
    'cert_file',
    'may_save',
]
struct_svn_auth_cred_ssl_client_cert_t._fields_ = [
    ('cert_file', String),
    ('may_save', svn_boolean_t),
]

svn_auth_cred_ssl_client_cert_t = struct_svn_auth_cred_ssl_client_cert_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 248

svn_auth_ssl_client_cert_pw_provider_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 252

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 283
class struct_svn_auth_cred_ssl_client_cert_pw_t(Structure):
    pass

struct_svn_auth_cred_ssl_client_cert_pw_t.__slots__ = [
    'password',
    'may_save',
]
struct_svn_auth_cred_ssl_client_cert_pw_t._fields_ = [
    ('password', String),
    ('may_save', svn_boolean_t),
]

svn_auth_cred_ssl_client_cert_pw_t = struct_svn_auth_cred_ssl_client_cert_pw_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 283

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 319
class struct_svn_auth_ssl_server_cert_info_t(Structure):
    pass

struct_svn_auth_ssl_server_cert_info_t.__slots__ = [
    'hostname',
    'fingerprint',
    'valid_from',
    'valid_until',
    'issuer_dname',
    'ascii_cert',
]
struct_svn_auth_ssl_server_cert_info_t._fields_ = [
    ('hostname', String),
    ('fingerprint', String),
    ('valid_from', String),
    ('valid_until', String),
    ('issuer_dname', String),
    ('ascii_cert', String),
]

svn_auth_ssl_server_cert_info_t = struct_svn_auth_ssl_server_cert_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 319

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 326
if _libs["svn_subr-1"].has("svn_auth_ssl_server_cert_info_dup", "cdecl"):
    svn_auth_ssl_server_cert_info_dup = _libs["svn_subr-1"].get("svn_auth_ssl_server_cert_info_dup", "cdecl")
    svn_auth_ssl_server_cert_info_dup.argtypes = [POINTER(svn_auth_ssl_server_cert_info_t), POINTER(apr_pool_t)]
    svn_auth_ssl_server_cert_info_dup.restype = POINTER(svn_auth_ssl_server_cert_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 340
class struct_svn_auth_cred_ssl_server_trust_t(Structure):
    pass

struct_svn_auth_cred_ssl_server_trust_t.__slots__ = [
    'may_save',
    'accepted_failures',
]
struct_svn_auth_cred_ssl_server_trust_t._fields_ = [
    ('may_save', svn_boolean_t),
    ('accepted_failures', apr_uint32_t),
]

svn_auth_cred_ssl_server_trust_t = struct_svn_auth_cred_ssl_server_trust_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 340

svn_auth_simple_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_auth_cred_simple_t)), POINTER(None), String, String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 376

svn_auth_username_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_auth_cred_username_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 396

svn_auth_ssl_server_trust_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_auth_cred_ssl_server_trust_t)), POINTER(None), String, apr_uint32_t, POINTER(svn_auth_ssl_server_cert_info_t), svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 439

svn_auth_ssl_client_cert_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_auth_cred_ssl_client_cert_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 459

svn_auth_ssl_client_cert_pw_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_auth_cred_ssl_client_cert_pw_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 477

svn_auth_plaintext_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 497

svn_auth_plaintext_passphrase_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 516

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 534
if _libs["svn_subr-1"].has("svn_auth_open", "cdecl"):
    svn_auth_open = _libs["svn_subr-1"].get("svn_auth_open", "cdecl")
    svn_auth_open.argtypes = [POINTER(POINTER(svn_auth_baton_t)), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_auth_open.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 546
if _libs["svn_subr-1"].has("svn_auth_set_parameter", "cdecl"):
    svn_auth_set_parameter = _libs["svn_subr-1"].get("svn_auth_set_parameter", "cdecl")
    svn_auth_set_parameter.argtypes = [POINTER(svn_auth_baton_t), String, POINTER(None)]
    svn_auth_set_parameter.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 555
if _libs["svn_subr-1"].has("svn_auth_get_parameter", "cdecl"):
    svn_auth_get_parameter = _libs["svn_subr-1"].get("svn_auth_get_parameter", "cdecl")
    svn_auth_get_parameter.argtypes = [POINTER(svn_auth_baton_t), String]
    svn_auth_get_parameter.restype = POINTER(c_ubyte)
    svn_auth_get_parameter.errcheck = lambda v,*a : cast(v, c_void_p)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 663
if _libs["svn_subr-1"].has("svn_auth_first_credentials", "cdecl"):
    svn_auth_first_credentials = _libs["svn_subr-1"].get("svn_auth_first_credentials", "cdecl")
    svn_auth_first_credentials.argtypes = [POINTER(POINTER(None)), POINTER(POINTER(svn_auth_iterstate_t)), String, String, POINTER(svn_auth_baton_t), POINTER(apr_pool_t)]
    svn_auth_first_credentials.restype = POINTER(svn_error_t)
    svn_auth_first_credentials.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 681
if _libs["svn_subr-1"].has("svn_auth_next_credentials", "cdecl"):
    svn_auth_next_credentials = _libs["svn_subr-1"].get("svn_auth_next_credentials", "cdecl")
    svn_auth_next_credentials.argtypes = [POINTER(POINTER(None)), POINTER(svn_auth_iterstate_t), POINTER(apr_pool_t)]
    svn_auth_next_credentials.restype = POINTER(svn_error_t)
    svn_auth_next_credentials.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 694
if _libs["svn_subr-1"].has("svn_auth_save_credentials", "cdecl"):
    svn_auth_save_credentials = _libs["svn_subr-1"].get("svn_auth_save_credentials", "cdecl")
    svn_auth_save_credentials.argtypes = [POINTER(svn_auth_iterstate_t), POINTER(apr_pool_t)]
    svn_auth_save_credentials.restype = POINTER(svn_error_t)
    svn_auth_save_credentials.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 714
if _libs["svn_subr-1"].has("svn_auth_forget_credentials", "cdecl"):
    svn_auth_forget_credentials = _libs["svn_subr-1"].get("svn_auth_forget_credentials", "cdecl")
    svn_auth_forget_credentials.argtypes = [POINTER(svn_auth_baton_t), String, String, POINTER(apr_pool_t)]
    svn_auth_forget_credentials.restype = POINTER(svn_error_t)
    svn_auth_forget_credentials.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 738
if _libs["svn_subr-1"].has("svn_auth_get_simple_prompt_provider", "cdecl"):
    svn_auth_get_simple_prompt_provider = _libs["svn_subr-1"].get("svn_auth_get_simple_prompt_provider", "cdecl")
    svn_auth_get_simple_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_simple_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_auth_get_simple_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 760
if _libs["svn_subr-1"].has("svn_auth_get_username_prompt_provider", "cdecl"):
    svn_auth_get_username_prompt_provider = _libs["svn_subr-1"].get("svn_auth_get_username_prompt_provider", "cdecl")
    svn_auth_get_username_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_username_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_auth_get_username_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 800
if _libs["svn_subr-1"].has("svn_auth_get_simple_provider2", "cdecl"):
    svn_auth_get_simple_provider2 = _libs["svn_subr-1"].get("svn_auth_get_simple_provider2", "cdecl")
    svn_auth_get_simple_provider2.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_plaintext_prompt_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_auth_get_simple_provider2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 815
if _libs["svn_subr-1"].has("svn_auth_get_simple_provider", "cdecl"):
    svn_auth_get_simple_provider = _libs["svn_subr-1"].get("svn_auth_get_simple_provider", "cdecl")
    svn_auth_get_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_simple_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 837
if _libs["svn_subr-1"].has("svn_auth_get_platform_specific_provider", "cdecl"):
    svn_auth_get_platform_specific_provider = _libs["svn_subr-1"].get("svn_auth_get_platform_specific_provider", "cdecl")
    svn_auth_get_platform_specific_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), String, String, POINTER(apr_pool_t)]
    svn_auth_get_platform_specific_provider.restype = POINTER(svn_error_t)
    svn_auth_get_platform_specific_provider.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 862
if _libs["svn_subr-1"].has("svn_auth_get_platform_specific_client_providers", "cdecl"):
    svn_auth_get_platform_specific_client_providers = _libs["svn_subr-1"].get("svn_auth_get_platform_specific_client_providers", "cdecl")
    svn_auth_get_platform_specific_client_providers.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_config_t), POINTER(apr_pool_t)]
    svn_auth_get_platform_specific_client_providers.restype = POINTER(svn_error_t)
    svn_auth_get_platform_specific_client_providers.errcheck = _svn_errcheck

svn_auth_gnome_keyring_unlock_prompt_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(c_char)), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1004

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1030
for _lib in _libs.values():
    if not _lib.has("svn_auth_gnome_keyring_version", "cdecl"):
        continue
    svn_auth_gnome_keyring_version = _lib.get("svn_auth_gnome_keyring_version", "cdecl")
    svn_auth_gnome_keyring_version.argtypes = []
    svn_auth_gnome_keyring_version.restype = POINTER(svn_version_t)
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1060
for _lib in _libs.values():
    if not _lib.has("svn_auth_get_gnome_keyring_simple_provider", "cdecl"):
        continue
    svn_auth_get_gnome_keyring_simple_provider = _lib.get("svn_auth_get_gnome_keyring_simple_provider", "cdecl")
    svn_auth_get_gnome_keyring_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_gnome_keyring_simple_provider.restype = None
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1091
for _lib in _libs.values():
    if not _lib.has("svn_auth_get_gnome_keyring_ssl_client_cert_pw_provider", "cdecl"):
        continue
    svn_auth_get_gnome_keyring_ssl_client_cert_pw_provider = _lib.get("svn_auth_get_gnome_keyring_ssl_client_cert_pw_provider", "cdecl")
    svn_auth_get_gnome_keyring_ssl_client_cert_pw_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_gnome_keyring_ssl_client_cert_pw_provider.restype = None
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1101
for _lib in _libs.values():
    if not _lib.has("svn_auth_kwallet_version", "cdecl"):
        continue
    svn_auth_kwallet_version = _lib.get("svn_auth_kwallet_version", "cdecl")
    svn_auth_kwallet_version.argtypes = []
    svn_auth_kwallet_version.restype = POINTER(svn_version_t)
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1123
for _lib in _libs.values():
    if not _lib.has("svn_auth_get_kwallet_simple_provider", "cdecl"):
        continue
    svn_auth_get_kwallet_simple_provider = _lib.get("svn_auth_get_kwallet_simple_provider", "cdecl")
    svn_auth_get_kwallet_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_kwallet_simple_provider.restype = None
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1145
for _lib in _libs.values():
    if not _lib.has("svn_auth_get_kwallet_ssl_client_cert_pw_provider", "cdecl"):
        continue
    svn_auth_get_kwallet_ssl_client_cert_pw_provider = _lib.get("svn_auth_get_kwallet_ssl_client_cert_pw_provider", "cdecl")
    svn_auth_get_kwallet_ssl_client_cert_pw_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_kwallet_ssl_client_cert_pw_provider.restype = None
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1171
if _libs["svn_subr-1"].has("svn_auth_get_gpg_agent_simple_provider", "cdecl"):
    svn_auth_get_gpg_agent_simple_provider = _libs["svn_subr-1"].get("svn_auth_get_gpg_agent_simple_provider", "cdecl")
    svn_auth_get_gpg_agent_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_gpg_agent_simple_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1189
if _libs["svn_subr-1"].has("svn_auth_get_username_provider", "cdecl"):
    svn_auth_get_username_provider = _libs["svn_subr-1"].get("svn_auth_get_username_provider", "cdecl")
    svn_auth_get_username_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_username_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1203
if _libs["svn_subr-1"].has("svn_auth_get_ssl_server_trust_file_provider", "cdecl"):
    svn_auth_get_ssl_server_trust_file_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_server_trust_file_provider", "cdecl")
    svn_auth_get_ssl_server_trust_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_ssl_server_trust_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1217
if _libs["svn_subr-1"].has("svn_auth_get_ssl_client_cert_file_provider", "cdecl"):
    svn_auth_get_ssl_client_cert_file_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_client_cert_file_provider", "cdecl")
    svn_auth_get_ssl_client_cert_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_ssl_client_cert_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1245
if _libs["svn_subr-1"].has("svn_auth_get_ssl_client_cert_pw_file_provider2", "cdecl"):
    svn_auth_get_ssl_client_cert_pw_file_provider2 = _libs["svn_subr-1"].get("svn_auth_get_ssl_client_cert_pw_file_provider2", "cdecl")
    svn_auth_get_ssl_client_cert_pw_file_provider2.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_plaintext_passphrase_prompt_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_auth_get_ssl_client_cert_pw_file_provider2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1261
if _libs["svn_subr-1"].has("svn_auth_get_ssl_client_cert_pw_file_provider", "cdecl"):
    svn_auth_get_ssl_client_cert_pw_file_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_client_cert_pw_file_provider", "cdecl")
    svn_auth_get_ssl_client_cert_pw_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_auth_get_ssl_client_cert_pw_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1276
if _libs["svn_subr-1"].has("svn_auth_get_ssl_server_trust_prompt_provider", "cdecl"):
    svn_auth_get_ssl_server_trust_prompt_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_server_trust_prompt_provider", "cdecl")
    svn_auth_get_ssl_server_trust_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_server_trust_prompt_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_auth_get_ssl_server_trust_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1295
if _libs["svn_subr-1"].has("svn_auth_get_ssl_client_cert_prompt_provider", "cdecl"):
    svn_auth_get_ssl_client_cert_prompt_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_client_cert_prompt_provider", "cdecl")
    svn_auth_get_ssl_client_cert_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_client_cert_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_auth_get_ssl_client_cert_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1315
if _libs["svn_subr-1"].has("svn_auth_get_ssl_client_cert_pw_prompt_provider", "cdecl"):
    svn_auth_get_ssl_client_cert_pw_prompt_provider = _libs["svn_subr-1"].get("svn_auth_get_ssl_client_cert_pw_prompt_provider", "cdecl")
    svn_auth_get_ssl_client_cert_pw_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_client_cert_pw_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_auth_get_ssl_client_cert_pw_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 57
if _libs["svn_subr-1"].has("svn_base64_encode2", "cdecl"):
    svn_base64_encode2 = _libs["svn_subr-1"].get("svn_base64_encode2", "cdecl")
    svn_base64_encode2.argtypes = [POINTER(svn_stream_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_base64_encode2.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 68
if _libs["svn_subr-1"].has("svn_base64_encode", "cdecl"):
    svn_base64_encode = _libs["svn_subr-1"].get("svn_base64_encode", "cdecl")
    svn_base64_encode.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_base64_encode.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 76
if _libs["svn_subr-1"].has("svn_base64_decode", "cdecl"):
    svn_base64_decode = _libs["svn_subr-1"].get("svn_base64_decode", "cdecl")
    svn_base64_decode.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_base64_decode.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 91
if _libs["svn_subr-1"].has("svn_base64_encode_string2", "cdecl"):
    svn_base64_encode_string2 = _libs["svn_subr-1"].get("svn_base64_encode_string2", "cdecl")
    svn_base64_encode_string2.argtypes = [POINTER(svn_string_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_base64_encode_string2.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 103
if _libs["svn_subr-1"].has("svn_base64_encode_string", "cdecl"):
    svn_base64_encode_string = _libs["svn_subr-1"].get("svn_base64_encode_string", "cdecl")
    svn_base64_encode_string.argtypes = [POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_base64_encode_string.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 114
if _libs["svn_subr-1"].has("svn_base64_decode_string", "cdecl"):
    svn_base64_decode_string = _libs["svn_subr-1"].get("svn_base64_decode_string", "cdecl")
    svn_base64_decode_string.argtypes = [POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_base64_decode_string.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_base64.h: 127
if _libs["svn_subr-1"].has("svn_base64_from_md5", "cdecl"):
    svn_base64_from_md5 = _libs["svn_subr-1"].get("svn_base64_from_md5", "cdecl")
    svn_base64_from_md5.argtypes = [POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_base64_from_md5.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cache_config.h: 64
class struct_svn_cache_config_t(Structure):
    pass

struct_svn_cache_config_t.__slots__ = [
    'cache_size',
    'file_handle_count',
    'single_threaded',
]
struct_svn_cache_config_t._fields_ = [
    ('cache_size', apr_uint64_t),
    ('file_handle_count', apr_size_t),
    ('single_threaded', svn_boolean_t),
]

svn_cache_config_t = struct_svn_cache_config_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cache_config.h: 64

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cache_config.h: 71
if _libs["svn_subr-1"].has("svn_cache_config_get", "cdecl"):
    svn_cache_config_get = _libs["svn_subr-1"].get("svn_cache_config_get", "cdecl")
    svn_cache_config_get.argtypes = []
    svn_cache_config_get.restype = POINTER(svn_cache_config_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cache_config.h: 84
if _libs["svn_subr-1"].has("svn_cache_config_set", "cdecl"):
    svn_cache_config_set = _libs["svn_subr-1"].get("svn_cache_config_set", "cdecl")
    svn_cache_config_set.argtypes = [POINTER(svn_cache_config_t)]
    svn_cache_config_set.restype = None

apr_getopt_err_fn_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), String)# /usr/include/apr/apr_getopt.h: 42

# /usr/include/apr/apr_getopt.h: 50
class struct_apr_getopt_t(Structure):
    pass

apr_getopt_t = struct_apr_getopt_t# /usr/include/apr/apr_getopt.h: 45

struct_apr_getopt_t.__slots__ = [
    'cont',
    'errfn',
    'errarg',
    'ind',
    'opt',
    'reset',
    'argc',
    'argv',
    'place',
    'interleave',
    'skip_start',
    'skip_end',
]
struct_apr_getopt_t._fields_ = [
    ('cont', POINTER(apr_pool_t)),
    ('errfn', POINTER(apr_getopt_err_fn_t)),
    ('errarg', POINTER(None)),
    ('ind', c_int),
    ('opt', c_int),
    ('reset', c_int),
    ('argc', c_int),
    ('argv', POINTER(POINTER(c_char))),
    ('place', String),
    ('interleave', c_int),
    ('skip_start', c_int),
    ('skip_end', c_int),
]

# /usr/include/apr/apr_getopt.h: 83
class struct_apr_getopt_option_t(Structure):
    pass

apr_getopt_option_t = struct_apr_getopt_option_t# /usr/include/apr/apr_getopt.h: 78

struct_apr_getopt_option_t.__slots__ = [
    'name',
    'optch',
    'has_arg',
    'description',
]
struct_apr_getopt_option_t._fields_ = [
    ('name', String),
    ('optch', c_int),
    ('has_arg', c_int),
    ('description', String),
]

# /usr/include/apr/apr_getopt.h: 103
if _libs["apr-1"].has("apr_getopt_init", "cdecl"):
    apr_getopt_init = _libs["apr-1"].get("apr_getopt_init", "cdecl")
    apr_getopt_init.argtypes = [POINTER(POINTER(apr_getopt_t)), POINTER(apr_pool_t), c_int, POINTER(POINTER(c_char))]
    apr_getopt_init.restype = apr_status_t

# /usr/include/apr/apr_getopt.h: 122
if _libs["apr-1"].has("apr_getopt", "cdecl"):
    apr_getopt = _libs["apr-1"].get("apr_getopt", "cdecl")
    apr_getopt.argtypes = [POINTER(apr_getopt_t), String, String, POINTER(POINTER(c_char))]
    apr_getopt.restype = apr_status_t

# /usr/include/apr/apr_getopt.h: 150
if _libs["apr-1"].has("apr_getopt_long", "cdecl"):
    apr_getopt_long = _libs["apr-1"].get("apr_getopt_long", "cdecl")
    apr_getopt_long.argtypes = [POINTER(apr_getopt_t), POINTER(apr_getopt_option_t), POINTER(c_int), POINTER(POINTER(c_char))]
    apr_getopt_long.restype = apr_status_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 77
if _libs["svn_delta-1"].has("svn_delta_version", "cdecl"):
    svn_delta_version = _libs["svn_delta-1"].get("svn_delta_version", "cdecl")
    svn_delta_version.argtypes = []
    svn_delta_version.restype = POINTER(svn_version_t)

enum_svn_delta_action = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 116

svn_txdelta_source = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 116

svn_txdelta_target = (svn_txdelta_source + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 116

svn_txdelta_new = (svn_txdelta_target + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 116

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 167
class struct_svn_txdelta_op_t(Structure):
    pass

struct_svn_txdelta_op_t.__slots__ = [
    'action_code',
    'offset',
    'length',
]
struct_svn_txdelta_op_t._fields_ = [
    ('action_code', enum_svn_delta_action),
    ('offset', apr_size_t),
    ('length', apr_size_t),
]

svn_txdelta_op_t = struct_svn_txdelta_op_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 167

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 216
class struct_svn_txdelta_window_t(Structure):
    pass

struct_svn_txdelta_window_t.__slots__ = [
    'sview_offset',
    'sview_len',
    'tview_len',
    'num_ops',
    'src_ops',
    'ops',
    'new_data',
]
struct_svn_txdelta_window_t._fields_ = [
    ('sview_offset', svn_filesize_t),
    ('sview_len', apr_size_t),
    ('tview_len', apr_size_t),
    ('num_ops', c_int),
    ('src_ops', c_int),
    ('ops', POINTER(svn_txdelta_op_t)),
    ('new_data', POINTER(svn_string_t)),
]

svn_txdelta_window_t = struct_svn_txdelta_window_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 216

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 223
if _libs["svn_delta-1"].has("svn_txdelta_window_dup", "cdecl"):
    svn_txdelta_window_dup = _libs["svn_delta-1"].get("svn_txdelta_window_dup", "cdecl")
    svn_txdelta_window_dup.argtypes = [POINTER(svn_txdelta_window_t), POINTER(apr_pool_t)]
    svn_txdelta_window_dup.restype = POINTER(svn_txdelta_window_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 233
if _libs["svn_delta-1"].has("svn_txdelta_compose_windows", "cdecl"):
    svn_txdelta_compose_windows = _libs["svn_delta-1"].get("svn_txdelta_compose_windows", "cdecl")
    svn_txdelta_compose_windows.argtypes = [POINTER(svn_txdelta_window_t), POINTER(svn_txdelta_window_t), POINTER(apr_pool_t)]
    svn_txdelta_compose_windows.restype = POINTER(svn_txdelta_window_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 255
if _libs["svn_delta-1"].has("svn_txdelta_apply_instructions", "cdecl"):
    svn_txdelta_apply_instructions = _libs["svn_delta-1"].get("svn_txdelta_apply_instructions", "cdecl")
    svn_txdelta_apply_instructions.argtypes = [POINTER(svn_txdelta_window_t), String, String, POINTER(apr_size_t)]
    svn_txdelta_apply_instructions.restype = None

svn_txdelta_window_handler_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_txdelta_window_t), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 265

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 287
if _libs["svn_delta-1"].has("svn_txdelta_run", "cdecl"):
    svn_txdelta_run = _libs["svn_delta-1"].get("svn_txdelta_run", "cdecl")
    svn_txdelta_run.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), svn_txdelta_window_handler_t, POINTER(None), svn_checksum_kind_t, POINTER(POINTER(svn_checksum_t)), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_txdelta_run.restype = POINTER(svn_error_t)
    svn_txdelta_run.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 305
class struct_svn_txdelta_stream_t(Structure):
    pass

svn_txdelta_stream_t = struct_svn_txdelta_stream_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 305

svn_txdelta_next_window_fn_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_txdelta_window_t)), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 316

svn_txdelta_md5_digest_fn_t = CFUNCTYPE(UNCHECKED(POINTER(c_ubyte)), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 330

svn_txdelta_stream_open_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_txdelta_stream_t)), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 339

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 351
if _libs["svn_delta-1"].has("svn_txdelta_stream_create", "cdecl"):
    svn_txdelta_stream_create = _libs["svn_delta-1"].get("svn_txdelta_stream_create", "cdecl")
    svn_txdelta_stream_create.argtypes = [POINTER(None), svn_txdelta_next_window_fn_t, svn_txdelta_md5_digest_fn_t, POINTER(apr_pool_t)]
    svn_txdelta_stream_create.restype = POINTER(svn_txdelta_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 363
if _libs["svn_delta-1"].has("svn_txdelta_next_window", "cdecl"):
    svn_txdelta_next_window = _libs["svn_delta-1"].get("svn_txdelta_next_window", "cdecl")
    svn_txdelta_next_window.argtypes = [POINTER(POINTER(svn_txdelta_window_t)), POINTER(svn_txdelta_stream_t), POINTER(apr_pool_t)]
    svn_txdelta_next_window.restype = POINTER(svn_error_t)
    svn_txdelta_next_window.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 374
if _libs["svn_delta-1"].has("svn_txdelta_md5_digest", "cdecl"):
    svn_txdelta_md5_digest = _libs["svn_delta-1"].get("svn_txdelta_md5_digest", "cdecl")
    svn_txdelta_md5_digest.argtypes = [POINTER(svn_txdelta_stream_t)]
    svn_txdelta_md5_digest.restype = POINTER(c_ubyte)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 391
if _libs["svn_delta-1"].has("svn_txdelta2", "cdecl"):
    svn_txdelta2 = _libs["svn_delta-1"].get("svn_txdelta2", "cdecl")
    svn_txdelta2.argtypes = [POINTER(POINTER(svn_txdelta_stream_t)), POINTER(svn_stream_t), POINTER(svn_stream_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_txdelta2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 403
if _libs["svn_delta-1"].has("svn_txdelta", "cdecl"):
    svn_txdelta = _libs["svn_delta-1"].get("svn_txdelta", "cdecl")
    svn_txdelta.argtypes = [POINTER(POINTER(svn_txdelta_stream_t)), POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_txdelta.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 419
if _libs["svn_delta-1"].has("svn_txdelta_target_push", "cdecl"):
    svn_txdelta_target_push = _libs["svn_delta-1"].get("svn_txdelta_target_push", "cdecl")
    svn_txdelta_target_push.argtypes = [svn_txdelta_window_handler_t, POINTER(None), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_txdelta_target_push.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 432
if _libs["svn_delta-1"].has("svn_txdelta_send_string", "cdecl"):
    svn_txdelta_send_string = _libs["svn_delta-1"].get("svn_txdelta_send_string", "cdecl")
    svn_txdelta_send_string.argtypes = [POINTER(svn_string_t), svn_txdelta_window_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_txdelta_send_string.restype = POINTER(svn_error_t)
    svn_txdelta_send_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 448
if _libs["svn_delta-1"].has("svn_txdelta_send_stream", "cdecl"):
    svn_txdelta_send_stream = _libs["svn_delta-1"].get("svn_txdelta_send_stream", "cdecl")
    svn_txdelta_send_stream.argtypes = [POINTER(svn_stream_t), svn_txdelta_window_handler_t, POINTER(None), POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_txdelta_send_stream.restype = POINTER(svn_error_t)
    svn_txdelta_send_stream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 460
if _libs["svn_delta-1"].has("svn_txdelta_send_txstream", "cdecl"):
    svn_txdelta_send_txstream = _libs["svn_delta-1"].get("svn_txdelta_send_txstream", "cdecl")
    svn_txdelta_send_txstream.argtypes = [POINTER(svn_txdelta_stream_t), svn_txdelta_window_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_txdelta_send_txstream.restype = POINTER(svn_error_t)
    svn_txdelta_send_txstream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 474
if _libs["svn_delta-1"].has("svn_txdelta_send_contents", "cdecl"):
    svn_txdelta_send_contents = _libs["svn_delta-1"].get("svn_txdelta_send_contents", "cdecl")
    svn_txdelta_send_contents.argtypes = [POINTER(c_ubyte), apr_size_t, svn_txdelta_window_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_txdelta_send_contents.restype = POINTER(svn_error_t)
    svn_txdelta_send_contents.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 506
if _libs["svn_delta-1"].has("svn_txdelta_apply", "cdecl"):
    svn_txdelta_apply = _libs["svn_delta-1"].get("svn_txdelta_apply", "cdecl")
    svn_txdelta_apply.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(c_ubyte), String, POINTER(apr_pool_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None))]
    svn_txdelta_apply.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 532
if _libs["svn_delta-1"].has("svn_txdelta_to_svndiff3", "cdecl"):
    svn_txdelta_to_svndiff3 = _libs["svn_delta-1"].get("svn_txdelta_to_svndiff3", "cdecl")
    svn_txdelta_to_svndiff3.argtypes = [POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(svn_stream_t), c_int, c_int, POINTER(apr_pool_t)]
    svn_txdelta_to_svndiff3.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 547
if _libs["svn_delta-1"].has("svn_txdelta_to_svndiff2", "cdecl"):
    svn_txdelta_to_svndiff2 = _libs["svn_delta-1"].get("svn_txdelta_to_svndiff2", "cdecl")
    svn_txdelta_to_svndiff2.argtypes = [POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(svn_stream_t), c_int, POINTER(apr_pool_t)]
    svn_txdelta_to_svndiff2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 560
if _libs["svn_delta-1"].has("svn_txdelta_to_svndiff", "cdecl"):
    svn_txdelta_to_svndiff = _libs["svn_delta-1"].get("svn_txdelta_to_svndiff", "cdecl")
    svn_txdelta_to_svndiff.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None))]
    svn_txdelta_to_svndiff.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 573
if _libs["svn_delta-1"].has("svn_txdelta_to_svndiff_stream", "cdecl"):
    svn_txdelta_to_svndiff_stream = _libs["svn_delta-1"].get("svn_txdelta_to_svndiff_stream", "cdecl")
    svn_txdelta_to_svndiff_stream.argtypes = [POINTER(svn_txdelta_stream_t), c_int, c_int, POINTER(apr_pool_t)]
    svn_txdelta_to_svndiff_stream.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 602
if _libs["svn_delta-1"].has("svn_txdelta_parse_svndiff", "cdecl"):
    svn_txdelta_parse_svndiff = _libs["svn_delta-1"].get("svn_txdelta_parse_svndiff", "cdecl")
    svn_txdelta_parse_svndiff.argtypes = [svn_txdelta_window_handler_t, POINTER(None), svn_boolean_t, POINTER(apr_pool_t)]
    svn_txdelta_parse_svndiff.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 619
if _libs["svn_delta-1"].has("svn_txdelta_read_svndiff_window", "cdecl"):
    svn_txdelta_read_svndiff_window = _libs["svn_delta-1"].get("svn_txdelta_read_svndiff_window", "cdecl")
    svn_txdelta_read_svndiff_window.argtypes = [POINTER(POINTER(svn_txdelta_window_t)), POINTER(svn_stream_t), c_int, POINTER(apr_pool_t)]
    svn_txdelta_read_svndiff_window.restype = POINTER(svn_error_t)
    svn_txdelta_read_svndiff_window.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 636
if _libs["svn_delta-1"].has("svn_txdelta_skip_svndiff_window", "cdecl"):
    svn_txdelta_skip_svndiff_window = _libs["svn_delta-1"].get("svn_txdelta_skip_svndiff_window", "cdecl")
    svn_txdelta_skip_svndiff_window.argtypes = [POINTER(apr_file_t), c_int, POINTER(apr_pool_t)]
    svn_txdelta_skip_svndiff_window.restype = POINTER(svn_error_t)
    svn_txdelta_skip_svndiff_window.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 883
class struct_svn_delta_editor_t(Structure):
    pass

struct_svn_delta_editor_t.__slots__ = [
    'set_target_revision',
    'open_root',
    'delete_entry',
    'add_directory',
    'open_directory',
    'change_dir_prop',
    'close_directory',
    'absent_directory',
    'add_file',
    'open_file',
    'apply_textdelta',
    'change_file_prop',
    'close_file',
    'absent_file',
    'close_edit',
    'abort_edit',
    'apply_textdelta_stream',
]
struct_svn_delta_editor_t._fields_ = [
    ('set_target_revision', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, POINTER(apr_pool_t))),
    ('open_root', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, POINTER(apr_pool_t), POINTER(POINTER(None)))),
    ('delete_entry', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, svn_revnum_t, POINTER(None), POINTER(apr_pool_t))),
    ('add_directory', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), String, svn_revnum_t, POINTER(apr_pool_t), POINTER(POINTER(None)))),
    ('open_directory', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), svn_revnum_t, POINTER(apr_pool_t), POINTER(POINTER(None)))),
    ('change_dir_prop', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t), POINTER(apr_pool_t))),
    ('close_directory', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('absent_directory', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), POINTER(apr_pool_t))),
    ('add_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), String, svn_revnum_t, POINTER(apr_pool_t), POINTER(POINTER(None)))),
    ('open_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), svn_revnum_t, POINTER(apr_pool_t), POINTER(POINTER(None)))),
    ('apply_textdelta', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_pool_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)))),
    ('change_file_prop', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t), POINTER(apr_pool_t))),
    ('close_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_pool_t))),
    ('absent_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), POINTER(apr_pool_t))),
    ('close_edit', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('abort_edit', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('apply_textdelta_stream', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(struct_svn_delta_editor_t), POINTER(None), String, svn_txdelta_stream_open_func_t, POINTER(None), POINTER(apr_pool_t))),
]

svn_delta_editor_t = struct_svn_delta_editor_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1190

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1206
if _libs["svn_delta-1"].has("svn_delta_default_editor", "cdecl"):
    svn_delta_default_editor = _libs["svn_delta-1"].get("svn_delta_default_editor", "cdecl")
    svn_delta_default_editor.argtypes = [POINTER(apr_pool_t)]
    svn_delta_default_editor.restype = POINTER(svn_delta_editor_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1214
if _libs["svn_delta-1"].has("svn_delta_noop_window_handler", "cdecl"):
    svn_delta_noop_window_handler = _libs["svn_delta-1"].get("svn_delta_noop_window_handler", "cdecl")
    svn_delta_noop_window_handler.argtypes = [POINTER(svn_txdelta_window_t), POINTER(None)]
    svn_delta_noop_window_handler.restype = POINTER(svn_error_t)
    svn_delta_noop_window_handler.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1228
if _libs["svn_delta-1"].has("svn_delta_get_cancellation_editor", "cdecl"):
    svn_delta_get_cancellation_editor = _libs["svn_delta-1"].get("svn_delta_get_cancellation_editor", "cdecl")
    svn_delta_get_cancellation_editor.argtypes = [svn_cancel_func_t, POINTER(None), POINTER(svn_delta_editor_t), POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_delta_get_cancellation_editor.restype = POINTER(svn_error_t)
    svn_delta_get_cancellation_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1271
if _libs["svn_delta-1"].has("svn_delta_depth_filter_editor", "cdecl"):
    svn_delta_depth_filter_editor = _libs["svn_delta-1"].get("svn_delta_depth_filter_editor", "cdecl")
    svn_delta_depth_filter_editor.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_delta_editor_t), POINTER(None), svn_depth_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_delta_depth_filter_editor.restype = POINTER(svn_error_t)
    svn_delta_depth_filter_editor.errcheck = _svn_errcheck

svn_delta_path_driver_cb_func2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(svn_delta_editor_t), POINTER(None), POINTER(None), POINTER(None), String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1317

svn_delta_path_driver_cb_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(None), POINTER(None), String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1334

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1365
if _libs["svn_delta-1"].has("svn_delta_path_driver3", "cdecl"):
    svn_delta_path_driver3 = _libs["svn_delta-1"].get("svn_delta_path_driver3", "cdecl")
    svn_delta_path_driver3.argtypes = [POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_array_header_t), svn_boolean_t, svn_delta_path_driver_cb_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_delta_path_driver3.restype = POINTER(svn_error_t)
    svn_delta_path_driver3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1386
if _libs["svn_delta-1"].has("svn_delta_path_driver2", "cdecl"):
    svn_delta_path_driver2 = _libs["svn_delta-1"].get("svn_delta_path_driver2", "cdecl")
    svn_delta_path_driver2.argtypes = [POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_array_header_t), svn_boolean_t, svn_delta_path_driver_cb_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_delta_path_driver2.restype = POINTER(svn_error_t)
    svn_delta_path_driver2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1406
if _libs["svn_delta-1"].has("svn_delta_path_driver", "cdecl"):
    svn_delta_path_driver = _libs["svn_delta-1"].get("svn_delta_path_driver", "cdecl")
    svn_delta_path_driver.argtypes = [POINTER(svn_delta_editor_t), POINTER(None), svn_revnum_t, POINTER(apr_array_header_t), svn_delta_path_driver_cb_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_delta_path_driver.restype = POINTER(svn_error_t)
    svn_delta_path_driver.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1422
class struct_svn_delta_path_driver_state_t(Structure):
    pass

svn_delta_path_driver_state_t = struct_svn_delta_path_driver_state_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1422

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1436
if _libs["svn_delta-1"].has("svn_delta_path_driver_start", "cdecl"):
    svn_delta_path_driver_start = _libs["svn_delta-1"].get("svn_delta_path_driver_start", "cdecl")
    svn_delta_path_driver_start.argtypes = [POINTER(POINTER(svn_delta_path_driver_state_t)), POINTER(svn_delta_editor_t), POINTER(None), svn_delta_path_driver_cb_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_delta_path_driver_start.restype = POINTER(svn_error_t)
    svn_delta_path_driver_start.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1471
if _libs["svn_delta-1"].has("svn_delta_path_driver_step", "cdecl"):
    svn_delta_path_driver_step = _libs["svn_delta-1"].get("svn_delta_path_driver_step", "cdecl")
    svn_delta_path_driver_step.argtypes = [POINTER(svn_delta_path_driver_state_t), String, POINTER(apr_pool_t)]
    svn_delta_path_driver_step.restype = POINTER(svn_error_t)
    svn_delta_path_driver_step.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1485
if _libs["svn_delta-1"].has("svn_delta_path_driver_finish", "cdecl"):
    svn_delta_path_driver_finish = _libs["svn_delta-1"].get("svn_delta_path_driver_finish", "cdecl")
    svn_delta_path_driver_finish.argtypes = [POINTER(svn_delta_path_driver_state_t), POINTER(apr_pool_t)]
    svn_delta_path_driver_finish.restype = POINTER(svn_error_t)
    svn_delta_path_driver_finish.errcheck = _svn_errcheck

svn_file_rev_handler_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(apr_array_header_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1519

svn_file_rev_handler_old_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(apr_hash_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(apr_array_header_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1541

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1565
if _libs["svn_delta-1"].has("svn_compat_wrap_file_rev_handler", "cdecl"):
    svn_compat_wrap_file_rev_handler = _libs["svn_delta-1"].get("svn_compat_wrap_file_rev_handler", "cdecl")
    svn_compat_wrap_file_rev_handler.argtypes = [POINTER(svn_file_rev_handler_t), POINTER(POINTER(None)), svn_file_rev_handler_old_t, POINTER(None), POINTER(apr_pool_t)]
    svn_compat_wrap_file_rev_handler.restype = None

enum_svn_opt_revision_kind = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_unspecified = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_number = (svn_opt_revision_unspecified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_date = (svn_opt_revision_number + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_committed = (svn_opt_revision_date + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_previous = (svn_opt_revision_committed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_base = (svn_opt_revision_previous + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_working = (svn_opt_revision_base + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_revision_head = (svn_opt_revision_working + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt_impl.h: 54

svn_opt_subcommand_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(apr_getopt_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 64

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 111
class struct_anon_79(Structure):
    pass

struct_anon_79.__slots__ = [
    'optch',
    'desc',
]
struct_anon_79._fields_ = [
    ('optch', c_int),
    ('desc', String),
]

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 112
class struct_svn_opt_subcommand_desc3_t(Structure):
    pass

struct_svn_opt_subcommand_desc3_t.__slots__ = [
    'name',
    'cmd_func',
    'aliases',
    'help',
    'valid_options',
    'desc_overrides',
]
struct_svn_opt_subcommand_desc3_t._fields_ = [
    ('name', String),
    ('cmd_func', POINTER(svn_opt_subcommand_t)),
    ('aliases', POINTER(c_char) * int(3)),
    ('help', POINTER(c_char) * int(100)),
    ('valid_options', c_int * int(50)),
    ('desc_overrides', struct_anon_79 * int(50)),
]

svn_opt_subcommand_desc3_t = struct_svn_opt_subcommand_desc3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 112

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 143
class struct_anon_80(Structure):
    pass

struct_anon_80.__slots__ = [
    'optch',
    'desc',
]
struct_anon_80._fields_ = [
    ('optch', c_int),
    ('desc', String),
]

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 144
class struct_svn_opt_subcommand_desc2_t(Structure):
    pass

struct_svn_opt_subcommand_desc2_t.__slots__ = [
    'name',
    'cmd_func',
    'aliases',
    'help',
    'valid_options',
    'desc_overrides',
]
struct_svn_opt_subcommand_desc2_t._fields_ = [
    ('name', String),
    ('cmd_func', POINTER(svn_opt_subcommand_t)),
    ('aliases', POINTER(c_char) * int(3)),
    ('help', String),
    ('valid_options', c_int * int(50)),
    ('desc_overrides', struct_anon_80 * int(50)),
]

svn_opt_subcommand_desc2_t = struct_svn_opt_subcommand_desc2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 144

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 173
class struct_svn_opt_subcommand_desc_t(Structure):
    pass

struct_svn_opt_subcommand_desc_t.__slots__ = [
    'name',
    'cmd_func',
    'aliases',
    'help',
    'valid_options',
]
struct_svn_opt_subcommand_desc_t._fields_ = [
    ('name', String),
    ('cmd_func', POINTER(svn_opt_subcommand_t)),
    ('aliases', POINTER(c_char) * int(3)),
    ('help', String),
    ('valid_options', c_int * int(50)),
]

svn_opt_subcommand_desc_t = struct_svn_opt_subcommand_desc_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 173

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 182
if _libs["svn_subr-1"].has("svn_opt_get_canonical_subcommand3", "cdecl"):
    svn_opt_get_canonical_subcommand3 = _libs["svn_subr-1"].get("svn_opt_get_canonical_subcommand3", "cdecl")
    svn_opt_get_canonical_subcommand3.argtypes = [POINTER(svn_opt_subcommand_desc3_t), String]
    svn_opt_get_canonical_subcommand3.restype = POINTER(svn_opt_subcommand_desc3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 195
if _libs["svn_subr-1"].has("svn_opt_get_canonical_subcommand2", "cdecl"):
    svn_opt_get_canonical_subcommand2 = _libs["svn_subr-1"].get("svn_opt_get_canonical_subcommand2", "cdecl")
    svn_opt_get_canonical_subcommand2.argtypes = [POINTER(svn_opt_subcommand_desc2_t), String]
    svn_opt_get_canonical_subcommand2.restype = POINTER(svn_opt_subcommand_desc2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 210
if _libs["svn_subr-1"].has("svn_opt_get_canonical_subcommand", "cdecl"):
    svn_opt_get_canonical_subcommand = _libs["svn_subr-1"].get("svn_opt_get_canonical_subcommand", "cdecl")
    svn_opt_get_canonical_subcommand.argtypes = [POINTER(svn_opt_subcommand_desc_t), String]
    svn_opt_get_canonical_subcommand.restype = POINTER(svn_opt_subcommand_desc_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 226
if _libs["svn_subr-1"].has("svn_opt_get_option_from_code3", "cdecl"):
    svn_opt_get_option_from_code3 = _libs["svn_subr-1"].get("svn_opt_get_option_from_code3", "cdecl")
    svn_opt_get_option_from_code3.argtypes = [c_int, POINTER(apr_getopt_option_t), POINTER(svn_opt_subcommand_desc3_t), POINTER(apr_pool_t)]
    svn_opt_get_option_from_code3.restype = POINTER(apr_getopt_option_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 240
if _libs["svn_subr-1"].has("svn_opt_get_option_from_code2", "cdecl"):
    svn_opt_get_option_from_code2 = _libs["svn_subr-1"].get("svn_opt_get_option_from_code2", "cdecl")
    svn_opt_get_option_from_code2.argtypes = [c_int, POINTER(apr_getopt_option_t), POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_pool_t)]
    svn_opt_get_option_from_code2.restype = POINTER(apr_getopt_option_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 255
if _libs["svn_subr-1"].has("svn_opt_get_option_from_code", "cdecl"):
    svn_opt_get_option_from_code = _libs["svn_subr-1"].get("svn_opt_get_option_from_code", "cdecl")
    svn_opt_get_option_from_code.argtypes = [c_int, POINTER(apr_getopt_option_t)]
    svn_opt_get_option_from_code.restype = POINTER(apr_getopt_option_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 269
if _libs["svn_subr-1"].has("svn_opt_subcommand_takes_option4", "cdecl"):
    svn_opt_subcommand_takes_option4 = _libs["svn_subr-1"].get("svn_opt_subcommand_takes_option4", "cdecl")
    svn_opt_subcommand_takes_option4.argtypes = [POINTER(svn_opt_subcommand_desc3_t), c_int, POINTER(c_int)]
    svn_opt_subcommand_takes_option4.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 282
if _libs["svn_subr-1"].has("svn_opt_subcommand_takes_option3", "cdecl"):
    svn_opt_subcommand_takes_option3 = _libs["svn_subr-1"].get("svn_opt_subcommand_takes_option3", "cdecl")
    svn_opt_subcommand_takes_option3.argtypes = [POINTER(svn_opt_subcommand_desc2_t), c_int, POINTER(c_int)]
    svn_opt_subcommand_takes_option3.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 294
if _libs["svn_subr-1"].has("svn_opt_subcommand_takes_option2", "cdecl"):
    svn_opt_subcommand_takes_option2 = _libs["svn_subr-1"].get("svn_opt_subcommand_takes_option2", "cdecl")
    svn_opt_subcommand_takes_option2.argtypes = [POINTER(svn_opt_subcommand_desc2_t), c_int]
    svn_opt_subcommand_takes_option2.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 309
if _libs["svn_subr-1"].has("svn_opt_subcommand_takes_option", "cdecl"):
    svn_opt_subcommand_takes_option = _libs["svn_subr-1"].get("svn_opt_subcommand_takes_option", "cdecl")
    svn_opt_subcommand_takes_option.argtypes = [POINTER(svn_opt_subcommand_desc_t), c_int]
    svn_opt_subcommand_takes_option.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 328
if _libs["svn_subr-1"].has("svn_opt_print_generic_help3", "cdecl"):
    svn_opt_print_generic_help3 = _libs["svn_subr-1"].get("svn_opt_print_generic_help3", "cdecl")
    svn_opt_print_generic_help3.argtypes = [String, POINTER(svn_opt_subcommand_desc3_t), POINTER(apr_getopt_option_t), String, POINTER(apr_pool_t), POINTER(FILE)]
    svn_opt_print_generic_help3.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 344
if _libs["svn_subr-1"].has("svn_opt_print_generic_help2", "cdecl"):
    svn_opt_print_generic_help2 = _libs["svn_subr-1"].get("svn_opt_print_generic_help2", "cdecl")
    svn_opt_print_generic_help2.argtypes = [String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), String, POINTER(apr_pool_t), POINTER(FILE)]
    svn_opt_print_generic_help2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 360
if _libs["svn_subr-1"].has("svn_opt_print_generic_help", "cdecl"):
    svn_opt_print_generic_help = _libs["svn_subr-1"].get("svn_opt_print_generic_help", "cdecl")
    svn_opt_print_generic_help.argtypes = [String, POINTER(svn_opt_subcommand_desc_t), POINTER(apr_getopt_option_t), String, POINTER(apr_pool_t), POINTER(FILE)]
    svn_opt_print_generic_help.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 374
if _libs["svn_subr-1"].has("svn_opt_format_option", "cdecl"):
    svn_opt_format_option = _libs["svn_subr-1"].get("svn_opt_format_option", "cdecl")
    svn_opt_format_option.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_getopt_option_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_opt_format_option.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 397
if _libs["svn_subr-1"].has("svn_opt_subcommand_help4", "cdecl"):
    svn_opt_subcommand_help4 = _libs["svn_subr-1"].get("svn_opt_subcommand_help4", "cdecl")
    svn_opt_subcommand_help4.argtypes = [String, POINTER(svn_opt_subcommand_desc3_t), POINTER(apr_getopt_option_t), POINTER(c_int), POINTER(apr_pool_t)]
    svn_opt_subcommand_help4.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 412
if _libs["svn_subr-1"].has("svn_opt_subcommand_help3", "cdecl"):
    svn_opt_subcommand_help3 = _libs["svn_subr-1"].get("svn_opt_subcommand_help3", "cdecl")
    svn_opt_subcommand_help3.argtypes = [String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), POINTER(c_int), POINTER(apr_pool_t)]
    svn_opt_subcommand_help3.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 426
if _libs["svn_subr-1"].has("svn_opt_subcommand_help2", "cdecl"):
    svn_opt_subcommand_help2 = _libs["svn_subr-1"].get("svn_opt_subcommand_help2", "cdecl")
    svn_opt_subcommand_help2.argtypes = [String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), POINTER(apr_pool_t)]
    svn_opt_subcommand_help2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 440
if _libs["svn_subr-1"].has("svn_opt_subcommand_help", "cdecl"):
    svn_opt_subcommand_help = _libs["svn_subr-1"].get("svn_opt_subcommand_help", "cdecl")
    svn_opt_subcommand_help.argtypes = [String, POINTER(svn_opt_subcommand_desc_t), POINTER(apr_getopt_option_t), POINTER(apr_pool_t)]
    svn_opt_subcommand_help.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 466
class union_svn_opt_revision_value_t(Union):
    pass

union_svn_opt_revision_value_t.__slots__ = [
    'number',
    'date',
]
union_svn_opt_revision_value_t._fields_ = [
    ('number', svn_revnum_t),
    ('date', apr_time_t),
]

svn_opt_revision_value_t = union_svn_opt_revision_value_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 466

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 473
class struct_svn_opt_revision_t(Structure):
    pass

struct_svn_opt_revision_t.__slots__ = [
    'kind',
    'value',
]
struct_svn_opt_revision_t._fields_ = [
    ('kind', enum_svn_opt_revision_kind),
    ('value', svn_opt_revision_value_t),
]

svn_opt_revision_t = struct_svn_opt_revision_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 473

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 483
class struct_svn_opt_revision_range_t(Structure):
    pass

struct_svn_opt_revision_range_t.__slots__ = [
    'start',
    'end',
]
struct_svn_opt_revision_range_t._fields_ = [
    ('start', svn_opt_revision_t),
    ('end', svn_opt_revision_t),
]

svn_opt_revision_range_t = struct_svn_opt_revision_range_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 483

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 507
if _libs["svn_subr-1"].has("svn_opt_parse_revision", "cdecl"):
    svn_opt_parse_revision = _libs["svn_subr-1"].get("svn_opt_parse_revision", "cdecl")
    svn_opt_parse_revision.argtypes = [POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, POINTER(apr_pool_t)]
    svn_opt_parse_revision.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 532
if _libs["svn_subr-1"].has("svn_opt_parse_revision_to_range", "cdecl"):
    svn_opt_parse_revision_to_range = _libs["svn_subr-1"].get("svn_opt_parse_revision_to_range", "cdecl")
    svn_opt_parse_revision_to_range.argtypes = [POINTER(apr_array_header_t), String, POINTER(apr_pool_t)]
    svn_opt_parse_revision_to_range.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 561
if _libs["svn_subr-1"].has("svn_opt_resolve_revisions", "cdecl"):
    svn_opt_resolve_revisions = _libs["svn_subr-1"].get("svn_opt_resolve_revisions", "cdecl")
    svn_opt_resolve_revisions.argtypes = [POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_opt_resolve_revisions.restype = POINTER(svn_error_t)
    svn_opt_resolve_revisions.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 595
if _libs["svn_subr-1"].has("svn_opt_args_to_target_array3", "cdecl"):
    svn_opt_args_to_target_array3 = _libs["svn_subr-1"].get("svn_opt_args_to_target_array3", "cdecl")
    svn_opt_args_to_target_array3.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_opt_args_to_target_array3.restype = POINTER(svn_error_t)
    svn_opt_args_to_target_array3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 611
if _libs["svn_subr-1"].has("svn_opt_args_to_target_array2", "cdecl"):
    svn_opt_args_to_target_array2 = _libs["svn_subr-1"].get("svn_opt_args_to_target_array2", "cdecl")
    svn_opt_args_to_target_array2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_opt_args_to_target_array2.restype = POINTER(svn_error_t)
    svn_opt_args_to_target_array2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 633
if _libs["svn_subr-1"].has("svn_opt_args_to_target_array", "cdecl"):
    svn_opt_args_to_target_array = _libs["svn_subr-1"].get("svn_opt_args_to_target_array", "cdecl")
    svn_opt_args_to_target_array.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_opt_args_to_target_array.restype = POINTER(svn_error_t)
    svn_opt_args_to_target_array.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 652
if _libs["svn_subr-1"].has("svn_opt_parse_revprop", "cdecl"):
    svn_opt_parse_revprop = _libs["svn_subr-1"].get("svn_opt_parse_revprop", "cdecl")
    svn_opt_parse_revprop.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_opt_parse_revprop.restype = POINTER(svn_error_t)
    svn_opt_parse_revprop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 665
if _libs["svn_subr-1"].has("svn_opt_push_implicit_dot_target", "cdecl"):
    svn_opt_push_implicit_dot_target = _libs["svn_subr-1"].get("svn_opt_push_implicit_dot_target", "cdecl")
    svn_opt_push_implicit_dot_target.argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_opt_push_implicit_dot_target.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 674
if _libs["svn_subr-1"].has("svn_opt_parse_num_args", "cdecl"):
    svn_opt_parse_num_args = _libs["svn_subr-1"].get("svn_opt_parse_num_args", "cdecl")
    svn_opt_parse_num_args.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), c_int, POINTER(apr_pool_t)]
    svn_opt_parse_num_args.restype = POINTER(svn_error_t)
    svn_opt_parse_num_args.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 686
if _libs["svn_subr-1"].has("svn_opt_parse_all_args", "cdecl"):
    svn_opt_parse_all_args = _libs["svn_subr-1"].get("svn_opt_parse_all_args", "cdecl")
    svn_opt_parse_all_args.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_pool_t)]
    svn_opt_parse_all_args.restype = POINTER(svn_error_t)
    svn_opt_parse_all_args.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 737
if _libs["svn_subr-1"].has("svn_opt_parse_path", "cdecl"):
    svn_opt_parse_path = _libs["svn_subr-1"].get("svn_opt_parse_path", "cdecl")
    svn_opt_parse_path.argtypes = [POINTER(svn_opt_revision_t), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_opt_parse_path.restype = POINTER(svn_error_t)
    svn_opt_parse_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 778
if _libs["svn_subr-1"].has("svn_opt_print_help5", "cdecl"):
    svn_opt_print_help5 = _libs["svn_subr-1"].get("svn_opt_print_help5", "cdecl")
    svn_opt_print_help5.argtypes = [POINTER(apr_getopt_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, String, POINTER(svn_opt_subcommand_desc3_t), POINTER(apr_getopt_option_t), POINTER(c_int), String, POINTER(apr_pool_t)]
    svn_opt_print_help5.restype = POINTER(svn_error_t)
    svn_opt_print_help5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 800
if _libs["svn_subr-1"].has("svn_opt_print_help4", "cdecl"):
    svn_opt_print_help4 = _libs["svn_subr-1"].get("svn_opt_print_help4", "cdecl")
    svn_opt_print_help4.argtypes = [POINTER(apr_getopt_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), POINTER(c_int), String, POINTER(apr_pool_t)]
    svn_opt_print_help4.restype = POINTER(svn_error_t)
    svn_opt_print_help4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 821
if _libs["svn_subr-1"].has("svn_opt_print_help3", "cdecl"):
    svn_opt_print_help3 = _libs["svn_subr-1"].get("svn_opt_print_help3", "cdecl")
    svn_opt_print_help3.argtypes = [POINTER(apr_getopt_t), String, svn_boolean_t, svn_boolean_t, String, String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), POINTER(c_int), String, POINTER(apr_pool_t)]
    svn_opt_print_help3.restype = POINTER(svn_error_t)
    svn_opt_print_help3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 842
if _libs["svn_subr-1"].has("svn_opt_print_help2", "cdecl"):
    svn_opt_print_help2 = _libs["svn_subr-1"].get("svn_opt_print_help2", "cdecl")
    svn_opt_print_help2.argtypes = [POINTER(apr_getopt_t), String, svn_boolean_t, svn_boolean_t, String, String, POINTER(svn_opt_subcommand_desc2_t), POINTER(apr_getopt_option_t), String, POINTER(apr_pool_t)]
    svn_opt_print_help2.restype = POINTER(svn_error_t)
    svn_opt_print_help2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 861
if _libs["svn_subr-1"].has("svn_opt_print_help", "cdecl"):
    svn_opt_print_help = _libs["svn_subr-1"].get("svn_opt_print_help", "cdecl")
    svn_opt_print_help.argtypes = [POINTER(apr_getopt_t), String, svn_boolean_t, svn_boolean_t, String, String, POINTER(svn_opt_subcommand_desc_t), POINTER(apr_getopt_option_t), String, POINTER(apr_pool_t)]
    svn_opt_print_help.restype = POINTER(svn_error_t)
    svn_opt_print_help.errcheck = _svn_errcheck

svn_rangelist_t = apr_array_header_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 135

svn_mergeinfo_t = POINTER(apr_hash_t)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 142

svn_mergeinfo_catalog_t = POINTER(apr_hash_t)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 150

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 173
if _libs["svn_subr-1"].has("svn_mergeinfo_parse", "cdecl"):
    svn_mergeinfo_parse = _libs["svn_subr-1"].get("svn_mergeinfo_parse", "cdecl")
    svn_mergeinfo_parse.argtypes = [POINTER(svn_mergeinfo_t), String, POINTER(apr_pool_t)]
    svn_mergeinfo_parse.restype = POINTER(svn_error_t)
    svn_mergeinfo_parse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 200
if _libs["svn_subr-1"].has("svn_mergeinfo_diff2", "cdecl"):
    svn_mergeinfo_diff2 = _libs["svn_subr-1"].get("svn_mergeinfo_diff2", "cdecl")
    svn_mergeinfo_diff2.argtypes = [POINTER(svn_mergeinfo_t), POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_diff2.restype = POINTER(svn_error_t)
    svn_mergeinfo_diff2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 213
if _libs["svn_subr-1"].has("svn_mergeinfo_diff", "cdecl"):
    svn_mergeinfo_diff = _libs["svn_subr-1"].get("svn_mergeinfo_diff", "cdecl")
    svn_mergeinfo_diff.argtypes = [POINTER(svn_mergeinfo_t), POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_mergeinfo_diff.restype = POINTER(svn_error_t)
    svn_mergeinfo_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 236
if _libs["svn_subr-1"].has("svn_mergeinfo_merge2", "cdecl"):
    svn_mergeinfo_merge2 = _libs["svn_subr-1"].get("svn_mergeinfo_merge2", "cdecl")
    svn_mergeinfo_merge2.argtypes = [svn_mergeinfo_t, svn_mergeinfo_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_merge2.restype = POINTER(svn_error_t)
    svn_mergeinfo_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 247
if _libs["svn_subr-1"].has("svn_mergeinfo_merge", "cdecl"):
    svn_mergeinfo_merge = _libs["svn_subr-1"].get("svn_mergeinfo_merge", "cdecl")
    svn_mergeinfo_merge.argtypes = [svn_mergeinfo_t, svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_merge.restype = POINTER(svn_error_t)
    svn_mergeinfo_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 261
if _libs["svn_subr-1"].has("svn_mergeinfo_catalog_merge", "cdecl"):
    svn_mergeinfo_catalog_merge = _libs["svn_subr-1"].get("svn_mergeinfo_catalog_merge", "cdecl")
    svn_mergeinfo_catalog_merge.argtypes = [svn_mergeinfo_catalog_t, svn_mergeinfo_catalog_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_catalog_merge.restype = POINTER(svn_error_t)
    svn_mergeinfo_catalog_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 272
if _libs["svn_subr-1"].has("svn_mergeinfo_remove", "cdecl"):
    svn_mergeinfo_remove = _libs["svn_subr-1"].get("svn_mergeinfo_remove", "cdecl")
    svn_mergeinfo_remove.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_remove.restype = POINTER(svn_error_t)
    svn_mergeinfo_remove.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 287
if _libs["svn_subr-1"].has("svn_mergeinfo_remove2", "cdecl"):
    svn_mergeinfo_remove2 = _libs["svn_subr-1"].get("svn_mergeinfo_remove2", "cdecl")
    svn_mergeinfo_remove2.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_remove2.restype = POINTER(svn_error_t)
    svn_mergeinfo_remove2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 306
if _libs["svn_subr-1"].has("svn_rangelist_diff", "cdecl"):
    svn_rangelist_diff = _libs["svn_subr-1"].get("svn_rangelist_diff", "cdecl")
    svn_rangelist_diff.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), POINTER(svn_rangelist_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_rangelist_diff.restype = POINTER(svn_error_t)
    svn_rangelist_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 333
if _libs["svn_subr-1"].has("svn_rangelist_merge2", "cdecl"):
    svn_rangelist_merge2 = _libs["svn_subr-1"].get("svn_rangelist_merge2", "cdecl")
    svn_rangelist_merge2.argtypes = [POINTER(svn_rangelist_t), POINTER(svn_rangelist_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_rangelist_merge2.restype = POINTER(svn_error_t)
    svn_rangelist_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 352
if _libs["svn_subr-1"].has("svn_rangelist_merge", "cdecl"):
    svn_rangelist_merge = _libs["svn_subr-1"].get("svn_rangelist_merge", "cdecl")
    svn_rangelist_merge.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), POINTER(apr_pool_t)]
    svn_rangelist_merge.restype = POINTER(svn_error_t)
    svn_rangelist_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 372
if _libs["svn_subr-1"].has("svn_rangelist_remove", "cdecl"):
    svn_rangelist_remove = _libs["svn_subr-1"].get("svn_rangelist_remove", "cdecl")
    svn_rangelist_remove.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), POINTER(svn_rangelist_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_rangelist_remove.restype = POINTER(svn_error_t)
    svn_rangelist_remove.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 389
if _libs["svn_subr-1"].has("svn_mergeinfo_intersect2", "cdecl"):
    svn_mergeinfo_intersect2 = _libs["svn_subr-1"].get("svn_mergeinfo_intersect2", "cdecl")
    svn_mergeinfo_intersect2.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_intersect2.restype = POINTER(svn_error_t)
    svn_mergeinfo_intersect2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 402
if _libs["svn_subr-1"].has("svn_mergeinfo_intersect", "cdecl"):
    svn_mergeinfo_intersect = _libs["svn_subr-1"].get("svn_mergeinfo_intersect", "cdecl")
    svn_mergeinfo_intersect.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_intersect.restype = POINTER(svn_error_t)
    svn_mergeinfo_intersect.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 429
if _libs["svn_subr-1"].has("svn_rangelist_intersect", "cdecl"):
    svn_rangelist_intersect = _libs["svn_subr-1"].get("svn_rangelist_intersect", "cdecl")
    svn_rangelist_intersect.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), POINTER(svn_rangelist_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_rangelist_intersect.restype = POINTER(svn_error_t)
    svn_rangelist_intersect.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 446
if _libs["svn_subr-1"].has("svn_rangelist_reverse", "cdecl"):
    svn_rangelist_reverse = _libs["svn_subr-1"].get("svn_rangelist_reverse", "cdecl")
    svn_rangelist_reverse.argtypes = [POINTER(svn_rangelist_t), POINTER(apr_pool_t)]
    svn_rangelist_reverse.restype = POINTER(svn_error_t)
    svn_rangelist_reverse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 455
if _libs["svn_subr-1"].has("svn_rangelist_to_string", "cdecl"):
    svn_rangelist_to_string = _libs["svn_subr-1"].get("svn_rangelist_to_string", "cdecl")
    svn_rangelist_to_string.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_rangelist_t), POINTER(apr_pool_t)]
    svn_rangelist_to_string.restype = POINTER(svn_error_t)
    svn_rangelist_to_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 478
if _libs["svn_subr-1"].has("svn_rangelist_inheritable2", "cdecl"):
    svn_rangelist_inheritable2 = _libs["svn_subr-1"].get("svn_rangelist_inheritable2", "cdecl")
    svn_rangelist_inheritable2.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_rangelist_inheritable2.restype = POINTER(svn_error_t)
    svn_rangelist_inheritable2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 493
if _libs["svn_subr-1"].has("svn_rangelist_inheritable", "cdecl"):
    svn_rangelist_inheritable = _libs["svn_subr-1"].get("svn_rangelist_inheritable", "cdecl")
    svn_rangelist_inheritable.argtypes = [POINTER(POINTER(svn_rangelist_t)), POINTER(svn_rangelist_t), svn_revnum_t, svn_revnum_t, POINTER(apr_pool_t)]
    svn_rangelist_inheritable.restype = POINTER(svn_error_t)
    svn_rangelist_inheritable.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 523
if _libs["svn_subr-1"].has("svn_mergeinfo_inheritable2", "cdecl"):
    svn_mergeinfo_inheritable2 = _libs["svn_subr-1"].get("svn_mergeinfo_inheritable2", "cdecl")
    svn_mergeinfo_inheritable2.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, String, svn_revnum_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_mergeinfo_inheritable2.restype = POINTER(svn_error_t)
    svn_mergeinfo_inheritable2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 539
if _libs["svn_subr-1"].has("svn_mergeinfo_inheritable", "cdecl"):
    svn_mergeinfo_inheritable = _libs["svn_subr-1"].get("svn_mergeinfo_inheritable", "cdecl")
    svn_mergeinfo_inheritable.argtypes = [POINTER(svn_mergeinfo_t), svn_mergeinfo_t, String, svn_revnum_t, svn_revnum_t, POINTER(apr_pool_t)]
    svn_mergeinfo_inheritable.restype = POINTER(svn_error_t)
    svn_mergeinfo_inheritable.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 556
if _libs["svn_subr-1"].has("svn_mergeinfo_to_string", "cdecl"):
    svn_mergeinfo_to_string = _libs["svn_subr-1"].get("svn_mergeinfo_to_string", "cdecl")
    svn_mergeinfo_to_string.argtypes = [POINTER(POINTER(svn_string_t)), svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_to_string.restype = POINTER(svn_error_t)
    svn_mergeinfo_to_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 569
if _libs["svn_subr-1"].has("svn_mergeinfo_sort", "cdecl"):
    svn_mergeinfo_sort = _libs["svn_subr-1"].get("svn_mergeinfo_sort", "cdecl")
    svn_mergeinfo_sort.argtypes = [svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_sort.restype = POINTER(svn_error_t)
    svn_mergeinfo_sort.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 577
if _libs["svn_subr-1"].has("svn_mergeinfo_catalog_dup", "cdecl"):
    svn_mergeinfo_catalog_dup = _libs["svn_subr-1"].get("svn_mergeinfo_catalog_dup", "cdecl")
    svn_mergeinfo_catalog_dup.argtypes = [svn_mergeinfo_catalog_t, POINTER(apr_pool_t)]
    svn_mergeinfo_catalog_dup.restype = svn_mergeinfo_catalog_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 585
if _libs["svn_subr-1"].has("svn_mergeinfo_dup", "cdecl"):
    svn_mergeinfo_dup = _libs["svn_subr-1"].get("svn_mergeinfo_dup", "cdecl")
    svn_mergeinfo_dup.argtypes = [svn_mergeinfo_t, POINTER(apr_pool_t)]
    svn_mergeinfo_dup.restype = svn_mergeinfo_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 591
if _libs["svn_subr-1"].has("svn_rangelist_dup", "cdecl"):
    svn_rangelist_dup = _libs["svn_subr-1"].get("svn_rangelist_dup", "cdecl")
    svn_rangelist_dup.argtypes = [POINTER(svn_rangelist_t), POINTER(apr_pool_t)]
    svn_rangelist_dup.restype = POINTER(svn_rangelist_t)

enum_svn_mergeinfo_inheritance_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 614

svn_mergeinfo_explicit = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 614

svn_mergeinfo_inherited = (svn_mergeinfo_explicit + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 614

svn_mergeinfo_nearest_ancestor = (svn_mergeinfo_inherited + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 614

svn_mergeinfo_inheritance_t = enum_svn_mergeinfo_inheritance_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 614

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 623
if _libs["svn_subr-1"].has("svn_inheritance_to_word", "cdecl"):
    svn_inheritance_to_word = _libs["svn_subr-1"].get("svn_inheritance_to_word", "cdecl")
    svn_inheritance_to_word.argtypes = [svn_mergeinfo_inheritance_t]
    svn_inheritance_to_word.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 634
if _libs["svn_subr-1"].has("svn_inheritance_from_word", "cdecl"):
    svn_inheritance_from_word = _libs["svn_subr-1"].get("svn_inheritance_from_word", "cdecl")
    svn_inheritance_from_word.argtypes = [String]
    svn_inheritance_from_word.restype = svn_mergeinfo_inheritance_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 56
if _libs["svn_ra-1"].has("svn_ra_version", "cdecl"):
    svn_ra_version = _libs["svn_ra-1"].get("svn_ra_version", "cdecl")
    svn_ra_version.argtypes = []
    svn_ra_version.restype = POINTER(svn_version_t)

svn_ra_get_wc_prop_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, POINTER(POINTER(svn_string_t)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 73

svn_ra_set_wc_prop_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, POINTER(svn_string_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 85

svn_ra_push_wc_prop_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, POINTER(svn_string_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 105

svn_ra_invalidate_wc_props_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 118

svn_ra_get_wc_contents_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_stream_t)), POINTER(svn_checksum_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 130

svn_ra_get_latest_revnum_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_revnum_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 141

svn_ra_get_client_string_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(c_char)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 152

svn_ra_file_rev_handler_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(apr_hash_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(apr_array_header_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 174

svn_ra_lock_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_boolean_t, POINTER(svn_lock_t), POINTER(svn_error_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 203

svn_ra_progress_notify_func_t = CFUNCTYPE(UNCHECKED(None), apr_off_t, apr_off_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 219

svn_ra_replay_revstart_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), svn_revnum_t, POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 241

svn_ra_replay_revfinish_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), svn_revnum_t, POINTER(None), POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 265

svn_ra_check_tunnel_func_t = CFUNCTYPE(UNCHECKED(svn_boolean_t), POINTER(None), String)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 283

svn_ra_close_tunnel_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 299

svn_ra_open_tunnel_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_stream_t)), POINTER(POINTER(svn_stream_t)), POINTER(svn_ra_close_tunnel_func_t), POINTER(POINTER(None)), POINTER(None), String, String, String, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 322

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 438
class struct_svn_ra_reporter3_t(Structure):
    pass

struct_svn_ra_reporter3_t.__slots__ = [
    'set_path',
    'delete_path',
    'link_path',
    'finish_report',
    'abort_report',
]
struct_svn_ra_reporter3_t._fields_ = [
    ('set_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, svn_depth_t, svn_boolean_t, String, POINTER(apr_pool_t))),
    ('delete_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_pool_t))),
    ('link_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, svn_revnum_t, svn_depth_t, svn_boolean_t, String, POINTER(apr_pool_t))),
    ('finish_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('abort_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
]

svn_ra_reporter3_t = struct_svn_ra_reporter3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 438

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 479
class struct_svn_ra_reporter2_t(Structure):
    pass

struct_svn_ra_reporter2_t.__slots__ = [
    'set_path',
    'delete_path',
    'link_path',
    'finish_report',
    'abort_report',
]
struct_svn_ra_reporter2_t._fields_ = [
    ('set_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, svn_boolean_t, String, POINTER(apr_pool_t))),
    ('delete_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_pool_t))),
    ('link_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, svn_revnum_t, svn_boolean_t, String, POINTER(apr_pool_t))),
    ('finish_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('abort_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
]

svn_ra_reporter2_t = struct_svn_ra_reporter2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 479

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 517
class struct_svn_ra_reporter_t(Structure):
    pass

struct_svn_ra_reporter_t.__slots__ = [
    'set_path',
    'delete_path',
    'link_path',
    'finish_report',
    'abort_report',
]
struct_svn_ra_reporter_t._fields_ = [
    ('set_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t))),
    ('delete_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_pool_t))),
    ('link_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t))),
    ('finish_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
    ('abort_report', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))),
]

svn_ra_reporter_t = struct_svn_ra_reporter_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 517

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 624
class struct_svn_ra_callbacks2_t(Structure):
    pass

struct_svn_ra_callbacks2_t.__slots__ = [
    'open_tmp_file',
    'auth_baton',
    'get_wc_prop',
    'set_wc_prop',
    'push_wc_prop',
    'invalidate_wc_props',
    'progress_func',
    'progress_baton',
    'cancel_func',
    'get_client_string',
    'get_wc_contents',
    'check_tunnel_func',
    'open_tunnel_func',
    'tunnel_baton',
]
struct_svn_ra_callbacks2_t._fields_ = [
    ('open_tmp_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(apr_file_t)), POINTER(None), POINTER(apr_pool_t))),
    ('auth_baton', POINTER(svn_auth_baton_t)),
    ('get_wc_prop', svn_ra_get_wc_prop_func_t),
    ('set_wc_prop', svn_ra_set_wc_prop_func_t),
    ('push_wc_prop', svn_ra_push_wc_prop_func_t),
    ('invalidate_wc_props', svn_ra_invalidate_wc_props_func_t),
    ('progress_func', svn_ra_progress_notify_func_t),
    ('progress_baton', POINTER(None)),
    ('cancel_func', svn_cancel_func_t),
    ('get_client_string', svn_ra_get_client_string_func_t),
    ('get_wc_contents', svn_ra_get_wc_contents_func_t),
    ('check_tunnel_func', svn_ra_check_tunnel_func_t),
    ('open_tunnel_func', svn_ra_open_tunnel_func_t),
    ('tunnel_baton', POINTER(None)),
]

svn_ra_callbacks2_t = struct_svn_ra_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 624

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 647
class struct_svn_ra_callbacks_t(Structure):
    pass

struct_svn_ra_callbacks_t.__slots__ = [
    'open_tmp_file',
    'auth_baton',
    'get_wc_prop',
    'set_wc_prop',
    'push_wc_prop',
    'invalidate_wc_props',
]
struct_svn_ra_callbacks_t._fields_ = [
    ('open_tmp_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(apr_file_t)), POINTER(None), POINTER(apr_pool_t))),
    ('auth_baton', POINTER(svn_auth_baton_t)),
    ('get_wc_prop', svn_ra_get_wc_prop_func_t),
    ('set_wc_prop', svn_ra_set_wc_prop_func_t),
    ('push_wc_prop', svn_ra_push_wc_prop_func_t),
    ('invalidate_wc_props', svn_ra_invalidate_wc_props_func_t),
]

svn_ra_callbacks_t = struct_svn_ra_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 647

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 664
if _libs["svn_ra-1"].has("svn_ra_initialize", "cdecl"):
    svn_ra_initialize = _libs["svn_ra-1"].get("svn_ra_initialize", "cdecl")
    svn_ra_initialize.argtypes = [POINTER(apr_pool_t)]
    svn_ra_initialize.restype = POINTER(svn_error_t)
    svn_ra_initialize.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 675
if _libs["svn_ra-1"].has("svn_ra_create_callbacks", "cdecl"):
    svn_ra_create_callbacks = _libs["svn_ra-1"].get("svn_ra_create_callbacks", "cdecl")
    svn_ra_create_callbacks.argtypes = [POINTER(POINTER(svn_ra_callbacks2_t)), POINTER(apr_pool_t)]
    svn_ra_create_callbacks.restype = POINTER(svn_error_t)
    svn_ra_create_callbacks.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 685
class struct_svn_ra_session_t(Structure):
    pass

svn_ra_session_t = struct_svn_ra_session_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 685

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 741
if _libs["svn_ra-1"].has("svn_ra_open5", "cdecl"):
    svn_ra_open5 = _libs["svn_ra-1"].get("svn_ra_open5", "cdecl")
    svn_ra_open5.argtypes = [POINTER(POINTER(svn_ra_session_t)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, String, POINTER(svn_ra_callbacks2_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_ra_open5.restype = POINTER(svn_error_t)
    svn_ra_open5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 759
if _libs["svn_ra-1"].has("svn_ra_open4", "cdecl"):
    svn_ra_open4 = _libs["svn_ra-1"].get("svn_ra_open4", "cdecl")
    svn_ra_open4.argtypes = [POINTER(POINTER(svn_ra_session_t)), POINTER(POINTER(c_char)), String, String, POINTER(svn_ra_callbacks2_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_ra_open4.restype = POINTER(svn_error_t)
    svn_ra_open4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 776
if _libs["svn_ra-1"].has("svn_ra_open3", "cdecl"):
    svn_ra_open3 = _libs["svn_ra-1"].get("svn_ra_open3", "cdecl")
    svn_ra_open3.argtypes = [POINTER(POINTER(svn_ra_session_t)), String, String, POINTER(svn_ra_callbacks2_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_ra_open3.restype = POINTER(svn_error_t)
    svn_ra_open3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 792
if _libs["svn_ra-1"].has("svn_ra_open2", "cdecl"):
    svn_ra_open2 = _libs["svn_ra-1"].get("svn_ra_open2", "cdecl")
    svn_ra_open2.argtypes = [POINTER(POINTER(svn_ra_session_t)), String, POINTER(svn_ra_callbacks2_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_ra_open2.restype = POINTER(svn_error_t)
    svn_ra_open2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 806
if _libs["svn_ra-1"].has("svn_ra_open", "cdecl"):
    svn_ra_open = _libs["svn_ra-1"].get("svn_ra_open", "cdecl")
    svn_ra_open.argtypes = [POINTER(POINTER(svn_ra_session_t)), String, POINTER(svn_ra_callbacks_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_ra_open.restype = POINTER(svn_error_t)
    svn_ra_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 823
if _libs["svn_ra-1"].has("svn_ra_reparent", "cdecl"):
    svn_ra_reparent = _libs["svn_ra-1"].get("svn_ra_reparent", "cdecl")
    svn_ra_reparent.argtypes = [POINTER(svn_ra_session_t), String, POINTER(apr_pool_t)]
    svn_ra_reparent.restype = POINTER(svn_error_t)
    svn_ra_reparent.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 833
if _libs["svn_ra-1"].has("svn_ra_get_session_url", "cdecl"):
    svn_ra_get_session_url = _libs["svn_ra-1"].get("svn_ra_get_session_url", "cdecl")
    svn_ra_get_session_url.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_ra_get_session_url.restype = POINTER(svn_error_t)
    svn_ra_get_session_url.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 848
if _libs["svn_ra-1"].has("svn_ra_get_path_relative_to_session", "cdecl"):
    svn_ra_get_path_relative_to_session = _libs["svn_ra-1"].get("svn_ra_get_path_relative_to_session", "cdecl")
    svn_ra_get_path_relative_to_session.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_ra_get_path_relative_to_session.restype = POINTER(svn_error_t)
    svn_ra_get_path_relative_to_session.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 864
if _libs["svn_ra-1"].has("svn_ra_get_path_relative_to_root", "cdecl"):
    svn_ra_get_path_relative_to_root = _libs["svn_ra-1"].get("svn_ra_get_path_relative_to_root", "cdecl")
    svn_ra_get_path_relative_to_root.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_ra_get_path_relative_to_root.restype = POINTER(svn_error_t)
    svn_ra_get_path_relative_to_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 877
if _libs["svn_ra-1"].has("svn_ra_get_latest_revnum", "cdecl"):
    svn_ra_get_latest_revnum = _libs["svn_ra-1"].get("svn_ra_get_latest_revnum", "cdecl")
    svn_ra_get_latest_revnum.argtypes = [POINTER(svn_ra_session_t), POINTER(svn_revnum_t), POINTER(apr_pool_t)]
    svn_ra_get_latest_revnum.restype = POINTER(svn_error_t)
    svn_ra_get_latest_revnum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 890
if _libs["svn_ra-1"].has("svn_ra_get_dated_revision", "cdecl"):
    svn_ra_get_dated_revision = _libs["svn_ra-1"].get("svn_ra_get_dated_revision", "cdecl")
    svn_ra_get_dated_revision.argtypes = [POINTER(svn_ra_session_t), POINTER(svn_revnum_t), apr_time_t, POINTER(apr_pool_t)]
    svn_ra_get_dated_revision.restype = POINTER(svn_error_t)
    svn_ra_get_dated_revision.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 920
if _libs["svn_ra-1"].has("svn_ra_change_rev_prop2", "cdecl"):
    svn_ra_change_rev_prop2 = _libs["svn_ra-1"].get("svn_ra_change_rev_prop2", "cdecl")
    svn_ra_change_rev_prop2.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, String, POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_ra_change_rev_prop2.restype = POINTER(svn_error_t)
    svn_ra_change_rev_prop2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 936
if _libs["svn_ra-1"].has("svn_ra_change_rev_prop", "cdecl"):
    svn_ra_change_rev_prop = _libs["svn_ra-1"].get("svn_ra_change_rev_prop", "cdecl")
    svn_ra_change_rev_prop.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_ra_change_rev_prop.restype = POINTER(svn_error_t)
    svn_ra_change_rev_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 952
if _libs["svn_ra-1"].has("svn_ra_rev_proplist", "cdecl"):
    svn_ra_rev_proplist = _libs["svn_ra-1"].get("svn_ra_rev_proplist", "cdecl")
    svn_ra_rev_proplist.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t)]
    svn_ra_rev_proplist.restype = POINTER(svn_error_t)
    svn_ra_rev_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 967
if _libs["svn_ra-1"].has("svn_ra_rev_prop", "cdecl"):
    svn_ra_rev_prop = _libs["svn_ra-1"].get("svn_ra_rev_prop", "cdecl")
    svn_ra_rev_prop.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, String, POINTER(POINTER(svn_string_t)), POINTER(apr_pool_t)]
    svn_ra_rev_prop.restype = POINTER(svn_error_t)
    svn_ra_rev_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1019
if _libs["svn_ra-1"].has("svn_ra_get_commit_editor3", "cdecl"):
    svn_ra_get_commit_editor3 = _libs["svn_ra-1"].get("svn_ra_get_commit_editor3", "cdecl")
    svn_ra_get_commit_editor3.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_ra_get_commit_editor3.restype = POINTER(svn_error_t)
    svn_ra_get_commit_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1040
if _libs["svn_ra-1"].has("svn_ra_get_commit_editor2", "cdecl"):
    svn_ra_get_commit_editor2 = _libs["svn_ra-1"].get("svn_ra_get_commit_editor2", "cdecl")
    svn_ra_get_commit_editor2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), String, svn_commit_callback2_t, POINTER(None), POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_ra_get_commit_editor2.restype = POINTER(svn_error_t)
    svn_ra_get_commit_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1059
if _libs["svn_ra-1"].has("svn_ra_get_commit_editor", "cdecl"):
    svn_ra_get_commit_editor = _libs["svn_ra-1"].get("svn_ra_get_commit_editor", "cdecl")
    svn_ra_get_commit_editor.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), String, svn_commit_callback_t, POINTER(None), POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_ra_get_commit_editor.restype = POINTER(svn_error_t)
    svn_ra_get_commit_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1095
if _libs["svn_ra-1"].has("svn_ra_get_file", "cdecl"):
    svn_ra_get_file = _libs["svn_ra-1"].get("svn_ra_get_file", "cdecl")
    svn_ra_get_file.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, POINTER(svn_stream_t), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t)]
    svn_ra_get_file.restype = POINTER(svn_error_t)
    svn_ra_get_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1130
if _libs["svn_ra-1"].has("svn_ra_get_dir2", "cdecl"):
    svn_ra_get_dir2 = _libs["svn_ra-1"].get("svn_ra_get_dir2", "cdecl")
    svn_ra_get_dir2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(apr_hash_t)), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), String, svn_revnum_t, apr_uint32_t, POINTER(apr_pool_t)]
    svn_ra_get_dir2.restype = POINTER(svn_error_t)
    svn_ra_get_dir2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1149
if _libs["svn_ra-1"].has("svn_ra_get_dir", "cdecl"):
    svn_ra_get_dir = _libs["svn_ra-1"].get("svn_ra_get_dir", "cdecl")
    svn_ra_get_dir.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, POINTER(POINTER(apr_hash_t)), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t)]
    svn_ra_get_dir.restype = POINTER(svn_error_t)
    svn_ra_get_dir.errcheck = _svn_errcheck

svn_ra_dirent_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(svn_dirent_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1171

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1204
if _libs["svn_ra-1"].has("svn_ra_list", "cdecl"):
    svn_ra_list = _libs["svn_ra-1"].get("svn_ra_list", "cdecl")
    svn_ra_list.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, POINTER(apr_array_header_t), svn_depth_t, apr_uint32_t, svn_ra_dirent_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_list.restype = POINTER(svn_error_t)
    svn_ra_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1243
if _libs["svn_ra-1"].has("svn_ra_get_mergeinfo", "cdecl"):
    svn_ra_get_mergeinfo = _libs["svn_ra-1"].get("svn_ra_get_mergeinfo", "cdecl")
    svn_ra_get_mergeinfo.argtypes = [POINTER(svn_ra_session_t), POINTER(svn_mergeinfo_catalog_t), POINTER(apr_array_header_t), svn_revnum_t, svn_mergeinfo_inheritance_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_ra_get_mergeinfo.restype = POINTER(svn_error_t)
    svn_ra_get_mergeinfo.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1311
if _libs["svn_ra-1"].has("svn_ra_do_update3", "cdecl"):
    svn_ra_do_update3 = _libs["svn_ra-1"].get("svn_ra_do_update3", "cdecl")
    svn_ra_do_update3.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_ra_do_update3.restype = POINTER(svn_error_t)
    svn_ra_do_update3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1332
if _libs["svn_ra-1"].has("svn_ra_do_update2", "cdecl"):
    svn_ra_do_update2 = _libs["svn_ra-1"].get("svn_ra_do_update2", "cdecl")
    svn_ra_do_update2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_depth_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_update2.restype = POINTER(svn_error_t)
    svn_ra_do_update2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1353
if _libs["svn_ra-1"].has("svn_ra_do_update", "cdecl"):
    svn_ra_do_update = _libs["svn_ra-1"].get("svn_ra_do_update", "cdecl")
    svn_ra_do_update.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter2_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_update.restype = POINTER(svn_error_t)
    svn_ra_do_update.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1378
if _libs["svn_ra-1"].has("svn_ra_do_switch3", "cdecl"):
    svn_ra_do_switch3 = _libs["svn_ra-1"].get("svn_ra_do_switch3", "cdecl")
    svn_ra_do_switch3.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_depth_t, String, svn_boolean_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_ra_do_switch3.restype = POINTER(svn_error_t)
    svn_ra_do_switch3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1401
if _libs["svn_ra-1"].has("svn_ra_do_switch2", "cdecl"):
    svn_ra_do_switch2 = _libs["svn_ra-1"].get("svn_ra_do_switch2", "cdecl")
    svn_ra_do_switch2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_depth_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_switch2.restype = POINTER(svn_error_t)
    svn_ra_do_switch2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1423
if _libs["svn_ra-1"].has("svn_ra_do_switch", "cdecl"):
    svn_ra_do_switch = _libs["svn_ra-1"].get("svn_ra_do_switch", "cdecl")
    svn_ra_do_switch.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter2_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_switch.restype = POINTER(svn_error_t)
    svn_ra_do_switch.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1476
if _libs["svn_ra-1"].has("svn_ra_do_status2", "cdecl"):
    svn_ra_do_status2 = _libs["svn_ra-1"].get("svn_ra_do_status2", "cdecl")
    svn_ra_do_status2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), String, svn_revnum_t, svn_depth_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_status2.restype = POINTER(svn_error_t)
    svn_ra_do_status2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1498
if _libs["svn_ra-1"].has("svn_ra_do_status", "cdecl"):
    svn_ra_do_status = _libs["svn_ra-1"].get("svn_ra_do_status", "cdecl")
    svn_ra_do_status.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter2_t)), POINTER(POINTER(None)), String, svn_revnum_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_status.restype = POINTER(svn_error_t)
    svn_ra_do_status.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1566
if _libs["svn_ra-1"].has("svn_ra_do_diff3", "cdecl"):
    svn_ra_do_diff3 = _libs["svn_ra-1"].get("svn_ra_do_diff3", "cdecl")
    svn_ra_do_diff3.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter3_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_depth_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_diff3.restype = POINTER(svn_error_t)
    svn_ra_do_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1590
if _libs["svn_ra-1"].has("svn_ra_do_diff2", "cdecl"):
    svn_ra_do_diff2 = _libs["svn_ra-1"].get("svn_ra_do_diff2", "cdecl")
    svn_ra_do_diff2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter2_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_diff2.restype = POINTER(svn_error_t)
    svn_ra_do_diff2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1611
if _libs["svn_ra-1"].has("svn_ra_do_diff", "cdecl"):
    svn_ra_do_diff = _libs["svn_ra-1"].get("svn_ra_do_diff", "cdecl")
    svn_ra_do_diff.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_ra_reporter2_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_do_diff.restype = POINTER(svn_error_t)
    svn_ra_do_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1682
if _libs["svn_ra-1"].has("svn_ra_get_log2", "cdecl"):
    svn_ra_get_log2 = _libs["svn_ra-1"].get("svn_ra_get_log2", "cdecl")
    svn_ra_get_log2.argtypes = [POINTER(svn_ra_session_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, c_int, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_log_entry_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_get_log2.restype = POINTER(svn_error_t)
    svn_ra_get_log2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1706
if _libs["svn_ra-1"].has("svn_ra_get_log", "cdecl"):
    svn_ra_get_log = _libs["svn_ra-1"].get("svn_ra_get_log", "cdecl")
    svn_ra_get_log.argtypes = [POINTER(svn_ra_session_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, c_int, svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_get_log.restype = POINTER(svn_error_t)
    svn_ra_get_log.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1727
if _libs["svn_ra-1"].has("svn_ra_check_path", "cdecl"):
    svn_ra_check_path = _libs["svn_ra-1"].get("svn_ra_check_path", "cdecl")
    svn_ra_check_path.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, POINTER(svn_node_kind_t), POINTER(apr_pool_t)]
    svn_ra_check_path.restype = POINTER(svn_error_t)
    svn_ra_check_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1743
if _libs["svn_ra-1"].has("svn_ra_stat", "cdecl"):
    svn_ra_stat = _libs["svn_ra-1"].get("svn_ra_stat", "cdecl")
    svn_ra_stat.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, POINTER(POINTER(svn_dirent_t)), POINTER(apr_pool_t)]
    svn_ra_stat.restype = POINTER(svn_error_t)
    svn_ra_stat.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1756
if _libs["svn_ra-1"].has("svn_ra_get_uuid2", "cdecl"):
    svn_ra_get_uuid2 = _libs["svn_ra-1"].get("svn_ra_get_uuid2", "cdecl")
    svn_ra_get_uuid2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_ra_get_uuid2.restype = POINTER(svn_error_t)
    svn_ra_get_uuid2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1769
if _libs["svn_ra-1"].has("svn_ra_get_uuid", "cdecl"):
    svn_ra_get_uuid = _libs["svn_ra-1"].get("svn_ra_get_uuid", "cdecl")
    svn_ra_get_uuid.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_ra_get_uuid.restype = POINTER(svn_error_t)
    svn_ra_get_uuid.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1781
if _libs["svn_ra-1"].has("svn_ra_get_repos_root2", "cdecl"):
    svn_ra_get_repos_root2 = _libs["svn_ra-1"].get("svn_ra_get_repos_root2", "cdecl")
    svn_ra_get_repos_root2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_ra_get_repos_root2.restype = POINTER(svn_error_t)
    svn_ra_get_repos_root2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1795
if _libs["svn_ra-1"].has("svn_ra_get_repos_root", "cdecl"):
    svn_ra_get_repos_root = _libs["svn_ra-1"].get("svn_ra_get_repos_root", "cdecl")
    svn_ra_get_repos_root.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_ra_get_repos_root.restype = POINTER(svn_error_t)
    svn_ra_get_repos_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1814
if _libs["svn_ra-1"].has("svn_ra_get_locations", "cdecl"):
    svn_ra_get_locations = _libs["svn_ra-1"].get("svn_ra_get_locations", "cdecl")
    svn_ra_get_locations.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(apr_hash_t)), String, svn_revnum_t, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_ra_get_locations.restype = POINTER(svn_error_t)
    svn_ra_get_locations.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1842
if _libs["svn_ra-1"].has("svn_ra_get_location_segments", "cdecl"):
    svn_ra_get_location_segments = _libs["svn_ra-1"].get("svn_ra_get_location_segments", "cdecl")
    svn_ra_get_location_segments.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, svn_revnum_t, svn_revnum_t, svn_location_segment_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_get_location_segments.restype = POINTER(svn_error_t)
    svn_ra_get_location_segments.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1891
if _libs["svn_ra-1"].has("svn_ra_get_file_revs2", "cdecl"):
    svn_ra_get_file_revs2 = _libs["svn_ra-1"].get("svn_ra_get_file_revs2", "cdecl")
    svn_ra_get_file_revs2.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_file_rev_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_get_file_revs2.restype = POINTER(svn_error_t)
    svn_ra_get_file_revs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1909
if _libs["svn_ra-1"].has("svn_ra_get_file_revs", "cdecl"):
    svn_ra_get_file_revs = _libs["svn_ra-1"].get("svn_ra_get_file_revs", "cdecl")
    svn_ra_get_file_revs.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, svn_revnum_t, svn_ra_file_rev_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_get_file_revs.restype = POINTER(svn_error_t)
    svn_ra_get_file_revs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1950
if _libs["svn_ra-1"].has("svn_ra_lock", "cdecl"):
    svn_ra_lock = _libs["svn_ra-1"].get("svn_ra_lock", "cdecl")
    svn_ra_lock.argtypes = [POINTER(svn_ra_session_t), POINTER(apr_hash_t), String, svn_boolean_t, svn_ra_lock_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_lock.restype = POINTER(svn_error_t)
    svn_ra_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 1982
if _libs["svn_ra-1"].has("svn_ra_unlock", "cdecl"):
    svn_ra_unlock = _libs["svn_ra-1"].get("svn_ra_unlock", "cdecl")
    svn_ra_unlock.argtypes = [POINTER(svn_ra_session_t), POINTER(apr_hash_t), svn_boolean_t, svn_ra_lock_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_unlock.restype = POINTER(svn_error_t)
    svn_ra_unlock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2001
if _libs["svn_ra-1"].has("svn_ra_get_lock", "cdecl"):
    svn_ra_get_lock = _libs["svn_ra-1"].get("svn_ra_get_lock", "cdecl")
    svn_ra_get_lock.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(svn_lock_t)), String, POINTER(apr_pool_t)]
    svn_ra_get_lock.restype = POINTER(svn_error_t)
    svn_ra_get_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2029
if _libs["svn_ra-1"].has("svn_ra_get_locks2", "cdecl"):
    svn_ra_get_locks2 = _libs["svn_ra-1"].get("svn_ra_get_locks2", "cdecl")
    svn_ra_get_locks2.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(apr_hash_t)), String, svn_depth_t, POINTER(apr_pool_t)]
    svn_ra_get_locks2.restype = POINTER(svn_error_t)
    svn_ra_get_locks2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2044
if _libs["svn_ra-1"].has("svn_ra_get_locks", "cdecl"):
    svn_ra_get_locks = _libs["svn_ra-1"].get("svn_ra_get_locks", "cdecl")
    svn_ra_get_locks.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(apr_hash_t)), String, POINTER(apr_pool_t)]
    svn_ra_get_locks.restype = POINTER(svn_error_t)
    svn_ra_get_locks.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2077
if _libs["svn_ra-1"].has("svn_ra_replay_range", "cdecl"):
    svn_ra_replay_range = _libs["svn_ra-1"].get("svn_ra_replay_range", "cdecl")
    svn_ra_replay_range.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_ra_replay_revstart_callback_t, svn_ra_replay_revfinish_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_ra_replay_range.restype = POINTER(svn_error_t)
    svn_ra_replay_range.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2107
if _libs["svn_ra-1"].has("svn_ra_replay", "cdecl"):
    svn_ra_replay = _libs["svn_ra-1"].get("svn_ra_replay", "cdecl")
    svn_ra_replay.argtypes = [POINTER(svn_ra_session_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_replay.restype = POINTER(svn_error_t)
    svn_ra_replay.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2131
if _libs["svn_ra-1"].has("svn_ra_get_deleted_rev", "cdecl"):
    svn_ra_get_deleted_rev = _libs["svn_ra-1"].get("svn_ra_get_deleted_rev", "cdecl")
    svn_ra_get_deleted_rev.argtypes = [POINTER(svn_ra_session_t), String, svn_revnum_t, svn_revnum_t, POINTER(svn_revnum_t), POINTER(apr_pool_t)]
    svn_ra_get_deleted_rev.restype = POINTER(svn_error_t)
    svn_ra_get_deleted_rev.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2158
if _libs["svn_ra-1"].has("svn_ra_get_inherited_props", "cdecl"):
    svn_ra_get_inherited_props = _libs["svn_ra-1"].get("svn_ra_get_inherited_props", "cdecl")
    svn_ra_get_inherited_props.argtypes = [POINTER(svn_ra_session_t), POINTER(POINTER(apr_array_header_t)), String, svn_revnum_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_ra_get_inherited_props.restype = POINTER(svn_error_t)
    svn_ra_get_inherited_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2184
if _libs["svn_ra-1"].has("svn_ra_has_capability", "cdecl"):
    svn_ra_has_capability = _libs["svn_ra-1"].get("svn_ra_has_capability", "cdecl")
    svn_ra_has_capability.argtypes = [POINTER(svn_ra_session_t), POINTER(svn_boolean_t), String, POINTER(apr_pool_t)]
    svn_ra_has_capability.restype = POINTER(svn_error_t)
    svn_ra_has_capability.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2290
if _libs["svn_ra-1"].has("svn_ra_print_modules", "cdecl"):
    svn_ra_print_modules = _libs["svn_ra-1"].get("svn_ra_print_modules", "cdecl")
    svn_ra_print_modules.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_ra_print_modules.restype = POINTER(svn_error_t)
    svn_ra_print_modules.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2302
if _libs["svn_ra-1"].has("svn_ra_print_ra_libraries", "cdecl"):
    svn_ra_print_ra_libraries = _libs["svn_ra-1"].get("svn_ra_print_ra_libraries", "cdecl")
    svn_ra_print_ra_libraries.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(None), POINTER(apr_pool_t)]
    svn_ra_print_ra_libraries.restype = POINTER(svn_error_t)
    svn_ra_print_ra_libraries.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2536
class struct_svn_ra_plugin_t(Structure):
    pass

struct_svn_ra_plugin_t.__slots__ = [
    'name',
    'description',
    'open',
    'get_latest_revnum',
    'get_dated_revision',
    'change_rev_prop',
    'rev_proplist',
    'rev_prop',
    'get_commit_editor',
    'get_file',
    'get_dir',
    'do_update',
    'do_switch',
    'do_status',
    'do_diff',
    'get_log',
    'check_path',
    'get_uuid',
    'get_repos_root',
    'get_locations',
    'get_file_revs',
    'get_version',
]
struct_svn_ra_plugin_t._fields_ = [
    ('name', String),
    ('description', String),
    ('open', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), String, POINTER(svn_ra_callbacks_t), POINTER(None), POINTER(apr_hash_t), POINTER(apr_pool_t))),
    ('get_latest_revnum', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_revnum_t), POINTER(apr_pool_t))),
    ('get_dated_revision', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_revnum_t), apr_time_t, POINTER(apr_pool_t))),
    ('change_rev_prop', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, String, POINTER(svn_string_t), POINTER(apr_pool_t))),
    ('rev_proplist', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t))),
    ('rev_prop', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, String, POINTER(POINTER(svn_string_t)), POINTER(apr_pool_t))),
    ('get_commit_editor', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), String, svn_commit_callback_t, POINTER(None), POINTER(apr_pool_t))),
    ('get_file', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(svn_stream_t), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t))),
    ('get_dir', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(POINTER(apr_hash_t)), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t))),
    ('do_update', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_ra_reporter_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t))),
    ('do_switch', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_ra_reporter_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t))),
    ('do_status', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_ra_reporter_t)), POINTER(POINTER(None)), String, svn_revnum_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t))),
    ('do_diff', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(svn_ra_reporter_t)), POINTER(POINTER(None)), svn_revnum_t, String, svn_boolean_t, svn_boolean_t, String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t))),
    ('get_log', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t))),
    ('check_path', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(svn_node_kind_t), POINTER(apr_pool_t))),
    ('get_uuid', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(c_char)), POINTER(apr_pool_t))),
    ('get_repos_root', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(c_char)), POINTER(apr_pool_t))),
    ('get_locations', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(apr_hash_t)), String, svn_revnum_t, POINTER(apr_array_header_t), POINTER(apr_pool_t))),
    ('get_file_revs', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, svn_revnum_t, svn_ra_file_rev_handler_t, POINTER(None), POINTER(apr_pool_t))),
    ('get_version', CFUNCTYPE(UNCHECKED(POINTER(svn_version_t)), )),
]

svn_ra_plugin_t = struct_svn_ra_plugin_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2536

svn_ra_init_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), c_int, POINTER(apr_pool_t), POINTER(apr_hash_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2555

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2592
if _libs["svn_ra-1"].has("svn_ra_dav_init", "cdecl"):
    svn_ra_dav_init = _libs["svn_ra-1"].get("svn_ra_dav_init", "cdecl")
    svn_ra_dav_init.argtypes = [c_int, POINTER(apr_pool_t), POINTER(apr_hash_t)]
    svn_ra_dav_init.restype = POINTER(svn_error_t)
    svn_ra_dav_init.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2601
if _libs["svn_ra-1"].has("svn_ra_local_init", "cdecl"):
    svn_ra_local_init = _libs["svn_ra-1"].get("svn_ra_local_init", "cdecl")
    svn_ra_local_init.argtypes = [c_int, POINTER(apr_pool_t), POINTER(apr_hash_t)]
    svn_ra_local_init.restype = POINTER(svn_error_t)
    svn_ra_local_init.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2610
if _libs["svn_ra-1"].has("svn_ra_svn_init", "cdecl"):
    svn_ra_svn_init = _libs["svn_ra-1"].get("svn_ra_svn_init", "cdecl")
    svn_ra_svn_init.argtypes = [c_int, POINTER(apr_pool_t), POINTER(apr_hash_t)]
    svn_ra_svn_init.restype = POINTER(svn_error_t)
    svn_ra_svn_init.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2620
if _libs["svn_ra-1"].has("svn_ra_serf_init", "cdecl"):
    svn_ra_serf_init = _libs["svn_ra-1"].get("svn_ra_serf_init", "cdecl")
    svn_ra_serf_init.argtypes = [c_int, POINTER(apr_pool_t), POINTER(apr_hash_t)]
    svn_ra_serf_init.restype = POINTER(svn_error_t)
    svn_ra_serf_init.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2633
if _libs["svn_ra-1"].has("svn_ra_init_ra_libs", "cdecl"):
    svn_ra_init_ra_libs = _libs["svn_ra-1"].get("svn_ra_init_ra_libs", "cdecl")
    svn_ra_init_ra_libs.argtypes = [POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_ra_init_ra_libs.restype = POINTER(svn_error_t)
    svn_ra_init_ra_libs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2646
if _libs["svn_ra-1"].has("svn_ra_get_ra_library", "cdecl"):
    svn_ra_get_ra_library = _libs["svn_ra-1"].get("svn_ra_get_ra_library", "cdecl")
    svn_ra_get_ra_library.argtypes = [POINTER(POINTER(svn_ra_plugin_t)), POINTER(None), String, POINTER(apr_pool_t)]
    svn_ra_get_ra_library.restype = POINTER(svn_error_t)
    svn_ra_get_ra_library.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 98
if _libs["svn_wc-1"].has("svn_wc_version", "cdecl"):
    svn_wc_version = _libs["svn_wc-1"].get("svn_wc_version", "cdecl")
    svn_wc_version.argtypes = []
    svn_wc_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 179
class struct_svn_wc_context_t(Structure):
    pass

svn_wc_context_t = struct_svn_wc_context_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 179

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 200
if _libs["svn_wc-1"].has("svn_wc_context_create", "cdecl"):
    svn_wc_context_create = _libs["svn_wc-1"].get("svn_wc_context_create", "cdecl")
    svn_wc_context_create.argtypes = [POINTER(POINTER(svn_wc_context_t)), POINTER(svn_config_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_context_create.restype = POINTER(svn_error_t)
    svn_wc_context_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 212
if _libs["svn_wc-1"].has("svn_wc_context_destroy", "cdecl"):
    svn_wc_context_destroy = _libs["svn_wc-1"].get("svn_wc_context_destroy", "cdecl")
    svn_wc_context_destroy.argtypes = [POINTER(svn_wc_context_t)]
    svn_wc_context_destroy.restype = POINTER(svn_error_t)
    svn_wc_context_destroy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 237
class struct_svn_wc_adm_access_t(Structure):
    pass

svn_wc_adm_access_t = struct_svn_wc_adm_access_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 237

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 285
if _libs["svn_wc-1"].has("svn_wc_adm_open3", "cdecl"):
    svn_wc_adm_open3 = _libs["svn_wc-1"].get("svn_wc_adm_open3", "cdecl")
    svn_wc_adm_open3.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_adm_open3.restype = POINTER(svn_error_t)
    svn_wc_adm_open3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 301
if _libs["svn_wc-1"].has("svn_wc_adm_open2", "cdecl"):
    svn_wc_adm_open2 = _libs["svn_wc-1"].get("svn_wc_adm_open2", "cdecl")
    svn_wc_adm_open2.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, POINTER(apr_pool_t)]
    svn_wc_adm_open2.restype = POINTER(svn_error_t)
    svn_wc_adm_open2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 317
if _libs["svn_wc-1"].has("svn_wc_adm_open", "cdecl"):
    svn_wc_adm_open = _libs["svn_wc-1"].get("svn_wc_adm_open", "cdecl")
    svn_wc_adm_open.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_adm_open.restype = POINTER(svn_error_t)
    svn_wc_adm_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 342
if _libs["svn_wc-1"].has("svn_wc_adm_probe_open3", "cdecl"):
    svn_wc_adm_probe_open3 = _libs["svn_wc-1"].get("svn_wc_adm_probe_open3", "cdecl")
    svn_wc_adm_probe_open3.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_adm_probe_open3.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_open3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 359
if _libs["svn_wc-1"].has("svn_wc_adm_probe_open2", "cdecl"):
    svn_wc_adm_probe_open2 = _libs["svn_wc-1"].get("svn_wc_adm_probe_open2", "cdecl")
    svn_wc_adm_probe_open2.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, POINTER(apr_pool_t)]
    svn_wc_adm_probe_open2.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_open2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 375
if _libs["svn_wc-1"].has("svn_wc_adm_probe_open", "cdecl"):
    svn_wc_adm_probe_open = _libs["svn_wc-1"].get("svn_wc_adm_probe_open", "cdecl")
    svn_wc_adm_probe_open.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_adm_probe_open.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 408
if _libs["svn_wc-1"].has("svn_wc_adm_open_anchor", "cdecl"):
    svn_wc_adm_open_anchor = _libs["svn_wc-1"].get("svn_wc_adm_open_anchor", "cdecl")
    svn_wc_adm_open_anchor.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(POINTER(svn_wc_adm_access_t)), POINTER(POINTER(c_char)), String, svn_boolean_t, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_adm_open_anchor.restype = POINTER(svn_error_t)
    svn_wc_adm_open_anchor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 431
if _libs["svn_wc-1"].has("svn_wc_adm_retrieve", "cdecl"):
    svn_wc_adm_retrieve = _libs["svn_wc-1"].get("svn_wc_adm_retrieve", "cdecl")
    svn_wc_adm_retrieve.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, POINTER(apr_pool_t)]
    svn_wc_adm_retrieve.restype = POINTER(svn_error_t)
    svn_wc_adm_retrieve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 447
if _libs["svn_wc-1"].has("svn_wc_adm_probe_retrieve", "cdecl"):
    svn_wc_adm_probe_retrieve = _libs["svn_wc-1"].get("svn_wc_adm_probe_retrieve", "cdecl")
    svn_wc_adm_probe_retrieve.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, POINTER(apr_pool_t)]
    svn_wc_adm_probe_retrieve.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_retrieve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 479
if _libs["svn_wc-1"].has("svn_wc_adm_probe_try3", "cdecl"):
    svn_wc_adm_probe_try3 = _libs["svn_wc-1"].get("svn_wc_adm_probe_try3", "cdecl")
    svn_wc_adm_probe_try3.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_adm_probe_try3.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_try3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 496
if _libs["svn_wc-1"].has("svn_wc_adm_probe_try2", "cdecl"):
    svn_wc_adm_probe_try2 = _libs["svn_wc-1"].get("svn_wc_adm_probe_try2", "cdecl")
    svn_wc_adm_probe_try2.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, c_int, POINTER(apr_pool_t)]
    svn_wc_adm_probe_try2.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_try2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 512
if _libs["svn_wc-1"].has("svn_wc_adm_probe_try", "cdecl"):
    svn_wc_adm_probe_try = _libs["svn_wc-1"].get("svn_wc_adm_probe_try", "cdecl")
    svn_wc_adm_probe_try.argtypes = [POINTER(POINTER(svn_wc_adm_access_t)), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_adm_probe_try.restype = POINTER(svn_error_t)
    svn_wc_adm_probe_try.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 533
if _libs["svn_wc-1"].has("svn_wc_adm_close2", "cdecl"):
    svn_wc_adm_close2 = _libs["svn_wc-1"].get("svn_wc_adm_close2", "cdecl")
    svn_wc_adm_close2.argtypes = [POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_adm_close2.restype = POINTER(svn_error_t)
    svn_wc_adm_close2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 544
if _libs["svn_wc-1"].has("svn_wc_adm_close", "cdecl"):
    svn_wc_adm_close = _libs["svn_wc-1"].get("svn_wc_adm_close", "cdecl")
    svn_wc_adm_close.argtypes = [POINTER(svn_wc_adm_access_t)]
    svn_wc_adm_close.restype = POINTER(svn_error_t)
    svn_wc_adm_close.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 552
if _libs["svn_wc-1"].has("svn_wc_adm_access_path", "cdecl"):
    svn_wc_adm_access_path = _libs["svn_wc-1"].get("svn_wc_adm_access_path", "cdecl")
    svn_wc_adm_access_path.argtypes = [POINTER(svn_wc_adm_access_t)]
    svn_wc_adm_access_path.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 560
if _libs["svn_wc-1"].has("svn_wc_adm_access_pool", "cdecl"):
    svn_wc_adm_access_pool = _libs["svn_wc-1"].get("svn_wc_adm_access_pool", "cdecl")
    svn_wc_adm_access_pool.argtypes = [POINTER(svn_wc_adm_access_t)]
    svn_wc_adm_access_pool.restype = POINTER(apr_pool_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 572
if _libs["svn_wc-1"].has("svn_wc_adm_locked", "cdecl"):
    svn_wc_adm_locked = _libs["svn_wc-1"].get("svn_wc_adm_locked", "cdecl")
    svn_wc_adm_locked.argtypes = [POINTER(svn_wc_adm_access_t)]
    svn_wc_adm_locked.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 589
if _libs["svn_wc-1"].has("svn_wc_locked2", "cdecl"):
    svn_wc_locked2 = _libs["svn_wc-1"].get("svn_wc_locked2", "cdecl")
    svn_wc_locked2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_locked2.restype = POINTER(svn_error_t)
    svn_wc_locked2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 603
if _libs["svn_wc-1"].has("svn_wc_locked", "cdecl"):
    svn_wc_locked = _libs["svn_wc-1"].get("svn_wc_locked", "cdecl")
    svn_wc_locked.argtypes = [POINTER(svn_boolean_t), String, POINTER(apr_pool_t)]
    svn_wc_locked.restype = POINTER(svn_error_t)
    svn_wc_locked.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 639
if _libs["svn_wc-1"].has("svn_wc_is_adm_dir", "cdecl"):
    svn_wc_is_adm_dir = _libs["svn_wc-1"].get("svn_wc_is_adm_dir", "cdecl")
    svn_wc_is_adm_dir.argtypes = [String, POINTER(apr_pool_t)]
    svn_wc_is_adm_dir.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 651
if _libs["svn_wc-1"].has("svn_wc_get_adm_dir", "cdecl"):
    svn_wc_get_adm_dir = _libs["svn_wc-1"].get("svn_wc_get_adm_dir", "cdecl")
    svn_wc_get_adm_dir.argtypes = [POINTER(apr_pool_t)]
    svn_wc_get_adm_dir.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 668
if _libs["svn_wc-1"].has("svn_wc_set_adm_dir", "cdecl"):
    svn_wc_set_adm_dir = _libs["svn_wc-1"].get("svn_wc_set_adm_dir", "cdecl")
    svn_wc_set_adm_dir.argtypes = [String, POINTER(apr_pool_t)]
    svn_wc_set_adm_dir.restype = POINTER(svn_error_t)
    svn_wc_set_adm_dir.errcheck = _svn_errcheck

svn_wc_external_update_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t), POINTER(svn_string_t), svn_depth_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 688

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 707
class struct_svn_wc_traversal_info_t(Structure):
    pass

svn_wc_traversal_info_t = struct_svn_wc_traversal_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 707

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 717
if _libs["svn_wc-1"].has("svn_wc_init_traversal_info", "cdecl"):
    svn_wc_init_traversal_info = _libs["svn_wc-1"].get("svn_wc_init_traversal_info", "cdecl")
    svn_wc_init_traversal_info.argtypes = [POINTER(apr_pool_t)]
    svn_wc_init_traversal_info.restype = POINTER(svn_wc_traversal_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 745
if _libs["svn_wc-1"].has("svn_wc_edited_externals", "cdecl"):
    svn_wc_edited_externals = _libs["svn_wc-1"].get("svn_wc_edited_externals", "cdecl")
    svn_wc_edited_externals.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_traversal_info_t)]
    svn_wc_edited_externals.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 775
if _libs["svn_wc-1"].has("svn_wc_traversed_depths", "cdecl"):
    svn_wc_traversed_depths = _libs["svn_wc-1"].get("svn_wc_traversed_depths", "cdecl")
    svn_wc_traversed_depths.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_traversal_info_t)]
    svn_wc_traversed_depths.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 812
class struct_svn_wc_external_item2_t(Structure):
    pass

struct_svn_wc_external_item2_t.__slots__ = [
    'target_dir',
    'url',
    'revision',
    'peg_revision',
]
struct_svn_wc_external_item2_t._fields_ = [
    ('target_dir', String),
    ('url', String),
    ('revision', svn_opt_revision_t),
    ('peg_revision', svn_opt_revision_t),
]

svn_wc_external_item2_t = struct_svn_wc_external_item2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 812

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 828
if _libs["svn_wc-1"].has("svn_wc_external_item2_create", "cdecl"):
    svn_wc_external_item2_create = _libs["svn_wc-1"].get("svn_wc_external_item2_create", "cdecl")
    svn_wc_external_item2_create.argtypes = [POINTER(POINTER(svn_wc_external_item2_t)), POINTER(apr_pool_t)]
    svn_wc_external_item2_create.restype = POINTER(svn_error_t)
    svn_wc_external_item2_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 840
if _libs["svn_wc-1"].has("svn_wc_external_item_create", "cdecl"):
    svn_wc_external_item_create = _libs["svn_wc-1"].get("svn_wc_external_item_create", "cdecl")
    svn_wc_external_item_create.argtypes = [POINTER(POINTER(svn_wc_external_item2_t)), POINTER(apr_pool_t)]
    svn_wc_external_item_create.restype = POINTER(svn_error_t)
    svn_wc_external_item_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 850
if _libs["svn_wc-1"].has("svn_wc_external_item2_dup", "cdecl"):
    svn_wc_external_item2_dup = _libs["svn_wc-1"].get("svn_wc_external_item2_dup", "cdecl")
    svn_wc_external_item2_dup.argtypes = [POINTER(svn_wc_external_item2_t), POINTER(apr_pool_t)]
    svn_wc_external_item2_dup.restype = POINTER(svn_wc_external_item2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 872
class struct_svn_wc_external_item_t(Structure):
    pass

struct_svn_wc_external_item_t.__slots__ = [
    'target_dir',
    'url',
    'revision',
]
struct_svn_wc_external_item_t._fields_ = [
    ('target_dir', String),
    ('url', String),
    ('revision', svn_opt_revision_t),
]

svn_wc_external_item_t = struct_svn_wc_external_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 872

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 883
if _libs["svn_wc-1"].has("svn_wc_external_item_dup", "cdecl"):
    svn_wc_external_item_dup = _libs["svn_wc-1"].get("svn_wc_external_item_dup", "cdecl")
    svn_wc_external_item_dup.argtypes = [POINTER(svn_wc_external_item_t), POINTER(apr_pool_t)]
    svn_wc_external_item_dup.restype = POINTER(svn_wc_external_item_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 916
if _libs["svn_wc-1"].has("svn_wc_parse_externals_description3", "cdecl"):
    svn_wc_parse_externals_description3 = _libs["svn_wc-1"].get("svn_wc_parse_externals_description3", "cdecl")
    svn_wc_parse_externals_description3.argtypes = [POINTER(POINTER(apr_array_header_t)), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_parse_externals_description3.restype = POINTER(svn_error_t)
    svn_wc_parse_externals_description3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 934
if _libs["svn_wc-1"].has("svn_wc_parse_externals_description2", "cdecl"):
    svn_wc_parse_externals_description2 = _libs["svn_wc-1"].get("svn_wc_parse_externals_description2", "cdecl")
    svn_wc_parse_externals_description2.argtypes = [POINTER(POINTER(apr_array_header_t)), String, String, POINTER(apr_pool_t)]
    svn_wc_parse_externals_description2.restype = POINTER(svn_error_t)
    svn_wc_parse_externals_description2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 949
if _libs["svn_wc-1"].has("svn_wc_parse_externals_description", "cdecl"):
    svn_wc_parse_externals_description = _libs["svn_wc-1"].get("svn_wc_parse_externals_description", "cdecl")
    svn_wc_parse_externals_description.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, POINTER(apr_pool_t)]
    svn_wc_parse_externals_description.restype = POINTER(svn_error_t)
    svn_wc_parse_externals_description.errcheck = _svn_errcheck

enum_svn_wc_notify_action_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_add = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_copy = (svn_wc_notify_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_delete = (svn_wc_notify_copy + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_restore = (svn_wc_notify_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_revert = (svn_wc_notify_restore + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_revert = (svn_wc_notify_revert + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_resolved = (svn_wc_notify_failed_revert + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_skip = (svn_wc_notify_resolved + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_delete = (svn_wc_notify_skip + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_add = (svn_wc_notify_update_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_update = (svn_wc_notify_update_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_completed = (svn_wc_notify_update_update + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_external = (svn_wc_notify_update_completed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_status_completed = (svn_wc_notify_update_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_status_external = (svn_wc_notify_status_completed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_modified = (svn_wc_notify_status_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_added = (svn_wc_notify_commit_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_deleted = (svn_wc_notify_commit_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_replaced = (svn_wc_notify_commit_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_postfix_txdelta = (svn_wc_notify_commit_replaced + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_blame_revision = (svn_wc_notify_commit_postfix_txdelta + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_locked = (svn_wc_notify_blame_revision + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_unlocked = (svn_wc_notify_locked + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_lock = (svn_wc_notify_unlocked + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_unlock = (svn_wc_notify_failed_lock + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_exists = (svn_wc_notify_failed_unlock + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_changelist_set = (svn_wc_notify_exists + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_changelist_clear = (svn_wc_notify_changelist_set + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_changelist_moved = (svn_wc_notify_changelist_clear + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_merge_begin = (svn_wc_notify_changelist_moved + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_foreign_merge_begin = (svn_wc_notify_merge_begin + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_replace = (svn_wc_notify_foreign_merge_begin + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_property_added = (svn_wc_notify_update_replace + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_property_modified = (svn_wc_notify_property_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_property_deleted = (svn_wc_notify_property_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_property_deleted_nonexistent = (svn_wc_notify_property_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_revprop_set = (svn_wc_notify_property_deleted_nonexistent + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_revprop_deleted = (svn_wc_notify_revprop_set + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_merge_completed = (svn_wc_notify_revprop_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_tree_conflict = (svn_wc_notify_merge_completed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_external = (svn_wc_notify_tree_conflict + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_started = (svn_wc_notify_failed_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_skip_obstruction = (svn_wc_notify_update_started + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_skip_working_only = (svn_wc_notify_update_skip_obstruction + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_skip_access_denied = (svn_wc_notify_update_skip_working_only + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_external_removed = (svn_wc_notify_update_skip_access_denied + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_shadowed_add = (svn_wc_notify_update_external_removed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_shadowed_update = (svn_wc_notify_update_shadowed_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_shadowed_delete = (svn_wc_notify_update_shadowed_update + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_merge_record_info = (svn_wc_notify_update_shadowed_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_upgraded_path = (svn_wc_notify_merge_record_info + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_merge_record_info_begin = (svn_wc_notify_upgraded_path + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_merge_elide_info = (svn_wc_notify_merge_record_info_begin + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_patch = (svn_wc_notify_merge_elide_info + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_patch_applied_hunk = (svn_wc_notify_patch + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_patch_rejected_hunk = (svn_wc_notify_patch_applied_hunk + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_patch_hunk_already_applied = (svn_wc_notify_patch_rejected_hunk + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_copied = (svn_wc_notify_patch_hunk_already_applied + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_copied_replaced = (svn_wc_notify_commit_copied + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_url_redirect = (svn_wc_notify_commit_copied_replaced + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_path_nonexistent = (svn_wc_notify_url_redirect + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_exclude = (svn_wc_notify_path_nonexistent + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_conflict = (svn_wc_notify_exclude + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_missing = (svn_wc_notify_failed_conflict + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_out_of_date = (svn_wc_notify_failed_missing + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_no_parent = (svn_wc_notify_failed_out_of_date + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_locked = (svn_wc_notify_failed_no_parent + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_forbidden_by_server = (svn_wc_notify_failed_locked + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_skip_conflicted = (svn_wc_notify_failed_forbidden_by_server + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_update_broken_lock = (svn_wc_notify_skip_conflicted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_obstruction = (svn_wc_notify_update_broken_lock + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_conflict_resolver_starting = (svn_wc_notify_failed_obstruction + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_conflict_resolver_done = (svn_wc_notify_conflict_resolver_starting + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_left_local_modifications = (svn_wc_notify_conflict_resolver_done + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_foreign_copy_begin = (svn_wc_notify_left_local_modifications + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_move_broken = (svn_wc_notify_foreign_copy_begin + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_cleanup_external = (svn_wc_notify_move_broken + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_failed_requires_target = (svn_wc_notify_cleanup_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_info_external = (svn_wc_notify_failed_requires_target + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_commit_finalizing = (svn_wc_notify_info_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_resolved_text = (svn_wc_notify_commit_finalizing + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_resolved_prop = (svn_wc_notify_resolved_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_resolved_tree = (svn_wc_notify_resolved_prop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_begin_search_tree_conflict_details = (svn_wc_notify_resolved_tree + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_tree_conflict_details_progress = (svn_wc_notify_begin_search_tree_conflict_details + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_end_search_tree_conflict_details = (svn_wc_notify_tree_conflict_details_progress + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

svn_wc_notify_action_t = enum_svn_wc_notify_action_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1308

enum_svn_wc_notify_state_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_inapplicable = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_unknown = (svn_wc_notify_state_inapplicable + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_unchanged = (svn_wc_notify_state_unknown + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_missing = (svn_wc_notify_state_unchanged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_obstructed = (svn_wc_notify_state_missing + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_changed = (svn_wc_notify_state_obstructed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_merged = (svn_wc_notify_state_changed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_conflicted = (svn_wc_notify_state_merged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_source_missing = (svn_wc_notify_state_conflicted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

svn_wc_notify_state_t = enum_svn_wc_notify_state_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1340

enum_svn_wc_notify_lock_state_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_inapplicable = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_unknown = (svn_wc_notify_lock_state_inapplicable + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_unchanged = (svn_wc_notify_lock_state_unknown + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_locked = (svn_wc_notify_lock_state_unchanged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_unlocked = (svn_wc_notify_lock_state_locked + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

svn_wc_notify_lock_state_t = enum_svn_wc_notify_lock_state_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1362

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1495
class struct_svn_wc_notify_t(Structure):
    pass

struct_svn_wc_notify_t.__slots__ = [
    'path',
    'action',
    'kind',
    'mime_type',
    'lock',
    'err',
    'content_state',
    'prop_state',
    'lock_state',
    'revision',
    'changelist_name',
    'merge_range',
    'url',
    'path_prefix',
    'prop_name',
    'rev_props',
    'old_revision',
    'hunk_original_start',
    'hunk_original_length',
    'hunk_modified_start',
    'hunk_modified_length',
    'hunk_matched_line',
    'hunk_fuzz',
]
struct_svn_wc_notify_t._fields_ = [
    ('path', String),
    ('action', svn_wc_notify_action_t),
    ('kind', svn_node_kind_t),
    ('mime_type', String),
    ('lock', POINTER(svn_lock_t)),
    ('err', POINTER(svn_error_t)),
    ('content_state', svn_wc_notify_state_t),
    ('prop_state', svn_wc_notify_state_t),
    ('lock_state', svn_wc_notify_lock_state_t),
    ('revision', svn_revnum_t),
    ('changelist_name', String),
    ('merge_range', POINTER(svn_merge_range_t)),
    ('url', String),
    ('path_prefix', String),
    ('prop_name', String),
    ('rev_props', POINTER(apr_hash_t)),
    ('old_revision', svn_revnum_t),
    ('hunk_original_start', svn_linenum_t),
    ('hunk_original_length', svn_linenum_t),
    ('hunk_modified_start', svn_linenum_t),
    ('hunk_modified_length', svn_linenum_t),
    ('hunk_matched_line', svn_linenum_t),
    ('hunk_fuzz', svn_linenum_t),
]

svn_wc_notify_t = struct_svn_wc_notify_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1495

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1508
if _libs["svn_wc-1"].has("svn_wc_create_notify", "cdecl"):
    svn_wc_create_notify = _libs["svn_wc-1"].get("svn_wc_create_notify", "cdecl")
    svn_wc_create_notify.argtypes = [String, svn_wc_notify_action_t, POINTER(apr_pool_t)]
    svn_wc_create_notify.restype = POINTER(svn_wc_notify_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1524
if _libs["svn_wc-1"].has("svn_wc_create_notify_url", "cdecl"):
    svn_wc_create_notify_url = _libs["svn_wc-1"].get("svn_wc_create_notify_url", "cdecl")
    svn_wc_create_notify_url.argtypes = [String, svn_wc_notify_action_t, POINTER(apr_pool_t)]
    svn_wc_create_notify_url.restype = POINTER(svn_wc_notify_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1534
if _libs["svn_wc-1"].has("svn_wc_dup_notify", "cdecl"):
    svn_wc_dup_notify = _libs["svn_wc-1"].get("svn_wc_dup_notify", "cdecl")
    svn_wc_dup_notify.argtypes = [POINTER(svn_wc_notify_t), POINTER(apr_pool_t)]
    svn_wc_dup_notify.restype = POINTER(svn_wc_notify_t)

svn_wc_notify_func2_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(svn_wc_notify_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1553

svn_wc_notify_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), String, svn_wc_notify_action_t, svn_node_kind_t, String, svn_wc_notify_state_t, svn_wc_notify_state_t, svn_revnum_t)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1563

enum_svn_wc_conflict_action_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

svn_wc_conflict_action_edit = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

svn_wc_conflict_action_add = (svn_wc_conflict_action_edit + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

svn_wc_conflict_action_delete = (svn_wc_conflict_action_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

svn_wc_conflict_action_replace = (svn_wc_conflict_action_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

svn_wc_conflict_action_t = enum_svn_wc_conflict_action_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1630

enum_svn_wc_conflict_reason_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_edited = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_obstructed = (svn_wc_conflict_reason_edited + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_deleted = (svn_wc_conflict_reason_obstructed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_missing = (svn_wc_conflict_reason_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_unversioned = (svn_wc_conflict_reason_missing + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_added = (svn_wc_conflict_reason_unversioned + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_replaced = (svn_wc_conflict_reason_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_moved_away = (svn_wc_conflict_reason_replaced + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_moved_here = (svn_wc_conflict_reason_moved_away + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

svn_wc_conflict_reason_t = enum_svn_wc_conflict_reason_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1658

enum_svn_wc_conflict_kind_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1674

svn_wc_conflict_kind_text = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1674

svn_wc_conflict_kind_property = (svn_wc_conflict_kind_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1674

svn_wc_conflict_kind_tree = (svn_wc_conflict_kind_property + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1674

svn_wc_conflict_kind_t = enum_svn_wc_conflict_kind_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1674

enum_svn_wc_operation_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

svn_wc_operation_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

svn_wc_operation_update = (svn_wc_operation_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

svn_wc_operation_switch = (svn_wc_operation_update + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

svn_wc_operation_merge = (svn_wc_operation_switch + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

svn_wc_operation_t = enum_svn_wc_operation_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1688

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1735
class struct_svn_wc_conflict_version_t(Structure):
    pass

struct_svn_wc_conflict_version_t.__slots__ = [
    'repos_url',
    'peg_rev',
    'path_in_repos',
    'node_kind',
    'repos_uuid',
]
struct_svn_wc_conflict_version_t._fields_ = [
    ('repos_url', String),
    ('peg_rev', svn_revnum_t),
    ('path_in_repos', String),
    ('node_kind', svn_node_kind_t),
    ('repos_uuid', String),
]

svn_wc_conflict_version_t = struct_svn_wc_conflict_version_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1735

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1752
if _libs["svn_wc-1"].has("svn_wc_conflict_version_create2", "cdecl"):
    svn_wc_conflict_version_create2 = _libs["svn_wc-1"].get("svn_wc_conflict_version_create2", "cdecl")
    svn_wc_conflict_version_create2.argtypes = [String, String, String, svn_revnum_t, svn_node_kind_t, POINTER(apr_pool_t)]
    svn_wc_conflict_version_create2.restype = POINTER(svn_wc_conflict_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1767
if _libs["svn_wc-1"].has("svn_wc_conflict_version_create", "cdecl"):
    svn_wc_conflict_version_create = _libs["svn_wc-1"].get("svn_wc_conflict_version_create", "cdecl")
    svn_wc_conflict_version_create.argtypes = [String, String, svn_revnum_t, svn_node_kind_t, POINTER(apr_pool_t)]
    svn_wc_conflict_version_create.restype = POINTER(svn_wc_conflict_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1779
if _libs["svn_wc-1"].has("svn_wc_conflict_version_dup", "cdecl"):
    svn_wc_conflict_version_dup = _libs["svn_wc-1"].get("svn_wc_conflict_version_dup", "cdecl")
    svn_wc_conflict_version_dup.argtypes = [POINTER(svn_wc_conflict_version_t), POINTER(apr_pool_t)]
    svn_wc_conflict_version_dup.restype = POINTER(svn_wc_conflict_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1930
class struct_svn_wc_conflict_description2_t(Structure):
    pass

struct_svn_wc_conflict_description2_t.__slots__ = [
    'local_abspath',
    'node_kind',
    'kind',
    'property_name',
    'is_binary',
    'mime_type',
    'action',
    'reason',
    'base_abspath',
    'their_abspath',
    'my_abspath',
    'merged_file',
    'operation',
    'src_left_version',
    'src_right_version',
    'prop_reject_abspath',
    'prop_value_base',
    'prop_value_working',
    'prop_value_incoming_old',
    'prop_value_incoming_new',
]
struct_svn_wc_conflict_description2_t._fields_ = [
    ('local_abspath', String),
    ('node_kind', svn_node_kind_t),
    ('kind', svn_wc_conflict_kind_t),
    ('property_name', String),
    ('is_binary', svn_boolean_t),
    ('mime_type', String),
    ('action', svn_wc_conflict_action_t),
    ('reason', svn_wc_conflict_reason_t),
    ('base_abspath', String),
    ('their_abspath', String),
    ('my_abspath', String),
    ('merged_file', String),
    ('operation', svn_wc_operation_t),
    ('src_left_version', POINTER(svn_wc_conflict_version_t)),
    ('src_right_version', POINTER(svn_wc_conflict_version_t)),
    ('prop_reject_abspath', String),
    ('prop_value_base', POINTER(svn_string_t)),
    ('prop_value_working', POINTER(svn_string_t)),
    ('prop_value_incoming_old', POINTER(svn_string_t)),
    ('prop_value_incoming_new', POINTER(svn_string_t)),
]

svn_wc_conflict_description2_t = struct_svn_wc_conflict_description2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1930

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2023
class struct_svn_wc_conflict_description_t(Structure):
    pass

struct_svn_wc_conflict_description_t.__slots__ = [
    'path',
    'node_kind',
    'kind',
    'property_name',
    'is_binary',
    'mime_type',
    'access',
    'action',
    'reason',
    'base_file',
    'their_file',
    'my_file',
    'merged_file',
    'operation',
    'src_left_version',
    'src_right_version',
]
struct_svn_wc_conflict_description_t._fields_ = [
    ('path', String),
    ('node_kind', svn_node_kind_t),
    ('kind', svn_wc_conflict_kind_t),
    ('property_name', String),
    ('is_binary', svn_boolean_t),
    ('mime_type', String),
    ('access', POINTER(svn_wc_adm_access_t)),
    ('action', svn_wc_conflict_action_t),
    ('reason', svn_wc_conflict_reason_t),
    ('base_file', String),
    ('their_file', String),
    ('my_file', String),
    ('merged_file', String),
    ('operation', svn_wc_operation_t),
    ('src_left_version', POINTER(svn_wc_conflict_version_t)),
    ('src_right_version', POINTER(svn_wc_conflict_version_t)),
]

svn_wc_conflict_description_t = struct_svn_wc_conflict_description_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2023

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2040
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_text2", "cdecl"):
    svn_wc_conflict_description_create_text2 = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_text2", "cdecl")
    svn_wc_conflict_description_create_text2.argtypes = [String, POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_text2.restype = POINTER(svn_wc_conflict_description2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2052
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_text", "cdecl"):
    svn_wc_conflict_description_create_text = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_text", "cdecl")
    svn_wc_conflict_description_create_text.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_text.restype = POINTER(svn_wc_conflict_description_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2071
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_prop2", "cdecl"):
    svn_wc_conflict_description_create_prop2 = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_prop2", "cdecl")
    svn_wc_conflict_description_create_prop2.argtypes = [String, svn_node_kind_t, String, POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_prop2.restype = POINTER(svn_wc_conflict_description2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2084
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_prop", "cdecl"):
    svn_wc_conflict_description_create_prop = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_prop", "cdecl")
    svn_wc_conflict_description_create_prop.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_node_kind_t, String, POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_prop.restype = POINTER(svn_wc_conflict_description_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2107
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_tree2", "cdecl"):
    svn_wc_conflict_description_create_tree2 = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_tree2", "cdecl")
    svn_wc_conflict_description_create_tree2.argtypes = [String, svn_node_kind_t, svn_wc_operation_t, POINTER(svn_wc_conflict_version_t), POINTER(svn_wc_conflict_version_t), POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_tree2.restype = POINTER(svn_wc_conflict_description2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2124
if _libs["svn_wc-1"].has("svn_wc_conflict_description_create_tree", "cdecl"):
    svn_wc_conflict_description_create_tree = _libs["svn_wc-1"].get("svn_wc_conflict_description_create_tree", "cdecl")
    svn_wc_conflict_description_create_tree.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_node_kind_t, svn_wc_operation_t, POINTER(svn_wc_conflict_version_t), POINTER(svn_wc_conflict_version_t), POINTER(apr_pool_t)]
    svn_wc_conflict_description_create_tree.restype = POINTER(svn_wc_conflict_description_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2140
if _libs["svn_wc-1"].has("svn_wc_conflict_description2_dup", "cdecl"):
    svn_wc_conflict_description2_dup = _libs["svn_wc-1"].get("svn_wc_conflict_description2_dup", "cdecl")
    svn_wc_conflict_description2_dup.argtypes = [POINTER(svn_wc_conflict_description2_t), POINTER(apr_pool_t)]
    svn_wc_conflict_description2_dup.restype = POINTER(svn_wc_conflict_description2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2153
if _libs["svn_wc-1"].has("svn_wc__conflict_description2_dup", "cdecl"):
    svn_wc__conflict_description2_dup = _libs["svn_wc-1"].get("svn_wc__conflict_description2_dup", "cdecl")
    svn_wc__conflict_description2_dup.argtypes = [POINTER(svn_wc_conflict_description2_t), POINTER(apr_pool_t)]
    svn_wc__conflict_description2_dup.restype = POINTER(svn_wc_conflict_description2_t)

enum_svn_wc_conflict_choice_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_undefined = (-1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_postpone = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_base = (svn_wc_conflict_choose_postpone + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_theirs_full = (svn_wc_conflict_choose_base + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_mine_full = (svn_wc_conflict_choose_theirs_full + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_theirs_conflict = (svn_wc_conflict_choose_mine_full + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_mine_conflict = (svn_wc_conflict_choose_theirs_conflict + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_merged = (svn_wc_conflict_choose_mine_conflict + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choose_unspecified = (svn_wc_conflict_choose_merged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

svn_wc_conflict_choice_t = enum_svn_wc_conflict_choice_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2192

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2230
class struct_svn_wc_conflict_result_t(Structure):
    pass

struct_svn_wc_conflict_result_t.__slots__ = [
    'choice',
    'merged_file',
    'save_merged',
    'merged_value',
]
struct_svn_wc_conflict_result_t._fields_ = [
    ('choice', svn_wc_conflict_choice_t),
    ('merged_file', String),
    ('save_merged', svn_boolean_t),
    ('merged_value', POINTER(svn_string_t)),
]

svn_wc_conflict_result_t = struct_svn_wc_conflict_result_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2230

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2244
if _libs["svn_wc-1"].has("svn_wc_create_conflict_result", "cdecl"):
    svn_wc_create_conflict_result = _libs["svn_wc-1"].get("svn_wc_create_conflict_result", "cdecl")
    svn_wc_create_conflict_result.argtypes = [svn_wc_conflict_choice_t, String, POINTER(apr_pool_t)]
    svn_wc_create_conflict_result.restype = POINTER(svn_wc_conflict_result_t)

svn_wc_conflict_resolver_func2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_wc_conflict_result_t)), POINTER(svn_wc_conflict_description2_t), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2276

svn_wc_conflict_resolver_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_wc_conflict_result_t)), POINTER(svn_wc_conflict_description_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2291

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2509
class struct_svn_wc_diff_callbacks4_t(Structure):
    pass

struct_svn_wc_diff_callbacks4_t.__slots__ = [
    'file_opened',
    'file_changed',
    'file_added',
    'file_deleted',
    'dir_deleted',
    'dir_opened',
    'dir_added',
    'dir_props_changed',
    'dir_closed',
]
struct_svn_wc_diff_callbacks4_t._fields_ = [
    ('file_opened', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, svn_revnum_t, POINTER(None), POINTER(apr_pool_t))),
    ('file_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('file_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, String, svn_revnum_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('file_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, String, String, POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('dir_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t))),
    ('dir_opened', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, svn_revnum_t, POINTER(None), POINTER(apr_pool_t))),
    ('dir_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, svn_revnum_t, String, svn_revnum_t, POINTER(None), POINTER(apr_pool_t))),
    ('dir_props_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('dir_closed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, svn_boolean_t, POINTER(None), POINTER(apr_pool_t))),
]

svn_wc_diff_callbacks4_t = struct_svn_wc_diff_callbacks4_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2509

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2606
class struct_svn_wc_diff_callbacks3_t(Structure):
    pass

struct_svn_wc_diff_callbacks3_t.__slots__ = [
    'file_changed',
    'file_added',
    'file_deleted',
    'dir_added',
    'dir_deleted',
    'dir_props_changed',
    'dir_opened',
    'dir_closed',
]
struct_svn_wc_diff_callbacks3_t._fields_ = [
    ('file_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
    ('file_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
    ('file_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, String, String, String, String, POINTER(apr_hash_t), POINTER(None))),
    ('dir_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, svn_revnum_t, POINTER(None))),
    ('dir_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, POINTER(None))),
    ('dir_props_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
    ('dir_opened', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_boolean_t), String, svn_revnum_t, POINTER(None))),
    ('dir_closed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), POINTER(svn_boolean_t), String, POINTER(None))),
]

svn_wc_diff_callbacks3_t = struct_svn_wc_diff_callbacks3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2606

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2679
class struct_svn_wc_diff_callbacks2_t(Structure):
    pass

struct_svn_wc_diff_callbacks2_t.__slots__ = [
    'file_changed',
    'file_added',
    'file_deleted',
    'dir_added',
    'dir_deleted',
    'dir_props_changed',
]
struct_svn_wc_diff_callbacks2_t._fields_ = [
    ('file_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
    ('file_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), POINTER(svn_wc_notify_state_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
    ('file_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, String, String, String, String, POINTER(apr_hash_t), POINTER(None))),
    ('dir_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, svn_revnum_t, POINTER(None))),
    ('dir_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, POINTER(None))),
    ('dir_props_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
]

svn_wc_diff_callbacks2_t = struct_svn_wc_diff_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2679

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2749
class struct_svn_wc_diff_callbacks_t(Structure):
    pass

struct_svn_wc_diff_callbacks_t.__slots__ = [
    'file_changed',
    'file_added',
    'file_deleted',
    'dir_added',
    'dir_deleted',
    'props_changed',
]
struct_svn_wc_diff_callbacks_t._fields_ = [
    ('file_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(None))),
    ('file_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, String, String, svn_revnum_t, svn_revnum_t, String, String, POINTER(None))),
    ('file_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, String, String, String, String, POINTER(None))),
    ('dir_added', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, svn_revnum_t, POINTER(None))),
    ('dir_deleted', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, POINTER(None))),
    ('props_changed', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_wc_adm_access_t), POINTER(svn_wc_notify_state_t), String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(None))),
]

svn_wc_diff_callbacks_t = struct_svn_wc_diff_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2749

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2762
if _libs["svn_wc-1"].has("svn_wc_check_wc2", "cdecl"):
    svn_wc_check_wc2 = _libs["svn_wc-1"].get("svn_wc_check_wc2", "cdecl")
    svn_wc_check_wc2.argtypes = [POINTER(c_int), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_check_wc2.restype = POINTER(svn_error_t)
    svn_wc_check_wc2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2775
if _libs["svn_wc-1"].has("svn_wc_check_wc", "cdecl"):
    svn_wc_check_wc = _libs["svn_wc-1"].get("svn_wc_check_wc", "cdecl")
    svn_wc_check_wc.argtypes = [String, POINTER(c_int), POINTER(apr_pool_t)]
    svn_wc_check_wc.restype = POINTER(svn_error_t)
    svn_wc_check_wc.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2790
if _libs["svn_wc-1"].has("svn_wc_has_binary_prop", "cdecl"):
    svn_wc_has_binary_prop = _libs["svn_wc-1"].get("svn_wc_has_binary_prop", "cdecl")
    svn_wc_has_binary_prop.argtypes = [POINTER(svn_boolean_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_has_binary_prop.restype = POINTER(svn_error_t)
    svn_wc_has_binary_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2814
if _libs["svn_wc-1"].has("svn_wc_text_modified_p2", "cdecl"):
    svn_wc_text_modified_p2 = _libs["svn_wc-1"].get("svn_wc_text_modified_p2", "cdecl")
    svn_wc_text_modified_p2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_wc_context_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_text_modified_p2.restype = POINTER(svn_error_t)
    svn_wc_text_modified_p2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2827
if _libs["svn_wc-1"].has("svn_wc_text_modified_p", "cdecl"):
    svn_wc_text_modified_p = _libs["svn_wc-1"].get("svn_wc_text_modified_p", "cdecl")
    svn_wc_text_modified_p.argtypes = [POINTER(svn_boolean_t), String, svn_boolean_t, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_text_modified_p.restype = POINTER(svn_error_t)
    svn_wc_text_modified_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2840
if _libs["svn_wc-1"].has("svn_wc_props_modified_p2", "cdecl"):
    svn_wc_props_modified_p2 = _libs["svn_wc-1"].get("svn_wc_props_modified_p2", "cdecl")
    svn_wc_props_modified_p2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_props_modified_p2.restype = POINTER(svn_error_t)
    svn_wc_props_modified_p2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2852
if _libs["svn_wc-1"].has("svn_wc_props_modified_p", "cdecl"):
    svn_wc_props_modified_p = _libs["svn_wc-1"].get("svn_wc_props_modified_p", "cdecl")
    svn_wc_props_modified_p.argtypes = [POINTER(svn_boolean_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_props_modified_p.restype = POINTER(svn_error_t)
    svn_wc_props_modified_p.errcheck = _svn_errcheck

enum_svn_wc_schedule_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

svn_wc_schedule_normal = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

svn_wc_schedule_add = (svn_wc_schedule_normal + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

svn_wc_schedule_delete = (svn_wc_schedule_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

svn_wc_schedule_replace = (svn_wc_schedule_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

svn_wc_schedule_t = enum_svn_wc_schedule_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2880

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3135
class struct_svn_wc_entry_t(Structure):
    pass

struct_svn_wc_entry_t.__slots__ = [
    'name',
    'revision',
    'url',
    'repos',
    'uuid',
    'kind',
    'schedule',
    'copied',
    'deleted',
    'absent',
    'incomplete',
    'copyfrom_url',
    'copyfrom_rev',
    'conflict_old',
    'conflict_new',
    'conflict_wrk',
    'prejfile',
    'text_time',
    'prop_time',
    'checksum',
    'cmt_rev',
    'cmt_date',
    'cmt_author',
    'lock_token',
    'lock_owner',
    'lock_comment',
    'lock_creation_date',
    'has_props',
    'has_prop_mods',
    'cachable_props',
    'present_props',
    'changelist',
    'working_size',
    'keep_local',
    'depth',
    'tree_conflict_data',
    'file_external_path',
    'file_external_peg_rev',
    'file_external_rev',
]
struct_svn_wc_entry_t._fields_ = [
    ('name', String),
    ('revision', svn_revnum_t),
    ('url', String),
    ('repos', String),
    ('uuid', String),
    ('kind', svn_node_kind_t),
    ('schedule', svn_wc_schedule_t),
    ('copied', svn_boolean_t),
    ('deleted', svn_boolean_t),
    ('absent', svn_boolean_t),
    ('incomplete', svn_boolean_t),
    ('copyfrom_url', String),
    ('copyfrom_rev', svn_revnum_t),
    ('conflict_old', String),
    ('conflict_new', String),
    ('conflict_wrk', String),
    ('prejfile', String),
    ('text_time', apr_time_t),
    ('prop_time', apr_time_t),
    ('checksum', String),
    ('cmt_rev', svn_revnum_t),
    ('cmt_date', apr_time_t),
    ('cmt_author', String),
    ('lock_token', String),
    ('lock_owner', String),
    ('lock_comment', String),
    ('lock_creation_date', apr_time_t),
    ('has_props', svn_boolean_t),
    ('has_prop_mods', svn_boolean_t),
    ('cachable_props', String),
    ('present_props', String),
    ('changelist', String),
    ('working_size', apr_off_t),
    ('keep_local', svn_boolean_t),
    ('depth', svn_depth_t),
    ('tree_conflict_data', String),
    ('file_external_path', String),
    ('file_external_peg_rev', svn_opt_revision_t),
    ('file_external_rev', svn_opt_revision_t),
]

svn_wc_entry_t = struct_svn_wc_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3135

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3171
if _libs["svn_wc-1"].has("svn_wc_entry", "cdecl"):
    svn_wc_entry = _libs["svn_wc-1"].get("svn_wc_entry", "cdecl")
    svn_wc_entry.argtypes = [POINTER(POINTER(svn_wc_entry_t)), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_entry.restype = POINTER(svn_error_t)
    svn_wc_entry.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3213
if _libs["svn_wc-1"].has("svn_wc_entries_read", "cdecl"):
    svn_wc_entries_read = _libs["svn_wc-1"].get("svn_wc_entries_read", "cdecl")
    svn_wc_entries_read.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_entries_read.restype = POINTER(svn_error_t)
    svn_wc_entries_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3226
if _libs["svn_wc-1"].has("svn_wc_entry_dup", "cdecl"):
    svn_wc_entry_dup = _libs["svn_wc-1"].get("svn_wc_entry_dup", "cdecl")
    svn_wc_entry_dup.argtypes = [POINTER(svn_wc_entry_t), POINTER(apr_pool_t)]
    svn_wc_entry_dup.restype = POINTER(svn_wc_entry_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3291
class struct_svn_wc_info_t(Structure):
    pass

struct_svn_wc_info_t.__slots__ = [
    'schedule',
    'copyfrom_url',
    'copyfrom_rev',
    'checksum',
    'changelist',
    'depth',
    'recorded_size',
    'recorded_time',
    'conflicts',
    'wcroot_abspath',
    'moved_from_abspath',
    'moved_to_abspath',
]
struct_svn_wc_info_t._fields_ = [
    ('schedule', svn_wc_schedule_t),
    ('copyfrom_url', String),
    ('copyfrom_rev', svn_revnum_t),
    ('checksum', POINTER(svn_checksum_t)),
    ('changelist', String),
    ('depth', svn_depth_t),
    ('recorded_size', svn_filesize_t),
    ('recorded_time', apr_time_t),
    ('conflicts', POINTER(apr_array_header_t)),
    ('wcroot_abspath', String),
    ('moved_from_abspath', String),
    ('moved_to_abspath', String),
]

svn_wc_info_t = struct_svn_wc_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3291

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3299
if _libs["svn_wc-1"].has("svn_wc_info_dup", "cdecl"):
    svn_wc_info_dup = _libs["svn_wc-1"].get("svn_wc_info_dup", "cdecl")
    svn_wc_info_dup.argtypes = [POINTER(svn_wc_info_t), POINTER(apr_pool_t)]
    svn_wc_info_dup.restype = POINTER(svn_wc_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3326
if _libs["svn_wc-1"].has("svn_wc_conflicted_p3", "cdecl"):
    svn_wc_conflicted_p3 = _libs["svn_wc-1"].get("svn_wc_conflicted_p3", "cdecl")
    svn_wc_conflicted_p3.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_conflicted_p3.restype = POINTER(svn_error_t)
    svn_wc_conflicted_p3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3341
if _libs["svn_wc-1"].has("svn_wc_conflicted_p2", "cdecl"):
    svn_wc_conflicted_p2 = _libs["svn_wc-1"].get("svn_wc_conflicted_p2", "cdecl")
    svn_wc_conflicted_p2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_conflicted_p2.restype = POINTER(svn_error_t)
    svn_wc_conflicted_p2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3367
if _libs["svn_wc-1"].has("svn_wc_conflicted_p", "cdecl"):
    svn_wc_conflicted_p = _libs["svn_wc-1"].get("svn_wc_conflicted_p", "cdecl")
    svn_wc_conflicted_p.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), String, POINTER(svn_wc_entry_t), POINTER(apr_pool_t)]
    svn_wc_conflicted_p.restype = POINTER(svn_error_t)
    svn_wc_conflicted_p.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3384
if _libs["svn_wc-1"].has("svn_wc_get_ancestry", "cdecl"):
    svn_wc_get_ancestry = _libs["svn_wc-1"].get("svn_wc_get_ancestry", "cdecl")
    svn_wc_get_ancestry.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_revnum_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_get_ancestry.restype = POINTER(svn_error_t)
    svn_wc_get_ancestry.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3412
class struct_svn_wc_entry_callbacks2_t(Structure):
    pass

struct_svn_wc_entry_callbacks2_t.__slots__ = [
    'found_entry',
    'handle_error',
]
struct_svn_wc_entry_callbacks2_t._fields_ = [
    ('found_entry', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(svn_wc_entry_t), POINTER(None), POINTER(apr_pool_t))),
    ('handle_error', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(svn_error_t), POINTER(None), POINTER(apr_pool_t))),
]

svn_wc_entry_callbacks2_t = struct_svn_wc_entry_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3412

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3423
class struct_svn_wc_entry_callbacks_t(Structure):
    pass

struct_svn_wc_entry_callbacks_t.__slots__ = [
    'found_entry',
]
struct_svn_wc_entry_callbacks_t._fields_ = [
    ('found_entry', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(svn_wc_entry_t), POINTER(None), POINTER(apr_pool_t))),
]

svn_wc_entry_callbacks_t = struct_svn_wc_entry_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3423

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3463
if _libs["svn_wc-1"].has("svn_wc_walk_entries3", "cdecl"):
    svn_wc_walk_entries3 = _libs["svn_wc-1"].get("svn_wc_walk_entries3", "cdecl")
    svn_wc_walk_entries3.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_wc_entry_callbacks2_t), POINTER(None), svn_depth_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_walk_entries3.restype = POINTER(svn_error_t)
    svn_wc_walk_entries3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3483
if _libs["svn_wc-1"].has("svn_wc_walk_entries2", "cdecl"):
    svn_wc_walk_entries2 = _libs["svn_wc-1"].get("svn_wc_walk_entries2", "cdecl")
    svn_wc_walk_entries2.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_wc_entry_callbacks_t), POINTER(None), svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_walk_entries2.restype = POINTER(svn_error_t)
    svn_wc_walk_entries2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3499
if _libs["svn_wc-1"].has("svn_wc_walk_entries", "cdecl"):
    svn_wc_walk_entries = _libs["svn_wc-1"].get("svn_wc_walk_entries", "cdecl")
    svn_wc_walk_entries.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_wc_entry_callbacks_t), POINTER(None), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_walk_entries.restype = POINTER(svn_error_t)
    svn_wc_walk_entries.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3519
if _libs["svn_wc-1"].has("svn_wc_mark_missing_deleted", "cdecl"):
    svn_wc_mark_missing_deleted = _libs["svn_wc-1"].get("svn_wc_mark_missing_deleted", "cdecl")
    svn_wc_mark_missing_deleted.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_mark_missing_deleted.restype = POINTER(svn_error_t)
    svn_wc_mark_missing_deleted.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3550
if _libs["svn_wc-1"].has("svn_wc_ensure_adm4", "cdecl"):
    svn_wc_ensure_adm4 = _libs["svn_wc-1"].get("svn_wc_ensure_adm4", "cdecl")
    svn_wc_ensure_adm4.argtypes = [POINTER(svn_wc_context_t), String, String, String, String, svn_revnum_t, svn_depth_t, POINTER(apr_pool_t)]
    svn_wc_ensure_adm4.restype = POINTER(svn_error_t)
    svn_wc_ensure_adm4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3571
if _libs["svn_wc-1"].has("svn_wc_ensure_adm3", "cdecl"):
    svn_wc_ensure_adm3 = _libs["svn_wc-1"].get("svn_wc_ensure_adm3", "cdecl")
    svn_wc_ensure_adm3.argtypes = [String, String, String, String, svn_revnum_t, svn_depth_t, POINTER(apr_pool_t)]
    svn_wc_ensure_adm3.restype = POINTER(svn_error_t)
    svn_wc_ensure_adm3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3592
if _libs["svn_wc-1"].has("svn_wc_ensure_adm2", "cdecl"):
    svn_wc_ensure_adm2 = _libs["svn_wc-1"].get("svn_wc_ensure_adm2", "cdecl")
    svn_wc_ensure_adm2.argtypes = [String, String, String, String, svn_revnum_t, POINTER(apr_pool_t)]
    svn_wc_ensure_adm2.restype = POINTER(svn_error_t)
    svn_wc_ensure_adm2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3610
if _libs["svn_wc-1"].has("svn_wc_ensure_adm", "cdecl"):
    svn_wc_ensure_adm = _libs["svn_wc-1"].get("svn_wc_ensure_adm", "cdecl")
    svn_wc_ensure_adm.argtypes = [String, String, String, svn_revnum_t, POINTER(apr_pool_t)]
    svn_wc_ensure_adm.restype = POINTER(svn_error_t)
    svn_wc_ensure_adm.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3630
if _libs["svn_wc-1"].has("svn_wc_maybe_set_repos_root", "cdecl"):
    svn_wc_maybe_set_repos_root = _libs["svn_wc-1"].get("svn_wc_maybe_set_repos_root", "cdecl")
    svn_wc_maybe_set_repos_root.argtypes = [POINTER(svn_wc_adm_access_t), String, String, POINTER(apr_pool_t)]
    svn_wc_maybe_set_repos_root.restype = POINTER(svn_error_t)
    svn_wc_maybe_set_repos_root.errcheck = _svn_errcheck

enum_svn_wc_status_kind = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_none = 1# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_unversioned = (svn_wc_status_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_normal = (svn_wc_status_unversioned + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_added = (svn_wc_status_normal + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_missing = (svn_wc_status_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_deleted = (svn_wc_status_missing + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_replaced = (svn_wc_status_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_modified = (svn_wc_status_replaced + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_merged = (svn_wc_status_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_conflicted = (svn_wc_status_merged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_ignored = (svn_wc_status_conflicted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_obstructed = (svn_wc_status_ignored + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_external = (svn_wc_status_obstructed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

svn_wc_status_incomplete = (svn_wc_status_external + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3665

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3880
class struct_svn_wc_status3_t(Structure):
    pass

struct_svn_wc_status3_t.__slots__ = [
    'kind',
    'depth',
    'filesize',
    'versioned',
    'conflicted',
    'node_status',
    'text_status',
    'prop_status',
    'copied',
    'revision',
    'changed_rev',
    'changed_date',
    'changed_author',
    'repos_root_url',
    'repos_uuid',
    'repos_relpath',
    'switched',
    'locked',
    'lock',
    'changelist',
    'ood_kind',
    'repos_node_status',
    'repos_text_status',
    'repos_prop_status',
    'repos_lock',
    'ood_changed_rev',
    'ood_changed_date',
    'ood_changed_author',
    'moved_from_abspath',
    'moved_to_abspath',
    'file_external',
    'actual_kind',
]
struct_svn_wc_status3_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('depth', svn_depth_t),
    ('filesize', svn_filesize_t),
    ('versioned', svn_boolean_t),
    ('conflicted', svn_boolean_t),
    ('node_status', enum_svn_wc_status_kind),
    ('text_status', enum_svn_wc_status_kind),
    ('prop_status', enum_svn_wc_status_kind),
    ('copied', svn_boolean_t),
    ('revision', svn_revnum_t),
    ('changed_rev', svn_revnum_t),
    ('changed_date', apr_time_t),
    ('changed_author', String),
    ('repos_root_url', String),
    ('repos_uuid', String),
    ('repos_relpath', String),
    ('switched', svn_boolean_t),
    ('locked', svn_boolean_t),
    ('lock', POINTER(svn_lock_t)),
    ('changelist', String),
    ('ood_kind', svn_node_kind_t),
    ('repos_node_status', enum_svn_wc_status_kind),
    ('repos_text_status', enum_svn_wc_status_kind),
    ('repos_prop_status', enum_svn_wc_status_kind),
    ('repos_lock', POINTER(svn_lock_t)),
    ('ood_changed_rev', svn_revnum_t),
    ('ood_changed_date', apr_time_t),
    ('ood_changed_author', String),
    ('moved_from_abspath', String),
    ('moved_to_abspath', String),
    ('file_external', svn_boolean_t),
    ('actual_kind', svn_node_kind_t),
]

svn_wc_status3_t = struct_svn_wc_status3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3880

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3996
class struct_svn_wc_status2_t(Structure):
    pass

struct_svn_wc_status2_t.__slots__ = [
    'entry',
    'text_status',
    'prop_status',
    'locked',
    'copied',
    'switched',
    'repos_text_status',
    'repos_prop_status',
    'repos_lock',
    'url',
    'ood_last_cmt_rev',
    'ood_last_cmt_date',
    'ood_kind',
    'ood_last_cmt_author',
    'tree_conflict',
    'file_external',
    'pristine_text_status',
    'pristine_prop_status',
]
struct_svn_wc_status2_t._fields_ = [
    ('entry', POINTER(svn_wc_entry_t)),
    ('text_status', enum_svn_wc_status_kind),
    ('prop_status', enum_svn_wc_status_kind),
    ('locked', svn_boolean_t),
    ('copied', svn_boolean_t),
    ('switched', svn_boolean_t),
    ('repos_text_status', enum_svn_wc_status_kind),
    ('repos_prop_status', enum_svn_wc_status_kind),
    ('repos_lock', POINTER(svn_lock_t)),
    ('url', String),
    ('ood_last_cmt_rev', svn_revnum_t),
    ('ood_last_cmt_date', apr_time_t),
    ('ood_kind', svn_node_kind_t),
    ('ood_last_cmt_author', String),
    ('tree_conflict', POINTER(svn_wc_conflict_description_t)),
    ('file_external', svn_boolean_t),
    ('pristine_text_status', enum_svn_wc_status_kind),
    ('pristine_prop_status', enum_svn_wc_status_kind),
]

svn_wc_status2_t = struct_svn_wc_status2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3996

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4035
class struct_svn_wc_status_t(Structure):
    pass

struct_svn_wc_status_t.__slots__ = [
    'entry',
    'text_status',
    'prop_status',
    'locked',
    'copied',
    'switched',
    'repos_text_status',
    'repos_prop_status',
]
struct_svn_wc_status_t._fields_ = [
    ('entry', POINTER(svn_wc_entry_t)),
    ('text_status', enum_svn_wc_status_kind),
    ('prop_status', enum_svn_wc_status_kind),
    ('locked', svn_boolean_t),
    ('copied', svn_boolean_t),
    ('switched', svn_boolean_t),
    ('repos_text_status', enum_svn_wc_status_kind),
    ('repos_prop_status', enum_svn_wc_status_kind),
]

svn_wc_status_t = struct_svn_wc_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4035

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4044
if _libs["svn_wc-1"].has("svn_wc_dup_status3", "cdecl"):
    svn_wc_dup_status3 = _libs["svn_wc-1"].get("svn_wc_dup_status3", "cdecl")
    svn_wc_dup_status3.argtypes = [POINTER(svn_wc_status3_t), POINTER(apr_pool_t)]
    svn_wc_dup_status3.restype = POINTER(svn_wc_status3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4055
if _libs["svn_wc-1"].has("svn_wc_dup_status2", "cdecl"):
    svn_wc_dup_status2 = _libs["svn_wc-1"].get("svn_wc_dup_status2", "cdecl")
    svn_wc_dup_status2.argtypes = [POINTER(svn_wc_status2_t), POINTER(apr_pool_t)]
    svn_wc_dup_status2.restype = POINTER(svn_wc_status2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4066
if _libs["svn_wc-1"].has("svn_wc_dup_status", "cdecl"):
    svn_wc_dup_status = _libs["svn_wc-1"].get("svn_wc_dup_status", "cdecl")
    svn_wc_dup_status.argtypes = [POINTER(svn_wc_status_t), POINTER(apr_pool_t)]
    svn_wc_dup_status.restype = POINTER(svn_wc_status_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4095
if _libs["svn_wc-1"].has("svn_wc_status3", "cdecl"):
    svn_wc_status3 = _libs["svn_wc-1"].get("svn_wc_status3", "cdecl")
    svn_wc_status3.argtypes = [POINTER(POINTER(svn_wc_status3_t)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_status3.restype = POINTER(svn_error_t)
    svn_wc_status3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4109
if _libs["svn_wc-1"].has("svn_wc_status2", "cdecl"):
    svn_wc_status2 = _libs["svn_wc-1"].get("svn_wc_status2", "cdecl")
    svn_wc_status2.argtypes = [POINTER(POINTER(svn_wc_status2_t)), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_status2.restype = POINTER(svn_error_t)
    svn_wc_status2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4122
if _libs["svn_wc-1"].has("svn_wc_status", "cdecl"):
    svn_wc_status = _libs["svn_wc-1"].get("svn_wc_status", "cdecl")
    svn_wc_status.argtypes = [POINTER(POINTER(svn_wc_status_t)), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_status.restype = POINTER(svn_error_t)
    svn_wc_status.errcheck = _svn_errcheck

svn_wc_status_func4_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_wc_status3_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4141

svn_wc_status_func3_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_wc_status2_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4153

svn_wc_status_func2_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), String, POINTER(svn_wc_status2_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4165

svn_wc_status_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), String, POINTER(svn_wc_status_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4174

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4224
if _libs["svn_wc-1"].has("svn_wc_walk_status", "cdecl"):
    svn_wc_walk_status = _libs["svn_wc-1"].get("svn_wc_walk_status", "cdecl")
    svn_wc_walk_status.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_wc_status_func4_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_walk_status.restype = POINTER(svn_error_t)
    svn_wc_walk_status.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4307
if _libs["svn_wc-1"].has("svn_wc_get_status_editor5", "cdecl"):
    svn_wc_get_status_editor5 = _libs["svn_wc-1"].get("svn_wc_get_status_editor5", "cdecl")
    svn_wc_get_status_editor5.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_context_t), String, String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_wc_status_func4_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_status_editor5.restype = POINTER(svn_error_t)
    svn_wc_get_status_editor5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4340
if _libs["svn_wc-1"].has("svn_wc_get_status_editor4", "cdecl"):
    svn_wc_get_status_editor4 = _libs["svn_wc-1"].get("svn_wc_get_status_editor4", "cdecl")
    svn_wc_get_status_editor4.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_wc_status_func3_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_status_editor4.restype = POINTER(svn_error_t)
    svn_wc_get_status_editor4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4366
if _libs["svn_wc-1"].has("svn_wc_get_status_editor3", "cdecl"):
    svn_wc_get_status_editor3 = _libs["svn_wc-1"].get("svn_wc_get_status_editor3", "cdecl")
    svn_wc_get_status_editor3.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_wc_status_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_status_editor3.restype = POINTER(svn_error_t)
    svn_wc_get_status_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4395
if _libs["svn_wc-1"].has("svn_wc_get_status_editor2", "cdecl"):
    svn_wc_get_status_editor2 = _libs["svn_wc-1"].get("svn_wc_get_status_editor2", "cdecl")
    svn_wc_get_status_editor2.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, POINTER(apr_hash_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_status_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_status_editor2.restype = POINTER(svn_error_t)
    svn_wc_get_status_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4420
if _libs["svn_wc-1"].has("svn_wc_get_status_editor", "cdecl"):
    svn_wc_get_status_editor = _libs["svn_wc-1"].get("svn_wc_get_status_editor", "cdecl")
    svn_wc_get_status_editor.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, POINTER(apr_hash_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_status_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_status_editor.restype = POINTER(svn_error_t)
    svn_wc_get_status_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4451
if _libs["svn_wc-1"].has("svn_wc_status_set_repos_locks", "cdecl"):
    svn_wc_status_set_repos_locks = _libs["svn_wc-1"].get("svn_wc_status_set_repos_locks", "cdecl")
    svn_wc_status_set_repos_locks.argtypes = [POINTER(None), POINTER(apr_hash_t), String, POINTER(apr_pool_t)]
    svn_wc_status_set_repos_locks.restype = POINTER(svn_error_t)
    svn_wc_status_set_repos_locks.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4487
if _libs["svn_wc-1"].has("svn_wc_copy3", "cdecl"):
    svn_wc_copy3 = _libs["svn_wc-1"].get("svn_wc_copy3", "cdecl")
    svn_wc_copy3.argtypes = [POINTER(svn_wc_context_t), String, String, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_copy3.restype = POINTER(svn_error_t)
    svn_wc_copy3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4505
if _libs["svn_wc-1"].has("svn_wc_copy2", "cdecl"):
    svn_wc_copy2 = _libs["svn_wc-1"].get("svn_wc_copy2", "cdecl")
    svn_wc_copy2.argtypes = [String, POINTER(svn_wc_adm_access_t), String, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_copy2.restype = POINTER(svn_error_t)
    svn_wc_copy2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4521
if _libs["svn_wc-1"].has("svn_wc_copy", "cdecl"):
    svn_wc_copy = _libs["svn_wc-1"].get("svn_wc_copy", "cdecl")
    svn_wc_copy.argtypes = [String, POINTER(svn_wc_adm_access_t), String, svn_cancel_func_t, POINTER(None), svn_wc_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_copy.restype = POINTER(svn_error_t)
    svn_wc_copy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4562
if _libs["svn_wc-1"].has("svn_wc_move", "cdecl"):
    svn_wc_move = _libs["svn_wc-1"].get("svn_wc_move", "cdecl")
    svn_wc_move.argtypes = [POINTER(svn_wc_context_t), String, String, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_move.restype = POINTER(svn_error_t)
    svn_wc_move.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4612
if _libs["svn_wc-1"].has("svn_wc_delete4", "cdecl"):
    svn_wc_delete4 = _libs["svn_wc-1"].get("svn_wc_delete4", "cdecl")
    svn_wc_delete4.argtypes = [POINTER(svn_wc_context_t), String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_delete4.restype = POINTER(svn_error_t)
    svn_wc_delete4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4634
if _libs["svn_wc-1"].has("svn_wc_delete3", "cdecl"):
    svn_wc_delete3 = _libs["svn_wc-1"].get("svn_wc_delete3", "cdecl")
    svn_wc_delete3.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_delete3.restype = POINTER(svn_error_t)
    svn_wc_delete3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4650
if _libs["svn_wc-1"].has("svn_wc_delete2", "cdecl"):
    svn_wc_delete2 = _libs["svn_wc-1"].get("svn_wc_delete2", "cdecl")
    svn_wc_delete2.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_delete2.restype = POINTER(svn_error_t)
    svn_wc_delete2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4665
if _libs["svn_wc-1"].has("svn_wc_delete", "cdecl"):
    svn_wc_delete = _libs["svn_wc-1"].get("svn_wc_delete", "cdecl")
    svn_wc_delete.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_delete.restype = POINTER(svn_error_t)
    svn_wc_delete.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4701
if _libs["svn_wc-1"].has("svn_wc_add_from_disk3", "cdecl"):
    svn_wc_add_from_disk3 = _libs["svn_wc-1"].get("svn_wc_add_from_disk3", "cdecl")
    svn_wc_add_from_disk3.argtypes = [POINTER(svn_wc_context_t), String, POINTER(apr_hash_t), svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add_from_disk3.restype = POINTER(svn_error_t)
    svn_wc_add_from_disk3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4718
if _libs["svn_wc-1"].has("svn_wc_add_from_disk2", "cdecl"):
    svn_wc_add_from_disk2 = _libs["svn_wc-1"].get("svn_wc_add_from_disk2", "cdecl")
    svn_wc_add_from_disk2.argtypes = [POINTER(svn_wc_context_t), String, POINTER(apr_hash_t), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add_from_disk2.restype = POINTER(svn_error_t)
    svn_wc_add_from_disk2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4740
if _libs["svn_wc-1"].has("svn_wc_add_from_disk", "cdecl"):
    svn_wc_add_from_disk = _libs["svn_wc-1"].get("svn_wc_add_from_disk", "cdecl")
    svn_wc_add_from_disk.argtypes = [POINTER(svn_wc_context_t), String, svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add_from_disk.restype = POINTER(svn_error_t)
    svn_wc_add_from_disk.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4790
if _libs["svn_wc-1"].has("svn_wc_add4", "cdecl"):
    svn_wc_add4 = _libs["svn_wc-1"].get("svn_wc_add4", "cdecl")
    svn_wc_add4.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, String, svn_revnum_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add4.restype = POINTER(svn_error_t)
    svn_wc_add4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4809
if _libs["svn_wc-1"].has("svn_wc_add3", "cdecl"):
    svn_wc_add3 = _libs["svn_wc-1"].get("svn_wc_add3", "cdecl")
    svn_wc_add3.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_depth_t, String, svn_revnum_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add3.restype = POINTER(svn_error_t)
    svn_wc_add3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4829
if _libs["svn_wc-1"].has("svn_wc_add2", "cdecl"):
    svn_wc_add2 = _libs["svn_wc-1"].get("svn_wc_add2", "cdecl")
    svn_wc_add2.argtypes = [String, POINTER(svn_wc_adm_access_t), String, svn_revnum_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add2.restype = POINTER(svn_error_t)
    svn_wc_add2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4846
if _libs["svn_wc-1"].has("svn_wc_add", "cdecl"):
    svn_wc_add = _libs["svn_wc-1"].get("svn_wc_add", "cdecl")
    svn_wc_add.argtypes = [String, POINTER(svn_wc_adm_access_t), String, svn_revnum_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add.restype = POINTER(svn_error_t)
    svn_wc_add.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4901
if _libs["svn_wc-1"].has("svn_wc_add_repos_file4", "cdecl"):
    svn_wc_add_repos_file4 = _libs["svn_wc-1"].get("svn_wc_add_repos_file4", "cdecl")
    svn_wc_add_repos_file4.argtypes = [POINTER(svn_wc_context_t), String, POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_hash_t), POINTER(apr_hash_t), String, svn_revnum_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add_repos_file4.restype = POINTER(svn_error_t)
    svn_wc_add_repos_file4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4923
if _libs["svn_wc-1"].has("svn_wc_add_repos_file3", "cdecl"):
    svn_wc_add_repos_file3 = _libs["svn_wc-1"].get("svn_wc_add_repos_file3", "cdecl")
    svn_wc_add_repos_file3.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_hash_t), POINTER(apr_hash_t), String, svn_revnum_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_add_repos_file3.restype = POINTER(svn_error_t)
    svn_wc_add_repos_file3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4946
if _libs["svn_wc-1"].has("svn_wc_add_repos_file2", "cdecl"):
    svn_wc_add_repos_file2 = _libs["svn_wc-1"].get("svn_wc_add_repos_file2", "cdecl")
    svn_wc_add_repos_file2.argtypes = [String, POINTER(svn_wc_adm_access_t), String, String, POINTER(apr_hash_t), POINTER(apr_hash_t), String, svn_revnum_t, POINTER(apr_pool_t)]
    svn_wc_add_repos_file2.restype = POINTER(svn_error_t)
    svn_wc_add_repos_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4963
if _libs["svn_wc-1"].has("svn_wc_add_repos_file", "cdecl"):
    svn_wc_add_repos_file = _libs["svn_wc-1"].get("svn_wc_add_repos_file", "cdecl")
    svn_wc_add_repos_file.argtypes = [String, POINTER(svn_wc_adm_access_t), String, POINTER(apr_hash_t), String, svn_revnum_t, POINTER(apr_pool_t)]
    svn_wc_add_repos_file.restype = POINTER(svn_error_t)
    svn_wc_add_repos_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5004
if _libs["svn_wc-1"].has("svn_wc_remove_from_revision_control2", "cdecl"):
    svn_wc_remove_from_revision_control2 = _libs["svn_wc-1"].get("svn_wc_remove_from_revision_control2", "cdecl")
    svn_wc_remove_from_revision_control2.argtypes = [POINTER(svn_wc_context_t), String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_remove_from_revision_control2.restype = POINTER(svn_error_t)
    svn_wc_remove_from_revision_control2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5024
if _libs["svn_wc-1"].has("svn_wc_remove_from_revision_control", "cdecl"):
    svn_wc_remove_from_revision_control = _libs["svn_wc-1"].get("svn_wc_remove_from_revision_control", "cdecl")
    svn_wc_remove_from_revision_control.argtypes = [POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_remove_from_revision_control.restype = POINTER(svn_error_t)
    svn_wc_remove_from_revision_control.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5092
if _libs["svn_wc-1"].has("svn_wc_resolved_conflict5", "cdecl"):
    svn_wc_resolved_conflict5 = _libs["svn_wc-1"].get("svn_wc_resolved_conflict5", "cdecl")
    svn_wc_resolved_conflict5.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_boolean_t, String, svn_boolean_t, svn_wc_conflict_choice_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_resolved_conflict5.restype = POINTER(svn_error_t)
    svn_wc_resolved_conflict5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5114
if _libs["svn_wc-1"].has("svn_wc_resolved_conflict4", "cdecl"):
    svn_wc_resolved_conflict4 = _libs["svn_wc-1"].get("svn_wc_resolved_conflict4", "cdecl")
    svn_wc_resolved_conflict4.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_depth_t, svn_wc_conflict_choice_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_resolved_conflict4.restype = POINTER(svn_error_t)
    svn_wc_resolved_conflict4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5137
if _libs["svn_wc-1"].has("svn_wc_resolved_conflict3", "cdecl"):
    svn_wc_resolved_conflict3 = _libs["svn_wc-1"].get("svn_wc_resolved_conflict3", "cdecl")
    svn_wc_resolved_conflict3.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_depth_t, svn_wc_conflict_choice_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_resolved_conflict3.restype = POINTER(svn_error_t)
    svn_wc_resolved_conflict3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5161
if _libs["svn_wc-1"].has("svn_wc_resolved_conflict2", "cdecl"):
    svn_wc_resolved_conflict2 = _libs["svn_wc-1"].get("svn_wc_resolved_conflict2", "cdecl")
    svn_wc_resolved_conflict2.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_resolved_conflict2.restype = POINTER(svn_error_t)
    svn_wc_resolved_conflict2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5180
if _libs["svn_wc-1"].has("svn_wc_resolved_conflict", "cdecl"):
    svn_wc_resolved_conflict = _libs["svn_wc-1"].get("svn_wc_resolved_conflict", "cdecl")
    svn_wc_resolved_conflict.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_resolved_conflict.restype = POINTER(svn_error_t)
    svn_wc_resolved_conflict.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5199
class struct_svn_wc_committed_queue_t(Structure):
    pass

svn_wc_committed_queue_t = struct_svn_wc_committed_queue_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5199

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5211
if _libs["svn_wc-1"].has("svn_wc_committed_queue_create", "cdecl"):
    svn_wc_committed_queue_create = _libs["svn_wc-1"].get("svn_wc_committed_queue_create", "cdecl")
    svn_wc_committed_queue_create.argtypes = [POINTER(apr_pool_t)]
    svn_wc_committed_queue_create.restype = POINTER(svn_wc_committed_queue_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5274
if _libs["svn_wc-1"].has("svn_wc_queue_committed4", "cdecl"):
    svn_wc_queue_committed4 = _libs["svn_wc-1"].get("svn_wc_queue_committed4", "cdecl")
    svn_wc_queue_committed4.argtypes = [POINTER(svn_wc_committed_queue_t), POINTER(svn_wc_context_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_wc_queue_committed4.restype = POINTER(svn_error_t)
    svn_wc_queue_committed4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5292
if _libs["svn_wc-1"].has("svn_wc_queue_committed3", "cdecl"):
    svn_wc_queue_committed3 = _libs["svn_wc-1"].get("svn_wc_queue_committed3", "cdecl")
    svn_wc_queue_committed3.argtypes = [POINTER(svn_wc_committed_queue_t), POINTER(svn_wc_context_t), String, svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_wc_queue_committed3.restype = POINTER(svn_error_t)
    svn_wc_queue_committed3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5312
if _libs["svn_wc-1"].has("svn_wc_queue_committed2", "cdecl"):
    svn_wc_queue_committed2 = _libs["svn_wc-1"].get("svn_wc_queue_committed2", "cdecl")
    svn_wc_queue_committed2.argtypes = [POINTER(svn_wc_committed_queue_t), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_checksum_t), POINTER(apr_pool_t)]
    svn_wc_queue_committed2.restype = POINTER(svn_error_t)
    svn_wc_queue_committed2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5335
if _libs["svn_wc-1"].has("svn_wc_queue_committed", "cdecl"):
    svn_wc_queue_committed = _libs["svn_wc-1"].get("svn_wc_queue_committed", "cdecl")
    svn_wc_queue_committed.argtypes = [POINTER(POINTER(svn_wc_committed_queue_t)), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_wc_queue_committed.restype = POINTER(svn_error_t)
    svn_wc_queue_committed.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5357
if _libs["svn_wc-1"].has("svn_wc_process_committed_queue2", "cdecl"):
    svn_wc_process_committed_queue2 = _libs["svn_wc-1"].get("svn_wc_process_committed_queue2", "cdecl")
    svn_wc_process_committed_queue2.argtypes = [POINTER(svn_wc_committed_queue_t), POINTER(svn_wc_context_t), svn_revnum_t, String, String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_process_committed_queue2.restype = POINTER(svn_error_t)
    svn_wc_process_committed_queue2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5373
if _libs["svn_wc-1"].has("svn_wc_process_committed_queue", "cdecl"):
    svn_wc_process_committed_queue = _libs["svn_wc-1"].get("svn_wc_process_committed_queue", "cdecl")
    svn_wc_process_committed_queue.argtypes = [POINTER(svn_wc_committed_queue_t), POINTER(svn_wc_adm_access_t), svn_revnum_t, String, String, POINTER(apr_pool_t)]
    svn_wc_process_committed_queue.restype = POINTER(svn_error_t)
    svn_wc_process_committed_queue.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5392
if _libs["svn_wc-1"].has("svn_wc_process_committed4", "cdecl"):
    svn_wc_process_committed4 = _libs["svn_wc-1"].get("svn_wc_process_committed4", "cdecl")
    svn_wc_process_committed4.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_wc_process_committed4.restype = POINTER(svn_error_t)
    svn_wc_process_committed4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5411
if _libs["svn_wc-1"].has("svn_wc_process_committed3", "cdecl"):
    svn_wc_process_committed3 = _libs["svn_wc-1"].get("svn_wc_process_committed3", "cdecl")
    svn_wc_process_committed3.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), svn_boolean_t, POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_wc_process_committed3.restype = POINTER(svn_error_t)
    svn_wc_process_committed3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5429
if _libs["svn_wc-1"].has("svn_wc_process_committed2", "cdecl"):
    svn_wc_process_committed2 = _libs["svn_wc-1"].get("svn_wc_process_committed2", "cdecl")
    svn_wc_process_committed2.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_process_committed2.restype = POINTER(svn_error_t)
    svn_wc_process_committed2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5446
if _libs["svn_wc-1"].has("svn_wc_process_committed", "cdecl"):
    svn_wc_process_committed = _libs["svn_wc-1"].get("svn_wc_process_committed", "cdecl")
    svn_wc_process_committed.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_revnum_t, String, String, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_wc_process_committed.restype = POINTER(svn_error_t)
    svn_wc_process_committed.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5519
if _libs["svn_wc-1"].has("svn_wc_crawl_revisions5", "cdecl"):
    svn_wc_crawl_revisions5 = _libs["svn_wc-1"].get("svn_wc_crawl_revisions5", "cdecl")
    svn_wc_crawl_revisions5.argtypes = [POINTER(svn_wc_context_t), String, POINTER(svn_ra_reporter3_t), POINTER(None), svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_crawl_revisions5.restype = POINTER(svn_error_t)
    svn_wc_crawl_revisions5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5545
if _libs["svn_wc-1"].has("svn_wc_crawl_revisions4", "cdecl"):
    svn_wc_crawl_revisions4 = _libs["svn_wc-1"].get("svn_wc_crawl_revisions4", "cdecl")
    svn_wc_crawl_revisions4.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_ra_reporter3_t), POINTER(None), svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_crawl_revisions4.restype = POINTER(svn_error_t)
    svn_wc_crawl_revisions4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5568
if _libs["svn_wc-1"].has("svn_wc_crawl_revisions3", "cdecl"):
    svn_wc_crawl_revisions3 = _libs["svn_wc-1"].get("svn_wc_crawl_revisions3", "cdecl")
    svn_wc_crawl_revisions3.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_ra_reporter3_t), POINTER(None), svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_crawl_revisions3.restype = POINTER(svn_error_t)
    svn_wc_crawl_revisions3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5591
if _libs["svn_wc-1"].has("svn_wc_crawl_revisions2", "cdecl"):
    svn_wc_crawl_revisions2 = _libs["svn_wc-1"].get("svn_wc_crawl_revisions2", "cdecl")
    svn_wc_crawl_revisions2.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_ra_reporter2_t), POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_crawl_revisions2.restype = POINTER(svn_error_t)
    svn_wc_crawl_revisions2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5611
if _libs["svn_wc-1"].has("svn_wc_crawl_revisions", "cdecl"):
    svn_wc_crawl_revisions = _libs["svn_wc-1"].get("svn_wc_crawl_revisions", "cdecl")
    svn_wc_crawl_revisions.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_ra_reporter_t), POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func_t, POINTER(None), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_crawl_revisions.restype = POINTER(svn_error_t)
    svn_wc_crawl_revisions.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5644
if _libs["svn_wc-1"].has("svn_wc_check_root", "cdecl"):
    svn_wc_check_root = _libs["svn_wc-1"].get("svn_wc_check_root", "cdecl")
    svn_wc_check_root.argtypes = [POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_node_kind_t), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_check_root.restype = POINTER(svn_error_t)
    svn_wc_check_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5670
if _libs["svn_wc-1"].has("svn_wc_is_wc_root2", "cdecl"):
    svn_wc_is_wc_root2 = _libs["svn_wc-1"].get("svn_wc_is_wc_root2", "cdecl")
    svn_wc_is_wc_root2.argtypes = [POINTER(svn_boolean_t), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_is_wc_root2.restype = POINTER(svn_error_t)
    svn_wc_is_wc_root2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5686
if _libs["svn_wc-1"].has("svn_wc_is_wc_root", "cdecl"):
    svn_wc_is_wc_root = _libs["svn_wc-1"].get("svn_wc_is_wc_root", "cdecl")
    svn_wc_is_wc_root.argtypes = [POINTER(svn_boolean_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_is_wc_root.restype = POINTER(svn_error_t)
    svn_wc_is_wc_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5720
if _libs["svn_wc-1"].has("svn_wc_get_actual_target2", "cdecl"):
    svn_wc_get_actual_target2 = _libs["svn_wc-1"].get("svn_wc_get_actual_target2", "cdecl")
    svn_wc_get_actual_target2.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_actual_target2.restype = POINTER(svn_error_t)
    svn_wc_get_actual_target2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5735
if _libs["svn_wc-1"].has("svn_wc_get_actual_target", "cdecl"):
    svn_wc_get_actual_target = _libs["svn_wc-1"].get("svn_wc_get_actual_target", "cdecl")
    svn_wc_get_actual_target.argtypes = [String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_wc_get_actual_target.restype = POINTER(svn_error_t)
    svn_wc_get_actual_target.errcheck = _svn_errcheck

svn_wc_get_file_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(svn_stream_t), POINTER(svn_revnum_t), POINTER(POINTER(apr_hash_t)), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5758

svn_wc_dirents_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(POINTER(apr_hash_t)), String, String, POINTER(apr_pool_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5780

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5873
if _libs["svn_wc-1"].has("svn_wc_get_update_editor4", "cdecl"):
    svn_wc_get_update_editor4 = _libs["svn_wc-1"].get("svn_wc_get_update_editor4", "cdecl")
    svn_wc_get_update_editor4.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_context_t), String, String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_array_header_t), svn_wc_dirents_func_t, POINTER(None), svn_wc_conflict_resolver_func2_t, POINTER(None), svn_wc_external_update_t, POINTER(None), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_update_editor4.restype = POINTER(svn_error_t)
    svn_wc_get_update_editor4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5928
if _libs["svn_wc-1"].has("svn_wc_get_update_editor3", "cdecl"):
    svn_wc_get_update_editor3 = _libs["svn_wc-1"].get("svn_wc_get_update_editor3", "cdecl")
    svn_wc_get_update_editor3.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), svn_wc_conflict_resolver_func_t, POINTER(None), svn_wc_get_file_t, POINTER(None), String, POINTER(apr_array_header_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_update_editor3.restype = POINTER(svn_error_t)
    svn_wc_get_update_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5963
if _libs["svn_wc-1"].has("svn_wc_get_update_editor2", "cdecl"):
    svn_wc_get_update_editor2 = _libs["svn_wc-1"].get("svn_wc_get_update_editor2", "cdecl")
    svn_wc_get_update_editor2.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), String, POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_update_editor2.restype = POINTER(svn_error_t)
    svn_wc_get_update_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5986
if _libs["svn_wc-1"].has("svn_wc_get_update_editor", "cdecl"):
    svn_wc_get_update_editor = _libs["svn_wc-1"].get("svn_wc_get_update_editor", "cdecl")
    svn_wc_get_update_editor.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, svn_boolean_t, svn_boolean_t, svn_wc_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), String, POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_update_editor.restype = POINTER(svn_error_t)
    svn_wc_get_update_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6020
if _libs["svn_wc-1"].has("svn_wc_get_switch_editor4", "cdecl"):
    svn_wc_get_switch_editor4 = _libs["svn_wc-1"].get("svn_wc_get_switch_editor4", "cdecl")
    svn_wc_get_switch_editor4.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_revnum_t), POINTER(svn_wc_context_t), String, String, String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_array_header_t), svn_wc_dirents_func_t, POINTER(None), svn_wc_conflict_resolver_func2_t, POINTER(None), svn_wc_external_update_t, POINTER(None), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_switch_editor4.restype = POINTER(svn_error_t)
    svn_wc_get_switch_editor4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6070
if _libs["svn_wc-1"].has("svn_wc_get_switch_editor3", "cdecl"):
    svn_wc_get_switch_editor3 = _libs["svn_wc-1"].get("svn_wc_get_switch_editor3", "cdecl")
    svn_wc_get_switch_editor3.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), svn_wc_conflict_resolver_func_t, POINTER(None), String, POINTER(apr_array_header_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_switch_editor3.restype = POINTER(svn_error_t)
    svn_wc_get_switch_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6103
if _libs["svn_wc-1"].has("svn_wc_get_switch_editor2", "cdecl"):
    svn_wc_get_switch_editor2 = _libs["svn_wc-1"].get("svn_wc_get_switch_editor2", "cdecl")
    svn_wc_get_switch_editor2.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), String, POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_switch_editor2.restype = POINTER(svn_error_t)
    svn_wc_get_switch_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6127
if _libs["svn_wc-1"].has("svn_wc_get_switch_editor", "cdecl"):
    svn_wc_get_switch_editor = _libs["svn_wc-1"].get("svn_wc_get_switch_editor", "cdecl")
    svn_wc_get_switch_editor.argtypes = [POINTER(svn_revnum_t), POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_boolean_t, svn_wc_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), String, POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_traversal_info_t), POINTER(apr_pool_t)]
    svn_wc_get_switch_editor.restype = POINTER(svn_error_t)
    svn_wc_get_switch_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6163
if _libs["svn_wc-1"].has("svn_wc_prop_list2", "cdecl"):
    svn_wc_prop_list2 = _libs["svn_wc-1"].get("svn_wc_prop_list2", "cdecl")
    svn_wc_prop_list2.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_prop_list2.restype = POINTER(svn_error_t)
    svn_wc_prop_list2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6176
if _libs["svn_wc-1"].has("svn_wc_prop_list", "cdecl"):
    svn_wc_prop_list = _libs["svn_wc-1"].get("svn_wc_prop_list", "cdecl")
    svn_wc_prop_list.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_prop_list.restype = POINTER(svn_error_t)
    svn_wc_prop_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6213
if _libs["svn_wc-1"].has("svn_wc_get_pristine_props", "cdecl"):
    svn_wc_get_pristine_props = _libs["svn_wc-1"].get("svn_wc_get_pristine_props", "cdecl")
    svn_wc_get_pristine_props.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_pristine_props.restype = POINTER(svn_error_t)
    svn_wc_get_pristine_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6232
if _libs["svn_wc-1"].has("svn_wc_prop_get2", "cdecl"):
    svn_wc_prop_get2 = _libs["svn_wc-1"].get("svn_wc_prop_get2", "cdecl")
    svn_wc_prop_get2.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_wc_context_t), String, String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_prop_get2.restype = POINTER(svn_error_t)
    svn_wc_prop_get2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6248
if _libs["svn_wc-1"].has("svn_wc_prop_get", "cdecl"):
    svn_wc_prop_get = _libs["svn_wc-1"].get("svn_wc_prop_get", "cdecl")
    svn_wc_prop_get.argtypes = [POINTER(POINTER(svn_string_t)), String, String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_prop_get.restype = POINTER(svn_error_t)
    svn_wc_prop_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6310
if _libs["svn_wc-1"].has("svn_wc_prop_set4", "cdecl"):
    svn_wc_prop_set4 = _libs["svn_wc-1"].get("svn_wc_prop_set4", "cdecl")
    svn_wc_prop_set4.argtypes = [POINTER(svn_wc_context_t), String, String, POINTER(svn_string_t), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_prop_set4.restype = POINTER(svn_error_t)
    svn_wc_prop_set4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6332
if _libs["svn_wc-1"].has("svn_wc_prop_set3", "cdecl"):
    svn_wc_prop_set3 = _libs["svn_wc-1"].get("svn_wc_prop_set3", "cdecl")
    svn_wc_prop_set3.argtypes = [String, POINTER(svn_string_t), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_prop_set3.restype = POINTER(svn_error_t)
    svn_wc_prop_set3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6350
if _libs["svn_wc-1"].has("svn_wc_prop_set2", "cdecl"):
    svn_wc_prop_set2 = _libs["svn_wc-1"].get("svn_wc_prop_set2", "cdecl")
    svn_wc_prop_set2.argtypes = [String, POINTER(svn_string_t), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_prop_set2.restype = POINTER(svn_error_t)
    svn_wc_prop_set2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6365
if _libs["svn_wc-1"].has("svn_wc_prop_set", "cdecl"):
    svn_wc_prop_set = _libs["svn_wc-1"].get("svn_wc_prop_set", "cdecl")
    svn_wc_prop_set.argtypes = [String, POINTER(svn_string_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_prop_set.restype = POINTER(svn_error_t)
    svn_wc_prop_set.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6387
if _libs["svn_wc-1"].has("svn_wc_is_normal_prop", "cdecl"):
    svn_wc_is_normal_prop = _libs["svn_wc-1"].get("svn_wc_is_normal_prop", "cdecl")
    svn_wc_is_normal_prop.argtypes = [String]
    svn_wc_is_normal_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6393
if _libs["svn_wc-1"].has("svn_wc_is_wc_prop", "cdecl"):
    svn_wc_is_wc_prop = _libs["svn_wc-1"].get("svn_wc_is_wc_prop", "cdecl")
    svn_wc_is_wc_prop.argtypes = [String]
    svn_wc_is_wc_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6397
if _libs["svn_wc-1"].has("svn_wc_is_entry_prop", "cdecl"):
    svn_wc_is_entry_prop = _libs["svn_wc-1"].get("svn_wc_is_entry_prop", "cdecl")
    svn_wc_is_entry_prop.argtypes = [String]
    svn_wc_is_entry_prop.restype = svn_boolean_t

svn_wc_canonicalize_svn_prop_get_file_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_string_t)), POINTER(svn_stream_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6413

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6481
if _libs["svn_wc-1"].has("svn_wc_canonicalize_svn_prop", "cdecl"):
    svn_wc_canonicalize_svn_prop = _libs["svn_wc-1"].get("svn_wc_canonicalize_svn_prop", "cdecl")
    svn_wc_canonicalize_svn_prop.argtypes = [POINTER(POINTER(svn_string_t)), String, POINTER(svn_string_t), String, svn_node_kind_t, svn_boolean_t, svn_wc_canonicalize_svn_prop_get_file_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_canonicalize_svn_prop.restype = POINTER(svn_error_t)
    svn_wc_canonicalize_svn_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6564
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor6", "cdecl"):
    svn_wc_get_diff_editor6 = _libs["svn_wc-1"].get("svn_wc_get_diff_editor6", "cdecl")
    svn_wc_get_diff_editor6.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_wc_context_t), String, String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_wc_diff_callbacks4_t), POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor6.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6598
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor5", "cdecl"):
    svn_wc_get_diff_editor5 = _libs["svn_wc-1"].get("svn_wc_get_diff_editor5", "cdecl")
    svn_wc_get_diff_editor5.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks3_t), POINTER(None), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_array_header_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor5.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6621
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor4", "cdecl"):
    svn_wc_get_diff_editor4 = _libs["svn_wc-1"].get("svn_wc_get_diff_editor4", "cdecl")
    svn_wc_get_diff_editor4.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks2_t), POINTER(None), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_array_header_t), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor4.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6647
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor3", "cdecl"):
    svn_wc_get_diff_editor3 = _libs["svn_wc-1"].get("svn_wc_get_diff_editor3", "cdecl")
    svn_wc_get_diff_editor3.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks2_t), POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor3.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6670
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor2", "cdecl"):
    svn_wc_get_diff_editor2 = _libs["svn_wc-1"].get("svn_wc_get_diff_editor2", "cdecl")
    svn_wc_get_diff_editor2.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks_t), POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor2.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6693
if _libs["svn_wc-1"].has("svn_wc_get_diff_editor", "cdecl"):
    svn_wc_get_diff_editor = _libs["svn_wc-1"].get("svn_wc_get_diff_editor", "cdecl")
    svn_wc_get_diff_editor.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks_t), POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(apr_pool_t)]
    svn_wc_get_diff_editor.restype = POINTER(svn_error_t)
    svn_wc_get_diff_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6748
if _libs["svn_wc-1"].has("svn_wc_diff6", "cdecl"):
    svn_wc_diff6 = _libs["svn_wc-1"].get("svn_wc_diff6", "cdecl")
    svn_wc_diff6.argtypes = [POINTER(svn_wc_context_t), String, POINTER(svn_wc_diff_callbacks4_t), POINTER(None), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_diff6.restype = POINTER(svn_error_t)
    svn_wc_diff6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6772
if _libs["svn_wc-1"].has("svn_wc_diff5", "cdecl"):
    svn_wc_diff5 = _libs["svn_wc-1"].get("svn_wc_diff5", "cdecl")
    svn_wc_diff5.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks3_t), POINTER(None), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_wc_diff5.restype = POINTER(svn_error_t)
    svn_wc_diff5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6790
if _libs["svn_wc-1"].has("svn_wc_diff4", "cdecl"):
    svn_wc_diff4 = _libs["svn_wc-1"].get("svn_wc_diff4", "cdecl")
    svn_wc_diff4.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks2_t), POINTER(None), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_wc_diff4.restype = POINTER(svn_error_t)
    svn_wc_diff4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6809
if _libs["svn_wc-1"].has("svn_wc_diff3", "cdecl"):
    svn_wc_diff3 = _libs["svn_wc-1"].get("svn_wc_diff3", "cdecl")
    svn_wc_diff3.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks2_t), POINTER(None), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_diff3.restype = POINTER(svn_error_t)
    svn_wc_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6826
if _libs["svn_wc-1"].has("svn_wc_diff2", "cdecl"):
    svn_wc_diff2 = _libs["svn_wc-1"].get("svn_wc_diff2", "cdecl")
    svn_wc_diff2.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks_t), POINTER(None), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_diff2.restype = POINTER(svn_error_t)
    svn_wc_diff2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6842
if _libs["svn_wc-1"].has("svn_wc_diff", "cdecl"):
    svn_wc_diff = _libs["svn_wc-1"].get("svn_wc_diff", "cdecl")
    svn_wc_diff.argtypes = [POINTER(svn_wc_adm_access_t), String, POINTER(svn_wc_diff_callbacks_t), POINTER(None), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_diff.restype = POINTER(svn_error_t)
    svn_wc_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6867
if _libs["svn_wc-1"].has("svn_wc_get_prop_diffs2", "cdecl"):
    svn_wc_get_prop_diffs2 = _libs["svn_wc-1"].get("svn_wc_get_prop_diffs2", "cdecl")
    svn_wc_get_prop_diffs2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(POINTER(apr_hash_t)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_prop_diffs2.restype = POINTER(svn_error_t)
    svn_wc_get_prop_diffs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6881
if _libs["svn_wc-1"].has("svn_wc_get_prop_diffs", "cdecl"):
    svn_wc_get_prop_diffs = _libs["svn_wc-1"].get("svn_wc_get_prop_diffs", "cdecl")
    svn_wc_get_prop_diffs.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(POINTER(apr_hash_t)), String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_get_prop_diffs.restype = POINTER(svn_error_t)
    svn_wc_get_prop_diffs.errcheck = _svn_errcheck

enum_svn_wc_merge_outcome_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

svn_wc_merge_unchanged = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

svn_wc_merge_merged = (svn_wc_merge_unchanged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

svn_wc_merge_conflict = (svn_wc_merge_merged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

svn_wc_merge_no_merge = (svn_wc_merge_conflict + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

svn_wc_merge_outcome_t = enum_svn_wc_merge_outcome_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 6919

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7011
if _libs["svn_wc-1"].has("svn_wc_merge5", "cdecl"):
    svn_wc_merge5 = _libs["svn_wc-1"].get("svn_wc_merge5", "cdecl")
    svn_wc_merge5.argtypes = [POINTER(enum_svn_wc_merge_outcome_t), POINTER(enum_svn_wc_notify_state_t), POINTER(svn_wc_context_t), String, String, String, String, String, String, POINTER(svn_wc_conflict_version_t), POINTER(svn_wc_conflict_version_t), svn_boolean_t, String, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(apr_array_header_t), svn_wc_conflict_resolver_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_merge5.restype = POINTER(svn_error_t)
    svn_wc_merge5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7045
if _libs["svn_wc-1"].has("svn_wc_merge4", "cdecl"):
    svn_wc_merge4 = _libs["svn_wc-1"].get("svn_wc_merge4", "cdecl")
    svn_wc_merge4.argtypes = [POINTER(enum_svn_wc_merge_outcome_t), POINTER(svn_wc_context_t), String, String, String, String, String, String, POINTER(svn_wc_conflict_version_t), POINTER(svn_wc_conflict_version_t), svn_boolean_t, String, POINTER(apr_array_header_t), POINTER(apr_array_header_t), svn_wc_conflict_resolver_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_merge4.restype = POINTER(svn_error_t)
    svn_wc_merge4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7081
if _libs["svn_wc-1"].has("svn_wc_merge3", "cdecl"):
    svn_wc_merge3 = _libs["svn_wc-1"].get("svn_wc_merge3", "cdecl")
    svn_wc_merge3.argtypes = [POINTER(enum_svn_wc_merge_outcome_t), String, String, String, POINTER(svn_wc_adm_access_t), String, String, String, svn_boolean_t, String, POINTER(apr_array_header_t), POINTER(apr_array_header_t), svn_wc_conflict_resolver_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_merge3.restype = POINTER(svn_error_t)
    svn_wc_merge3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7105
if _libs["svn_wc-1"].has("svn_wc_merge2", "cdecl"):
    svn_wc_merge2 = _libs["svn_wc-1"].get("svn_wc_merge2", "cdecl")
    svn_wc_merge2.argtypes = [POINTER(enum_svn_wc_merge_outcome_t), String, String, String, POINTER(svn_wc_adm_access_t), String, String, String, svn_boolean_t, String, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_wc_merge2.restype = POINTER(svn_error_t)
    svn_wc_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7125
if _libs["svn_wc-1"].has("svn_wc_merge", "cdecl"):
    svn_wc_merge = _libs["svn_wc-1"].get("svn_wc_merge", "cdecl")
    svn_wc_merge.argtypes = [String, String, String, POINTER(svn_wc_adm_access_t), String, String, String, svn_boolean_t, POINTER(enum_svn_wc_merge_outcome_t), String, POINTER(apr_pool_t)]
    svn_wc_merge.restype = POINTER(svn_error_t)
    svn_wc_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7169
if _libs["svn_wc-1"].has("svn_wc_merge_props3", "cdecl"):
    svn_wc_merge_props3 = _libs["svn_wc-1"].get("svn_wc_merge_props3", "cdecl")
    svn_wc_merge_props3.argtypes = [POINTER(svn_wc_notify_state_t), POINTER(svn_wc_context_t), String, POINTER(svn_wc_conflict_version_t), POINTER(svn_wc_conflict_version_t), POINTER(apr_hash_t), POINTER(apr_array_header_t), svn_boolean_t, svn_wc_conflict_resolver_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_merge_props3.restype = POINTER(svn_error_t)
    svn_wc_merge_props3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7205
if _libs["svn_wc-1"].has("svn_wc_merge_props2", "cdecl"):
    svn_wc_merge_props2 = _libs["svn_wc-1"].get("svn_wc_merge_props2", "cdecl")
    svn_wc_merge_props2.argtypes = [POINTER(svn_wc_notify_state_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_hash_t), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, svn_wc_conflict_resolver_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_merge_props2.restype = POINTER(svn_error_t)
    svn_wc_merge_props2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7226
if _libs["svn_wc-1"].has("svn_wc_merge_props", "cdecl"):
    svn_wc_merge_props = _libs["svn_wc-1"].get("svn_wc_merge_props", "cdecl")
    svn_wc_merge_props.argtypes = [POINTER(svn_wc_notify_state_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_hash_t), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_merge_props.restype = POINTER(svn_error_t)
    svn_wc_merge_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7249
if _libs["svn_wc-1"].has("svn_wc_merge_prop_diffs", "cdecl"):
    svn_wc_merge_prop_diffs = _libs["svn_wc-1"].get("svn_wc_merge_prop_diffs", "cdecl")
    svn_wc_merge_prop_diffs.argtypes = [POINTER(svn_wc_notify_state_t), String, POINTER(svn_wc_adm_access_t), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_merge_prop_diffs.restype = POINTER(svn_error_t)
    svn_wc_merge_prop_diffs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7281
if _libs["svn_wc-1"].has("svn_wc_get_pristine_contents2", "cdecl"):
    svn_wc_get_pristine_contents2 = _libs["svn_wc-1"].get("svn_wc_get_pristine_contents2", "cdecl")
    svn_wc_get_pristine_contents2.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(svn_wc_context_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_pristine_contents2.restype = POINTER(svn_error_t)
    svn_wc_get_pristine_contents2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7295
if _libs["svn_wc-1"].has("svn_wc_get_pristine_contents", "cdecl"):
    svn_wc_get_pristine_contents = _libs["svn_wc-1"].get("svn_wc_get_pristine_contents", "cdecl")
    svn_wc_get_pristine_contents.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_pristine_contents.restype = POINTER(svn_error_t)
    svn_wc_get_pristine_contents.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7318
if _libs["svn_wc-1"].has("svn_wc_get_pristine_copy_path", "cdecl"):
    svn_wc_get_pristine_copy_path = _libs["svn_wc-1"].get("svn_wc_get_pristine_copy_path", "cdecl")
    svn_wc_get_pristine_copy_path.argtypes = [String, POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_wc_get_pristine_copy_path.restype = POINTER(svn_error_t)
    svn_wc_get_pristine_copy_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7356
if _libs["svn_wc-1"].has("svn_wc_cleanup4", "cdecl"):
    svn_wc_cleanup4 = _libs["svn_wc-1"].get("svn_wc_cleanup4", "cdecl")
    svn_wc_cleanup4.argtypes = [POINTER(svn_wc_context_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_cleanup4.restype = POINTER(svn_error_t)
    svn_wc_cleanup4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7378
if _libs["svn_wc-1"].has("svn_wc_cleanup3", "cdecl"):
    svn_wc_cleanup3 = _libs["svn_wc-1"].get("svn_wc_cleanup3", "cdecl")
    svn_wc_cleanup3.argtypes = [POINTER(svn_wc_context_t), String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_cleanup3.restype = POINTER(svn_error_t)
    svn_wc_cleanup3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7393
if _libs["svn_wc-1"].has("svn_wc_cleanup2", "cdecl"):
    svn_wc_cleanup2 = _libs["svn_wc-1"].get("svn_wc_cleanup2", "cdecl")
    svn_wc_cleanup2.argtypes = [String, String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_cleanup2.restype = POINTER(svn_error_t)
    svn_wc_cleanup2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7407
if _libs["svn_wc-1"].has("svn_wc_cleanup", "cdecl"):
    svn_wc_cleanup = _libs["svn_wc-1"].get("svn_wc_cleanup", "cdecl")
    svn_wc_cleanup.argtypes = [String, POINTER(svn_wc_adm_access_t), String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_cleanup.restype = POINTER(svn_error_t)
    svn_wc_cleanup.errcheck = _svn_errcheck

svn_wc_upgrade_get_repos_info_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(None), String, POINTER(apr_pool_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7423

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7452
if _libs["svn_wc-1"].has("svn_wc_upgrade", "cdecl"):
    svn_wc_upgrade = _libs["svn_wc-1"].get("svn_wc_upgrade", "cdecl")
    svn_wc_upgrade.argtypes = [POINTER(svn_wc_context_t), String, svn_wc_upgrade_get_repos_info_t, POINTER(None), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_upgrade.restype = POINTER(svn_error_t)
    svn_wc_upgrade.errcheck = _svn_errcheck

svn_wc_relocation_validator3_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7478

svn_wc_relocation_validator2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7492

svn_wc_relocation_validator_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7504

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7521
if _libs["svn_wc-1"].has("svn_wc_relocate4", "cdecl"):
    svn_wc_relocate4 = _libs["svn_wc-1"].get("svn_wc_relocate4", "cdecl")
    svn_wc_relocate4.argtypes = [POINTER(svn_wc_context_t), String, String, String, svn_wc_relocation_validator3_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_relocate4.restype = POINTER(svn_error_t)
    svn_wc_relocate4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7541
if _libs["svn_wc-1"].has("svn_wc_relocate3", "cdecl"):
    svn_wc_relocate3 = _libs["svn_wc-1"].get("svn_wc_relocate3", "cdecl")
    svn_wc_relocate3.argtypes = [String, POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_wc_relocation_validator3_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_relocate3.restype = POINTER(svn_error_t)
    svn_wc_relocate3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7556
if _libs["svn_wc-1"].has("svn_wc_relocate2", "cdecl"):
    svn_wc_relocate2 = _libs["svn_wc-1"].get("svn_wc_relocate2", "cdecl")
    svn_wc_relocate2.argtypes = [String, POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_wc_relocation_validator2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_relocate2.restype = POINTER(svn_error_t)
    svn_wc_relocate2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7570
if _libs["svn_wc-1"].has("svn_wc_relocate", "cdecl"):
    svn_wc_relocate = _libs["svn_wc-1"].get("svn_wc_relocate", "cdecl")
    svn_wc_relocate.argtypes = [String, POINTER(svn_wc_adm_access_t), String, String, svn_boolean_t, svn_wc_relocation_validator_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_relocate.restype = POINTER(svn_error_t)
    svn_wc_relocate.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7632
if _libs["svn_wc-1"].has("svn_wc_revert6", "cdecl"):
    svn_wc_revert6 = _libs["svn_wc-1"].get("svn_wc_revert6", "cdecl")
    svn_wc_revert6.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert6.restype = POINTER(svn_error_t)
    svn_wc_revert6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7654
if _libs["svn_wc-1"].has("svn_wc_revert5", "cdecl"):
    svn_wc_revert5 = _libs["svn_wc-1"].get("svn_wc_revert5", "cdecl")
    svn_wc_revert5.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert5.restype = POINTER(svn_error_t)
    svn_wc_revert5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7675
if _libs["svn_wc-1"].has("svn_wc_revert4", "cdecl"):
    svn_wc_revert4 = _libs["svn_wc-1"].get("svn_wc_revert4", "cdecl")
    svn_wc_revert4.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert4.restype = POINTER(svn_error_t)
    svn_wc_revert4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7693
if _libs["svn_wc-1"].has("svn_wc_revert3", "cdecl"):
    svn_wc_revert3 = _libs["svn_wc-1"].get("svn_wc_revert3", "cdecl")
    svn_wc_revert3.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert3.restype = POINTER(svn_error_t)
    svn_wc_revert3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7718
if _libs["svn_wc-1"].has("svn_wc_revert2", "cdecl"):
    svn_wc_revert2 = _libs["svn_wc-1"].get("svn_wc_revert2", "cdecl")
    svn_wc_revert2.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert2.restype = POINTER(svn_error_t)
    svn_wc_revert2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7735
if _libs["svn_wc-1"].has("svn_wc_revert", "cdecl"):
    svn_wc_revert = _libs["svn_wc-1"].get("svn_wc_revert", "cdecl")
    svn_wc_revert.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revert.restype = POINTER(svn_error_t)
    svn_wc_revert.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7759
if _libs["svn_wc-1"].has("svn_wc_restore", "cdecl"):
    svn_wc_restore = _libs["svn_wc-1"].get("svn_wc_restore", "cdecl")
    svn_wc_restore.argtypes = [POINTER(svn_wc_context_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_restore.restype = POINTER(svn_error_t)
    svn_wc_restore.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7782
if _libs["svn_wc-1"].has("svn_wc_create_tmp_file2", "cdecl"):
    svn_wc_create_tmp_file2 = _libs["svn_wc-1"].get("svn_wc_create_tmp_file2", "cdecl")
    svn_wc_create_tmp_file2.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(POINTER(c_char)), String, svn_io_file_del_t, POINTER(apr_pool_t)]
    svn_wc_create_tmp_file2.restype = POINTER(svn_error_t)
    svn_wc_create_tmp_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7796
if _libs["svn_wc-1"].has("svn_wc_create_tmp_file", "cdecl"):
    svn_wc_create_tmp_file = _libs["svn_wc-1"].get("svn_wc_create_tmp_file", "cdecl")
    svn_wc_create_tmp_file.argtypes = [POINTER(POINTER(apr_file_t)), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_create_tmp_file.restype = POINTER(svn_error_t)
    svn_wc_create_tmp_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7846
if _libs["svn_wc-1"].has("svn_wc_translated_file2", "cdecl"):
    svn_wc_translated_file2 = _libs["svn_wc-1"].get("svn_wc_translated_file2", "cdecl")
    svn_wc_translated_file2.argtypes = [POINTER(POINTER(c_char)), String, String, POINTER(svn_wc_adm_access_t), apr_uint32_t, POINTER(apr_pool_t)]
    svn_wc_translated_file2.restype = POINTER(svn_error_t)
    svn_wc_translated_file2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7861
if _libs["svn_wc-1"].has("svn_wc_translated_file", "cdecl"):
    svn_wc_translated_file = _libs["svn_wc-1"].get("svn_wc_translated_file", "cdecl")
    svn_wc_translated_file.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_translated_file.restype = POINTER(svn_error_t)
    svn_wc_translated_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7887
if _libs["svn_wc-1"].has("svn_wc_translated_stream", "cdecl"):
    svn_wc_translated_stream = _libs["svn_wc-1"].get("svn_wc_translated_stream", "cdecl")
    svn_wc_translated_stream.argtypes = [POINTER(POINTER(svn_stream_t)), String, String, POINTER(svn_wc_adm_access_t), apr_uint32_t, POINTER(apr_pool_t)]
    svn_wc_translated_stream.restype = POINTER(svn_error_t)
    svn_wc_translated_stream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7929
if _libs["svn_wc-1"].has("svn_wc_transmit_text_deltas3", "cdecl"):
    svn_wc_transmit_text_deltas3 = _libs["svn_wc-1"].get("svn_wc_transmit_text_deltas3", "cdecl")
    svn_wc_transmit_text_deltas3.argtypes = [POINTER(POINTER(svn_checksum_t)), POINTER(POINTER(svn_checksum_t)), POINTER(svn_wc_context_t), String, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_transmit_text_deltas3.restype = POINTER(svn_error_t)
    svn_wc_transmit_text_deltas3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7956
if _libs["svn_wc-1"].has("svn_wc_transmit_text_deltas2", "cdecl"):
    svn_wc_transmit_text_deltas2 = _libs["svn_wc-1"].get("svn_wc_transmit_text_deltas2", "cdecl")
    svn_wc_transmit_text_deltas2.argtypes = [POINTER(POINTER(c_char)), POINTER(c_ubyte), String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_wc_transmit_text_deltas2.restype = POINTER(svn_error_t)
    svn_wc_transmit_text_deltas2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7971
if _libs["svn_wc-1"].has("svn_wc_transmit_text_deltas", "cdecl"):
    svn_wc_transmit_text_deltas = _libs["svn_wc-1"].get("svn_wc_transmit_text_deltas", "cdecl")
    svn_wc_transmit_text_deltas.argtypes = [String, POINTER(svn_wc_adm_access_t), svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_wc_transmit_text_deltas.restype = POINTER(svn_error_t)
    svn_wc_transmit_text_deltas.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 7987
if _libs["svn_wc-1"].has("svn_wc_transmit_prop_deltas2", "cdecl"):
    svn_wc_transmit_prop_deltas2 = _libs["svn_wc-1"].get("svn_wc_transmit_prop_deltas2", "cdecl")
    svn_wc_transmit_prop_deltas2.argtypes = [POINTER(svn_wc_context_t), String, POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_wc_transmit_prop_deltas2.restype = POINTER(svn_error_t)
    svn_wc_transmit_prop_deltas2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8008
if _libs["svn_wc-1"].has("svn_wc_transmit_prop_deltas", "cdecl"):
    svn_wc_transmit_prop_deltas = _libs["svn_wc-1"].get("svn_wc_transmit_prop_deltas", "cdecl")
    svn_wc_transmit_prop_deltas.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(svn_wc_entry_t), POINTER(svn_delta_editor_t), POINTER(None), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_wc_transmit_prop_deltas.restype = POINTER(svn_error_t)
    svn_wc_transmit_prop_deltas.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8029
if _libs["svn_wc-1"].has("svn_wc_get_default_ignores", "cdecl"):
    svn_wc_get_default_ignores = _libs["svn_wc-1"].get("svn_wc_get_default_ignores", "cdecl")
    svn_wc_get_default_ignores.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_wc_get_default_ignores.restype = POINTER(svn_error_t)
    svn_wc_get_default_ignores.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8042
if _libs["svn_wc-1"].has("svn_wc_get_ignores2", "cdecl"):
    svn_wc_get_ignores2 = _libs["svn_wc-1"].get("svn_wc_get_ignores2", "cdecl")
    svn_wc_get_ignores2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_wc_context_t), String, POINTER(apr_hash_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_get_ignores2.restype = POINTER(svn_error_t)
    svn_wc_get_ignores2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8057
if _libs["svn_wc-1"].has("svn_wc_get_ignores", "cdecl"):
    svn_wc_get_ignores = _libs["svn_wc-1"].get("svn_wc_get_ignores", "cdecl")
    svn_wc_get_ignores.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_hash_t), POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_get_ignores.restype = POINTER(svn_error_t)
    svn_wc_get_ignores.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8069
if _libs["svn_wc-1"].has("svn_wc_match_ignore_list", "cdecl"):
    svn_wc_match_ignore_list = _libs["svn_wc-1"].get("svn_wc_match_ignore_list", "cdecl")
    svn_wc_match_ignore_list.argtypes = [String, POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_wc_match_ignore_list.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8087
if _libs["svn_wc-1"].has("svn_wc_add_lock2", "cdecl"):
    svn_wc_add_lock2 = _libs["svn_wc-1"].get("svn_wc_add_lock2", "cdecl")
    svn_wc_add_lock2.argtypes = [POINTER(svn_wc_context_t), String, POINTER(svn_lock_t), POINTER(apr_pool_t)]
    svn_wc_add_lock2.restype = POINTER(svn_error_t)
    svn_wc_add_lock2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8101
if _libs["svn_wc-1"].has("svn_wc_add_lock", "cdecl"):
    svn_wc_add_lock = _libs["svn_wc-1"].get("svn_wc_add_lock", "cdecl")
    svn_wc_add_lock.argtypes = [String, POINTER(svn_lock_t), POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_add_lock.restype = POINTER(svn_error_t)
    svn_wc_add_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8114
if _libs["svn_wc-1"].has("svn_wc_remove_lock2", "cdecl"):
    svn_wc_remove_lock2 = _libs["svn_wc-1"].get("svn_wc_remove_lock2", "cdecl")
    svn_wc_remove_lock2.argtypes = [POINTER(svn_wc_context_t), String, POINTER(apr_pool_t)]
    svn_wc_remove_lock2.restype = POINTER(svn_error_t)
    svn_wc_remove_lock2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8127
if _libs["svn_wc-1"].has("svn_wc_remove_lock", "cdecl"):
    svn_wc_remove_lock = _libs["svn_wc-1"].get("svn_wc_remove_lock", "cdecl")
    svn_wc_remove_lock.argtypes = [String, POINTER(svn_wc_adm_access_t), POINTER(apr_pool_t)]
    svn_wc_remove_lock.restype = POINTER(svn_error_t)
    svn_wc_remove_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8158
class struct_svn_wc_revision_status_t(Structure):
    pass

struct_svn_wc_revision_status_t.__slots__ = [
    'min_rev',
    'max_rev',
    'switched',
    'modified',
    'sparse_checkout',
]
struct_svn_wc_revision_status_t._fields_ = [
    ('min_rev', svn_revnum_t),
    ('max_rev', svn_revnum_t),
    ('switched', svn_boolean_t),
    ('modified', svn_boolean_t),
    ('sparse_checkout', svn_boolean_t),
]

svn_wc_revision_status_t = struct_svn_wc_revision_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8158

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8191
if _libs["svn_wc-1"].has("svn_wc_revision_status2", "cdecl"):
    svn_wc_revision_status2 = _libs["svn_wc-1"].get("svn_wc_revision_status2", "cdecl")
    svn_wc_revision_status2.argtypes = [POINTER(POINTER(svn_wc_revision_status_t)), POINTER(svn_wc_context_t), String, String, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_wc_revision_status2.restype = POINTER(svn_error_t)
    svn_wc_revision_status2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8210
if _libs["svn_wc-1"].has("svn_wc_revision_status", "cdecl"):
    svn_wc_revision_status = _libs["svn_wc-1"].get("svn_wc_revision_status", "cdecl")
    svn_wc_revision_status.argtypes = [POINTER(POINTER(svn_wc_revision_status_t)), String, String, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_revision_status.restype = POINTER(svn_error_t)
    svn_wc_revision_status.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8252
if _libs["svn_wc-1"].has("svn_wc_set_changelist2", "cdecl"):
    svn_wc_set_changelist2 = _libs["svn_wc-1"].get("svn_wc_set_changelist2", "cdecl")
    svn_wc_set_changelist2.argtypes = [POINTER(svn_wc_context_t), String, String, svn_depth_t, POINTER(apr_array_header_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_set_changelist2.restype = POINTER(svn_error_t)
    svn_wc_set_changelist2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8271
if _libs["svn_wc-1"].has("svn_wc_set_changelist", "cdecl"):
    svn_wc_set_changelist = _libs["svn_wc-1"].get("svn_wc_set_changelist", "cdecl")
    svn_wc_set_changelist.argtypes = [String, String, POINTER(svn_wc_adm_access_t), svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_set_changelist.restype = POINTER(svn_error_t)
    svn_wc_set_changelist.errcheck = _svn_errcheck

svn_changelist_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8292

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8313
if _libs["svn_wc-1"].has("svn_wc_get_changelists", "cdecl"):
    svn_wc_get_changelists = _libs["svn_wc-1"].get("svn_wc_get_changelists", "cdecl")
    svn_wc_get_changelists.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, POINTER(apr_array_header_t), svn_changelist_receiver_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_get_changelists.restype = POINTER(svn_error_t)
    svn_wc_get_changelists.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8353
if _libs["svn_wc-1"].has("svn_wc_crop_tree2", "cdecl"):
    svn_wc_crop_tree2 = _libs["svn_wc-1"].get("svn_wc_crop_tree2", "cdecl")
    svn_wc_crop_tree2.argtypes = [POINTER(svn_wc_context_t), String, svn_depth_t, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_crop_tree2.restype = POINTER(svn_error_t)
    svn_wc_crop_tree2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8374
if _libs["svn_wc-1"].has("svn_wc_crop_tree", "cdecl"):
    svn_wc_crop_tree = _libs["svn_wc-1"].get("svn_wc_crop_tree", "cdecl")
    svn_wc_crop_tree.argtypes = [POINTER(svn_wc_adm_access_t), String, svn_depth_t, svn_wc_notify_func2_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_crop_tree.restype = POINTER(svn_error_t)
    svn_wc_crop_tree.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8403
if _libs["svn_wc-1"].has("svn_wc_exclude", "cdecl"):
    svn_wc_exclude = _libs["svn_wc-1"].get("svn_wc_exclude", "cdecl")
    svn_wc_exclude.argtypes = [POINTER(svn_wc_context_t), String, svn_cancel_func_t, POINTER(None), svn_wc_notify_func2_t, POINTER(None), POINTER(apr_pool_t)]
    svn_wc_exclude.restype = POINTER(svn_error_t)
    svn_wc_exclude.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8441
if _libs["svn_wc-1"].has("svn_wc_read_kind2", "cdecl"):
    svn_wc_read_kind2 = _libs["svn_wc-1"].get("svn_wc_read_kind2", "cdecl")
    svn_wc_read_kind2.argtypes = [POINTER(svn_node_kind_t), POINTER(svn_wc_context_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_read_kind2.restype = POINTER(svn_error_t)
    svn_wc_read_kind2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8456
if _libs["svn_wc-1"].has("svn_wc_read_kind", "cdecl"):
    svn_wc_read_kind = _libs["svn_wc-1"].get("svn_wc_read_kind", "cdecl")
    svn_wc_read_kind.argtypes = [POINTER(svn_node_kind_t), POINTER(svn_wc_context_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_wc_read_kind.restype = POINTER(svn_error_t)
    svn_wc_read_kind.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 71
if _libs["svn_diff-1"].has("svn_diff_version", "cdecl"):
    svn_diff_version = _libs["svn_diff-1"].get("svn_diff_version", "cdecl")
    svn_diff_version.argtypes = []
    svn_diff_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 82
class struct_svn_diff_t(Structure):
    pass

svn_diff_t = struct_svn_diff_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 82

enum_svn_diff_datasource_e = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

svn_diff_datasource_original = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

svn_diff_datasource_modified = (svn_diff_datasource_original + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

svn_diff_datasource_latest = (svn_diff_datasource_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

svn_diff_datasource_ancestor = (svn_diff_datasource_latest + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

svn_diff_datasource_e = enum_svn_diff_datasource_e# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 105

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 148
class struct_svn_diff_fns2_t(Structure):
    pass

struct_svn_diff_fns2_t.__slots__ = [
    'datasources_open',
    'datasource_close',
    'datasource_get_next_token',
    'token_compare',
    'token_discard',
    'token_discard_all',
]
struct_svn_diff_fns2_t._fields_ = [
    ('datasources_open', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_off_t), POINTER(apr_off_t), POINTER(svn_diff_datasource_e), apr_size_t)),
    ('datasource_close', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_diff_datasource_e)),
    ('datasource_get_next_token', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(apr_uint32_t), POINTER(POINTER(None)), POINTER(None), svn_diff_datasource_e)),
    ('token_compare', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(None), POINTER(None), POINTER(c_int))),
    ('token_discard', CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(None))),
    ('token_discard_all', CFUNCTYPE(UNCHECKED(None), POINTER(None))),
]

svn_diff_fns2_t = struct_svn_diff_fns2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 148

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 177
class struct_svn_diff_fns_t(Structure):
    pass

struct_svn_diff_fns_t.__slots__ = [
    'datasource_open',
    'datasource_close',
    'datasource_get_next_token',
    'token_compare',
    'token_discard',
    'token_discard_all',
]
struct_svn_diff_fns_t._fields_ = [
    ('datasource_open', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_diff_datasource_e)),
    ('datasource_close', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_diff_datasource_e)),
    ('datasource_get_next_token', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(apr_uint32_t), POINTER(POINTER(None)), POINTER(None), svn_diff_datasource_e)),
    ('token_compare', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(None), POINTER(None), POINTER(c_int))),
    ('token_discard', CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(None))),
    ('token_discard_all', CFUNCTYPE(UNCHECKED(None), POINTER(None))),
]

svn_diff_fns_t = struct_svn_diff_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 177

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 188
if _libs["svn_diff-1"].has("svn_diff_diff_2", "cdecl"):
    svn_diff_diff_2 = _libs["svn_diff-1"].get("svn_diff_diff_2", "cdecl")
    svn_diff_diff_2.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns2_t), POINTER(apr_pool_t)]
    svn_diff_diff_2.restype = POINTER(svn_error_t)
    svn_diff_diff_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 200
if _libs["svn_diff-1"].has("svn_diff_diff", "cdecl"):
    svn_diff_diff = _libs["svn_diff-1"].get("svn_diff_diff", "cdecl")
    svn_diff_diff.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns_t), POINTER(apr_pool_t)]
    svn_diff_diff.restype = POINTER(svn_error_t)
    svn_diff_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 213
if _libs["svn_diff-1"].has("svn_diff_diff3_2", "cdecl"):
    svn_diff_diff3_2 = _libs["svn_diff-1"].get("svn_diff_diff3_2", "cdecl")
    svn_diff_diff3_2.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns2_t), POINTER(apr_pool_t)]
    svn_diff_diff3_2.restype = POINTER(svn_error_t)
    svn_diff_diff3_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 225
if _libs["svn_diff-1"].has("svn_diff_diff3", "cdecl"):
    svn_diff_diff3 = _libs["svn_diff-1"].get("svn_diff_diff3", "cdecl")
    svn_diff_diff3.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns_t), POINTER(apr_pool_t)]
    svn_diff_diff3.restype = POINTER(svn_error_t)
    svn_diff_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 239
if _libs["svn_diff-1"].has("svn_diff_diff4_2", "cdecl"):
    svn_diff_diff4_2 = _libs["svn_diff-1"].get("svn_diff_diff4_2", "cdecl")
    svn_diff_diff4_2.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns2_t), POINTER(apr_pool_t)]
    svn_diff_diff4_2.restype = POINTER(svn_error_t)
    svn_diff_diff4_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 251
if _libs["svn_diff-1"].has("svn_diff_diff4", "cdecl"):
    svn_diff_diff4 = _libs["svn_diff-1"].get("svn_diff_diff4", "cdecl")
    svn_diff_diff4.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(None), POINTER(svn_diff_fns_t), POINTER(apr_pool_t)]
    svn_diff_diff4.restype = POINTER(svn_error_t)
    svn_diff_diff4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 264
if _libs["svn_diff-1"].has("svn_diff_contains_conflicts", "cdecl"):
    svn_diff_contains_conflicts = _libs["svn_diff-1"].get("svn_diff_contains_conflicts", "cdecl")
    svn_diff_contains_conflicts.argtypes = [POINTER(svn_diff_t)]
    svn_diff_contains_conflicts.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 271
if _libs["svn_diff-1"].has("svn_diff_contains_diffs", "cdecl"):
    svn_diff_contains_diffs = _libs["svn_diff-1"].get("svn_diff_contains_diffs", "cdecl")
    svn_diff_contains_diffs.argtypes = [POINTER(svn_diff_t)]
    svn_diff_contains_diffs.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 377
class struct_svn_diff_output_fns_t(Structure):
    pass

struct_svn_diff_output_fns_t.__slots__ = [
    'output_common',
    'output_diff_modified',
    'output_diff_latest',
    'output_diff_common',
    'output_conflict',
]
struct_svn_diff_output_fns_t._fields_ = [
    ('output_common', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t)),
    ('output_diff_modified', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t)),
    ('output_diff_latest', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t)),
    ('output_diff_common', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t)),
    ('output_conflict', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, apr_off_t, POINTER(svn_diff_t))),
]

svn_diff_output_fns_t = struct_svn_diff_output_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 377

enum_svn_diff_conflict_display_style_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_modified_latest = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_resolved_modified_latest = (svn_diff_conflict_display_modified_latest + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_modified_original_latest = (svn_diff_conflict_display_resolved_modified_latest + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_modified = (svn_diff_conflict_display_modified_original_latest + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_latest = (svn_diff_conflict_display_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_only_conflicts = (svn_diff_conflict_display_latest + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

svn_diff_conflict_display_style_t = enum_svn_diff_conflict_display_style_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 409

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 420
if _libs["svn_diff-1"].has("svn_diff_output2", "cdecl"):
    svn_diff_output2 = _libs["svn_diff-1"].get("svn_diff_output2", "cdecl")
    svn_diff_output2.argtypes = [POINTER(svn_diff_t), POINTER(None), POINTER(svn_diff_output_fns_t), svn_cancel_func_t, POINTER(None)]
    svn_diff_output2.restype = POINTER(svn_error_t)
    svn_diff_output2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 432
if _libs["svn_diff-1"].has("svn_diff_output", "cdecl"):
    svn_diff_output = _libs["svn_diff-1"].get("svn_diff_output", "cdecl")
    svn_diff_output.argtypes = [POINTER(svn_diff_t), POINTER(None), POINTER(svn_diff_output_fns_t)]
    svn_diff_output.restype = POINTER(svn_error_t)
    svn_diff_output.errcheck = _svn_errcheck

enum_svn_diff_file_ignore_space_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 456

svn_diff_file_ignore_space_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 456

svn_diff_file_ignore_space_change = (svn_diff_file_ignore_space_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 456

svn_diff_file_ignore_space_all = (svn_diff_file_ignore_space_change + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 456

svn_diff_file_ignore_space_t = enum_svn_diff_file_ignore_space_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 456

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 490
class struct_svn_diff_file_options_t(Structure):
    pass

struct_svn_diff_file_options_t.__slots__ = [
    'ignore_space',
    'ignore_eol_style',
    'show_c_function',
    'context_size',
]
struct_svn_diff_file_options_t._fields_ = [
    ('ignore_space', svn_diff_file_ignore_space_t),
    ('ignore_eol_style', svn_boolean_t),
    ('show_c_function', svn_boolean_t),
    ('context_size', c_int),
]

svn_diff_file_options_t = struct_svn_diff_file_options_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 490

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 497
if _libs["svn_diff-1"].has("svn_diff_file_options_create", "cdecl"):
    svn_diff_file_options_create = _libs["svn_diff-1"].get("svn_diff_file_options_create", "cdecl")
    svn_diff_file_options_create.argtypes = [POINTER(apr_pool_t)]
    svn_diff_file_options_create.restype = POINTER(svn_diff_file_options_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 515
if _libs["svn_diff-1"].has("svn_diff_file_options_parse", "cdecl"):
    svn_diff_file_options_parse = _libs["svn_diff-1"].get("svn_diff_file_options_parse", "cdecl")
    svn_diff_file_options_parse.argtypes = [POINTER(svn_diff_file_options_t), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_diff_file_options_parse.restype = POINTER(svn_error_t)
    svn_diff_file_options_parse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 531
if _libs["svn_diff-1"].has("svn_diff_file_diff_2", "cdecl"):
    svn_diff_file_diff_2 = _libs["svn_diff-1"].get("svn_diff_file_diff_2", "cdecl")
    svn_diff_file_diff_2.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_file_diff_2.restype = POINTER(svn_error_t)
    svn_diff_file_diff_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 544
if _libs["svn_diff-1"].has("svn_diff_file_diff", "cdecl"):
    svn_diff_file_diff = _libs["svn_diff-1"].get("svn_diff_file_diff", "cdecl")
    svn_diff_file_diff.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, POINTER(apr_pool_t)]
    svn_diff_file_diff.restype = POINTER(svn_error_t)
    svn_diff_file_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 560
if _libs["svn_diff-1"].has("svn_diff_file_diff3_2", "cdecl"):
    svn_diff_file_diff3_2 = _libs["svn_diff-1"].get("svn_diff_file_diff3_2", "cdecl")
    svn_diff_file_diff3_2.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, String, POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_file_diff3_2.restype = POINTER(svn_error_t)
    svn_diff_file_diff3_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 574
if _libs["svn_diff-1"].has("svn_diff_file_diff3", "cdecl"):
    svn_diff_file_diff3 = _libs["svn_diff-1"].get("svn_diff_file_diff3", "cdecl")
    svn_diff_file_diff3.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, String, POINTER(apr_pool_t)]
    svn_diff_file_diff3.restype = POINTER(svn_error_t)
    svn_diff_file_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 591
if _libs["svn_diff-1"].has("svn_diff_file_diff4_2", "cdecl"):
    svn_diff_file_diff4_2 = _libs["svn_diff-1"].get("svn_diff_file_diff4_2", "cdecl")
    svn_diff_file_diff4_2.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, String, String, POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_file_diff4_2.restype = POINTER(svn_error_t)
    svn_diff_file_diff4_2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 606
if _libs["svn_diff-1"].has("svn_diff_file_diff4", "cdecl"):
    svn_diff_file_diff4 = _libs["svn_diff-1"].get("svn_diff_file_diff4", "cdecl")
    svn_diff_file_diff4.argtypes = [POINTER(POINTER(svn_diff_t)), String, String, String, String, POINTER(apr_pool_t)]
    svn_diff_file_diff4.restype = POINTER(svn_error_t)
    svn_diff_file_diff4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 639
if _libs["svn_diff-1"].has("svn_diff_file_output_unified4", "cdecl"):
    svn_diff_file_output_unified4 = _libs["svn_diff-1"].get("svn_diff_file_output_unified4", "cdecl")
    svn_diff_file_output_unified4.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, String, svn_boolean_t, c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_diff_file_output_unified4.restype = POINTER(svn_error_t)
    svn_diff_file_output_unified4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 661
if _libs["svn_diff-1"].has("svn_diff_file_output_unified3", "cdecl"):
    svn_diff_file_output_unified3 = _libs["svn_diff-1"].get("svn_diff_file_output_unified3", "cdecl")
    svn_diff_file_output_unified3.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_diff_file_output_unified3.restype = POINTER(svn_error_t)
    svn_diff_file_output_unified3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 679
if _libs["svn_diff-1"].has("svn_diff_file_output_unified2", "cdecl"):
    svn_diff_file_output_unified2 = _libs["svn_diff-1"].get("svn_diff_file_output_unified2", "cdecl")
    svn_diff_file_output_unified2.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, POINTER(apr_pool_t)]
    svn_diff_file_output_unified2.restype = POINTER(svn_error_t)
    svn_diff_file_output_unified2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 695
if _libs["svn_diff-1"].has("svn_diff_file_output_unified", "cdecl"):
    svn_diff_file_output_unified = _libs["svn_diff-1"].get("svn_diff_file_output_unified", "cdecl")
    svn_diff_file_output_unified.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, POINTER(apr_pool_t)]
    svn_diff_file_output_unified.restype = POINTER(svn_error_t)
    svn_diff_file_output_unified.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 722
if _libs["svn_diff-1"].has("svn_diff_file_output_merge3", "cdecl"):
    svn_diff_file_output_merge3 = _libs["svn_diff-1"].get("svn_diff_file_output_merge3", "cdecl")
    svn_diff_file_output_merge3.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, String, String, svn_diff_conflict_display_style_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_diff_file_output_merge3.restype = POINTER(svn_error_t)
    svn_diff_file_output_merge3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 744
if _libs["svn_diff-1"].has("svn_diff_file_output_merge2", "cdecl"):
    svn_diff_file_output_merge2 = _libs["svn_diff-1"].get("svn_diff_file_output_merge2", "cdecl")
    svn_diff_file_output_merge2.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, String, String, svn_diff_conflict_display_style_t, POINTER(apr_pool_t)]
    svn_diff_file_output_merge2.restype = POINTER(svn_error_t)
    svn_diff_file_output_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 773
if _libs["svn_diff-1"].has("svn_diff_file_output_merge", "cdecl"):
    svn_diff_file_output_merge = _libs["svn_diff-1"].get("svn_diff_file_output_merge", "cdecl")
    svn_diff_file_output_merge.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, String, String, String, String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_diff_file_output_merge.restype = POINTER(svn_error_t)
    svn_diff_file_output_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 802
if _libs["svn_diff-1"].has("svn_diff_output_binary", "cdecl"):
    svn_diff_output_binary = _libs["svn_diff-1"].get("svn_diff_output_binary", "cdecl")
    svn_diff_output_binary.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(svn_stream_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_diff_output_binary.restype = POINTER(svn_error_t)
    svn_diff_output_binary.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 817
if _libs["svn_diff-1"].has("svn_diff_mem_string_diff", "cdecl"):
    svn_diff_mem_string_diff = _libs["svn_diff-1"].get("svn_diff_mem_string_diff", "cdecl")
    svn_diff_mem_string_diff.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_mem_string_diff.restype = POINTER(svn_error_t)
    svn_diff_mem_string_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 830
if _libs["svn_diff-1"].has("svn_diff_mem_string_diff3", "cdecl"):
    svn_diff_mem_string_diff3 = _libs["svn_diff-1"].get("svn_diff_mem_string_diff3", "cdecl")
    svn_diff_mem_string_diff3.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_mem_string_diff3.restype = POINTER(svn_error_t)
    svn_diff_mem_string_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 844
if _libs["svn_diff-1"].has("svn_diff_mem_string_diff4", "cdecl"):
    svn_diff_mem_string_diff4 = _libs["svn_diff-1"].get("svn_diff_mem_string_diff4", "cdecl")
    svn_diff_mem_string_diff4.argtypes = [POINTER(POINTER(svn_diff_t)), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_diff_file_options_t), POINTER(apr_pool_t)]
    svn_diff_mem_string_diff4.restype = POINTER(svn_error_t)
    svn_diff_mem_string_diff4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 881
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_unified3", "cdecl"):
    svn_diff_mem_string_output_unified3 = _libs["svn_diff-1"].get("svn_diff_mem_string_output_unified3", "cdecl")
    svn_diff_mem_string_output_unified3.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), svn_boolean_t, String, String, String, String, POINTER(svn_string_t), POINTER(svn_string_t), c_int, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_diff_mem_string_output_unified3.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_unified3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 904
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_unified2", "cdecl"):
    svn_diff_mem_string_output_unified2 = _libs["svn_diff-1"].get("svn_diff_mem_string_output_unified2", "cdecl")
    svn_diff_mem_string_output_unified2.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), svn_boolean_t, String, String, String, String, POINTER(svn_string_t), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_diff_mem_string_output_unified2.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_unified2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 925
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_unified", "cdecl"):
    svn_diff_mem_string_output_unified = _libs["svn_diff-1"].get("svn_diff_mem_string_output_unified", "cdecl")
    svn_diff_mem_string_output_unified.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), String, String, String, POINTER(svn_string_t), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_diff_mem_string_output_unified.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_unified.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 952
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_merge3", "cdecl"):
    svn_diff_mem_string_output_merge3 = _libs["svn_diff-1"].get("svn_diff_mem_string_output_merge3", "cdecl")
    svn_diff_mem_string_output_merge3.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), String, String, String, String, svn_diff_conflict_display_style_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_diff_mem_string_output_merge3.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_merge3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 974
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_merge2", "cdecl"):
    svn_diff_mem_string_output_merge2 = _libs["svn_diff-1"].get("svn_diff_mem_string_output_merge2", "cdecl")
    svn_diff_mem_string_output_merge2.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), String, String, String, String, svn_diff_conflict_display_style_t, POINTER(apr_pool_t)]
    svn_diff_mem_string_output_merge2.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1002
if _libs["svn_diff-1"].has("svn_diff_mem_string_output_merge", "cdecl"):
    svn_diff_mem_string_output_merge = _libs["svn_diff-1"].get("svn_diff_mem_string_output_merge", "cdecl")
    svn_diff_mem_string_output_merge.argtypes = [POINTER(svn_stream_t), POINTER(svn_diff_t), POINTER(svn_string_t), POINTER(svn_string_t), POINTER(svn_string_t), String, String, String, String, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_diff_mem_string_output_merge.restype = POINTER(svn_error_t)
    svn_diff_mem_string_output_merge.errcheck = _svn_errcheck

enum_svn_diff_operation_kind_e = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_unchanged = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_added = (svn_diff_op_unchanged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_deleted = (svn_diff_op_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_copied = (svn_diff_op_deleted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_moved = (svn_diff_op_copied + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_op_modified = (svn_diff_op_moved + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

svn_diff_operation_kind_t = enum_svn_diff_operation_kind_e# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1035

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1077
class struct_svn_diff_hunk_t(Structure):
    pass

svn_diff_hunk_t = struct_svn_diff_hunk_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1077

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1101
if _libs["svn_diff-1"].has("svn_diff_hunk_readline_diff_text", "cdecl"):
    svn_diff_hunk_readline_diff_text = _libs["svn_diff-1"].get("svn_diff_hunk_readline_diff_text", "cdecl")
    svn_diff_hunk_readline_diff_text.argtypes = [POINTER(svn_diff_hunk_t), POINTER(POINTER(svn_stringbuf_t)), POINTER(POINTER(c_char)), POINTER(svn_boolean_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_diff_hunk_readline_diff_text.restype = POINTER(svn_error_t)
    svn_diff_hunk_readline_diff_text.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1121
if _libs["svn_diff-1"].has("svn_diff_hunk_readline_original_text", "cdecl"):
    svn_diff_hunk_readline_original_text = _libs["svn_diff-1"].get("svn_diff_hunk_readline_original_text", "cdecl")
    svn_diff_hunk_readline_original_text.argtypes = [POINTER(svn_diff_hunk_t), POINTER(POINTER(svn_stringbuf_t)), POINTER(POINTER(c_char)), POINTER(svn_boolean_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_diff_hunk_readline_original_text.restype = POINTER(svn_error_t)
    svn_diff_hunk_readline_original_text.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1136
if _libs["svn_diff-1"].has("svn_diff_hunk_readline_modified_text", "cdecl"):
    svn_diff_hunk_readline_modified_text = _libs["svn_diff-1"].get("svn_diff_hunk_readline_modified_text", "cdecl")
    svn_diff_hunk_readline_modified_text.argtypes = [POINTER(svn_diff_hunk_t), POINTER(POINTER(svn_stringbuf_t)), POINTER(POINTER(c_char)), POINTER(svn_boolean_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_diff_hunk_readline_modified_text.restype = POINTER(svn_error_t)
    svn_diff_hunk_readline_modified_text.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1147
if _libs["svn_diff-1"].has("svn_diff_hunk_reset_diff_text", "cdecl"):
    svn_diff_hunk_reset_diff_text = _libs["svn_diff-1"].get("svn_diff_hunk_reset_diff_text", "cdecl")
    svn_diff_hunk_reset_diff_text.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_reset_diff_text.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1152
if _libs["svn_diff-1"].has("svn_diff_hunk_reset_original_text", "cdecl"):
    svn_diff_hunk_reset_original_text = _libs["svn_diff-1"].get("svn_diff_hunk_reset_original_text", "cdecl")
    svn_diff_hunk_reset_original_text.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_reset_original_text.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1157
if _libs["svn_diff-1"].has("svn_diff_hunk_reset_modified_text", "cdecl"):
    svn_diff_hunk_reset_modified_text = _libs["svn_diff-1"].get("svn_diff_hunk_reset_modified_text", "cdecl")
    svn_diff_hunk_reset_modified_text.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_reset_modified_text.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1163
if _libs["svn_diff-1"].has("svn_diff_hunk_get_original_start", "cdecl"):
    svn_diff_hunk_get_original_start = _libs["svn_diff-1"].get("svn_diff_hunk_get_original_start", "cdecl")
    svn_diff_hunk_get_original_start.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_original_start.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1169
if _libs["svn_diff-1"].has("svn_diff_hunk_get_original_length", "cdecl"):
    svn_diff_hunk_get_original_length = _libs["svn_diff-1"].get("svn_diff_hunk_get_original_length", "cdecl")
    svn_diff_hunk_get_original_length.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_original_length.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1175
if _libs["svn_diff-1"].has("svn_diff_hunk_get_modified_start", "cdecl"):
    svn_diff_hunk_get_modified_start = _libs["svn_diff-1"].get("svn_diff_hunk_get_modified_start", "cdecl")
    svn_diff_hunk_get_modified_start.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_modified_start.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1181
if _libs["svn_diff-1"].has("svn_diff_hunk_get_modified_length", "cdecl"):
    svn_diff_hunk_get_modified_length = _libs["svn_diff-1"].get("svn_diff_hunk_get_modified_length", "cdecl")
    svn_diff_hunk_get_modified_length.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_modified_length.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1188
if _libs["svn_diff-1"].has("svn_diff_hunk_get_leading_context", "cdecl"):
    svn_diff_hunk_get_leading_context = _libs["svn_diff-1"].get("svn_diff_hunk_get_leading_context", "cdecl")
    svn_diff_hunk_get_leading_context.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_leading_context.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1195
if _libs["svn_diff-1"].has("svn_diff_hunk_get_trailing_context", "cdecl"):
    svn_diff_hunk_get_trailing_context = _libs["svn_diff-1"].get("svn_diff_hunk_get_trailing_context", "cdecl")
    svn_diff_hunk_get_trailing_context.argtypes = [POINTER(svn_diff_hunk_t)]
    svn_diff_hunk_get_trailing_context.restype = svn_linenum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1212
class struct_svn_prop_patch_t(Structure):
    pass

struct_svn_prop_patch_t.__slots__ = [
    'name',
    'operation',
    'hunks',
]
struct_svn_prop_patch_t._fields_ = [
    ('name', String),
    ('operation', svn_diff_operation_kind_t),
    ('hunks', POINTER(apr_array_header_t)),
]

svn_prop_patch_t = struct_svn_prop_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1212

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1219
class struct_svn_diff_binary_patch_t(Structure):
    pass

svn_diff_binary_patch_t = struct_svn_diff_binary_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1219

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1230
if _libs["svn_diff-1"].has("svn_diff_get_binary_diff_original_stream", "cdecl"):
    svn_diff_get_binary_diff_original_stream = _libs["svn_diff-1"].get("svn_diff_get_binary_diff_original_stream", "cdecl")
    svn_diff_get_binary_diff_original_stream.argtypes = [POINTER(svn_diff_binary_patch_t), POINTER(apr_pool_t)]
    svn_diff_get_binary_diff_original_stream.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1243
if _libs["svn_diff-1"].has("svn_diff_get_binary_diff_result_stream", "cdecl"):
    svn_diff_get_binary_diff_result_stream = _libs["svn_diff-1"].get("svn_diff_get_binary_diff_result_stream", "cdecl")
    svn_diff_get_binary_diff_result_stream.argtypes = [POINTER(svn_diff_binary_patch_t), POINTER(apr_pool_t)]
    svn_diff_get_binary_diff_result_stream.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1329
class struct_svn_patch_t(Structure):
    pass

struct_svn_patch_t.__slots__ = [
    'old_filename',
    'new_filename',
    'hunks',
    'prop_patches',
    'operation',
    'reverse',
    'mergeinfo',
    'reverse_mergeinfo',
    'binary_patch',
    'old_executable_bit',
    'new_executable_bit',
    'old_symlink_bit',
    'new_symlink_bit',
]
struct_svn_patch_t._fields_ = [
    ('old_filename', String),
    ('new_filename', String),
    ('hunks', POINTER(apr_array_header_t)),
    ('prop_patches', POINTER(apr_hash_t)),
    ('operation', svn_diff_operation_kind_t),
    ('reverse', svn_boolean_t),
    ('mergeinfo', svn_mergeinfo_t),
    ('reverse_mergeinfo', svn_mergeinfo_t),
    ('binary_patch', POINTER(svn_diff_binary_patch_t)),
    ('old_executable_bit', svn_tristate_t),
    ('new_executable_bit', svn_tristate_t),
    ('old_symlink_bit', svn_tristate_t),
    ('new_symlink_bit', svn_tristate_t),
]

svn_patch_t = struct_svn_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1329

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1334
class struct_svn_patch_file_t(Structure):
    pass

svn_patch_file_t = struct_svn_patch_file_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1334

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1340
if _libs["svn_diff-1"].has("svn_diff_open_patch_file", "cdecl"):
    svn_diff_open_patch_file = _libs["svn_diff-1"].get("svn_diff_open_patch_file", "cdecl")
    svn_diff_open_patch_file.argtypes = [POINTER(POINTER(svn_patch_file_t)), String, POINTER(apr_pool_t)]
    svn_diff_open_patch_file.restype = POINTER(svn_error_t)
    svn_diff_open_patch_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1355
if _libs["svn_diff-1"].has("svn_diff_parse_next_patch", "cdecl"):
    svn_diff_parse_next_patch = _libs["svn_diff-1"].get("svn_diff_parse_next_patch", "cdecl")
    svn_diff_parse_next_patch.argtypes = [POINTER(POINTER(svn_patch_t)), POINTER(svn_patch_file_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_diff_parse_next_patch.restype = POINTER(svn_error_t)
    svn_diff_parse_next_patch.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1369
if _libs["svn_diff-1"].has("svn_diff_close_patch_file", "cdecl"):
    svn_diff_close_patch_file = _libs["svn_diff-1"].get("svn_diff_close_patch_file", "cdecl")
    svn_diff_close_patch_file.argtypes = [POINTER(svn_patch_file_t), POINTER(apr_pool_t)]
    svn_diff_close_patch_file.restype = POINTER(svn_error_t)
    svn_diff_close_patch_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 61
if _libs["svn_client-1"].has("svn_client_version", "cdecl"):
    svn_client_version = _libs["svn_client-1"].get("svn_client_version", "cdecl")
    svn_client_version.argtypes = []
    svn_client_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 103
if _libs["svn_client-1"].has("svn_client_get_simple_prompt_provider", "cdecl"):
    svn_client_get_simple_prompt_provider = _libs["svn_client-1"].get("svn_client_get_simple_prompt_provider", "cdecl")
    svn_client_get_simple_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_simple_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_client_get_simple_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 128
if _libs["svn_client-1"].has("svn_client_get_username_prompt_provider", "cdecl"):
    svn_client_get_username_prompt_provider = _libs["svn_client-1"].get("svn_client_get_username_prompt_provider", "cdecl")
    svn_client_get_username_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_username_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_client_get_username_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 151
if _libs["svn_client-1"].has("svn_client_get_simple_provider", "cdecl"):
    svn_client_get_simple_provider = _libs["svn_client-1"].get("svn_client_get_simple_provider", "cdecl")
    svn_client_get_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_simple_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 180
for _lib in _libs.values():
    if not _lib.has("svn_client_get_windows_simple_provider", "cdecl"):
        continue
    svn_client_get_windows_simple_provider = _lib.get("svn_client_get_windows_simple_provider", "cdecl")
    svn_client_get_windows_simple_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_windows_simple_provider.restype = None
    break

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 198
if _libs["svn_client-1"].has("svn_client_get_username_provider", "cdecl"):
    svn_client_get_username_provider = _libs["svn_client-1"].get("svn_client_get_username_provider", "cdecl")
    svn_client_get_username_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_username_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 214
if _libs["svn_client-1"].has("svn_client_get_ssl_server_trust_file_provider", "cdecl"):
    svn_client_get_ssl_server_trust_file_provider = _libs["svn_client-1"].get("svn_client_get_ssl_server_trust_file_provider", "cdecl")
    svn_client_get_ssl_server_trust_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_ssl_server_trust_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 231
if _libs["svn_client-1"].has("svn_client_get_ssl_client_cert_file_provider", "cdecl"):
    svn_client_get_ssl_client_cert_file_provider = _libs["svn_client-1"].get("svn_client_get_ssl_client_cert_file_provider", "cdecl")
    svn_client_get_ssl_client_cert_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_ssl_client_cert_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 248
if _libs["svn_client-1"].has("svn_client_get_ssl_client_cert_pw_file_provider", "cdecl"):
    svn_client_get_ssl_client_cert_pw_file_provider = _libs["svn_client-1"].get("svn_client_get_ssl_client_cert_pw_file_provider", "cdecl")
    svn_client_get_ssl_client_cert_pw_file_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), POINTER(apr_pool_t)]
    svn_client_get_ssl_client_cert_pw_file_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 265
if _libs["svn_client-1"].has("svn_client_get_ssl_server_trust_prompt_provider", "cdecl"):
    svn_client_get_ssl_server_trust_prompt_provider = _libs["svn_client-1"].get("svn_client_get_ssl_server_trust_prompt_provider", "cdecl")
    svn_client_get_ssl_server_trust_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_server_trust_prompt_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_client_get_ssl_server_trust_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 286
if _libs["svn_client-1"].has("svn_client_get_ssl_client_cert_prompt_provider", "cdecl"):
    svn_client_get_ssl_client_cert_prompt_provider = _libs["svn_client-1"].get("svn_client_get_ssl_client_cert_prompt_provider", "cdecl")
    svn_client_get_ssl_client_cert_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_client_cert_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_client_get_ssl_client_cert_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 308
if _libs["svn_client-1"].has("svn_client_get_ssl_client_cert_pw_prompt_provider", "cdecl"):
    svn_client_get_ssl_client_cert_pw_prompt_provider = _libs["svn_client-1"].get("svn_client_get_ssl_client_cert_pw_prompt_provider", "cdecl")
    svn_client_get_ssl_client_cert_pw_prompt_provider.argtypes = [POINTER(POINTER(svn_auth_provider_object_t)), svn_auth_ssl_client_cert_pw_prompt_func_t, POINTER(None), c_int, POINTER(apr_pool_t)]
    svn_client_get_ssl_client_cert_pw_prompt_provider.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 355
class struct_svn_client_proplist_item_t(Structure):
    pass

struct_svn_client_proplist_item_t.__slots__ = [
    'node_name',
    'prop_hash',
]
struct_svn_client_proplist_item_t._fields_ = [
    ('node_name', POINTER(svn_stringbuf_t)),
    ('prop_hash', POINTER(apr_hash_t)),
]

svn_client_proplist_item_t = struct_svn_client_proplist_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 355

svn_proplist_receiver2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_hash_t), POINTER(apr_array_header_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 378

svn_proplist_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(apr_hash_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 393

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 408
if _libs["svn_client-1"].has("svn_client_proplist_item_dup", "cdecl"):
    svn_client_proplist_item_dup = _libs["svn_client-1"].get("svn_client_proplist_item_dup", "cdecl")
    svn_client_proplist_item_dup.argtypes = [POINTER(svn_client_proplist_item_t), POINTER(apr_pool_t)]
    svn_client_proplist_item_dup.restype = POINTER(svn_client_proplist_item_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 427
class struct_svn_client_commit_info_t(Structure):
    pass

struct_svn_client_commit_info_t.__slots__ = [
    'revision',
    'date',
    'author',
]
struct_svn_client_commit_info_t._fields_ = [
    ('revision', svn_revnum_t),
    ('date', String),
    ('author', String),
]

svn_client_commit_info_t = struct_svn_client_commit_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 427

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 537
class struct_svn_client_commit_item3_t(Structure):
    pass

struct_svn_client_commit_item3_t.__slots__ = [
    'path',
    'kind',
    'url',
    'revision',
    'copyfrom_url',
    'copyfrom_rev',
    'state_flags',
    'incoming_prop_changes',
    'outgoing_prop_changes',
    'session_relpath',
    'moved_from_abspath',
]
struct_svn_client_commit_item3_t._fields_ = [
    ('path', String),
    ('kind', svn_node_kind_t),
    ('url', String),
    ('revision', svn_revnum_t),
    ('copyfrom_url', String),
    ('copyfrom_rev', svn_revnum_t),
    ('state_flags', apr_byte_t),
    ('incoming_prop_changes', POINTER(apr_array_header_t)),
    ('outgoing_prop_changes', POINTER(apr_array_header_t)),
    ('session_relpath', String),
    ('moved_from_abspath', String),
]

svn_client_commit_item3_t = struct_svn_client_commit_item3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 537

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 570
class struct_svn_client_commit_item2_t(Structure):
    pass

struct_svn_client_commit_item2_t.__slots__ = [
    'path',
    'kind',
    'url',
    'revision',
    'copyfrom_url',
    'copyfrom_rev',
    'state_flags',
    'wcprop_changes',
]
struct_svn_client_commit_item2_t._fields_ = [
    ('path', String),
    ('kind', svn_node_kind_t),
    ('url', String),
    ('revision', svn_revnum_t),
    ('copyfrom_url', String),
    ('copyfrom_rev', svn_revnum_t),
    ('state_flags', apr_byte_t),
    ('wcprop_changes', POINTER(apr_array_header_t)),
]

svn_client_commit_item2_t = struct_svn_client_commit_item2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 570

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 601
class struct_svn_client_commit_item_t(Structure):
    pass

struct_svn_client_commit_item_t.__slots__ = [
    'path',
    'kind',
    'url',
    'revision',
    'copyfrom_url',
    'state_flags',
    'wcprop_changes',
]
struct_svn_client_commit_item_t._fields_ = [
    ('path', String),
    ('kind', svn_node_kind_t),
    ('url', String),
    ('revision', svn_revnum_t),
    ('copyfrom_url', String),
    ('state_flags', apr_byte_t),
    ('wcprop_changes', POINTER(apr_array_header_t)),
]

svn_client_commit_item_t = struct_svn_client_commit_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 601

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 612
if _libs["svn_client-1"].has("svn_client_commit_item3_create", "cdecl"):
    svn_client_commit_item3_create = _libs["svn_client-1"].get("svn_client_commit_item3_create", "cdecl")
    svn_client_commit_item3_create.argtypes = [POINTER(apr_pool_t)]
    svn_client_commit_item3_create.restype = POINTER(svn_client_commit_item3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 622
if _libs["svn_client-1"].has("svn_client_commit_item_create", "cdecl"):
    svn_client_commit_item_create = _libs["svn_client-1"].get("svn_client_commit_item_create", "cdecl")
    svn_client_commit_item_create.argtypes = [POINTER(POINTER(svn_client_commit_item3_t)), POINTER(apr_pool_t)]
    svn_client_commit_item_create.restype = POINTER(svn_error_t)
    svn_client_commit_item_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 633
if _libs["svn_client-1"].has("svn_client_commit_item3_dup", "cdecl"):
    svn_client_commit_item3_dup = _libs["svn_client-1"].get("svn_client_commit_item3_dup", "cdecl")
    svn_client_commit_item3_dup.argtypes = [POINTER(svn_client_commit_item3_t), POINTER(apr_pool_t)]
    svn_client_commit_item3_dup.restype = POINTER(svn_client_commit_item3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 644
if _libs["svn_client-1"].has("svn_client_commit_item2_dup", "cdecl"):
    svn_client_commit_item2_dup = _libs["svn_client-1"].get("svn_client_commit_item2_dup", "cdecl")
    svn_client_commit_item2_dup.argtypes = [POINTER(svn_client_commit_item2_t), POINTER(apr_pool_t)]
    svn_client_commit_item2_dup.restype = POINTER(svn_client_commit_item2_t)

svn_client_get_commit_log3_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_array_header_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 668

svn_client_get_commit_log2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_array_header_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 695

svn_client_get_commit_log_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_array_header_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 722

svn_client_blame_receiver4_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), c_int64, svn_revnum_t, POINTER(apr_hash_t), svn_revnum_t, POINTER(apr_hash_t), String, POINTER(svn_string_t), svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 776

svn_client_blame_receiver3_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, svn_revnum_t, c_int64, svn_revnum_t, POINTER(apr_hash_t), svn_revnum_t, POINTER(apr_hash_t), String, String, svn_boolean_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 801

svn_client_blame_receiver2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), c_int64, svn_revnum_t, String, String, svn_revnum_t, String, String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 824

svn_client_blame_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), c_int64, svn_revnum_t, String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 848

enum_svn_client_diff_summarize_kind_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

svn_client_diff_summarize_kind_normal = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

svn_client_diff_summarize_kind_added = (svn_client_diff_summarize_kind_normal + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

svn_client_diff_summarize_kind_modified = (svn_client_diff_summarize_kind_added + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

svn_client_diff_summarize_kind_deleted = (svn_client_diff_summarize_kind_modified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

svn_client_diff_summarize_kind_t = enum_svn_client_diff_summarize_kind_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 884

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 911
class struct_svn_client_diff_summarize_t(Structure):
    pass

struct_svn_client_diff_summarize_t.__slots__ = [
    'path',
    'summarize_kind',
    'prop_changed',
    'node_kind',
]
struct_svn_client_diff_summarize_t._fields_ = [
    ('path', String),
    ('summarize_kind', svn_client_diff_summarize_kind_t),
    ('prop_changed', svn_boolean_t),
    ('node_kind', svn_node_kind_t),
]

svn_client_diff_summarize_t = struct_svn_client_diff_summarize_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 911

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 919
if _libs["svn_client-1"].has("svn_client_diff_summarize_dup", "cdecl"):
    svn_client_diff_summarize_dup = _libs["svn_client-1"].get("svn_client_diff_summarize_dup", "cdecl")
    svn_client_diff_summarize_dup.argtypes = [POINTER(svn_client_diff_summarize_t), POINTER(apr_pool_t)]
    svn_client_diff_summarize_dup.restype = POINTER(svn_client_diff_summarize_t)

svn_client_diff_summarize_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_client_diff_summarize_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 934

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1086
class struct_svn_client_ctx_t(Structure):
    pass

struct_svn_client_ctx_t.__slots__ = [
    'auth_baton',
    'notify_func',
    'notify_baton',
    'log_msg_func',
    'log_msg_baton',
    'config',
    'cancel_func',
    'cancel_baton',
    'notify_func2',
    'notify_baton2',
    'log_msg_func2',
    'log_msg_baton2',
    'progress_func',
    'progress_baton',
    'log_msg_func3',
    'log_msg_baton3',
    'mimetypes_map',
    'conflict_func',
    'conflict_baton',
    'client_name',
    'conflict_func2',
    'conflict_baton2',
    'wc_ctx',
    'check_tunnel_func',
    'open_tunnel_func',
    'tunnel_baton',
]
struct_svn_client_ctx_t._fields_ = [
    ('auth_baton', POINTER(svn_auth_baton_t)),
    ('notify_func', svn_wc_notify_func_t),
    ('notify_baton', POINTER(None)),
    ('log_msg_func', svn_client_get_commit_log_t),
    ('log_msg_baton', POINTER(None)),
    ('config', POINTER(apr_hash_t)),
    ('cancel_func', svn_cancel_func_t),
    ('cancel_baton', POINTER(None)),
    ('notify_func2', svn_wc_notify_func2_t),
    ('notify_baton2', POINTER(None)),
    ('log_msg_func2', svn_client_get_commit_log2_t),
    ('log_msg_baton2', POINTER(None)),
    ('progress_func', svn_ra_progress_notify_func_t),
    ('progress_baton', POINTER(None)),
    ('log_msg_func3', svn_client_get_commit_log3_t),
    ('log_msg_baton3', POINTER(None)),
    ('mimetypes_map', POINTER(apr_hash_t)),
    ('conflict_func', svn_wc_conflict_resolver_func_t),
    ('conflict_baton', POINTER(None)),
    ('client_name', String),
    ('conflict_func2', svn_wc_conflict_resolver_func2_t),
    ('conflict_baton2', POINTER(None)),
    ('wc_ctx', POINTER(svn_wc_context_t)),
    ('check_tunnel_func', svn_ra_check_tunnel_func_t),
    ('open_tunnel_func', svn_ra_open_tunnel_func_t),
    ('tunnel_baton', POINTER(None)),
]

svn_client_ctx_t = struct_svn_client_ctx_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1086

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1105
if _libs["svn_client-1"].has("svn_client_create_context2", "cdecl"):
    svn_client_create_context2 = _libs["svn_client-1"].get("svn_client_create_context2", "cdecl")
    svn_client_create_context2.argtypes = [POINTER(POINTER(svn_client_ctx_t)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_client_create_context2.restype = POINTER(svn_error_t)
    svn_client_create_context2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1116
if _libs["svn_client-1"].has("svn_client_create_context", "cdecl"):
    svn_client_create_context = _libs["svn_client-1"].get("svn_client_create_context", "cdecl")
    svn_client_create_context.argtypes = [POINTER(POINTER(svn_client_ctx_t)), POINTER(apr_pool_t)]
    svn_client_create_context.restype = POINTER(svn_error_t)
    svn_client_create_context.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1175
if _libs["svn_client-1"].has("svn_client_args_to_target_array2", "cdecl"):
    svn_client_args_to_target_array2 = _libs["svn_client-1"].get("svn_client_args_to_target_array2", "cdecl")
    svn_client_args_to_target_array2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_client_args_to_target_array2.restype = POINTER(svn_error_t)
    svn_client_args_to_target_array2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1193
if _libs["svn_client-1"].has("svn_client_args_to_target_array", "cdecl"):
    svn_client_args_to_target_array = _libs["svn_client-1"].get("svn_client_args_to_target_array", "cdecl")
    svn_client_args_to_target_array.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_getopt_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_args_to_target_array.restype = POINTER(svn_error_t)
    svn_client_args_to_target_array.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1262
if _libs["svn_client-1"].has("svn_client_checkout3", "cdecl"):
    svn_client_checkout3 = _libs["svn_client-1"].get("svn_client_checkout3", "cdecl")
    svn_client_checkout3.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_checkout3.restype = POINTER(svn_error_t)
    svn_client_checkout3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1284
if _libs["svn_client-1"].has("svn_client_checkout2", "cdecl"):
    svn_client_checkout2 = _libs["svn_client-1"].get("svn_client_checkout2", "cdecl")
    svn_client_checkout2.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_checkout2.restype = POINTER(svn_error_t)
    svn_client_checkout2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1304
if _libs["svn_client-1"].has("svn_client_checkout", "cdecl"):
    svn_client_checkout = _libs["svn_client-1"].get("svn_client_checkout", "cdecl")
    svn_client_checkout.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_checkout.restype = POINTER(svn_error_t)
    svn_client_checkout.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1393
if _libs["svn_client-1"].has("svn_client_update4", "cdecl"):
    svn_client_update4 = _libs["svn_client-1"].get("svn_client_update4", "cdecl")
    svn_client_update4.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_update4.restype = POINTER(svn_error_t)
    svn_client_update4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1414
if _libs["svn_client-1"].has("svn_client_update3", "cdecl"):
    svn_client_update3 = _libs["svn_client-1"].get("svn_client_update3", "cdecl")
    svn_client_update3.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_update3.restype = POINTER(svn_error_t)
    svn_client_update3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1435
if _libs["svn_client-1"].has("svn_client_update2", "cdecl"):
    svn_client_update2 = _libs["svn_client-1"].get("svn_client_update2", "cdecl")
    svn_client_update2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_update2.restype = POINTER(svn_error_t)
    svn_client_update2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1452
if _libs["svn_client-1"].has("svn_client_update", "cdecl"):
    svn_client_update = _libs["svn_client-1"].get("svn_client_update", "cdecl")
    svn_client_update.argtypes = [POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_update.restype = POINTER(svn_error_t)
    svn_client_update.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1530
if _libs["svn_client-1"].has("svn_client_switch3", "cdecl"):
    svn_client_switch3 = _libs["svn_client-1"].get("svn_client_switch3", "cdecl")
    svn_client_switch3.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_switch3.restype = POINTER(svn_error_t)
    svn_client_switch3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1553
if _libs["svn_client-1"].has("svn_client_switch2", "cdecl"):
    svn_client_switch2 = _libs["svn_client-1"].get("svn_client_switch2", "cdecl")
    svn_client_switch2.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_switch2.restype = POINTER(svn_error_t)
    svn_client_switch2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1577
if _libs["svn_client-1"].has("svn_client_switch", "cdecl"):
    svn_client_switch = _libs["svn_client-1"].get("svn_client_switch", "cdecl")
    svn_client_switch.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_switch.restype = POINTER(svn_error_t)
    svn_client_switch.errcheck = _svn_errcheck

svn_client__layout_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, String, svn_boolean_t, svn_boolean_t, String, svn_boolean_t, svn_revnum_t, svn_boolean_t, svn_depth_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1592

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1612
if _libs["svn_client-1"].has("svn_client__layout_list", "cdecl"):
    svn_client__layout_list = _libs["svn_client-1"].get("svn_client__layout_list", "cdecl")
    svn_client__layout_list.argtypes = [String, svn_client__layout_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client__layout_list.restype = POINTER(svn_error_t)
    svn_client__layout_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1679
if _libs["svn_client-1"].has("svn_client_add5", "cdecl"):
    svn_client_add5 = _libs["svn_client-1"].get("svn_client_add5", "cdecl")
    svn_client_add5.argtypes = [String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add5.restype = POINTER(svn_error_t)
    svn_client_add5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1696
if _libs["svn_client-1"].has("svn_client_add4", "cdecl"):
    svn_client_add4 = _libs["svn_client-1"].get("svn_client_add4", "cdecl")
    svn_client_add4.argtypes = [String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add4.restype = POINTER(svn_error_t)
    svn_client_add4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1713
if _libs["svn_client-1"].has("svn_client_add3", "cdecl"):
    svn_client_add3 = _libs["svn_client-1"].get("svn_client_add3", "cdecl")
    svn_client_add3.argtypes = [String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add3.restype = POINTER(svn_error_t)
    svn_client_add3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1728
if _libs["svn_client-1"].has("svn_client_add2", "cdecl"):
    svn_client_add2 = _libs["svn_client-1"].get("svn_client_add2", "cdecl")
    svn_client_add2.argtypes = [String, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add2.restype = POINTER(svn_error_t)
    svn_client_add2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1741
if _libs["svn_client-1"].has("svn_client_add", "cdecl"):
    svn_client_add = _libs["svn_client-1"].get("svn_client_add", "cdecl")
    svn_client_add.argtypes = [String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add.restype = POINTER(svn_error_t)
    svn_client_add.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1792
if _libs["svn_client-1"].has("svn_client_mkdir4", "cdecl"):
    svn_client_mkdir4 = _libs["svn_client-1"].get("svn_client_mkdir4", "cdecl")
    svn_client_mkdir4.argtypes = [POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mkdir4.restype = POINTER(svn_error_t)
    svn_client_mkdir4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1809
if _libs["svn_client-1"].has("svn_client_mkdir3", "cdecl"):
    svn_client_mkdir3 = _libs["svn_client-1"].get("svn_client_mkdir3", "cdecl")
    svn_client_mkdir3.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mkdir3.restype = POINTER(svn_error_t)
    svn_client_mkdir3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1826
if _libs["svn_client-1"].has("svn_client_mkdir2", "cdecl"):
    svn_client_mkdir2 = _libs["svn_client-1"].get("svn_client_mkdir2", "cdecl")
    svn_client_mkdir2.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mkdir2.restype = POINTER(svn_error_t)
    svn_client_mkdir2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1839
if _libs["svn_client-1"].has("svn_client_mkdir", "cdecl"):
    svn_client_mkdir = _libs["svn_client-1"].get("svn_client_mkdir", "cdecl")
    svn_client_mkdir.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mkdir.restype = POINTER(svn_error_t)
    svn_client_mkdir.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1900
if _libs["svn_client-1"].has("svn_client_delete4", "cdecl"):
    svn_client_delete4 = _libs["svn_client-1"].get("svn_client_delete4", "cdecl")
    svn_client_delete4.argtypes = [POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_delete4.restype = POINTER(svn_error_t)
    svn_client_delete4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1918
if _libs["svn_client-1"].has("svn_client_delete3", "cdecl"):
    svn_client_delete3 = _libs["svn_client-1"].get("svn_client_delete3", "cdecl")
    svn_client_delete3.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_delete3.restype = POINTER(svn_error_t)
    svn_client_delete3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1934
if _libs["svn_client-1"].has("svn_client_delete2", "cdecl"):
    svn_client_delete2 = _libs["svn_client-1"].get("svn_client_delete2", "cdecl")
    svn_client_delete2.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_delete2.restype = POINTER(svn_error_t)
    svn_client_delete2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1948
if _libs["svn_client-1"].has("svn_client_delete", "cdecl"):
    svn_client_delete = _libs["svn_client-1"].get("svn_client_delete", "cdecl")
    svn_client_delete.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_delete.restype = POINTER(svn_error_t)
    svn_client_delete.errcheck = _svn_errcheck

svn_client_import_filter_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_boolean_t), String, POINTER(svn_io_dirent2_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1982

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2061
if _libs["svn_client-1"].has("svn_client_import5", "cdecl"):
    svn_client_import5 = _libs["svn_client-1"].get("svn_client_import5", "cdecl")
    svn_client_import5.argtypes = [String, String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_client_import_filter_func_t, POINTER(None), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_import5.restype = POINTER(svn_error_t)
    svn_client_import5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2084
if _libs["svn_client-1"].has("svn_client_import4", "cdecl"):
    svn_client_import4 = _libs["svn_client-1"].get("svn_client_import4", "cdecl")
    svn_client_import4.argtypes = [String, String, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_import4.restype = POINTER(svn_error_t)
    svn_client_import4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2104
if _libs["svn_client-1"].has("svn_client_import3", "cdecl"):
    svn_client_import3 = _libs["svn_client-1"].get("svn_client_import3", "cdecl")
    svn_client_import3.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, String, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_import3.restype = POINTER(svn_error_t)
    svn_client_import3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2126
if _libs["svn_client-1"].has("svn_client_import2", "cdecl"):
    svn_client_import2 = _libs["svn_client-1"].get("svn_client_import2", "cdecl")
    svn_client_import2.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, String, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_import2.restype = POINTER(svn_error_t)
    svn_client_import2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2143
if _libs["svn_client-1"].has("svn_client_import", "cdecl"):
    svn_client_import = _libs["svn_client-1"].get("svn_client_import", "cdecl")
    svn_client_import.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_import.restype = POINTER(svn_error_t)
    svn_client_import.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2240
if _libs["svn_client-1"].has("svn_client_commit6", "cdecl"):
    svn_client_commit6 = _libs["svn_client-1"].get("svn_client_commit6", "cdecl")
    svn_client_commit6.argtypes = [POINTER(apr_array_header_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit6.restype = POINTER(svn_error_t)
    svn_client_commit6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2263
if _libs["svn_client-1"].has("svn_client_commit5", "cdecl"):
    svn_client_commit5 = _libs["svn_client-1"].get("svn_client_commit5", "cdecl")
    svn_client_commit5.argtypes = [POINTER(apr_array_header_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit5.restype = POINTER(svn_error_t)
    svn_client_commit5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2293
if _libs["svn_client-1"].has("svn_client_commit4", "cdecl"):
    svn_client_commit4 = _libs["svn_client-1"].get("svn_client_commit4", "cdecl")
    svn_client_commit4.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit4.restype = POINTER(svn_error_t)
    svn_client_commit4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2315
if _libs["svn_client-1"].has("svn_client_commit3", "cdecl"):
    svn_client_commit3 = _libs["svn_client-1"].get("svn_client_commit3", "cdecl")
    svn_client_commit3.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit3.restype = POINTER(svn_error_t)
    svn_client_commit3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2332
if _libs["svn_client-1"].has("svn_client_commit2", "cdecl"):
    svn_client_commit2 = _libs["svn_client-1"].get("svn_client_commit2", "cdecl")
    svn_client_commit2.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit2.restype = POINTER(svn_error_t)
    svn_client_commit2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2347
if _libs["svn_client-1"].has("svn_client_commit", "cdecl"):
    svn_client_commit = _libs["svn_client-1"].get("svn_client_commit", "cdecl")
    svn_client_commit.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_commit.restype = POINTER(svn_error_t)
    svn_client_commit.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2540
class struct_svn_client_status_t(Structure):
    pass

struct_svn_client_status_t.__slots__ = [
    'kind',
    'local_abspath',
    'filesize',
    'versioned',
    'conflicted',
    'node_status',
    'text_status',
    'prop_status',
    'wc_is_locked',
    'copied',
    'repos_root_url',
    'repos_uuid',
    'repos_relpath',
    'revision',
    'changed_rev',
    'changed_date',
    'changed_author',
    'switched',
    'file_external',
    'lock',
    'changelist',
    'depth',
    'ood_kind',
    'repos_node_status',
    'repos_text_status',
    'repos_prop_status',
    'repos_lock',
    'ood_changed_rev',
    'ood_changed_date',
    'ood_changed_author',
    'backwards_compatibility_baton',
    'moved_from_abspath',
    'moved_to_abspath',
]
struct_svn_client_status_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('local_abspath', String),
    ('filesize', svn_filesize_t),
    ('versioned', svn_boolean_t),
    ('conflicted', svn_boolean_t),
    ('node_status', enum_svn_wc_status_kind),
    ('text_status', enum_svn_wc_status_kind),
    ('prop_status', enum_svn_wc_status_kind),
    ('wc_is_locked', svn_boolean_t),
    ('copied', svn_boolean_t),
    ('repos_root_url', String),
    ('repos_uuid', String),
    ('repos_relpath', String),
    ('revision', svn_revnum_t),
    ('changed_rev', svn_revnum_t),
    ('changed_date', apr_time_t),
    ('changed_author', String),
    ('switched', svn_boolean_t),
    ('file_external', svn_boolean_t),
    ('lock', POINTER(svn_lock_t)),
    ('changelist', String),
    ('depth', svn_depth_t),
    ('ood_kind', svn_node_kind_t),
    ('repos_node_status', enum_svn_wc_status_kind),
    ('repos_text_status', enum_svn_wc_status_kind),
    ('repos_prop_status', enum_svn_wc_status_kind),
    ('repos_lock', POINTER(svn_lock_t)),
    ('ood_changed_rev', svn_revnum_t),
    ('ood_changed_date', apr_time_t),
    ('ood_changed_author', String),
    ('backwards_compatibility_baton', POINTER(None)),
    ('moved_from_abspath', String),
    ('moved_to_abspath', String),
]

svn_client_status_t = struct_svn_client_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2540

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2548
if _libs["svn_client-1"].has("svn_client_status_dup", "cdecl"):
    svn_client_status_dup = _libs["svn_client-1"].get("svn_client_status_dup", "cdecl")
    svn_client_status_dup.argtypes = [POINTER(svn_client_status_t), POINTER(apr_pool_t)]
    svn_client_status_dup.restype = POINTER(svn_client_status_t)

svn_client_status_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_client_status_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2563

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2625
if _libs["svn_client-1"].has("svn_client_status6", "cdecl"):
    svn_client_status6 = _libs["svn_client-1"].get("svn_client_status6", "cdecl")
    svn_client_status6.argtypes = [POINTER(svn_revnum_t), POINTER(svn_client_ctx_t), String, POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_status_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_client_status6.restype = POINTER(svn_error_t)
    svn_client_status6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2651
if _libs["svn_client-1"].has("svn_client_status5", "cdecl"):
    svn_client_status5 = _libs["svn_client-1"].get("svn_client_status5", "cdecl")
    svn_client_status5.argtypes = [POINTER(svn_revnum_t), POINTER(svn_client_ctx_t), String, POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_status_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_client_status5.restype = POINTER(svn_error_t)
    svn_client_status5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2675
if _libs["svn_client-1"].has("svn_client_status4", "cdecl"):
    svn_client_status4 = _libs["svn_client-1"].get("svn_client_status4", "cdecl")
    svn_client_status4.argtypes = [POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), svn_wc_status_func3_t, POINTER(None), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_status4.restype = POINTER(svn_error_t)
    svn_client_status4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2698
if _libs["svn_client-1"].has("svn_client_status3", "cdecl"):
    svn_client_status3 = _libs["svn_client-1"].get("svn_client_status3", "cdecl")
    svn_client_status3.argtypes = [POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), svn_wc_status_func2_t, POINTER(None), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_status3.restype = POINTER(svn_error_t)
    svn_client_status3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2723
if _libs["svn_client-1"].has("svn_client_status2", "cdecl"):
    svn_client_status2 = _libs["svn_client-1"].get("svn_client_status2", "cdecl")
    svn_client_status2.argtypes = [POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), svn_wc_status_func2_t, POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_status2.restype = POINTER(svn_error_t)
    svn_client_status2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2748
if _libs["svn_client-1"].has("svn_client_status", "cdecl"):
    svn_client_status = _libs["svn_client-1"].get("svn_client_status", "cdecl")
    svn_client_status.argtypes = [POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), svn_wc_status_func_t, POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_status.restype = POINTER(svn_error_t)
    svn_client_status.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2809
if _libs["svn_client-1"].has("svn_client_log5", "cdecl"):
    svn_client_log5 = _libs["svn_client-1"].get("svn_client_log5", "cdecl")
    svn_client_log5.argtypes = [POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(apr_array_header_t), c_int, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_log_entry_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_log5.restype = POINTER(svn_error_t)
    svn_client_log5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2831
if _libs["svn_client-1"].has("svn_client_log4", "cdecl"):
    svn_client_log4 = _libs["svn_client-1"].get("svn_client_log4", "cdecl")
    svn_client_log4.argtypes = [POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), c_int, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_log_entry_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_log4.restype = POINTER(svn_error_t)
    svn_client_log4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2856
if _libs["svn_client-1"].has("svn_client_log3", "cdecl"):
    svn_client_log3 = _libs["svn_client-1"].get("svn_client_log3", "cdecl")
    svn_client_log3.argtypes = [POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), c_int, svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_log3.restype = POINTER(svn_error_t)
    svn_client_log3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2885
if _libs["svn_client-1"].has("svn_client_log2", "cdecl"):
    svn_client_log2 = _libs["svn_client-1"].get("svn_client_log2", "cdecl")
    svn_client_log2.argtypes = [POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), c_int, svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_log2.restype = POINTER(svn_error_t)
    svn_client_log2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2919
if _libs["svn_client-1"].has("svn_client_log", "cdecl"):
    svn_client_log = _libs["svn_client-1"].get("svn_client_log", "cdecl")
    svn_client_log.argtypes = [POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_log.restype = POINTER(svn_error_t)
    svn_client_log.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2977
if _libs["svn_client-1"].has("svn_client_blame6", "cdecl"):
    svn_client_blame6 = _libs["svn_client-1"].get("svn_client_blame6", "cdecl")
    svn_client_blame6.argtypes = [POINTER(svn_revnum_t), POINTER(svn_revnum_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_diff_file_options_t), svn_boolean_t, svn_boolean_t, svn_client_blame_receiver4_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame6.restype = POINTER(svn_error_t)
    svn_client_blame6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3002
if _libs["svn_client-1"].has("svn_client_blame5", "cdecl"):
    svn_client_blame5 = _libs["svn_client-1"].get("svn_client_blame5", "cdecl")
    svn_client_blame5.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_diff_file_options_t), svn_boolean_t, svn_boolean_t, svn_client_blame_receiver3_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame5.restype = POINTER(svn_error_t)
    svn_client_blame5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3024
if _libs["svn_client-1"].has("svn_client_blame4", "cdecl"):
    svn_client_blame4 = _libs["svn_client-1"].get("svn_client_blame4", "cdecl")
    svn_client_blame4.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_diff_file_options_t), svn_boolean_t, svn_boolean_t, svn_client_blame_receiver2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame4.restype = POINTER(svn_error_t)
    svn_client_blame4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3046
if _libs["svn_client-1"].has("svn_client_blame3", "cdecl"):
    svn_client_blame3 = _libs["svn_client-1"].get("svn_client_blame3", "cdecl")
    svn_client_blame3.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_diff_file_options_t), svn_boolean_t, svn_client_blame_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame3.restype = POINTER(svn_error_t)
    svn_client_blame3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3068
if _libs["svn_client-1"].has("svn_client_blame2", "cdecl"):
    svn_client_blame2 = _libs["svn_client-1"].get("svn_client_blame2", "cdecl")
    svn_client_blame2.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_client_blame_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame2.restype = POINTER(svn_error_t)
    svn_client_blame2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3085
if _libs["svn_client-1"].has("svn_client_blame", "cdecl"):
    svn_client_blame = _libs["svn_client-1"].get("svn_client_blame", "cdecl")
    svn_client_blame.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_client_blame_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_blame.restype = POINTER(svn_error_t)
    svn_client_blame.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3201
if _libs["svn_client-1"].has("svn_client_diff7", "cdecl"):
    svn_client_diff7 = _libs["svn_client-1"].get("svn_client_diff7", "cdecl")
    svn_client_diff7.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff7.restype = POINTER(svn_error_t)
    svn_client_diff7.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3232
if _libs["svn_client-1"].has("svn_client_diff6", "cdecl"):
    svn_client_diff6 = _libs["svn_client-1"].get("svn_client_diff6", "cdecl")
    svn_client_diff6.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff6.restype = POINTER(svn_error_t)
    svn_client_diff6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3265
if _libs["svn_client-1"].has("svn_client_diff5", "cdecl"):
    svn_client_diff5 = _libs["svn_client-1"].get("svn_client_diff5", "cdecl")
    svn_client_diff5.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff5.restype = POINTER(svn_error_t)
    svn_client_diff5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3293
if _libs["svn_client-1"].has("svn_client_diff4", "cdecl"):
    svn_client_diff4 = _libs["svn_client-1"].get("svn_client_diff4", "cdecl")
    svn_client_diff4.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff4.restype = POINTER(svn_error_t)
    svn_client_diff4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3321
if _libs["svn_client-1"].has("svn_client_diff3", "cdecl"):
    svn_client_diff3 = _libs["svn_client-1"].get("svn_client_diff3", "cdecl")
    svn_client_diff3.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff3.restype = POINTER(svn_error_t)
    svn_client_diff3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3346
if _libs["svn_client-1"].has("svn_client_diff2", "cdecl"):
    svn_client_diff2 = _libs["svn_client-1"].get("svn_client_diff2", "cdecl")
    svn_client_diff2.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff2.restype = POINTER(svn_error_t)
    svn_client_diff2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3368
if _libs["svn_client-1"].has("svn_client_diff", "cdecl"):
    svn_client_diff = _libs["svn_client-1"].get("svn_client_diff", "cdecl")
    svn_client_diff.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff.restype = POINTER(svn_error_t)
    svn_client_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3396
if _libs["svn_client-1"].has("svn_client_diff_peg7", "cdecl"):
    svn_client_diff_peg7 = _libs["svn_client-1"].get("svn_client_diff_peg7", "cdecl")
    svn_client_diff_peg7.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg7.restype = POINTER(svn_error_t)
    svn_client_diff_peg7.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3427
if _libs["svn_client-1"].has("svn_client_diff_peg6", "cdecl"):
    svn_client_diff_peg6 = _libs["svn_client-1"].get("svn_client_diff_peg6", "cdecl")
    svn_client_diff_peg6.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg6.restype = POINTER(svn_error_t)
    svn_client_diff_peg6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3460
if _libs["svn_client-1"].has("svn_client_diff_peg5", "cdecl"):
    svn_client_diff_peg5 = _libs["svn_client-1"].get("svn_client_diff_peg5", "cdecl")
    svn_client_diff_peg5.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg5.restype = POINTER(svn_error_t)
    svn_client_diff_peg5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3488
if _libs["svn_client-1"].has("svn_client_diff_peg4", "cdecl"):
    svn_client_diff_peg4 = _libs["svn_client-1"].get("svn_client_diff_peg4", "cdecl")
    svn_client_diff_peg4.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg4.restype = POINTER(svn_error_t)
    svn_client_diff_peg4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3516
if _libs["svn_client-1"].has("svn_client_diff_peg3", "cdecl"):
    svn_client_diff_peg3 = _libs["svn_client-1"].get("svn_client_diff_peg3", "cdecl")
    svn_client_diff_peg3.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg3.restype = POINTER(svn_error_t)
    svn_client_diff_peg3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3540
if _libs["svn_client-1"].has("svn_client_diff_peg2", "cdecl"):
    svn_client_diff_peg2 = _libs["svn_client-1"].get("svn_client_diff_peg2", "cdecl")
    svn_client_diff_peg2.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg2.restype = POINTER(svn_error_t)
    svn_client_diff_peg2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3563
if _libs["svn_client-1"].has("svn_client_diff_peg", "cdecl"):
    svn_client_diff_peg = _libs["svn_client-1"].get("svn_client_diff_peg", "cdecl")
    svn_client_diff_peg.argtypes = [POINTER(apr_array_header_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_file_t), POINTER(apr_file_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_peg.restype = POINTER(svn_error_t)
    svn_client_diff_peg.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3594
if _libs["svn_client-1"].has("svn_client_diff_summarize2", "cdecl"):
    svn_client_diff_summarize2 = _libs["svn_client-1"].get("svn_client_diff_summarize2", "cdecl")
    svn_client_diff_summarize2.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_diff_summarize_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_summarize2.restype = POINTER(svn_error_t)
    svn_client_diff_summarize2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3618
if _libs["svn_client-1"].has("svn_client_diff_summarize", "cdecl"):
    svn_client_diff_summarize = _libs["svn_client-1"].get("svn_client_diff_summarize", "cdecl")
    svn_client_diff_summarize.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_client_diff_summarize_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_summarize.restype = POINTER(svn_error_t)
    svn_client_diff_summarize.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3650
if _libs["svn_client-1"].has("svn_client_diff_summarize_peg2", "cdecl"):
    svn_client_diff_summarize_peg2 = _libs["svn_client-1"].get("svn_client_diff_summarize_peg2", "cdecl")
    svn_client_diff_summarize_peg2.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_diff_summarize_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_summarize_peg2.restype = POINTER(svn_error_t)
    svn_client_diff_summarize_peg2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3675
if _libs["svn_client-1"].has("svn_client_diff_summarize_peg", "cdecl"):
    svn_client_diff_summarize_peg = _libs["svn_client-1"].get("svn_client_diff_summarize_peg", "cdecl")
    svn_client_diff_summarize_peg.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_client_diff_summarize_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_diff_summarize_peg.restype = POINTER(svn_error_t)
    svn_client_diff_summarize_peg.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3719
if _libs["svn_client-1"].has("svn_client_get_merging_summary", "cdecl"):
    svn_client_get_merging_summary = _libs["svn_client-1"].get("svn_client_get_merging_summary", "cdecl")
    svn_client_get_merging_summary.argtypes = [POINTER(svn_boolean_t), POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(POINTER(c_char)), String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_get_merging_summary.restype = POINTER(svn_error_t)
    svn_client_get_merging_summary.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3802
if _libs["svn_client-1"].has("svn_client_merge5", "cdecl"):
    svn_client_merge5 = _libs["svn_client-1"].get("svn_client_merge5", "cdecl")
    svn_client_merge5.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge5.restype = POINTER(svn_error_t)
    svn_client_merge5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3827
if _libs["svn_client-1"].has("svn_client_merge4", "cdecl"):
    svn_client_merge4 = _libs["svn_client-1"].get("svn_client_merge4", "cdecl")
    svn_client_merge4.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge4.restype = POINTER(svn_error_t)
    svn_client_merge4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3853
if _libs["svn_client-1"].has("svn_client_merge3", "cdecl"):
    svn_client_merge3 = _libs["svn_client-1"].get("svn_client_merge3", "cdecl")
    svn_client_merge3.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge3.restype = POINTER(svn_error_t)
    svn_client_merge3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3879
if _libs["svn_client-1"].has("svn_client_merge2", "cdecl"):
    svn_client_merge2 = _libs["svn_client-1"].get("svn_client_merge2", "cdecl")
    svn_client_merge2.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge2.restype = POINTER(svn_error_t)
    svn_client_merge2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3900
if _libs["svn_client-1"].has("svn_client_merge", "cdecl"):
    svn_client_merge = _libs["svn_client-1"].get("svn_client_merge", "cdecl")
    svn_client_merge.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge.restype = POINTER(svn_error_t)
    svn_client_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3931
if _libs["svn_client-1"].has("svn_client_merge_reintegrate", "cdecl"):
    svn_client_merge_reintegrate = _libs["svn_client-1"].get("svn_client_merge_reintegrate", "cdecl")
    svn_client_merge_reintegrate.argtypes = [String, POINTER(svn_opt_revision_t), String, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_reintegrate.restype = POINTER(svn_error_t)
    svn_client_merge_reintegrate.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3970
if _libs["svn_client-1"].has("svn_client_merge_peg5", "cdecl"):
    svn_client_merge_peg5 = _libs["svn_client-1"].get("svn_client_merge_peg5", "cdecl")
    svn_client_merge_peg5.argtypes = [String, POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_peg5.restype = POINTER(svn_error_t)
    svn_client_merge_peg5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 3995
if _libs["svn_client-1"].has("svn_client_merge_peg4", "cdecl"):
    svn_client_merge_peg4 = _libs["svn_client-1"].get("svn_client_merge_peg4", "cdecl")
    svn_client_merge_peg4.argtypes = [String, POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_peg4.restype = POINTER(svn_error_t)
    svn_client_merge_peg4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4020
if _libs["svn_client-1"].has("svn_client_merge_peg3", "cdecl"):
    svn_client_merge_peg3 = _libs["svn_client-1"].get("svn_client_merge_peg3", "cdecl")
    svn_client_merge_peg3.argtypes = [String, POINTER(apr_array_header_t), POINTER(svn_opt_revision_t), String, svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_peg3.restype = POINTER(svn_error_t)
    svn_client_merge_peg3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4045
if _libs["svn_client-1"].has("svn_client_merge_peg2", "cdecl"):
    svn_client_merge_peg2 = _libs["svn_client-1"].get("svn_client_merge_peg2", "cdecl")
    svn_client_merge_peg2.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_peg2.restype = POINTER(svn_error_t)
    svn_client_merge_peg2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4068
if _libs["svn_client-1"].has("svn_client_merge_peg", "cdecl"):
    svn_client_merge_peg = _libs["svn_client-1"].get("svn_client_merge_peg", "cdecl")
    svn_client_merge_peg.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_merge_peg.restype = POINTER(svn_error_t)
    svn_client_merge_peg.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4091
if _libs["svn_client-1"].has("svn_client_suggest_merge_sources", "cdecl"):
    svn_client_suggest_merge_sources = _libs["svn_client-1"].get("svn_client_suggest_merge_sources", "cdecl")
    svn_client_suggest_merge_sources.argtypes = [POINTER(POINTER(apr_array_header_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_suggest_merge_sources.restype = POINTER(svn_error_t)
    svn_client_suggest_merge_sources.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4121
if _libs["svn_client-1"].has("svn_client_mergeinfo_get_merged", "cdecl"):
    svn_client_mergeinfo_get_merged = _libs["svn_client-1"].get("svn_client_mergeinfo_get_merged", "cdecl")
    svn_client_mergeinfo_get_merged.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mergeinfo_get_merged.restype = POINTER(svn_error_t)
    svn_client_mergeinfo_get_merged.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4181
if _libs["svn_client-1"].has("svn_client_mergeinfo_log2", "cdecl"):
    svn_client_mergeinfo_log2 = _libs["svn_client-1"].get("svn_client_mergeinfo_log2", "cdecl")
    svn_client_mergeinfo_log2.argtypes = [svn_boolean_t, String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_log_entry_receiver_t, POINTER(None), svn_boolean_t, svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mergeinfo_log2.restype = POINTER(svn_error_t)
    svn_client_mergeinfo_log2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4205
if _libs["svn_client-1"].has("svn_client_mergeinfo_log", "cdecl"):
    svn_client_mergeinfo_log = _libs["svn_client-1"].get("svn_client_mergeinfo_log", "cdecl")
    svn_client_mergeinfo_log.argtypes = [svn_boolean_t, String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_log_entry_receiver_t, POINTER(None), svn_boolean_t, svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mergeinfo_log.restype = POINTER(svn_error_t)
    svn_client_mergeinfo_log.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4228
if _libs["svn_client-1"].has("svn_client_mergeinfo_log_merged", "cdecl"):
    svn_client_mergeinfo_log_merged = _libs["svn_client-1"].get("svn_client_mergeinfo_log_merged", "cdecl")
    svn_client_mergeinfo_log_merged.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_log_entry_receiver_t, POINTER(None), svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mergeinfo_log_merged.restype = POINTER(svn_error_t)
    svn_client_mergeinfo_log_merged.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4249
if _libs["svn_client-1"].has("svn_client_mergeinfo_log_eligible", "cdecl"):
    svn_client_mergeinfo_log_eligible = _libs["svn_client-1"].get("svn_client_mergeinfo_log_eligible", "cdecl")
    svn_client_mergeinfo_log_eligible.argtypes = [String, POINTER(svn_opt_revision_t), String, POINTER(svn_opt_revision_t), svn_log_entry_receiver_t, POINTER(None), svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_mergeinfo_log_eligible.restype = POINTER(svn_error_t)
    svn_client_mergeinfo_log_eligible.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4302
if _libs["svn_client-1"].has("svn_client_vacuum", "cdecl"):
    svn_client_vacuum = _libs["svn_client-1"].get("svn_client_vacuum", "cdecl")
    svn_client_vacuum.argtypes = [String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_vacuum.restype = POINTER(svn_error_t)
    svn_client_vacuum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4342
if _libs["svn_client-1"].has("svn_client_cleanup2", "cdecl"):
    svn_client_cleanup2 = _libs["svn_client-1"].get("svn_client_cleanup2", "cdecl")
    svn_client_cleanup2.argtypes = [String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_cleanup2.restype = POINTER(svn_error_t)
    svn_client_cleanup2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4358
if _libs["svn_client-1"].has("svn_client_cleanup", "cdecl"):
    svn_client_cleanup = _libs["svn_client-1"].get("svn_client_cleanup", "cdecl")
    svn_client_cleanup.argtypes = [String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_cleanup.restype = POINTER(svn_error_t)
    svn_client_cleanup.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4379
if _libs["svn_client-1"].has("svn_client_upgrade", "cdecl"):
    svn_client_upgrade = _libs["svn_client-1"].get("svn_client_upgrade", "cdecl")
    svn_client_upgrade.argtypes = [String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_upgrade.restype = POINTER(svn_error_t)
    svn_client_upgrade.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4408
if _libs["svn_client-1"].has("svn_client_relocate2", "cdecl"):
    svn_client_relocate2 = _libs["svn_client-1"].get("svn_client_relocate2", "cdecl")
    svn_client_relocate2.argtypes = [String, String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_relocate2.restype = POINTER(svn_error_t)
    svn_client_relocate2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4427
if _libs["svn_client-1"].has("svn_client_relocate", "cdecl"):
    svn_client_relocate = _libs["svn_client-1"].get("svn_client_relocate", "cdecl")
    svn_client_relocate.argtypes = [String, String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_relocate.restype = POINTER(svn_error_t)
    svn_client_relocate.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4499
if _libs["svn_client-1"].has("svn_client_revert4", "cdecl"):
    svn_client_revert4 = _libs["svn_client-1"].get("svn_client_revert4", "cdecl")
    svn_client_revert4.argtypes = [POINTER(apr_array_header_t), svn_depth_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revert4.restype = POINTER(svn_error_t)
    svn_client_revert4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4516
if _libs["svn_client-1"].has("svn_client_revert3", "cdecl"):
    svn_client_revert3 = _libs["svn_client-1"].get("svn_client_revert3", "cdecl")
    svn_client_revert3.argtypes = [POINTER(apr_array_header_t), svn_depth_t, POINTER(apr_array_header_t), svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revert3.restype = POINTER(svn_error_t)
    svn_client_revert3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4532
if _libs["svn_client-1"].has("svn_client_revert2", "cdecl"):
    svn_client_revert2 = _libs["svn_client-1"].get("svn_client_revert2", "cdecl")
    svn_client_revert2.argtypes = [POINTER(apr_array_header_t), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revert2.restype = POINTER(svn_error_t)
    svn_client_revert2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4552
if _libs["svn_client-1"].has("svn_client_revert", "cdecl"):
    svn_client_revert = _libs["svn_client-1"].get("svn_client_revert", "cdecl")
    svn_client_revert.argtypes = [POINTER(apr_array_header_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revert.restype = POINTER(svn_error_t)
    svn_client_revert.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4572
class struct_svn_client_conflict_t(Structure):
    pass

svn_client_conflict_t = struct_svn_client_conflict_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4572

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4579
class struct_svn_client_conflict_option_t(Structure):
    pass

svn_client_conflict_option_t = struct_svn_client_conflict_option_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4579

enum_svn_client_conflict_option_id_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_undefined = (-1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_postpone = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_base_text = (svn_client_conflict_option_postpone + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_text = (svn_client_conflict_option_base_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_working_text = (svn_client_conflict_option_incoming_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_text_where_conflicted = (svn_client_conflict_option_working_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_working_text_where_conflicted = (svn_client_conflict_option_incoming_text_where_conflicted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_merged_text = (svn_client_conflict_option_working_text_where_conflicted + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_unspecified = (svn_client_conflict_option_merged_text + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_accept_current_wc_state = (svn_client_conflict_option_unspecified + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_update_move_destination = (svn_client_conflict_option_accept_current_wc_state + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_update_any_moved_away_children = (svn_client_conflict_option_update_move_destination + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_add_ignore = (svn_client_conflict_option_update_any_moved_away_children + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_added_file_text_merge = (svn_client_conflict_option_incoming_add_ignore + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_added_file_replace_and_merge = (svn_client_conflict_option_incoming_added_file_text_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_added_dir_merge = (svn_client_conflict_option_incoming_added_file_replace_and_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_added_dir_replace = (svn_client_conflict_option_incoming_added_dir_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_added_dir_replace_and_merge = (svn_client_conflict_option_incoming_added_dir_replace + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_delete_ignore = (svn_client_conflict_option_incoming_added_dir_replace_and_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_delete_accept = (svn_client_conflict_option_incoming_delete_ignore + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_move_file_text_merge = (svn_client_conflict_option_incoming_delete_accept + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_incoming_move_dir_merge = (svn_client_conflict_option_incoming_move_file_text_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_local_move_file_text_merge = (svn_client_conflict_option_incoming_move_dir_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_local_move_dir_merge = (svn_client_conflict_option_local_move_file_text_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_sibling_move_file_text_merge = (svn_client_conflict_option_local_move_dir_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_sibling_move_dir_merge = (svn_client_conflict_option_sibling_move_file_text_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_both_moved_file_merge = (svn_client_conflict_option_sibling_move_dir_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_both_moved_file_move_merge = (svn_client_conflict_option_both_moved_file_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_both_moved_dir_merge = (svn_client_conflict_option_both_moved_file_move_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_both_moved_dir_move_merge = (svn_client_conflict_option_both_moved_dir_merge + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

svn_client_conflict_option_id_t = enum_svn_client_conflict_option_id_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4645

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4660
if _libs["svn_client-1"].has("svn_client_conflict_option_set_merged_propval", "cdecl"):
    svn_client_conflict_option_set_merged_propval = _libs["svn_client-1"].get("svn_client_conflict_option_set_merged_propval", "cdecl")
    svn_client_conflict_option_set_merged_propval.argtypes = [POINTER(svn_client_conflict_option_t), POINTER(svn_string_t)]
    svn_client_conflict_option_set_merged_propval.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4686
if _libs["svn_client-1"].has("svn_client_conflict_option_get_moved_to_repos_relpath_candidates2", "cdecl"):
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates2 = _libs["svn_client-1"].get("svn_client_conflict_option_get_moved_to_repos_relpath_candidates2", "cdecl")
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates2.restype = POINTER(svn_error_t)
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4705
if _libs["svn_client-1"].has("svn_client_conflict_option_get_moved_to_repos_relpath_candidates", "cdecl"):
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates = _libs["svn_client-1"].get("svn_client_conflict_option_get_moved_to_repos_relpath_candidates", "cdecl")
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates.restype = POINTER(svn_error_t)
    svn_client_conflict_option_get_moved_to_repos_relpath_candidates.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4726
if _libs["svn_client-1"].has("svn_client_conflict_option_set_moved_to_repos_relpath2", "cdecl"):
    svn_client_conflict_option_set_moved_to_repos_relpath2 = _libs["svn_client-1"].get("svn_client_conflict_option_set_moved_to_repos_relpath2", "cdecl")
    svn_client_conflict_option_set_moved_to_repos_relpath2.argtypes = [POINTER(svn_client_conflict_option_t), c_int, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_set_moved_to_repos_relpath2.restype = POINTER(svn_error_t)
    svn_client_conflict_option_set_moved_to_repos_relpath2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4742
if _libs["svn_client-1"].has("svn_client_conflict_option_set_moved_to_repos_relpath", "cdecl"):
    svn_client_conflict_option_set_moved_to_repos_relpath = _libs["svn_client-1"].get("svn_client_conflict_option_set_moved_to_repos_relpath", "cdecl")
    svn_client_conflict_option_set_moved_to_repos_relpath.argtypes = [POINTER(svn_client_conflict_option_t), c_int, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_set_moved_to_repos_relpath.restype = POINTER(svn_error_t)
    svn_client_conflict_option_set_moved_to_repos_relpath.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4772
if _libs["svn_client-1"].has("svn_client_conflict_option_get_moved_to_abspath_candidates2", "cdecl"):
    svn_client_conflict_option_get_moved_to_abspath_candidates2 = _libs["svn_client-1"].get("svn_client_conflict_option_get_moved_to_abspath_candidates2", "cdecl")
    svn_client_conflict_option_get_moved_to_abspath_candidates2.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_moved_to_abspath_candidates2.restype = POINTER(svn_error_t)
    svn_client_conflict_option_get_moved_to_abspath_candidates2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4791
if _libs["svn_client-1"].has("svn_client_conflict_option_get_moved_to_abspath_candidates", "cdecl"):
    svn_client_conflict_option_get_moved_to_abspath_candidates = _libs["svn_client-1"].get("svn_client_conflict_option_get_moved_to_abspath_candidates", "cdecl")
    svn_client_conflict_option_get_moved_to_abspath_candidates.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_moved_to_abspath_candidates.restype = POINTER(svn_error_t)
    svn_client_conflict_option_get_moved_to_abspath_candidates.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4812
if _libs["svn_client-1"].has("svn_client_conflict_option_set_moved_to_abspath2", "cdecl"):
    svn_client_conflict_option_set_moved_to_abspath2 = _libs["svn_client-1"].get("svn_client_conflict_option_set_moved_to_abspath2", "cdecl")
    svn_client_conflict_option_set_moved_to_abspath2.argtypes = [POINTER(svn_client_conflict_option_t), c_int, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_set_moved_to_abspath2.restype = POINTER(svn_error_t)
    svn_client_conflict_option_set_moved_to_abspath2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4828
if _libs["svn_client-1"].has("svn_client_conflict_option_set_moved_to_abspath", "cdecl"):
    svn_client_conflict_option_set_moved_to_abspath = _libs["svn_client-1"].get("svn_client_conflict_option_set_moved_to_abspath", "cdecl")
    svn_client_conflict_option_set_moved_to_abspath.argtypes = [POINTER(svn_client_conflict_option_t), c_int, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_set_moved_to_abspath.restype = POINTER(svn_error_t)
    svn_client_conflict_option_set_moved_to_abspath.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4843
if _libs["svn_client-1"].has("svn_client_conflict_option_find_by_id", "cdecl"):
    svn_client_conflict_option_find_by_id = _libs["svn_client-1"].get("svn_client_conflict_option_find_by_id", "cdecl")
    svn_client_conflict_option_find_by_id.argtypes = [POINTER(apr_array_header_t), svn_client_conflict_option_id_t]
    svn_client_conflict_option_find_by_id.restype = POINTER(svn_client_conflict_option_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4853
if _libs["svn_client-1"].has("svn_client_conflict_get", "cdecl"):
    svn_client_conflict_get = _libs["svn_client-1"].get("svn_client_conflict_get", "cdecl")
    svn_client_conflict_get.argtypes = [POINTER(POINTER(svn_client_conflict_t)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_get.restype = POINTER(svn_error_t)
    svn_client_conflict_get.errcheck = _svn_errcheck

svn_client_conflict_walk_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_client_conflict_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4868

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4886
if _libs["svn_client-1"].has("svn_client_conflict_walk", "cdecl"):
    svn_client_conflict_walk = _libs["svn_client-1"].get("svn_client_conflict_walk", "cdecl")
    svn_client_conflict_walk.argtypes = [String, svn_depth_t, svn_client_conflict_walk_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_walk.restype = POINTER(svn_error_t)
    svn_client_conflict_walk.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4905
if _libs["svn_client-1"].has("svn_client_conflict_get_conflicted", "cdecl"):
    svn_client_conflict_get_conflicted = _libs["svn_client-1"].get("svn_client_conflict_get_conflicted", "cdecl")
    svn_client_conflict_get_conflicted.argtypes = [POINTER(svn_boolean_t), POINTER(POINTER(apr_array_header_t)), POINTER(svn_boolean_t), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_get_conflicted.restype = POINTER(svn_error_t)
    svn_client_conflict_get_conflicted.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4924
if _libs["svn_client-1"].has("svn_client_conflict_prop_get_description", "cdecl"):
    svn_client_conflict_prop_get_description = _libs["svn_client-1"].get("svn_client_conflict_prop_get_description", "cdecl")
    svn_client_conflict_prop_get_description.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_prop_get_description.restype = POINTER(svn_error_t)
    svn_client_conflict_prop_get_description.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4968
if _libs["svn_client-1"].has("svn_client_conflict_tree_get_description", "cdecl"):
    svn_client_conflict_tree_get_description = _libs["svn_client-1"].get("svn_client_conflict_tree_get_description", "cdecl")
    svn_client_conflict_tree_get_description.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(svn_client_conflict_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_tree_get_description.restype = POINTER(svn_error_t)
    svn_client_conflict_tree_get_description.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4983
if _libs["svn_client-1"].has("svn_client_conflict_text_get_resolution_options", "cdecl"):
    svn_client_conflict_text_get_resolution_options = _libs["svn_client-1"].get("svn_client_conflict_text_get_resolution_options", "cdecl")
    svn_client_conflict_text_get_resolution_options.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_text_get_resolution_options.restype = POINTER(svn_error_t)
    svn_client_conflict_text_get_resolution_options.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4996
if _libs["svn_client-1"].has("svn_client_conflict_prop_get_resolution_options", "cdecl"):
    svn_client_conflict_prop_get_resolution_options = _libs["svn_client-1"].get("svn_client_conflict_prop_get_resolution_options", "cdecl")
    svn_client_conflict_prop_get_resolution_options.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_prop_get_resolution_options.restype = POINTER(svn_error_t)
    svn_client_conflict_prop_get_resolution_options.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5013
if _libs["svn_client-1"].has("svn_client_conflict_tree_get_resolution_options", "cdecl"):
    svn_client_conflict_tree_get_resolution_options = _libs["svn_client-1"].get("svn_client_conflict_tree_get_resolution_options", "cdecl")
    svn_client_conflict_tree_get_resolution_options.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_client_conflict_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_tree_get_resolution_options.restype = POINTER(svn_error_t)
    svn_client_conflict_tree_get_resolution_options.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5034
if _libs["svn_client-1"].has("svn_client_conflict_tree_get_details", "cdecl"):
    svn_client_conflict_tree_get_details = _libs["svn_client-1"].get("svn_client_conflict_tree_get_details", "cdecl")
    svn_client_conflict_tree_get_details.argtypes = [POINTER(svn_client_conflict_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_tree_get_details.restype = POINTER(svn_error_t)
    svn_client_conflict_tree_get_details.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5049
if _libs["svn_client-1"].has("svn_client_conflict_option_get_id", "cdecl"):
    svn_client_conflict_option_get_id = _libs["svn_client-1"].get("svn_client_conflict_option_get_id", "cdecl")
    svn_client_conflict_option_get_id.argtypes = [POINTER(svn_client_conflict_option_t)]
    svn_client_conflict_option_get_id.restype = svn_client_conflict_option_id_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5061
if _libs["svn_client-1"].has("svn_client_conflict_option_get_label", "cdecl"):
    svn_client_conflict_option_get_label = _libs["svn_client-1"].get("svn_client_conflict_option_get_label", "cdecl")
    svn_client_conflict_option_get_label.argtypes = [POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_label.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5075
if _libs["svn_client-1"].has("svn_client_conflict_option_get_description", "cdecl"):
    svn_client_conflict_option_get_description = _libs["svn_client-1"].get("svn_client_conflict_option_get_description", "cdecl")
    svn_client_conflict_option_get_description.argtypes = [POINTER(svn_client_conflict_option_t), POINTER(apr_pool_t)]
    svn_client_conflict_option_get_description.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5098
if _libs["svn_client-1"].has("svn_client_conflict_get_recommended_option_id", "cdecl"):
    svn_client_conflict_get_recommended_option_id = _libs["svn_client-1"].get("svn_client_conflict_get_recommended_option_id", "cdecl")
    svn_client_conflict_get_recommended_option_id.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_get_recommended_option_id.restype = svn_client_conflict_option_id_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5106
if _libs["svn_client-1"].has("svn_client_conflict_get_local_abspath", "cdecl"):
    svn_client_conflict_get_local_abspath = _libs["svn_client-1"].get("svn_client_conflict_get_local_abspath", "cdecl")
    svn_client_conflict_get_local_abspath.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_get_local_abspath.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5116
if _libs["svn_client-1"].has("svn_client_conflict_get_operation", "cdecl"):
    svn_client_conflict_get_operation = _libs["svn_client-1"].get("svn_client_conflict_get_operation", "cdecl")
    svn_client_conflict_get_operation.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_get_operation.restype = svn_wc_operation_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5125
if _libs["svn_client-1"].has("svn_client_conflict_get_incoming_change", "cdecl"):
    svn_client_conflict_get_incoming_change = _libs["svn_client-1"].get("svn_client_conflict_get_incoming_change", "cdecl")
    svn_client_conflict_get_incoming_change.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_get_incoming_change.restype = svn_wc_conflict_action_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5139
if _libs["svn_client-1"].has("svn_client_conflict_get_local_change", "cdecl"):
    svn_client_conflict_get_local_change = _libs["svn_client-1"].get("svn_client_conflict_get_local_change", "cdecl")
    svn_client_conflict_get_local_change.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_get_local_change.restype = svn_wc_conflict_reason_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5148
if _libs["svn_client-1"].has("svn_client_conflict_get_repos_info", "cdecl"):
    svn_client_conflict_get_repos_info = _libs["svn_client-1"].get("svn_client_conflict_get_repos_info", "cdecl")
    svn_client_conflict_get_repos_info.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_get_repos_info.restype = POINTER(svn_error_t)
    svn_client_conflict_get_repos_info.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5181
if _libs["svn_client-1"].has("svn_client_conflict_get_incoming_old_repos_location", "cdecl"):
    svn_client_conflict_get_incoming_old_repos_location = _libs["svn_client-1"].get("svn_client_conflict_get_incoming_old_repos_location", "cdecl")
    svn_client_conflict_get_incoming_old_repos_location.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(svn_node_kind_t), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_get_incoming_old_repos_location.restype = POINTER(svn_error_t)
    svn_client_conflict_get_incoming_old_repos_location.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5198
if _libs["svn_client-1"].has("svn_client_conflict_get_incoming_new_repos_location", "cdecl"):
    svn_client_conflict_get_incoming_new_repos_location = _libs["svn_client-1"].get("svn_client_conflict_get_incoming_new_repos_location", "cdecl")
    svn_client_conflict_get_incoming_new_repos_location.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(svn_node_kind_t), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_get_incoming_new_repos_location.restype = POINTER(svn_error_t)
    svn_client_conflict_get_incoming_new_repos_location.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5215
if _libs["svn_client-1"].has("svn_client_conflict_tree_get_victim_node_kind", "cdecl"):
    svn_client_conflict_tree_get_victim_node_kind = _libs["svn_client-1"].get("svn_client_conflict_tree_get_victim_node_kind", "cdecl")
    svn_client_conflict_tree_get_victim_node_kind.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_tree_get_victim_node_kind.restype = svn_node_kind_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5230
if _libs["svn_client-1"].has("svn_client_conflict_tree_resolve", "cdecl"):
    svn_client_conflict_tree_resolve = _libs["svn_client-1"].get("svn_client_conflict_tree_resolve", "cdecl")
    svn_client_conflict_tree_resolve.argtypes = [POINTER(svn_client_conflict_t), POINTER(svn_client_conflict_option_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_tree_resolve.restype = POINTER(svn_error_t)
    svn_client_conflict_tree_resolve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5246
if _libs["svn_client-1"].has("svn_client_conflict_tree_resolve_by_id", "cdecl"):
    svn_client_conflict_tree_resolve_by_id = _libs["svn_client-1"].get("svn_client_conflict_tree_resolve_by_id", "cdecl")
    svn_client_conflict_tree_resolve_by_id.argtypes = [POINTER(svn_client_conflict_t), svn_client_conflict_option_id_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_tree_resolve_by_id.restype = POINTER(svn_error_t)
    svn_client_conflict_tree_resolve_by_id.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5261
if _libs["svn_client-1"].has("svn_client_conflict_tree_get_resolution", "cdecl"):
    svn_client_conflict_tree_get_resolution = _libs["svn_client-1"].get("svn_client_conflict_tree_get_resolution", "cdecl")
    svn_client_conflict_tree_get_resolution.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_tree_get_resolution.restype = svn_client_conflict_option_id_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5272
if _libs["svn_client-1"].has("svn_client_conflict_prop_get_reject_abspath", "cdecl"):
    svn_client_conflict_prop_get_reject_abspath = _libs["svn_client-1"].get("svn_client_conflict_prop_get_reject_abspath", "cdecl")
    svn_client_conflict_prop_get_reject_abspath.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_prop_get_reject_abspath.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5286
if _libs["svn_client-1"].has("svn_client_conflict_prop_get_propvals", "cdecl"):
    svn_client_conflict_prop_get_propvals = _libs["svn_client-1"].get("svn_client_conflict_prop_get_propvals", "cdecl")
    svn_client_conflict_prop_get_propvals.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(POINTER(svn_string_t)), POINTER(POINTER(svn_string_t)), POINTER(POINTER(svn_string_t)), POINTER(svn_client_conflict_t), String, POINTER(apr_pool_t)]
    svn_client_conflict_prop_get_propvals.restype = POINTER(svn_error_t)
    svn_client_conflict_prop_get_propvals.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5302
if _libs["svn_client-1"].has("svn_client_conflict_prop_resolve", "cdecl"):
    svn_client_conflict_prop_resolve = _libs["svn_client-1"].get("svn_client_conflict_prop_resolve", "cdecl")
    svn_client_conflict_prop_resolve.argtypes = [POINTER(svn_client_conflict_t), String, POINTER(svn_client_conflict_option_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_prop_resolve.restype = POINTER(svn_error_t)
    svn_client_conflict_prop_resolve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5316
if _libs["svn_client-1"].has("svn_client_conflict_prop_resolve_by_id", "cdecl"):
    svn_client_conflict_prop_resolve_by_id = _libs["svn_client-1"].get("svn_client_conflict_prop_resolve_by_id", "cdecl")
    svn_client_conflict_prop_resolve_by_id.argtypes = [POINTER(svn_client_conflict_t), String, svn_client_conflict_option_id_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_prop_resolve_by_id.restype = POINTER(svn_error_t)
    svn_client_conflict_prop_resolve_by_id.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5333
if _libs["svn_client-1"].has("svn_client_conflict_prop_get_resolution", "cdecl"):
    svn_client_conflict_prop_get_resolution = _libs["svn_client-1"].get("svn_client_conflict_prop_get_resolution", "cdecl")
    svn_client_conflict_prop_get_resolution.argtypes = [POINTER(svn_client_conflict_t), String]
    svn_client_conflict_prop_get_resolution.restype = svn_client_conflict_option_id_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5343
if _libs["svn_client-1"].has("svn_client_conflict_text_get_mime_type", "cdecl"):
    svn_client_conflict_text_get_mime_type = _libs["svn_client-1"].get("svn_client_conflict_text_get_mime_type", "cdecl")
    svn_client_conflict_text_get_mime_type.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_text_get_mime_type.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5355
if _libs["svn_client-1"].has("svn_client_conflict_text_get_contents", "cdecl"):
    svn_client_conflict_text_get_contents = _libs["svn_client-1"].get("svn_client_conflict_text_get_contents", "cdecl")
    svn_client_conflict_text_get_contents.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(svn_client_conflict_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_conflict_text_get_contents.restype = POINTER(svn_error_t)
    svn_client_conflict_text_get_contents.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5369
if _libs["svn_client-1"].has("svn_client_conflict_text_resolve", "cdecl"):
    svn_client_conflict_text_resolve = _libs["svn_client-1"].get("svn_client_conflict_text_resolve", "cdecl")
    svn_client_conflict_text_resolve.argtypes = [POINTER(svn_client_conflict_t), POINTER(svn_client_conflict_option_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_text_resolve.restype = POINTER(svn_error_t)
    svn_client_conflict_text_resolve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5382
if _libs["svn_client-1"].has("svn_client_conflict_text_resolve_by_id", "cdecl"):
    svn_client_conflict_text_resolve_by_id = _libs["svn_client-1"].get("svn_client_conflict_text_resolve_by_id", "cdecl")
    svn_client_conflict_text_resolve_by_id.argtypes = [POINTER(svn_client_conflict_t), svn_client_conflict_option_id_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_conflict_text_resolve_by_id.restype = POINTER(svn_error_t)
    svn_client_conflict_text_resolve_by_id.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5397
if _libs["svn_client-1"].has("svn_client_conflict_text_get_resolution", "cdecl"):
    svn_client_conflict_text_get_resolution = _libs["svn_client-1"].get("svn_client_conflict_text_get_resolution", "cdecl")
    svn_client_conflict_text_get_resolution.argtypes = [POINTER(svn_client_conflict_t)]
    svn_client_conflict_text_get_resolution.restype = svn_client_conflict_option_id_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5416
if _libs["svn_client-1"].has("svn_client_resolved", "cdecl"):
    svn_client_resolved = _libs["svn_client-1"].get("svn_client_resolved", "cdecl")
    svn_client_resolved.argtypes = [String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_resolved.restype = POINTER(svn_error_t)
    svn_client_resolved.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5475
if _libs["svn_client-1"].has("svn_client_resolve", "cdecl"):
    svn_client_resolve = _libs["svn_client-1"].get("svn_client_resolve", "cdecl")
    svn_client_resolve.argtypes = [String, svn_depth_t, svn_wc_conflict_choice_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_resolve.restype = POINTER(svn_error_t)
    svn_client_resolve.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5507
class struct_svn_client_copy_source_t(Structure):
    pass

struct_svn_client_copy_source_t.__slots__ = [
    'path',
    'revision',
    'peg_revision',
]
struct_svn_client_copy_source_t._fields_ = [
    ('path', String),
    ('revision', POINTER(svn_opt_revision_t)),
    ('peg_revision', POINTER(svn_opt_revision_t)),
]

svn_client_copy_source_t = struct_svn_client_copy_source_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5507

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5604
if _libs["svn_client-1"].has("svn_client_copy7", "cdecl"):
    svn_client_copy7 = _libs["svn_client-1"].get("svn_client_copy7", "cdecl")
    svn_client_copy7.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy7.restype = POINTER(svn_error_t)
    svn_client_copy7.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5628
if _libs["svn_client-1"].has("svn_client_copy6", "cdecl"):
    svn_client_copy6 = _libs["svn_client-1"].get("svn_client_copy6", "cdecl")
    svn_client_copy6.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy6.restype = POINTER(svn_error_t)
    svn_client_copy6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5648
if _libs["svn_client-1"].has("svn_client_copy5", "cdecl"):
    svn_client_copy5 = _libs["svn_client-1"].get("svn_client_copy5", "cdecl")
    svn_client_copy5.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy5.restype = POINTER(svn_error_t)
    svn_client_copy5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5667
if _libs["svn_client-1"].has("svn_client_copy4", "cdecl"):
    svn_client_copy4 = _libs["svn_client-1"].get("svn_client_copy4", "cdecl")
    svn_client_copy4.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy4.restype = POINTER(svn_error_t)
    svn_client_copy4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5688
if _libs["svn_client-1"].has("svn_client_copy3", "cdecl"):
    svn_client_copy3 = _libs["svn_client-1"].get("svn_client_copy3", "cdecl")
    svn_client_copy3.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, POINTER(svn_opt_revision_t), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy3.restype = POINTER(svn_error_t)
    svn_client_copy3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5707
if _libs["svn_client-1"].has("svn_client_copy2", "cdecl"):
    svn_client_copy2 = _libs["svn_client-1"].get("svn_client_copy2", "cdecl")
    svn_client_copy2.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, POINTER(svn_opt_revision_t), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy2.restype = POINTER(svn_error_t)
    svn_client_copy2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5723
if _libs["svn_client-1"].has("svn_client_copy", "cdecl"):
    svn_client_copy = _libs["svn_client-1"].get("svn_client_copy", "cdecl")
    svn_client_copy.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), String, POINTER(svn_opt_revision_t), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_copy.restype = POINTER(svn_error_t)
    svn_client_copy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5824
if _libs["svn_client-1"].has("svn_client_move7", "cdecl"):
    svn_client_move7 = _libs["svn_client-1"].get("svn_client_move7", "cdecl")
    svn_client_move7.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move7.restype = POINTER(svn_error_t)
    svn_client_move7.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5845
if _libs["svn_client-1"].has("svn_client_move6", "cdecl"):
    svn_client_move6 = _libs["svn_client-1"].get("svn_client_move6", "cdecl")
    svn_client_move6.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move6.restype = POINTER(svn_error_t)
    svn_client_move6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5867
if _libs["svn_client-1"].has("svn_client_move5", "cdecl"):
    svn_client_move5 = _libs["svn_client-1"].get("svn_client_move5", "cdecl")
    svn_client_move5.argtypes = [POINTER(POINTER(svn_commit_info_t)), POINTER(apr_array_header_t), String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move5.restype = POINTER(svn_error_t)
    svn_client_move5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5893
if _libs["svn_client-1"].has("svn_client_move4", "cdecl"):
    svn_client_move4 = _libs["svn_client-1"].get("svn_client_move4", "cdecl")
    svn_client_move4.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move4.restype = POINTER(svn_error_t)
    svn_client_move4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5911
if _libs["svn_client-1"].has("svn_client_move3", "cdecl"):
    svn_client_move3 = _libs["svn_client-1"].get("svn_client_move3", "cdecl")
    svn_client_move3.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move3.restype = POINTER(svn_error_t)
    svn_client_move3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5928
if _libs["svn_client-1"].has("svn_client_move2", "cdecl"):
    svn_client_move2 = _libs["svn_client-1"].get("svn_client_move2", "cdecl")
    svn_client_move2.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), String, String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move2.restype = POINTER(svn_error_t)
    svn_client_move2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5945
if _libs["svn_client-1"].has("svn_client_move", "cdecl"):
    svn_client_move = _libs["svn_client-1"].get("svn_client_move", "cdecl")
    svn_client_move.argtypes = [POINTER(POINTER(svn_client_commit_info_t)), String, POINTER(svn_opt_revision_t), String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_move.restype = POINTER(svn_error_t)
    svn_client_move.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6006
if _libs["svn_client-1"].has("svn_client_propset_remote", "cdecl"):
    svn_client_propset_remote = _libs["svn_client-1"].get("svn_client_propset_remote", "cdecl")
    svn_client_propset_remote.argtypes = [String, POINTER(svn_string_t), String, svn_boolean_t, svn_revnum_t, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propset_remote.restype = POINTER(svn_error_t)
    svn_client_propset_remote.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6053
if _libs["svn_client-1"].has("svn_client_propset_local", "cdecl"):
    svn_client_propset_local = _libs["svn_client-1"].get("svn_client_propset_local", "cdecl")
    svn_client_propset_local.argtypes = [String, POINTER(svn_string_t), POINTER(apr_array_header_t), svn_depth_t, svn_boolean_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propset_local.restype = POINTER(svn_error_t)
    svn_client_propset_local.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6073
if _libs["svn_client-1"].has("svn_client_propset3", "cdecl"):
    svn_client_propset3 = _libs["svn_client-1"].get("svn_client_propset3", "cdecl")
    svn_client_propset3.argtypes = [POINTER(POINTER(svn_commit_info_t)), String, POINTER(svn_string_t), String, svn_depth_t, svn_boolean_t, svn_revnum_t, POINTER(apr_array_header_t), POINTER(apr_hash_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propset3.restype = POINTER(svn_error_t)
    svn_client_propset3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6096
if _libs["svn_client-1"].has("svn_client_propset2", "cdecl"):
    svn_client_propset2 = _libs["svn_client-1"].get("svn_client_propset2", "cdecl")
    svn_client_propset2.argtypes = [String, POINTER(svn_string_t), String, svn_boolean_t, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propset2.restype = POINTER(svn_error_t)
    svn_client_propset2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6112
if _libs["svn_client-1"].has("svn_client_propset", "cdecl"):
    svn_client_propset = _libs["svn_client-1"].get("svn_client_propset", "cdecl")
    svn_client_propset.argtypes = [String, POINTER(svn_string_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_client_propset.restype = POINTER(svn_error_t)
    svn_client_propset.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6164
if _libs["svn_client-1"].has("svn_client_revprop_set2", "cdecl"):
    svn_client_revprop_set2 = _libs["svn_client-1"].get("svn_client_revprop_set2", "cdecl")
    svn_client_revprop_set2.argtypes = [String, POINTER(svn_string_t), POINTER(svn_string_t), String, POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revprop_set2.restype = POINTER(svn_error_t)
    svn_client_revprop_set2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6182
if _libs["svn_client-1"].has("svn_client_revprop_set", "cdecl"):
    svn_client_revprop_set = _libs["svn_client-1"].get("svn_client_revprop_set", "cdecl")
    svn_client_revprop_set.argtypes = [String, POINTER(svn_string_t), String, POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revprop_set.restype = POINTER(svn_error_t)
    svn_client_revprop_set.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6258
if _libs["svn_client-1"].has("svn_client_propget5", "cdecl"):
    svn_client_propget5 = _libs["svn_client-1"].get("svn_client_propget5", "cdecl")
    svn_client_propget5.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(POINTER(apr_array_header_t)), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_propget5.restype = POINTER(svn_error_t)
    svn_client_propget5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6280
if _libs["svn_client-1"].has("svn_client_propget4", "cdecl"):
    svn_client_propget4 = _libs["svn_client-1"].get("svn_client_propget4", "cdecl")
    svn_client_propget4.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_propget4.restype = POINTER(svn_error_t)
    svn_client_propget4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6305
if _libs["svn_client-1"].has("svn_client_propget3", "cdecl"):
    svn_client_propget3 = _libs["svn_client-1"].get("svn_client_propget3", "cdecl")
    svn_client_propget3.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propget3.restype = POINTER(svn_error_t)
    svn_client_propget3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6326
if _libs["svn_client-1"].has("svn_client_propget2", "cdecl"):
    svn_client_propget2 = _libs["svn_client-1"].get("svn_client_propget2", "cdecl")
    svn_client_propget2.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propget2.restype = POINTER(svn_error_t)
    svn_client_propget2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6343
if _libs["svn_client-1"].has("svn_client_propget", "cdecl"):
    svn_client_propget = _libs["svn_client-1"].get("svn_client_propget", "cdecl")
    svn_client_propget.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_propget.restype = POINTER(svn_error_t)
    svn_client_propget.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6365
if _libs["svn_client-1"].has("svn_client_revprop_get", "cdecl"):
    svn_client_revprop_get = _libs["svn_client-1"].get("svn_client_revprop_get", "cdecl")
    svn_client_revprop_get.argtypes = [String, POINTER(POINTER(svn_string_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revprop_get.restype = POINTER(svn_error_t)
    svn_client_revprop_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6422
if _libs["svn_client-1"].has("svn_client_proplist4", "cdecl"):
    svn_client_proplist4 = _libs["svn_client-1"].get("svn_client_proplist4", "cdecl")
    svn_client_proplist4.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, POINTER(apr_array_header_t), svn_boolean_t, svn_proplist_receiver2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_proplist4.restype = POINTER(svn_error_t)
    svn_client_proplist4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6443
if _libs["svn_client-1"].has("svn_client_proplist3", "cdecl"):
    svn_client_proplist3 = _libs["svn_client-1"].get("svn_client_proplist3", "cdecl")
    svn_client_proplist3.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, POINTER(apr_array_header_t), svn_proplist_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_proplist3.restype = POINTER(svn_error_t)
    svn_client_proplist3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6467
if _libs["svn_client-1"].has("svn_client_proplist2", "cdecl"):
    svn_client_proplist2 = _libs["svn_client-1"].get("svn_client_proplist2", "cdecl")
    svn_client_proplist2.argtypes = [POINTER(POINTER(apr_array_header_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_proplist2.restype = POINTER(svn_error_t)
    svn_client_proplist2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6483
if _libs["svn_client-1"].has("svn_client_proplist", "cdecl"):
    svn_client_proplist = _libs["svn_client-1"].get("svn_client_proplist", "cdecl")
    svn_client_proplist.argtypes = [POINTER(POINTER(apr_array_header_t)), String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_proplist.restype = POINTER(svn_error_t)
    svn_client_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6503
if _libs["svn_client-1"].has("svn_client_revprop_list", "cdecl"):
    svn_client_revprop_list = _libs["svn_client-1"].get("svn_client_revprop_list", "cdecl")
    svn_client_revprop_list.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_revnum_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_revprop_list.restype = POINTER(svn_error_t)
    svn_client_revprop_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6579
if _libs["svn_client-1"].has("svn_client_export5", "cdecl"):
    svn_client_export5 = _libs["svn_client-1"].get("svn_client_export5", "cdecl")
    svn_client_export5.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_depth_t, String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_export5.restype = POINTER(svn_error_t)
    svn_client_export5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6601
if _libs["svn_client-1"].has("svn_client_export4", "cdecl"):
    svn_client_export4 = _libs["svn_client-1"].get("svn_client_export4", "cdecl")
    svn_client_export4.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_depth_t, String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_export4.restype = POINTER(svn_error_t)
    svn_client_export4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6626
if _libs["svn_client-1"].has("svn_client_export3", "cdecl"):
    svn_client_export3 = _libs["svn_client-1"].get("svn_client_export3", "cdecl")
    svn_client_export3.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, svn_boolean_t, svn_boolean_t, String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_export3.restype = POINTER(svn_error_t)
    svn_client_export3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6650
if _libs["svn_client-1"].has("svn_client_export2", "cdecl"):
    svn_client_export2 = _libs["svn_client-1"].get("svn_client_export2", "cdecl")
    svn_client_export2.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), svn_boolean_t, String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_export2.restype = POINTER(svn_error_t)
    svn_client_export2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6668
if _libs["svn_client-1"].has("svn_client_export", "cdecl"):
    svn_client_export = _libs["svn_client-1"].get("svn_client_export", "cdecl")
    svn_client_export.argtypes = [POINTER(svn_revnum_t), String, String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_export.restype = POINTER(svn_error_t)
    svn_client_export.errcheck = _svn_errcheck

svn_client_list_func2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_dirent_t), POINTER(svn_lock_t), String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6715

svn_client_list_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_dirent_t), POINTER(svn_lock_t), String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6734

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6784
if _libs["svn_client-1"].has("svn_client_list4", "cdecl"):
    svn_client_list4 = _libs["svn_client-1"].get("svn_client_list4", "cdecl")
    svn_client_list4.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(apr_array_header_t), svn_depth_t, apr_uint32_t, svn_boolean_t, svn_boolean_t, svn_client_list_func2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_list4.restype = POINTER(svn_error_t)
    svn_client_list4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6805
if _libs["svn_client-1"].has("svn_client_list3", "cdecl"):
    svn_client_list3 = _libs["svn_client-1"].get("svn_client_list3", "cdecl")
    svn_client_list3.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, apr_uint32_t, svn_boolean_t, svn_boolean_t, svn_client_list_func2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_list3.restype = POINTER(svn_error_t)
    svn_client_list3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6827
if _libs["svn_client-1"].has("svn_client_list2", "cdecl"):
    svn_client_list2 = _libs["svn_client-1"].get("svn_client_list2", "cdecl")
    svn_client_list2.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, apr_uint32_t, svn_boolean_t, svn_client_list_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_list2.restype = POINTER(svn_error_t)
    svn_client_list2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6849
if _libs["svn_client-1"].has("svn_client_list", "cdecl"):
    svn_client_list = _libs["svn_client-1"].get("svn_client_list", "cdecl")
    svn_client_list.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, apr_uint32_t, svn_boolean_t, svn_client_list_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_list.restype = POINTER(svn_error_t)
    svn_client_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6879
if _libs["svn_client-1"].has("svn_client_ls3", "cdecl"):
    svn_client_ls3 = _libs["svn_client-1"].get("svn_client_ls3", "cdecl")
    svn_client_ls3.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(POINTER(apr_hash_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_ls3.restype = POINTER(svn_error_t)
    svn_client_ls3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6898
if _libs["svn_client-1"].has("svn_client_ls2", "cdecl"):
    svn_client_ls2 = _libs["svn_client-1"].get("svn_client_ls2", "cdecl")
    svn_client_ls2.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_ls2.restype = POINTER(svn_error_t)
    svn_client_ls2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6915
if _libs["svn_client-1"].has("svn_client_ls", "cdecl"):
    svn_client_ls = _libs["svn_client-1"].get("svn_client_ls", "cdecl")
    svn_client_ls.argtypes = [POINTER(POINTER(apr_hash_t)), String, POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_ls.restype = POINTER(svn_error_t)
    svn_client_ls.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6961
if _libs["svn_client-1"].has("svn_client_cat3", "cdecl"):
    svn_client_cat3 = _libs["svn_client-1"].get("svn_client_cat3", "cdecl")
    svn_client_cat3.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_stream_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_cat3.restype = POINTER(svn_error_t)
    svn_client_cat3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6980
if _libs["svn_client-1"].has("svn_client_cat2", "cdecl"):
    svn_client_cat2 = _libs["svn_client-1"].get("svn_client_cat2", "cdecl")
    svn_client_cat2.argtypes = [POINTER(svn_stream_t), String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_cat2.restype = POINTER(svn_error_t)
    svn_client_cat2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 6996
if _libs["svn_client-1"].has("svn_client_cat", "cdecl"):
    svn_client_cat = _libs["svn_client-1"].get("svn_client_cat", "cdecl")
    svn_client_cat.argtypes = [POINTER(svn_stream_t), String, POINTER(svn_opt_revision_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_cat.restype = POINTER(svn_error_t)
    svn_client_cat.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7033
if _libs["svn_client-1"].has("svn_client_add_to_changelist", "cdecl"):
    svn_client_add_to_changelist = _libs["svn_client-1"].get("svn_client_add_to_changelist", "cdecl")
    svn_client_add_to_changelist.argtypes = [POINTER(apr_array_header_t), String, svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_add_to_changelist.restype = POINTER(svn_error_t)
    svn_client_add_to_changelist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7060
if _libs["svn_client-1"].has("svn_client_remove_from_changelists", "cdecl"):
    svn_client_remove_from_changelists = _libs["svn_client-1"].get("svn_client_remove_from_changelists", "cdecl")
    svn_client_remove_from_changelists.argtypes = [POINTER(apr_array_header_t), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_remove_from_changelists.restype = POINTER(svn_error_t)
    svn_client_remove_from_changelists.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7083
if _libs["svn_client-1"].has("svn_client_get_changelists", "cdecl"):
    svn_client_get_changelists = _libs["svn_client-1"].get("svn_client_get_changelists", "cdecl")
    svn_client_get_changelists.argtypes = [String, POINTER(apr_array_header_t), svn_depth_t, svn_changelist_receiver_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_get_changelists.restype = POINTER(svn_error_t)
    svn_client_get_changelists.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7125
if _libs["svn_client-1"].has("svn_client_lock", "cdecl"):
    svn_client_lock = _libs["svn_client-1"].get("svn_client_lock", "cdecl")
    svn_client_lock.argtypes = [POINTER(apr_array_header_t), String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_lock.restype = POINTER(svn_error_t)
    svn_client_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7161
if _libs["svn_client-1"].has("svn_client_unlock", "cdecl"):
    svn_client_unlock = _libs["svn_client-1"].get("svn_client_unlock", "cdecl")
    svn_client_unlock.argtypes = [POINTER(apr_array_header_t), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_unlock.restype = POINTER(svn_error_t)
    svn_client_unlock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7295
class struct_svn_info_t(Structure):
    pass

struct_svn_info_t.__slots__ = [
    'URL',
    'rev',
    'kind',
    'repos_root_URL',
    'repos_UUID',
    'last_changed_rev',
    'last_changed_date',
    'last_changed_author',
    'lock',
    'has_wc_info',
    'schedule',
    'copyfrom_url',
    'copyfrom_rev',
    'text_time',
    'prop_time',
    'checksum',
    'conflict_old',
    'conflict_new',
    'conflict_wrk',
    'prejfile',
    'changelist',
    'depth',
    'working_size',
    'size',
    'size64',
    'working_size64',
    'tree_conflict',
]
struct_svn_info_t._fields_ = [
    ('URL', String),
    ('rev', svn_revnum_t),
    ('kind', svn_node_kind_t),
    ('repos_root_URL', String),
    ('repos_UUID', String),
    ('last_changed_rev', svn_revnum_t),
    ('last_changed_date', apr_time_t),
    ('last_changed_author', String),
    ('lock', POINTER(svn_lock_t)),
    ('has_wc_info', svn_boolean_t),
    ('schedule', svn_wc_schedule_t),
    ('copyfrom_url', String),
    ('copyfrom_rev', svn_revnum_t),
    ('text_time', apr_time_t),
    ('prop_time', apr_time_t),
    ('checksum', String),
    ('conflict_old', String),
    ('conflict_new', String),
    ('conflict_wrk', String),
    ('prejfile', String),
    ('changelist', String),
    ('depth', svn_depth_t),
    ('working_size', apr_size_t),
    ('size', apr_size_t),
    ('size64', svn_filesize_t),
    ('working_size64', svn_filesize_t),
    ('tree_conflict', POINTER(svn_wc_conflict_description_t)),
]

svn_info_t = struct_svn_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7295

svn_info_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_info_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7308

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7323
if _libs["svn_client-1"].has("svn_info_dup", "cdecl"):
    svn_info_dup = _libs["svn_client-1"].get("svn_info_dup", "cdecl")
    svn_info_dup.argtypes = [POINTER(svn_info_t), POINTER(apr_pool_t)]
    svn_info_dup.restype = POINTER(svn_info_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7377
class struct_svn_client_info2_t(Structure):
    pass

struct_svn_client_info2_t.__slots__ = [
    'URL',
    'rev',
    'repos_root_URL',
    'repos_UUID',
    'kind',
    'size',
    'last_changed_rev',
    'last_changed_date',
    'last_changed_author',
    'lock',
    'wc_info',
]
struct_svn_client_info2_t._fields_ = [
    ('URL', String),
    ('rev', svn_revnum_t),
    ('repos_root_URL', String),
    ('repos_UUID', String),
    ('kind', svn_node_kind_t),
    ('size', svn_filesize_t),
    ('last_changed_rev', svn_revnum_t),
    ('last_changed_date', apr_time_t),
    ('last_changed_author', String),
    ('lock', POINTER(svn_lock_t)),
    ('wc_info', POINTER(svn_wc_info_t)),
]

svn_client_info2_t = struct_svn_client_info2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7377

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7385
if _libs["svn_client-1"].has("svn_client_info2_dup", "cdecl"):
    svn_client_info2_dup = _libs["svn_client-1"].get("svn_client_info2_dup", "cdecl")
    svn_client_info2_dup.argtypes = [POINTER(svn_client_info2_t), POINTER(apr_pool_t)]
    svn_client_info2_dup.restype = POINTER(svn_client_info2_t)

svn_client_info_receiver2_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_client_info2_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7396

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7452
if _libs["svn_client-1"].has("svn_client_info4", "cdecl"):
    svn_client_info4 = _libs["svn_client-1"].get("svn_client_info4", "cdecl")
    svn_client_info4.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_info_receiver2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_info4.restype = POINTER(svn_error_t)
    svn_client_info4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7473
if _libs["svn_client-1"].has("svn_client_info3", "cdecl"):
    svn_client_info3 = _libs["svn_client-1"].get("svn_client_info3", "cdecl")
    svn_client_info3.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_client_info_receiver2_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_info3.restype = POINTER(svn_error_t)
    svn_client_info3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7493
if _libs["svn_client-1"].has("svn_client_info2", "cdecl"):
    svn_client_info2 = _libs["svn_client-1"].get("svn_client_info2", "cdecl")
    svn_client_info2.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_info_receiver_t, POINTER(None), svn_depth_t, POINTER(apr_array_header_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_info2.restype = POINTER(svn_error_t)
    svn_client_info2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7512
if _libs["svn_client-1"].has("svn_client_info", "cdecl"):
    svn_client_info = _libs["svn_client-1"].get("svn_client_info", "cdecl")
    svn_client_info.argtypes = [String, POINTER(svn_opt_revision_t), POINTER(svn_opt_revision_t), svn_info_receiver_t, POINTER(None), svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_info.restype = POINTER(svn_error_t)
    svn_client_info.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7528
if _libs["svn_client-1"].has("svn_client_get_wc_root", "cdecl"):
    svn_client_get_wc_root = _libs["svn_client-1"].get("svn_client_get_wc_root", "cdecl")
    svn_client_get_wc_root.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_get_wc_root.restype = POINTER(svn_error_t)
    svn_client_get_wc_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7546
if _libs["svn_client-1"].has("svn_client_min_max_revisions", "cdecl"):
    svn_client_min_max_revisions = _libs["svn_client-1"].get("svn_client_min_max_revisions", "cdecl")
    svn_client_min_max_revisions.argtypes = [POINTER(svn_revnum_t), POINTER(svn_revnum_t), String, svn_boolean_t, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_min_max_revisions.restype = POINTER(svn_error_t)
    svn_client_min_max_revisions.errcheck = _svn_errcheck

svn_client_patch_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_boolean_t), String, String, String, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7590

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7639
if _libs["svn_client-1"].has("svn_client_patch", "cdecl"):
    svn_client_patch = _libs["svn_client-1"].get("svn_client_patch", "cdecl")
    svn_client_patch.argtypes = [String, String, svn_boolean_t, c_int, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_client_patch_func_t, POINTER(None), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_patch.restype = POINTER(svn_error_t)
    svn_client_patch.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7680
if _libs["svn_client-1"].has("svn_client_url_from_path2", "cdecl"):
    svn_client_url_from_path2 = _libs["svn_client-1"].get("svn_client_url_from_path2", "cdecl")
    svn_client_url_from_path2.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_url_from_path2.restype = POINTER(svn_error_t)
    svn_client_url_from_path2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7693
if _libs["svn_client-1"].has("svn_client_url_from_path", "cdecl"):
    svn_client_url_from_path = _libs["svn_client-1"].get("svn_client_url_from_path", "cdecl")
    svn_client_url_from_path.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_client_url_from_path.restype = POINTER(svn_error_t)
    svn_client_url_from_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7716
if _libs["svn_client-1"].has("svn_client_get_repos_root", "cdecl"):
    svn_client_get_repos_root = _libs["svn_client-1"].get("svn_client_get_repos_root", "cdecl")
    svn_client_get_repos_root.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_get_repos_root.restype = POINTER(svn_error_t)
    svn_client_get_repos_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7734
if _libs["svn_client-1"].has("svn_client_root_url_from_path", "cdecl"):
    svn_client_root_url_from_path = _libs["svn_client-1"].get("svn_client_root_url_from_path", "cdecl")
    svn_client_root_url_from_path.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_root_url_from_path.restype = POINTER(svn_error_t)
    svn_client_root_url_from_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7751
if _libs["svn_client-1"].has("svn_client_uuid_from_url", "cdecl"):
    svn_client_uuid_from_url = _libs["svn_client-1"].get("svn_client_uuid_from_url", "cdecl")
    svn_client_uuid_from_url.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_uuid_from_url.restype = POINTER(svn_error_t)
    svn_client_uuid_from_url.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7769
if _libs["svn_client-1"].has("svn_client_uuid_from_path2", "cdecl"):
    svn_client_uuid_from_path2 = _libs["svn_client-1"].get("svn_client_uuid_from_path2", "cdecl")
    svn_client_uuid_from_path2.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_uuid_from_path2.restype = POINTER(svn_error_t)
    svn_client_uuid_from_path2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7782
if _libs["svn_client-1"].has("svn_client_uuid_from_path", "cdecl"):
    svn_client_uuid_from_path = _libs["svn_client-1"].get("svn_client_uuid_from_path", "cdecl")
    svn_client_uuid_from_path.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_wc_adm_access_t), POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_uuid_from_path.restype = POINTER(svn_error_t)
    svn_client_uuid_from_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7804
if _libs["svn_client-1"].has("svn_client_open_ra_session2", "cdecl"):
    svn_client_open_ra_session2 = _libs["svn_client-1"].get("svn_client_open_ra_session2", "cdecl")
    svn_client_open_ra_session2.argtypes = [POINTER(POINTER(svn_ra_session_t)), String, String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_client_open_ra_session2.restype = POINTER(svn_error_t)
    svn_client_open_ra_session2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7820
if _libs["svn_client-1"].has("svn_client_open_ra_session", "cdecl"):
    svn_client_open_ra_session = _libs["svn_client-1"].get("svn_client_open_ra_session", "cdecl")
    svn_client_open_ra_session.argtypes = [POINTER(POINTER(svn_ra_session_t)), String, POINTER(svn_client_ctx_t), POINTER(apr_pool_t)]
    svn_client_open_ra_session.restype = POINTER(svn_error_t)
    svn_client_open_ra_session.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 60
if _libs["svn_subr-1"].has("svn_cmdline_init", "cdecl"):
    svn_cmdline_init = _libs["svn_subr-1"].get("svn_cmdline_init", "cdecl")
    svn_cmdline_init.argtypes = [String, POINTER(FILE)]
    svn_cmdline_init.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 67
if _libs["svn_subr-1"].has("svn_cmdline_cstring_from_utf8", "cdecl"):
    svn_cmdline_cstring_from_utf8 = _libs["svn_subr-1"].get("svn_cmdline_cstring_from_utf8", "cdecl")
    svn_cmdline_cstring_from_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_cmdline_cstring_from_utf8.restype = POINTER(svn_error_t)
    svn_cmdline_cstring_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 74
if _libs["svn_subr-1"].has("svn_cmdline_cstring_from_utf8_fuzzy", "cdecl"):
    svn_cmdline_cstring_from_utf8_fuzzy = _libs["svn_subr-1"].get("svn_cmdline_cstring_from_utf8_fuzzy", "cdecl")
    svn_cmdline_cstring_from_utf8_fuzzy.argtypes = [String, POINTER(apr_pool_t)]
    svn_cmdline_cstring_from_utf8_fuzzy.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 81
if _libs["svn_subr-1"].has("svn_cmdline_cstring_to_utf8", "cdecl"):
    svn_cmdline_cstring_to_utf8 = _libs["svn_subr-1"].get("svn_cmdline_cstring_to_utf8", "cdecl")
    svn_cmdline_cstring_to_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_cmdline_cstring_to_utf8.restype = POINTER(svn_error_t)
    svn_cmdline_cstring_to_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 89
if _libs["svn_subr-1"].has("svn_cmdline_path_local_style_from_utf8", "cdecl"):
    svn_cmdline_path_local_style_from_utf8 = _libs["svn_subr-1"].get("svn_cmdline_path_local_style_from_utf8", "cdecl")
    svn_cmdline_path_local_style_from_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_cmdline_path_local_style_from_utf8.restype = POINTER(svn_error_t)
    svn_cmdline_path_local_style_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 101
if _libs["svn_subr-1"].has("svn_cmdline_printf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_cmdline_printf", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    svn_cmdline_printf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 114
if _libs["svn_subr-1"].has("svn_cmdline_fprintf", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_cmdline_fprintf", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(FILE), POINTER(apr_pool_t), String]
    svn_cmdline_fprintf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 126
if _libs["svn_subr-1"].has("svn_cmdline_fputs", "cdecl"):
    svn_cmdline_fputs = _libs["svn_subr-1"].get("svn_cmdline_fputs", "cdecl")
    svn_cmdline_fputs.argtypes = [String, POINTER(FILE), POINTER(apr_pool_t)]
    svn_cmdline_fputs.restype = POINTER(svn_error_t)
    svn_cmdline_fputs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 137
if _libs["svn_subr-1"].has("svn_cmdline_fflush", "cdecl"):
    svn_cmdline_fflush = _libs["svn_subr-1"].get("svn_cmdline_fflush", "cdecl")
    svn_cmdline_fflush.argtypes = [POINTER(FILE)]
    svn_cmdline_fflush.restype = POINTER(svn_error_t)
    svn_cmdline_fflush.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 146
if _libs["svn_subr-1"].has("svn_cmdline_output_encoding", "cdecl"):
    svn_cmdline_output_encoding = _libs["svn_subr-1"].get("svn_cmdline_output_encoding", "cdecl")
    svn_cmdline_output_encoding.argtypes = [POINTER(apr_pool_t)]
    svn_cmdline_output_encoding.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 158
if _libs["svn_subr-1"].has("svn_cmdline_handle_exit_error", "cdecl"):
    svn_cmdline_handle_exit_error = _libs["svn_subr-1"].get("svn_cmdline_handle_exit_error", "cdecl")
    svn_cmdline_handle_exit_error.argtypes = [POINTER(svn_error_t), POINTER(apr_pool_t), String]
    svn_cmdline_handle_exit_error.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 172
class struct_svn_cmdline_prompt_baton2_t(Structure):
    pass

struct_svn_cmdline_prompt_baton2_t.__slots__ = [
    'cancel_func',
    'cancel_baton',
    'config_dir',
]
struct_svn_cmdline_prompt_baton2_t._fields_ = [
    ('cancel_func', svn_cancel_func_t),
    ('cancel_baton', POINTER(None)),
    ('config_dir', String),
]

svn_cmdline_prompt_baton2_t = struct_svn_cmdline_prompt_baton2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 172

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 183
class struct_svn_cmdline_prompt_baton_t(Structure):
    pass

struct_svn_cmdline_prompt_baton_t.__slots__ = [
    'cancel_func',
    'cancel_baton',
]
struct_svn_cmdline_prompt_baton_t._fields_ = [
    ('cancel_func', svn_cancel_func_t),
    ('cancel_baton', POINTER(None)),
]

svn_cmdline_prompt_baton_t = struct_svn_cmdline_prompt_baton_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 183

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 191
if _libs["svn_subr-1"].has("svn_cmdline_prompt_user2", "cdecl"):
    svn_cmdline_prompt_user2 = _libs["svn_subr-1"].get("svn_cmdline_prompt_user2", "cdecl")
    svn_cmdline_prompt_user2.argtypes = [POINTER(POINTER(c_char)), String, POINTER(svn_cmdline_prompt_baton_t), POINTER(apr_pool_t)]
    svn_cmdline_prompt_user2.restype = POINTER(svn_error_t)
    svn_cmdline_prompt_user2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 203
if _libs["svn_subr-1"].has("svn_cmdline_prompt_user", "cdecl"):
    svn_cmdline_prompt_user = _libs["svn_subr-1"].get("svn_cmdline_prompt_user", "cdecl")
    svn_cmdline_prompt_user.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_cmdline_prompt_user.restype = POINTER(svn_error_t)
    svn_cmdline_prompt_user.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 215
if _libs["svn_subr-1"].has("svn_cmdline_auth_simple_prompt", "cdecl"):
    svn_cmdline_auth_simple_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_simple_prompt", "cdecl")
    svn_cmdline_auth_simple_prompt.argtypes = [POINTER(POINTER(svn_auth_cred_simple_t)), POINTER(None), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cmdline_auth_simple_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_simple_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 231
if _libs["svn_subr-1"].has("svn_cmdline_auth_username_prompt", "cdecl"):
    svn_cmdline_auth_username_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_username_prompt", "cdecl")
    svn_cmdline_auth_username_prompt.argtypes = [POINTER(POINTER(svn_auth_cred_username_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cmdline_auth_username_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_username_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 246
if _libs["svn_subr-1"].has("svn_cmdline_auth_ssl_server_trust_prompt", "cdecl"):
    svn_cmdline_auth_ssl_server_trust_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_ssl_server_trust_prompt", "cdecl")
    svn_cmdline_auth_ssl_server_trust_prompt.argtypes = [POINTER(POINTER(svn_auth_cred_ssl_server_trust_t)), POINTER(None), String, apr_uint32_t, POINTER(svn_auth_ssl_server_cert_info_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_cmdline_auth_ssl_server_trust_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_ssl_server_trust_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 267
if _libs["svn_subr-1"].has("svn_cmdline_auth_ssl_client_cert_prompt", "cdecl"):
    svn_cmdline_auth_ssl_client_cert_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_ssl_client_cert_prompt", "cdecl")
    svn_cmdline_auth_ssl_client_cert_prompt.argtypes = [POINTER(POINTER(svn_auth_cred_ssl_client_cert_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cmdline_auth_ssl_client_cert_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_ssl_client_cert_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 283
if _libs["svn_subr-1"].has("svn_cmdline_auth_ssl_client_cert_pw_prompt", "cdecl"):
    svn_cmdline_auth_ssl_client_cert_pw_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_ssl_client_cert_pw_prompt", "cdecl")
    svn_cmdline_auth_ssl_client_cert_pw_prompt.argtypes = [POINTER(POINTER(svn_auth_cred_ssl_client_cert_pw_t)), POINTER(None), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_cmdline_auth_ssl_client_cert_pw_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_ssl_client_cert_pw_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 298
if _libs["svn_subr-1"].has("svn_cmdline_auth_plaintext_prompt", "cdecl"):
    svn_cmdline_auth_plaintext_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_plaintext_prompt", "cdecl")
    svn_cmdline_auth_plaintext_prompt.argtypes = [POINTER(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t)]
    svn_cmdline_auth_plaintext_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_plaintext_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 311
if _libs["svn_subr-1"].has("svn_cmdline_auth_plaintext_passphrase_prompt", "cdecl"):
    svn_cmdline_auth_plaintext_passphrase_prompt = _libs["svn_subr-1"].get("svn_cmdline_auth_plaintext_passphrase_prompt", "cdecl")
    svn_cmdline_auth_plaintext_passphrase_prompt.argtypes = [POINTER(svn_boolean_t), String, POINTER(None), POINTER(apr_pool_t)]
    svn_cmdline_auth_plaintext_passphrase_prompt.restype = POINTER(svn_error_t)
    svn_cmdline_auth_plaintext_passphrase_prompt.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 354
if _libs["svn_subr-1"].has("svn_cmdline_create_auth_baton2", "cdecl"):
    svn_cmdline_create_auth_baton2 = _libs["svn_subr-1"].get("svn_cmdline_create_auth_baton2", "cdecl")
    svn_cmdline_create_auth_baton2.argtypes = [POINTER(POINTER(svn_auth_baton_t)), svn_boolean_t, String, String, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_config_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_cmdline_create_auth_baton2.restype = POINTER(svn_error_t)
    svn_cmdline_create_auth_baton2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 378
if _libs["svn_subr-1"].has("svn_cmdline_create_auth_baton", "cdecl"):
    svn_cmdline_create_auth_baton = _libs["svn_subr-1"].get("svn_cmdline_create_auth_baton", "cdecl")
    svn_cmdline_create_auth_baton.argtypes = [POINTER(POINTER(svn_auth_baton_t)), svn_boolean_t, String, String, String, svn_boolean_t, svn_boolean_t, POINTER(svn_config_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_cmdline_create_auth_baton.restype = POINTER(svn_error_t)
    svn_cmdline_create_auth_baton.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 404
if _libs["svn_subr-1"].has("svn_cmdline_setup_auth_baton", "cdecl"):
    svn_cmdline_setup_auth_baton = _libs["svn_subr-1"].get("svn_cmdline_setup_auth_baton", "cdecl")
    svn_cmdline_setup_auth_baton.argtypes = [POINTER(POINTER(svn_auth_baton_t)), svn_boolean_t, String, String, String, svn_boolean_t, POINTER(svn_config_t), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_cmdline_setup_auth_baton.restype = POINTER(svn_error_t)
    svn_cmdline_setup_auth_baton.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 51
if _libs["svn_subr-1"].has("svn_compat_wrap_commit_callback", "cdecl"):
    svn_compat_wrap_commit_callback = _libs["svn_subr-1"].get("svn_compat_wrap_commit_callback", "cdecl")
    svn_compat_wrap_commit_callback.argtypes = [POINTER(svn_commit_callback2_t), POINTER(POINTER(None)), svn_commit_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_compat_wrap_commit_callback.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 64
if _libs["svn_subr-1"].has("svn_compat_log_revprops_clear", "cdecl"):
    svn_compat_log_revprops_clear = _libs["svn_subr-1"].get("svn_compat_log_revprops_clear", "cdecl")
    svn_compat_log_revprops_clear.argtypes = [POINTER(apr_hash_t)]
    svn_compat_log_revprops_clear.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 71
if _libs["svn_subr-1"].has("svn_compat_log_revprops_in", "cdecl"):
    svn_compat_log_revprops_in = _libs["svn_subr-1"].get("svn_compat_log_revprops_in", "cdecl")
    svn_compat_log_revprops_in.argtypes = [POINTER(apr_pool_t)]
    svn_compat_log_revprops_in.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 82
if _libs["svn_subr-1"].has("svn_compat_log_revprops_out_string", "cdecl"):
    svn_compat_log_revprops_out_string = _libs["svn_subr-1"].get("svn_compat_log_revprops_out_string", "cdecl")
    svn_compat_log_revprops_out_string.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(POINTER(svn_string_t)), POINTER(POINTER(svn_string_t)), POINTER(apr_hash_t)]
    svn_compat_log_revprops_out_string.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 93
if _libs["svn_subr-1"].has("svn_compat_log_revprops_out", "cdecl"):
    svn_compat_log_revprops_out = _libs["svn_subr-1"].get("svn_compat_log_revprops_out", "cdecl")
    svn_compat_log_revprops_out.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_hash_t)]
    svn_compat_log_revprops_out.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_compat.h: 106
if _libs["svn_subr-1"].has("svn_compat_wrap_log_receiver", "cdecl"):
    svn_compat_wrap_log_receiver = _libs["svn_subr-1"].get("svn_compat_wrap_log_receiver", "cdecl")
    svn_compat_wrap_log_receiver.argtypes = [POINTER(svn_log_entry_receiver_t), POINTER(POINTER(None)), svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_compat_wrap_log_receiver.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 41
try:
    svn_ctype_table = (POINTER(apr_uint32_t)).in_dll(_libs["svn_subr-1"], "svn_ctype_table")
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 186
if _libs["svn_subr-1"].has("svn_ctype_casecmp", "cdecl"):
    svn_ctype_casecmp = _libs["svn_subr-1"].get("svn_ctype_casecmp", "cdecl")
    svn_ctype_casecmp.argtypes = [c_int, c_int]
    svn_ctype_casecmp.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 161
if _libs["svn_subr-1"].has("svn_dirent_internal_style", "cdecl"):
    svn_dirent_internal_style = _libs["svn_subr-1"].get("svn_dirent_internal_style", "cdecl")
    svn_dirent_internal_style.argtypes = [String, POINTER(apr_pool_t)]
    svn_dirent_internal_style.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 183
if _libs["svn_subr-1"].has("svn_dirent_internal_style_safe", "cdecl"):
    svn_dirent_internal_style_safe = _libs["svn_subr-1"].get("svn_dirent_internal_style_safe", "cdecl")
    svn_dirent_internal_style_safe.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_dirent_internal_style_safe.restype = POINTER(svn_error_t)
    svn_dirent_internal_style_safe.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 198
if _libs["svn_subr-1"].has("svn_dirent_local_style", "cdecl"):
    svn_dirent_local_style = _libs["svn_subr-1"].get("svn_dirent_local_style", "cdecl")
    svn_dirent_local_style.argtypes = [String, POINTER(apr_pool_t)]
    svn_dirent_local_style.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 219
if _libs["svn_subr-1"].has("svn_dirent_join", "cdecl"):
    svn_dirent_join = _libs["svn_subr-1"].get("svn_dirent_join", "cdecl")
    svn_dirent_join.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_dirent_join.restype = ReturnString
    else:
        svn_dirent_join.restype = String
        svn_dirent_join.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 238
if _libs["svn_subr-1"].has("svn_dirent_join_many", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_dirent_join_many", "cdecl")
    _restype = String
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    svn_dirent_join_many = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 254
if _libs["svn_subr-1"].has("svn_relpath_join", "cdecl"):
    svn_relpath_join = _libs["svn_subr-1"].get("svn_relpath_join", "cdecl")
    svn_relpath_join.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_relpath_join.restype = ReturnString
    else:
        svn_relpath_join.restype = String
        svn_relpath_join.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 272
if _libs["svn_subr-1"].has("svn_dirent_basename", "cdecl"):
    svn_dirent_basename = _libs["svn_subr-1"].get("svn_dirent_basename", "cdecl")
    svn_dirent_basename.argtypes = [String, POINTER(apr_pool_t)]
    svn_dirent_basename.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 286
if _libs["svn_subr-1"].has("svn_dirent_dirname", "cdecl"):
    svn_dirent_dirname = _libs["svn_subr-1"].get("svn_dirent_dirname", "cdecl")
    svn_dirent_dirname.argtypes = [String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_dirent_dirname.restype = ReturnString
    else:
        svn_dirent_dirname.restype = String
        svn_dirent_dirname.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 316
if _libs["svn_subr-1"].has("svn_dirent_split", "cdecl"):
    svn_dirent_split = _libs["svn_subr-1"].get("svn_dirent_split", "cdecl")
    svn_dirent_split.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_dirent_split.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 341
if _libs["svn_subr-1"].has("svn_relpath_split", "cdecl"):
    svn_relpath_split = _libs["svn_subr-1"].get("svn_relpath_split", "cdecl")
    svn_relpath_split.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_relpath_split.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 360
if _libs["svn_subr-1"].has("svn_relpath_basename", "cdecl"):
    svn_relpath_basename = _libs["svn_subr-1"].get("svn_relpath_basename", "cdecl")
    svn_relpath_basename.argtypes = [String, POINTER(apr_pool_t)]
    svn_relpath_basename.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 373
if _libs["svn_subr-1"].has("svn_relpath_dirname", "cdecl"):
    svn_relpath_dirname = _libs["svn_subr-1"].get("svn_relpath_dirname", "cdecl")
    svn_relpath_dirname.argtypes = [String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_relpath_dirname.restype = ReturnString
    else:
        svn_relpath_dirname.restype = String
        svn_relpath_dirname.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 385
if _libs["svn_subr-1"].has("svn_relpath_prefix", "cdecl"):
    svn_relpath_prefix = _libs["svn_subr-1"].get("svn_relpath_prefix", "cdecl")
    svn_relpath_prefix.argtypes = [String, c_int, POINTER(apr_pool_t)]
    svn_relpath_prefix.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 410
if _libs["svn_subr-1"].has("svn_uri_split", "cdecl"):
    svn_uri_split = _libs["svn_subr-1"].get("svn_uri_split", "cdecl")
    svn_uri_split.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_uri_split.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 426
if _libs["svn_subr-1"].has("svn_uri_basename", "cdecl"):
    svn_uri_basename = _libs["svn_subr-1"].get("svn_uri_basename", "cdecl")
    svn_uri_basename.argtypes = [String, POINTER(apr_pool_t)]
    svn_uri_basename.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 440
if _libs["svn_subr-1"].has("svn_uri_dirname", "cdecl"):
    svn_uri_dirname = _libs["svn_subr-1"].get("svn_uri_dirname", "cdecl")
    svn_uri_dirname.argtypes = [String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_uri_dirname.restype = ReturnString
    else:
        svn_uri_dirname.restype = String
        svn_uri_dirname.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 451
if _libs["svn_subr-1"].has("svn_dirent_is_absolute", "cdecl"):
    svn_dirent_is_absolute = _libs["svn_subr-1"].get("svn_dirent_is_absolute", "cdecl")
    svn_dirent_is_absolute.argtypes = [String]
    svn_dirent_is_absolute.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 465
if _libs["svn_subr-1"].has("svn_dirent_is_root", "cdecl"):
    svn_dirent_is_root = _libs["svn_subr-1"].get("svn_dirent_is_root", "cdecl")
    svn_dirent_is_root.argtypes = [String, apr_size_t]
    svn_dirent_is_root.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 473
if _libs["svn_subr-1"].has("svn_uri_is_root", "cdecl"):
    svn_uri_is_root = _libs["svn_subr-1"].get("svn_uri_is_root", "cdecl")
    svn_uri_is_root.argtypes = [String, apr_size_t]
    svn_uri_is_root.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 497
if _libs["svn_subr-1"].has("svn_dirent_canonicalize", "cdecl"):
    svn_dirent_canonicalize = _libs["svn_subr-1"].get("svn_dirent_canonicalize", "cdecl")
    svn_dirent_canonicalize.argtypes = [String, POINTER(apr_pool_t)]
    svn_dirent_canonicalize.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 518
if _libs["svn_subr-1"].has("svn_dirent_canonicalize_safe", "cdecl"):
    svn_dirent_canonicalize_safe = _libs["svn_subr-1"].get("svn_dirent_canonicalize_safe", "cdecl")
    svn_dirent_canonicalize_safe.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_dirent_canonicalize_safe.restype = POINTER(svn_error_t)
    svn_dirent_canonicalize_safe.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 545
if _libs["svn_subr-1"].has("svn_relpath_canonicalize", "cdecl"):
    svn_relpath_canonicalize = _libs["svn_subr-1"].get("svn_relpath_canonicalize", "cdecl")
    svn_relpath_canonicalize.argtypes = [String, POINTER(apr_pool_t)]
    svn_relpath_canonicalize.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 567
if _libs["svn_subr-1"].has("svn_relpath_canonicalize_safe", "cdecl"):
    svn_relpath_canonicalize_safe = _libs["svn_subr-1"].get("svn_relpath_canonicalize_safe", "cdecl")
    svn_relpath_canonicalize_safe.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_relpath_canonicalize_safe.restype = POINTER(svn_error_t)
    svn_relpath_canonicalize_safe.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 599
if _libs["svn_subr-1"].has("svn_uri_canonicalize", "cdecl"):
    svn_uri_canonicalize = _libs["svn_subr-1"].get("svn_uri_canonicalize", "cdecl")
    svn_uri_canonicalize.argtypes = [String, POINTER(apr_pool_t)]
    svn_uri_canonicalize.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 620
if _libs["svn_subr-1"].has("svn_uri_canonicalize_safe", "cdecl"):
    svn_uri_canonicalize_safe = _libs["svn_subr-1"].get("svn_uri_canonicalize_safe", "cdecl")
    svn_uri_canonicalize_safe.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_uri_canonicalize_safe.restype = POINTER(svn_error_t)
    svn_uri_canonicalize_safe.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 640
if _libs["svn_subr-1"].has("svn_dirent_is_canonical", "cdecl"):
    svn_dirent_is_canonical = _libs["svn_subr-1"].get("svn_dirent_is_canonical", "cdecl")
    svn_dirent_is_canonical.argtypes = [String, POINTER(apr_pool_t)]
    svn_dirent_is_canonical.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 649
if _libs["svn_subr-1"].has("svn_relpath_is_canonical", "cdecl"):
    svn_relpath_is_canonical = _libs["svn_subr-1"].get("svn_relpath_is_canonical", "cdecl")
    svn_relpath_is_canonical.argtypes = [String]
    svn_relpath_is_canonical.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 659
if _libs["svn_subr-1"].has("svn_uri_is_canonical", "cdecl"):
    svn_uri_is_canonical = _libs["svn_subr-1"].get("svn_uri_is_canonical", "cdecl")
    svn_uri_is_canonical.argtypes = [String, POINTER(apr_pool_t)]
    svn_uri_is_canonical.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 670
if _libs["svn_subr-1"].has("svn_dirent_get_longest_ancestor", "cdecl"):
    svn_dirent_get_longest_ancestor = _libs["svn_subr-1"].get("svn_dirent_get_longest_ancestor", "cdecl")
    svn_dirent_get_longest_ancestor.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_dirent_get_longest_ancestor.restype = ReturnString
    else:
        svn_dirent_get_longest_ancestor.restype = String
        svn_dirent_get_longest_ancestor.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 683
if _libs["svn_subr-1"].has("svn_relpath_get_longest_ancestor", "cdecl"):
    svn_relpath_get_longest_ancestor = _libs["svn_subr-1"].get("svn_relpath_get_longest_ancestor", "cdecl")
    svn_relpath_get_longest_ancestor.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_relpath_get_longest_ancestor.restype = ReturnString
    else:
        svn_relpath_get_longest_ancestor.restype = String
        svn_relpath_get_longest_ancestor.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 700
if _libs["svn_subr-1"].has("svn_uri_get_longest_ancestor", "cdecl"):
    svn_uri_get_longest_ancestor = _libs["svn_subr-1"].get("svn_uri_get_longest_ancestor", "cdecl")
    svn_uri_get_longest_ancestor.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_uri_get_longest_ancestor.restype = ReturnString
    else:
        svn_uri_get_longest_ancestor.restype = String
        svn_uri_get_longest_ancestor.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 713
if _libs["svn_subr-1"].has("svn_dirent_get_absolute", "cdecl"):
    svn_dirent_get_absolute = _libs["svn_subr-1"].get("svn_dirent_get_absolute", "cdecl")
    svn_dirent_get_absolute.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_dirent_get_absolute.restype = POINTER(svn_error_t)
    svn_dirent_get_absolute.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 730
if _libs["svn_subr-1"].has("svn_dirent_is_child", "cdecl"):
    svn_dirent_is_child = _libs["svn_subr-1"].get("svn_dirent_is_child", "cdecl")
    svn_dirent_is_child.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_dirent_is_child.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 744
if _libs["svn_subr-1"].has("svn_dirent_is_ancestor", "cdecl"):
    svn_dirent_is_ancestor = _libs["svn_subr-1"].get("svn_dirent_is_ancestor", "cdecl")
    svn_dirent_is_ancestor.argtypes = [String, String]
    svn_dirent_is_ancestor.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 751
if _libs["svn_subr-1"].has("svn_uri__is_ancestor", "cdecl"):
    svn_uri__is_ancestor = _libs["svn_subr-1"].get("svn_uri__is_ancestor", "cdecl")
    svn_uri__is_ancestor.argtypes = [String, String]
    svn_uri__is_ancestor.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 765
if _libs["svn_subr-1"].has("svn_dirent_skip_ancestor", "cdecl"):
    svn_dirent_skip_ancestor = _libs["svn_subr-1"].get("svn_dirent_skip_ancestor", "cdecl")
    svn_dirent_skip_ancestor.argtypes = [String, String]
    svn_dirent_skip_ancestor.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 776
if _libs["svn_subr-1"].has("svn_relpath_skip_ancestor", "cdecl"):
    svn_relpath_skip_ancestor = _libs["svn_subr-1"].get("svn_relpath_skip_ancestor", "cdecl")
    svn_relpath_skip_ancestor.argtypes = [String, String]
    svn_relpath_skip_ancestor.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 788
if _libs["svn_subr-1"].has("svn_uri_skip_ancestor", "cdecl"):
    svn_uri_skip_ancestor = _libs["svn_subr-1"].get("svn_uri_skip_ancestor", "cdecl")
    svn_uri_skip_ancestor.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_uri_skip_ancestor.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 826
if _libs["svn_subr-1"].has("svn_dirent_condense_targets", "cdecl"):
    svn_dirent_condense_targets = _libs["svn_subr-1"].get("svn_dirent_condense_targets", "cdecl")
    svn_dirent_condense_targets.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_dirent_condense_targets.restype = POINTER(svn_error_t)
    svn_dirent_condense_targets.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 867
if _libs["svn_subr-1"].has("svn_uri_condense_targets", "cdecl"):
    svn_uri_condense_targets = _libs["svn_subr-1"].get("svn_uri_condense_targets", "cdecl")
    svn_uri_condense_targets.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_uri_condense_targets.restype = POINTER(svn_error_t)
    svn_uri_condense_targets.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 892
if _libs["svn_subr-1"].has("svn_dirent_is_under_root", "cdecl"):
    svn_dirent_is_under_root = _libs["svn_subr-1"].get("svn_dirent_is_under_root", "cdecl")
    svn_dirent_is_under_root.argtypes = [POINTER(svn_boolean_t), POINTER(POINTER(c_char)), String, String, POINTER(apr_pool_t)]
    svn_dirent_is_under_root.restype = POINTER(svn_error_t)
    svn_dirent_is_under_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 906
if _libs["svn_subr-1"].has("svn_uri_get_dirent_from_file_url", "cdecl"):
    svn_uri_get_dirent_from_file_url = _libs["svn_subr-1"].get("svn_uri_get_dirent_from_file_url", "cdecl")
    svn_uri_get_dirent_from_file_url.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_uri_get_dirent_from_file_url.restype = POINTER(svn_error_t)
    svn_uri_get_dirent_from_file_url.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dirent_uri.h: 918
if _libs["svn_subr-1"].has("svn_uri_get_file_url_from_dirent", "cdecl"):
    svn_uri_get_file_url_from_dirent = _libs["svn_subr-1"].get("svn_uri_get_file_url_from_dirent", "cdecl")
    svn_uri_get_file_url_from_dirent.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_uri_get_file_url_from_dirent.restype = POINTER(svn_error_t)
    svn_uri_get_file_url_from_dirent.errcheck = _svn_errcheck

# /usr/include/apr/apr_dso.h: 44
class struct_apr_dso_handle_t(Structure):
    pass

apr_dso_handle_t = struct_apr_dso_handle_t# /usr/include/apr/apr_dso.h: 44

apr_dso_handle_sym_t = POINTER(None)# /usr/include/apr/apr_dso.h: 49

# /usr/include/apr/apr_dso.h: 59
if _libs["apr-1"].has("apr_dso_load", "cdecl"):
    apr_dso_load = _libs["apr-1"].get("apr_dso_load", "cdecl")
    apr_dso_load.argtypes = [POINTER(POINTER(apr_dso_handle_t)), String, POINTER(apr_pool_t)]
    apr_dso_load.restype = apr_status_t

# /usr/include/apr/apr_dso.h: 66
if _libs["apr-1"].has("apr_dso_unload", "cdecl"):
    apr_dso_unload = _libs["apr-1"].get("apr_dso_unload", "cdecl")
    apr_dso_unload.argtypes = [POINTER(apr_dso_handle_t)]
    apr_dso_unload.restype = apr_status_t

# /usr/include/apr/apr_dso.h: 74
if _libs["apr-1"].has("apr_dso_sym", "cdecl"):
    apr_dso_sym = _libs["apr-1"].get("apr_dso_sym", "cdecl")
    apr_dso_sym.argtypes = [POINTER(apr_dso_handle_sym_t), POINTER(apr_dso_handle_t), String]
    apr_dso_sym.restype = apr_status_t

# /usr/include/apr/apr_dso.h: 84
if _libs["apr-1"].has("apr_dso_error", "cdecl"):
    apr_dso_error = _libs["apr-1"].get("apr_dso_error", "cdecl")
    apr_dso_error.argtypes = [POINTER(apr_dso_handle_t), String, apr_size_t]
    apr_dso_error.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dso.h: 58
if _libs["svn_subr-1"].has("svn_dso_initialize2", "cdecl"):
    svn_dso_initialize2 = _libs["svn_subr-1"].get("svn_dso_initialize2", "cdecl")
    svn_dso_initialize2.argtypes = []
    svn_dso_initialize2.restype = POINTER(svn_error_t)
    svn_dso_initialize2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dso.h: 70
if _libs["svn_subr-1"].has("svn_dso_initialize", "cdecl"):
    svn_dso_initialize = _libs["svn_subr-1"].get("svn_dso_initialize", "cdecl")
    svn_dso_initialize.argtypes = []
    svn_dso_initialize.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dso.h: 88
if _libs["svn_subr-1"].has("svn_dso_load", "cdecl"):
    svn_dso_load = _libs["svn_subr-1"].get("svn_dso_load", "cdecl")
    svn_dso_load.argtypes = [POINTER(POINTER(apr_dso_handle_t)), String]
    svn_dso_load.restype = POINTER(svn_error_t)
    svn_dso_load.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 54
if _libs["svn_fs-1"].has("svn_fs_version", "cdecl"):
    svn_fs_version = _libs["svn_fs-1"].get("svn_fs_version", "cdecl")
    svn_fs_version.argtypes = []
    svn_fs_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 66
class struct_svn_fs_t(Structure):
    pass

svn_fs_t = struct_svn_fs_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 66

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 255
if _libs["svn_fs-1"].has("svn_fs_initialize", "cdecl"):
    svn_fs_initialize = _libs["svn_fs-1"].get("svn_fs_initialize", "cdecl")
    svn_fs_initialize.argtypes = [POINTER(apr_pool_t)]
    svn_fs_initialize.restype = POINTER(svn_error_t)
    svn_fs_initialize.errcheck = _svn_errcheck

svn_fs_warning_callback_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(svn_error_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 266

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 279
if _libs["svn_fs-1"].has("svn_fs_set_warning_func", "cdecl"):
    svn_fs_set_warning_func = _libs["svn_fs-1"].get("svn_fs_set_warning_func", "cdecl")
    svn_fs_set_warning_func.argtypes = [POINTER(svn_fs_t), svn_fs_warning_callback_t, POINTER(None)]
    svn_fs_set_warning_func.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 316
if _libs["svn_fs-1"].has("svn_fs_create2", "cdecl"):
    svn_fs_create2 = _libs["svn_fs-1"].get("svn_fs_create2", "cdecl")
    svn_fs_create2.argtypes = [POINTER(POINTER(svn_fs_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_create2.restype = POINTER(svn_error_t)
    svn_fs_create2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 330
if _libs["svn_fs-1"].has("svn_fs_create", "cdecl"):
    svn_fs_create = _libs["svn_fs-1"].get("svn_fs_create", "cdecl")
    svn_fs_create.argtypes = [POINTER(POINTER(svn_fs_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_fs_create.restype = POINTER(svn_error_t)
    svn_fs_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 358
if _libs["svn_fs-1"].has("svn_fs_open2", "cdecl"):
    svn_fs_open2 = _libs["svn_fs-1"].get("svn_fs_open2", "cdecl")
    svn_fs_open2.argtypes = [POINTER(POINTER(svn_fs_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_open2.restype = POINTER(svn_error_t)
    svn_fs_open2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 372
if _libs["svn_fs-1"].has("svn_fs_open", "cdecl"):
    svn_fs_open = _libs["svn_fs-1"].get("svn_fs_open", "cdecl")
    svn_fs_open.argtypes = [POINTER(POINTER(svn_fs_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_fs_open.restype = POINTER(svn_error_t)
    svn_fs_open.errcheck = _svn_errcheck

enum_svn_fs_upgrade_notify_action_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 395

svn_fs_upgrade_pack_revprops = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 395

svn_fs_upgrade_cleanup_revprops = (svn_fs_upgrade_pack_revprops + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 395

svn_fs_upgrade_format_bumped = (svn_fs_upgrade_cleanup_revprops + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 395

svn_fs_upgrade_notify_action_t = enum_svn_fs_upgrade_notify_action_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 395

svn_fs_upgrade_notify_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_uint64_t, svn_fs_upgrade_notify_action_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 405

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 432
if _libs["svn_fs-1"].has("svn_fs_upgrade2", "cdecl"):
    svn_fs_upgrade2 = _libs["svn_fs-1"].get("svn_fs_upgrade2", "cdecl")
    svn_fs_upgrade2.argtypes = [String, svn_fs_upgrade_notify_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_upgrade2.restype = POINTER(svn_error_t)
    svn_fs_upgrade2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 448
if _libs["svn_fs-1"].has("svn_fs_upgrade", "cdecl"):
    svn_fs_upgrade = _libs["svn_fs-1"].get("svn_fs_upgrade", "cdecl")
    svn_fs_upgrade.argtypes = [String, POINTER(apr_pool_t)]
    svn_fs_upgrade.restype = POINTER(svn_error_t)
    svn_fs_upgrade.errcheck = _svn_errcheck

svn_fs_progress_notify_func_t = CFUNCTYPE(UNCHECKED(None), svn_revnum_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 461

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 480
if _libs["svn_fs-1"].has("svn_fs_type", "cdecl"):
    svn_fs_type = _libs["svn_fs-1"].get("svn_fs_type", "cdecl")
    svn_fs_type.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_fs_type.restype = POINTER(svn_error_t)
    svn_fs_type.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 492
if _libs["svn_fs-1"].has("svn_fs_path", "cdecl"):
    svn_fs_path = _libs["svn_fs-1"].get("svn_fs_path", "cdecl")
    svn_fs_path.argtypes = [POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_path.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 506
if _libs["svn_fs-1"].has("svn_fs_config", "cdecl"):
    svn_fs_config = _libs["svn_fs-1"].get("svn_fs_config", "cdecl")
    svn_fs_config.argtypes = [POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_config.restype = POINTER(apr_hash_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 519
if _libs["svn_fs-1"].has("svn_fs_delete_fs", "cdecl"):
    svn_fs_delete_fs = _libs["svn_fs-1"].get("svn_fs_delete_fs", "cdecl")
    svn_fs_delete_fs.argtypes = [String, POINTER(apr_pool_t)]
    svn_fs_delete_fs.restype = POINTER(svn_error_t)
    svn_fs_delete_fs.errcheck = _svn_errcheck

svn_fs_hotcopy_notify_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), svn_revnum_t, svn_revnum_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 529

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 560
if _libs["svn_fs-1"].has("svn_fs_hotcopy3", "cdecl"):
    svn_fs_hotcopy3 = _libs["svn_fs-1"].get("svn_fs_hotcopy3", "cdecl")
    svn_fs_hotcopy3.argtypes = [String, String, svn_boolean_t, svn_boolean_t, svn_fs_hotcopy_notify_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_hotcopy3.restype = POINTER(svn_error_t)
    svn_fs_hotcopy3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 579
if _libs["svn_fs-1"].has("svn_fs_hotcopy2", "cdecl"):
    svn_fs_hotcopy2 = _libs["svn_fs-1"].get("svn_fs_hotcopy2", "cdecl")
    svn_fs_hotcopy2.argtypes = [String, String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_hotcopy2.restype = POINTER(svn_error_t)
    svn_fs_hotcopy2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 596
if _libs["svn_fs-1"].has("svn_fs_hotcopy", "cdecl"):
    svn_fs_hotcopy = _libs["svn_fs-1"].get("svn_fs_hotcopy", "cdecl")
    svn_fs_hotcopy.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_hotcopy.restype = POINTER(svn_error_t)
    svn_fs_hotcopy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 637
if _libs["svn_fs-1"].has("svn_fs_recover", "cdecl"):
    svn_fs_recover = _libs["svn_fs-1"].get("svn_fs_recover", "cdecl")
    svn_fs_recover.argtypes = [String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_recover.restype = POINTER(svn_error_t)
    svn_fs_recover.errcheck = _svn_errcheck

svn_fs_freeze_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 649

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 668
if _libs["svn_fs-1"].has("svn_fs_freeze", "cdecl"):
    svn_fs_freeze = _libs["svn_fs-1"].get("svn_fs_freeze", "cdecl")
    svn_fs_freeze.argtypes = [POINTER(svn_fs_t), svn_fs_freeze_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_freeze.restype = POINTER(svn_error_t)
    svn_fs_freeze.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 710
if _libs["svn_fs-1"].has("svn_fs_set_berkeley_errcall", "cdecl"):
    svn_fs_set_berkeley_errcall = _libs["svn_fs-1"].get("svn_fs_set_berkeley_errcall", "cdecl")
    svn_fs_set_berkeley_errcall.argtypes = [POINTER(svn_fs_t), CFUNCTYPE(UNCHECKED(None), String, String)]
    svn_fs_set_berkeley_errcall.restype = POINTER(svn_error_t)
    svn_fs_set_berkeley_errcall.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 728
if _libs["svn_fs-1"].has("svn_fs_berkeley_logfiles", "cdecl"):
    svn_fs_berkeley_logfiles = _libs["svn_fs-1"].get("svn_fs_berkeley_logfiles", "cdecl")
    svn_fs_berkeley_logfiles.argtypes = [POINTER(POINTER(apr_array_header_t)), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_berkeley_logfiles.restype = POINTER(svn_error_t)
    svn_fs_berkeley_logfiles.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 749
if _libs["svn_fs-1"].has("svn_fs_new", "cdecl"):
    svn_fs_new = _libs["svn_fs-1"].get("svn_fs_new", "cdecl")
    svn_fs_new.argtypes = [POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_fs_new.restype = POINTER(svn_fs_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 755
if _libs["svn_fs-1"].has("svn_fs_create_berkeley", "cdecl"):
    svn_fs_create_berkeley = _libs["svn_fs-1"].get("svn_fs_create_berkeley", "cdecl")
    svn_fs_create_berkeley.argtypes = [POINTER(svn_fs_t), String]
    svn_fs_create_berkeley.restype = POINTER(svn_error_t)
    svn_fs_create_berkeley.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 761
if _libs["svn_fs-1"].has("svn_fs_open_berkeley", "cdecl"):
    svn_fs_open_berkeley = _libs["svn_fs-1"].get("svn_fs_open_berkeley", "cdecl")
    svn_fs_open_berkeley.argtypes = [POINTER(svn_fs_t), String]
    svn_fs_open_berkeley.restype = POINTER(svn_error_t)
    svn_fs_open_berkeley.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 767
if _libs["svn_fs-1"].has("svn_fs_berkeley_path", "cdecl"):
    svn_fs_berkeley_path = _libs["svn_fs-1"].get("svn_fs_berkeley_path", "cdecl")
    svn_fs_berkeley_path.argtypes = [POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_berkeley_path.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 773
if _libs["svn_fs-1"].has("svn_fs_delete_berkeley", "cdecl"):
    svn_fs_delete_berkeley = _libs["svn_fs-1"].get("svn_fs_delete_berkeley", "cdecl")
    svn_fs_delete_berkeley.argtypes = [String, POINTER(apr_pool_t)]
    svn_fs_delete_berkeley.restype = POINTER(svn_error_t)
    svn_fs_delete_berkeley.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 779
if _libs["svn_fs-1"].has("svn_fs_hotcopy_berkeley", "cdecl"):
    svn_fs_hotcopy_berkeley = _libs["svn_fs-1"].get("svn_fs_hotcopy_berkeley", "cdecl")
    svn_fs_hotcopy_berkeley.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_hotcopy_berkeley.restype = POINTER(svn_error_t)
    svn_fs_hotcopy_berkeley.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 787
if _libs["svn_fs-1"].has("svn_fs_berkeley_recover", "cdecl"):
    svn_fs_berkeley_recover = _libs["svn_fs-1"].get("svn_fs_berkeley_recover", "cdecl")
    svn_fs_berkeley_recover.argtypes = [String, POINTER(apr_pool_t)]
    svn_fs_berkeley_recover.restype = POINTER(svn_error_t)
    svn_fs_berkeley_recover.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 813
class struct_svn_fs_access_t(Structure):
    pass

svn_fs_access_t = struct_svn_fs_access_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 813

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 822
if _libs["svn_fs-1"].has("svn_fs_create_access", "cdecl"):
    svn_fs_create_access = _libs["svn_fs-1"].get("svn_fs_create_access", "cdecl")
    svn_fs_create_access.argtypes = [POINTER(POINTER(svn_fs_access_t)), String, POINTER(apr_pool_t)]
    svn_fs_create_access.restype = POINTER(svn_error_t)
    svn_fs_create_access.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 836
if _libs["svn_fs-1"].has("svn_fs_set_access", "cdecl"):
    svn_fs_set_access = _libs["svn_fs-1"].get("svn_fs_set_access", "cdecl")
    svn_fs_set_access.argtypes = [POINTER(svn_fs_t), POINTER(svn_fs_access_t)]
    svn_fs_set_access.restype = POINTER(svn_error_t)
    svn_fs_set_access.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 844
if _libs["svn_fs-1"].has("svn_fs_get_access", "cdecl"):
    svn_fs_get_access = _libs["svn_fs-1"].get("svn_fs_get_access", "cdecl")
    svn_fs_get_access.argtypes = [POINTER(POINTER(svn_fs_access_t)), POINTER(svn_fs_t)]
    svn_fs_get_access.restype = POINTER(svn_error_t)
    svn_fs_get_access.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 852
if _libs["svn_fs-1"].has("svn_fs_access_get_username", "cdecl"):
    svn_fs_access_get_username = _libs["svn_fs-1"].get("svn_fs_access_get_username", "cdecl")
    svn_fs_access_get_username.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_fs_access_t)]
    svn_fs_access_get_username.restype = POINTER(svn_error_t)
    svn_fs_access_get_username.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 864
if _libs["svn_fs-1"].has("svn_fs_access_add_lock_token2", "cdecl"):
    svn_fs_access_add_lock_token2 = _libs["svn_fs-1"].get("svn_fs_access_add_lock_token2", "cdecl")
    svn_fs_access_add_lock_token2.argtypes = [POINTER(svn_fs_access_t), String, String]
    svn_fs_access_add_lock_token2.restype = POINTER(svn_error_t)
    svn_fs_access_add_lock_token2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 875
if _libs["svn_fs-1"].has("svn_fs_access_add_lock_token", "cdecl"):
    svn_fs_access_add_lock_token = _libs["svn_fs-1"].get("svn_fs_access_add_lock_token", "cdecl")
    svn_fs_access_add_lock_token.argtypes = [POINTER(svn_fs_access_t), String]
    svn_fs_access_add_lock_token.restype = POINTER(svn_error_t)
    svn_fs_access_add_lock_token.errcheck = _svn_errcheck

enum_svn_fs_node_relation_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 963

svn_fs_node_unrelated = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 963

svn_fs_node_unchanged = (svn_fs_node_unrelated + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 963

svn_fs_node_common_ancestor = (svn_fs_node_unchanged + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 963

svn_fs_node_relation_t = enum_svn_fs_node_relation_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 963

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 966
class struct_svn_fs_id_t(Structure):
    pass

svn_fs_id_t = struct_svn_fs_id_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 966

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 977
if _libs["svn_fs-1"].has("svn_fs_compare_ids", "cdecl"):
    svn_fs_compare_ids = _libs["svn_fs-1"].get("svn_fs_compare_ids", "cdecl")
    svn_fs_compare_ids.argtypes = [POINTER(svn_fs_id_t), POINTER(svn_fs_id_t)]
    svn_fs_compare_ids.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 990
if _libs["svn_fs-1"].has("svn_fs_check_related", "cdecl"):
    svn_fs_check_related = _libs["svn_fs-1"].get("svn_fs_check_related", "cdecl")
    svn_fs_check_related.argtypes = [POINTER(svn_fs_id_t), POINTER(svn_fs_id_t)]
    svn_fs_check_related.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1002
if _libs["svn_fs-1"].has("svn_fs_parse_id", "cdecl"):
    svn_fs_parse_id = _libs["svn_fs-1"].get("svn_fs_parse_id", "cdecl")
    svn_fs_parse_id.argtypes = [String, apr_size_t, POINTER(apr_pool_t)]
    svn_fs_parse_id.restype = POINTER(svn_fs_id_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1012
if _libs["svn_fs-1"].has("svn_fs_unparse_id", "cdecl"):
    svn_fs_unparse_id = _libs["svn_fs-1"].get("svn_fs_unparse_id", "cdecl")
    svn_fs_unparse_id.argtypes = [POINTER(svn_fs_id_t), POINTER(apr_pool_t)]
    svn_fs_unparse_id.restype = POINTER(svn_string_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1111
class struct_svn_fs_txn_t(Structure):
    pass

svn_fs_txn_t = struct_svn_fs_txn_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1111

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1159
if _libs["svn_fs-1"].has("svn_fs_begin_txn2", "cdecl"):
    svn_fs_begin_txn2 = _libs["svn_fs-1"].get("svn_fs_begin_txn2", "cdecl")
    svn_fs_begin_txn2.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_fs_t), svn_revnum_t, apr_uint32_t, POINTER(apr_pool_t)]
    svn_fs_begin_txn2.restype = POINTER(svn_error_t)
    svn_fs_begin_txn2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1173
if _libs["svn_fs-1"].has("svn_fs_begin_txn", "cdecl"):
    svn_fs_begin_txn = _libs["svn_fs-1"].get("svn_fs_begin_txn", "cdecl")
    svn_fs_begin_txn.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_fs_t), svn_revnum_t, POINTER(apr_pool_t)]
    svn_fs_begin_txn.restype = POINTER(svn_error_t)
    svn_fs_begin_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1242
if _libs["svn_fs-1"].has("svn_fs_commit_txn", "cdecl"):
    svn_fs_commit_txn = _libs["svn_fs-1"].get("svn_fs_commit_txn", "cdecl")
    svn_fs_commit_txn.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_fs_commit_txn.restype = POINTER(svn_error_t)
    svn_fs_commit_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1259
if _libs["svn_fs-1"].has("svn_fs_abort_txn", "cdecl"):
    svn_fs_abort_txn = _libs["svn_fs-1"].get("svn_fs_abort_txn", "cdecl")
    svn_fs_abort_txn.argtypes = [POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_fs_abort_txn.restype = POINTER(svn_error_t)
    svn_fs_abort_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1270
if _libs["svn_fs-1"].has("svn_fs_purge_txn", "cdecl"):
    svn_fs_purge_txn = _libs["svn_fs-1"].get("svn_fs_purge_txn", "cdecl")
    svn_fs_purge_txn.argtypes = [POINTER(svn_fs_t), String, POINTER(apr_pool_t)]
    svn_fs_purge_txn.restype = POINTER(svn_error_t)
    svn_fs_purge_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1279
if _libs["svn_fs-1"].has("svn_fs_txn_name", "cdecl"):
    svn_fs_txn_name = _libs["svn_fs-1"].get("svn_fs_txn_name", "cdecl")
    svn_fs_txn_name.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_fs_txn_name.restype = POINTER(svn_error_t)
    svn_fs_txn_name.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1286
if _libs["svn_fs-1"].has("svn_fs_txn_base_revision", "cdecl"):
    svn_fs_txn_base_revision = _libs["svn_fs-1"].get("svn_fs_txn_base_revision", "cdecl")
    svn_fs_txn_base_revision.argtypes = [POINTER(svn_fs_txn_t)]
    svn_fs_txn_base_revision.restype = svn_revnum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1299
if _libs["svn_fs-1"].has("svn_fs_open_txn", "cdecl"):
    svn_fs_open_txn = _libs["svn_fs-1"].get("svn_fs_open_txn", "cdecl")
    svn_fs_open_txn.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_fs_t), String, POINTER(apr_pool_t)]
    svn_fs_open_txn.restype = POINTER(svn_error_t)
    svn_fs_open_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1310
if _libs["svn_fs-1"].has("svn_fs_list_transactions", "cdecl"):
    svn_fs_list_transactions = _libs["svn_fs-1"].get("svn_fs_list_transactions", "cdecl")
    svn_fs_list_transactions.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_list_transactions.restype = POINTER(svn_error_t)
    svn_fs_list_transactions.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1321
if _libs["svn_fs-1"].has("svn_fs_txn_prop", "cdecl"):
    svn_fs_txn_prop = _libs["svn_fs-1"].get("svn_fs_txn_prop", "cdecl")
    svn_fs_txn_prop.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_fs_txn_t), String, POINTER(apr_pool_t)]
    svn_fs_txn_prop.restype = POINTER(svn_error_t)
    svn_fs_txn_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1332
if _libs["svn_fs-1"].has("svn_fs_txn_proplist", "cdecl"):
    svn_fs_txn_proplist = _libs["svn_fs-1"].get("svn_fs_txn_proplist", "cdecl")
    svn_fs_txn_proplist.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_fs_txn_proplist.restype = POINTER(svn_error_t)
    svn_fs_txn_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1343
if _libs["svn_fs-1"].has("svn_fs_change_txn_prop", "cdecl"):
    svn_fs_change_txn_prop = _libs["svn_fs-1"].get("svn_fs_change_txn_prop", "cdecl")
    svn_fs_change_txn_prop.argtypes = [POINTER(svn_fs_txn_t), String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_fs_change_txn_prop.restype = POINTER(svn_error_t)
    svn_fs_change_txn_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1360
if _libs["svn_fs-1"].has("svn_fs_change_txn_props", "cdecl"):
    svn_fs_change_txn_props = _libs["svn_fs-1"].get("svn_fs_change_txn_props", "cdecl")
    svn_fs_change_txn_props.argtypes = [POINTER(svn_fs_txn_t), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_fs_change_txn_props.restype = POINTER(svn_error_t)
    svn_fs_change_txn_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1380
class struct_svn_fs_root_t(Structure):
    pass

svn_fs_root_t = struct_svn_fs_root_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1380

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1387
if _libs["svn_fs-1"].has("svn_fs_revision_root", "cdecl"):
    svn_fs_revision_root = _libs["svn_fs-1"].get("svn_fs_revision_root", "cdecl")
    svn_fs_revision_root.argtypes = [POINTER(POINTER(svn_fs_root_t)), POINTER(svn_fs_t), svn_revnum_t, POINTER(apr_pool_t)]
    svn_fs_revision_root.restype = POINTER(svn_error_t)
    svn_fs_revision_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1398
if _libs["svn_fs-1"].has("svn_fs_txn_root", "cdecl"):
    svn_fs_txn_root = _libs["svn_fs-1"].get("svn_fs_txn_root", "cdecl")
    svn_fs_txn_root.argtypes = [POINTER(POINTER(svn_fs_root_t)), POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_fs_txn_root.restype = POINTER(svn_error_t)
    svn_fs_txn_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1410
if _libs["svn_fs-1"].has("svn_fs_close_root", "cdecl"):
    svn_fs_close_root = _libs["svn_fs-1"].get("svn_fs_close_root", "cdecl")
    svn_fs_close_root.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_close_root.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1414
if _libs["svn_fs-1"].has("svn_fs_root_fs", "cdecl"):
    svn_fs_root_fs = _libs["svn_fs-1"].get("svn_fs_root_fs", "cdecl")
    svn_fs_root_fs.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_root_fs.restype = POINTER(svn_fs_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1420
if _libs["svn_fs-1"].has("svn_fs_is_txn_root", "cdecl"):
    svn_fs_is_txn_root = _libs["svn_fs-1"].get("svn_fs_is_txn_root", "cdecl")
    svn_fs_is_txn_root.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_is_txn_root.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1424
if _libs["svn_fs-1"].has("svn_fs_is_revision_root", "cdecl"):
    svn_fs_is_revision_root = _libs["svn_fs-1"].get("svn_fs_is_revision_root", "cdecl")
    svn_fs_is_revision_root.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_is_revision_root.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1430
if _libs["svn_fs-1"].has("svn_fs_txn_root_name", "cdecl"):
    svn_fs_txn_root_name = _libs["svn_fs-1"].get("svn_fs_txn_root_name", "cdecl")
    svn_fs_txn_root_name.argtypes = [POINTER(svn_fs_root_t), POINTER(apr_pool_t)]
    svn_fs_txn_root_name.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1441
if _libs["svn_fs-1"].has("svn_fs_txn_root_base_revision", "cdecl"):
    svn_fs_txn_root_base_revision = _libs["svn_fs-1"].get("svn_fs_txn_root_base_revision", "cdecl")
    svn_fs_txn_root_base_revision.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_txn_root_base_revision.restype = svn_revnum_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1447
if _libs["svn_fs-1"].has("svn_fs_revision_root_revision", "cdecl"):
    svn_fs_revision_root_revision = _libs["svn_fs-1"].get("svn_fs_revision_root_revision", "cdecl")
    svn_fs_revision_root_revision.argtypes = [POINTER(svn_fs_root_t)]
    svn_fs_revision_root_revision.restype = svn_revnum_t

enum_svn_fs_path_change_kind_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_modify = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_add = (svn_fs_path_change_modify + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_delete = (svn_fs_path_change_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_replace = (svn_fs_path_change_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_reset = (svn_fs_path_change_replace + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

svn_fs_path_change_kind_t = enum_svn_fs_path_change_kind_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1497

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1560
class struct_svn_fs_path_change3_t(Structure):
    pass

struct_svn_fs_path_change3_t.__slots__ = [
    'path',
    'change_kind',
    'node_kind',
    'text_mod',
    'prop_mod',
    'mergeinfo_mod',
    'copyfrom_known',
    'copyfrom_rev',
    'copyfrom_path',
]
struct_svn_fs_path_change3_t._fields_ = [
    ('path', svn_string_t),
    ('change_kind', svn_fs_path_change_kind_t),
    ('node_kind', svn_node_kind_t),
    ('text_mod', svn_boolean_t),
    ('prop_mod', svn_boolean_t),
    ('mergeinfo_mod', svn_tristate_t),
    ('copyfrom_known', svn_boolean_t),
    ('copyfrom_rev', svn_revnum_t),
    ('copyfrom_path', String),
]

svn_fs_path_change3_t = struct_svn_fs_path_change3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1560

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1627
class struct_svn_fs_path_change2_t(Structure):
    pass

struct_svn_fs_path_change2_t.__slots__ = [
    'node_rev_id',
    'change_kind',
    'text_mod',
    'prop_mod',
    'node_kind',
    'copyfrom_known',
    'copyfrom_rev',
    'copyfrom_path',
    'mergeinfo_mod',
]
struct_svn_fs_path_change2_t._fields_ = [
    ('node_rev_id', POINTER(svn_fs_id_t)),
    ('change_kind', svn_fs_path_change_kind_t),
    ('text_mod', svn_boolean_t),
    ('prop_mod', svn_boolean_t),
    ('node_kind', svn_node_kind_t),
    ('copyfrom_known', svn_boolean_t),
    ('copyfrom_rev', svn_revnum_t),
    ('copyfrom_path', String),
    ('mergeinfo_mod', svn_tristate_t),
]

svn_fs_path_change2_t = struct_svn_fs_path_change2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1627

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1650
class struct_svn_fs_path_change_t(Structure):
    pass

struct_svn_fs_path_change_t.__slots__ = [
    'node_rev_id',
    'change_kind',
    'text_mod',
    'prop_mod',
]
struct_svn_fs_path_change_t._fields_ = [
    ('node_rev_id', POINTER(svn_fs_id_t)),
    ('change_kind', svn_fs_path_change_kind_t),
    ('text_mod', svn_boolean_t),
    ('prop_mod', svn_boolean_t),
]

svn_fs_path_change_t = struct_svn_fs_path_change_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1650

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1662
if _libs["svn_fs-1"].has("svn_fs_path_change2_create", "cdecl"):
    svn_fs_path_change2_create = _libs["svn_fs-1"].get("svn_fs_path_change2_create", "cdecl")
    svn_fs_path_change2_create.argtypes = [POINTER(svn_fs_id_t), svn_fs_path_change_kind_t, POINTER(apr_pool_t)]
    svn_fs_path_change2_create.restype = POINTER(svn_fs_path_change2_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1676
if _libs["svn_fs-1"].has("svn_fs_path_change3_create", "cdecl"):
    svn_fs_path_change3_create = _libs["svn_fs-1"].get("svn_fs_path_change3_create", "cdecl")
    svn_fs_path_change3_create.argtypes = [svn_fs_path_change_kind_t, POINTER(apr_pool_t)]
    svn_fs_path_change3_create.restype = POINTER(svn_fs_path_change3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1685
if _libs["svn_fs-1"].has("svn_fs_path_change3_dup", "cdecl"):
    svn_fs_path_change3_dup = _libs["svn_fs-1"].get("svn_fs_path_change3_dup", "cdecl")
    svn_fs_path_change3_dup.argtypes = [POINTER(svn_fs_path_change3_t), POINTER(apr_pool_t)]
    svn_fs_path_change3_dup.restype = POINTER(svn_fs_path_change3_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1694
class struct_svn_fs_path_change_iterator_t(Structure):
    pass

svn_fs_path_change_iterator_t = struct_svn_fs_path_change_iterator_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1694

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1709
if _libs["svn_fs-1"].has("svn_fs_path_change_get", "cdecl"):
    svn_fs_path_change_get = _libs["svn_fs-1"].get("svn_fs_path_change_get", "cdecl")
    svn_fs_path_change_get.argtypes = [POINTER(POINTER(svn_fs_path_change3_t)), POINTER(svn_fs_path_change_iterator_t)]
    svn_fs_path_change_get.restype = POINTER(svn_error_t)
    svn_fs_path_change_get.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1732
if _libs["svn_fs-1"].has("svn_fs_paths_changed3", "cdecl"):
    svn_fs_paths_changed3 = _libs["svn_fs-1"].get("svn_fs_paths_changed3", "cdecl")
    svn_fs_paths_changed3.argtypes = [POINTER(POINTER(svn_fs_path_change_iterator_t)), POINTER(svn_fs_root_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_paths_changed3.restype = POINTER(svn_error_t)
    svn_fs_paths_changed3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1755
if _libs["svn_fs-1"].has("svn_fs_paths_changed2", "cdecl"):
    svn_fs_paths_changed2 = _libs["svn_fs-1"].get("svn_fs_paths_changed2", "cdecl")
    svn_fs_paths_changed2.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_root_t), POINTER(apr_pool_t)]
    svn_fs_paths_changed2.restype = POINTER(svn_error_t)
    svn_fs_paths_changed2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1767
if _libs["svn_fs-1"].has("svn_fs_paths_changed", "cdecl"):
    svn_fs_paths_changed = _libs["svn_fs-1"].get("svn_fs_paths_changed", "cdecl")
    svn_fs_paths_changed.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_root_t), POINTER(apr_pool_t)]
    svn_fs_paths_changed.restype = POINTER(svn_error_t)
    svn_fs_paths_changed.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1781
if _libs["svn_fs-1"].has("svn_fs_check_path", "cdecl"):
    svn_fs_check_path = _libs["svn_fs-1"].get("svn_fs_check_path", "cdecl")
    svn_fs_check_path.argtypes = [POINTER(svn_node_kind_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_check_path.restype = POINTER(svn_error_t)
    svn_fs_check_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1789
class struct_svn_fs_history_t(Structure):
    pass

svn_fs_history_t = struct_svn_fs_history_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1789

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1799
if _libs["svn_fs-1"].has("svn_fs_node_history2", "cdecl"):
    svn_fs_node_history2 = _libs["svn_fs-1"].get("svn_fs_node_history2", "cdecl")
    svn_fs_node_history2.argtypes = [POINTER(POINTER(svn_fs_history_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_node_history2.restype = POINTER(svn_error_t)
    svn_fs_node_history2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1812
if _libs["svn_fs-1"].has("svn_fs_node_history", "cdecl"):
    svn_fs_node_history = _libs["svn_fs-1"].get("svn_fs_node_history", "cdecl")
    svn_fs_node_history.argtypes = [POINTER(POINTER(svn_fs_history_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_history.restype = POINTER(svn_error_t)
    svn_fs_node_history.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1850
if _libs["svn_fs-1"].has("svn_fs_history_prev2", "cdecl"):
    svn_fs_history_prev2 = _libs["svn_fs-1"].get("svn_fs_history_prev2", "cdecl")
    svn_fs_history_prev2.argtypes = [POINTER(POINTER(svn_fs_history_t)), POINTER(svn_fs_history_t), svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_history_prev2.restype = POINTER(svn_error_t)
    svn_fs_history_prev2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1863
if _libs["svn_fs-1"].has("svn_fs_history_prev", "cdecl"):
    svn_fs_history_prev = _libs["svn_fs-1"].get("svn_fs_history_prev", "cdecl")
    svn_fs_history_prev.argtypes = [POINTER(POINTER(svn_fs_history_t)), POINTER(svn_fs_history_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_history_prev.restype = POINTER(svn_error_t)
    svn_fs_history_prev.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1874
if _libs["svn_fs-1"].has("svn_fs_history_location", "cdecl"):
    svn_fs_history_location = _libs["svn_fs-1"].get("svn_fs_history_location", "cdecl")
    svn_fs_history_location.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_revnum_t), POINTER(svn_fs_history_t), POINTER(apr_pool_t)]
    svn_fs_history_location.restype = POINTER(svn_error_t)
    svn_fs_history_location.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1884
if _libs["svn_fs-1"].has("svn_fs_is_dir", "cdecl"):
    svn_fs_is_dir = _libs["svn_fs-1"].get("svn_fs_is_dir", "cdecl")
    svn_fs_is_dir.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_is_dir.restype = POINTER(svn_error_t)
    svn_fs_is_dir.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1894
if _libs["svn_fs-1"].has("svn_fs_is_file", "cdecl"):
    svn_fs_is_file = _libs["svn_fs-1"].get("svn_fs_is_file", "cdecl")
    svn_fs_is_file.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_is_file.restype = POINTER(svn_error_t)
    svn_fs_is_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1910
if _libs["svn_fs-1"].has("svn_fs_node_id", "cdecl"):
    svn_fs_node_id = _libs["svn_fs-1"].get("svn_fs_node_id", "cdecl")
    svn_fs_node_id.argtypes = [POINTER(POINTER(svn_fs_id_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_id.restype = POINTER(svn_error_t)
    svn_fs_node_id.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1927
if _libs["svn_fs-1"].has("svn_fs_node_relation", "cdecl"):
    svn_fs_node_relation = _libs["svn_fs-1"].get("svn_fs_node_relation", "cdecl")
    svn_fs_node_relation.argtypes = [POINTER(svn_fs_node_relation_t), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_relation.restype = POINTER(svn_error_t)
    svn_fs_node_relation.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1945
if _libs["svn_fs-1"].has("svn_fs_node_created_rev", "cdecl"):
    svn_fs_node_created_rev = _libs["svn_fs-1"].get("svn_fs_node_created_rev", "cdecl")
    svn_fs_node_created_rev.argtypes = [POINTER(svn_revnum_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_created_rev.restype = POINTER(svn_error_t)
    svn_fs_node_created_rev.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1960
if _libs["svn_fs-1"].has("svn_fs_node_origin_rev", "cdecl"):
    svn_fs_node_origin_rev = _libs["svn_fs-1"].get("svn_fs_node_origin_rev", "cdecl")
    svn_fs_node_origin_rev.argtypes = [POINTER(svn_revnum_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_origin_rev.restype = POINTER(svn_error_t)
    svn_fs_node_origin_rev.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1972
if _libs["svn_fs-1"].has("svn_fs_node_created_path", "cdecl"):
    svn_fs_node_created_path = _libs["svn_fs-1"].get("svn_fs_node_created_path", "cdecl")
    svn_fs_node_created_path.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_created_path.restype = POINTER(svn_error_t)
    svn_fs_node_created_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1983
if _libs["svn_fs-1"].has("svn_fs_node_prop", "cdecl"):
    svn_fs_node_prop = _libs["svn_fs-1"].get("svn_fs_node_prop", "cdecl")
    svn_fs_node_prop.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_fs_root_t), String, String, POINTER(apr_pool_t)]
    svn_fs_node_prop.restype = POINTER(svn_error_t)
    svn_fs_node_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1996
if _libs["svn_fs-1"].has("svn_fs_node_proplist", "cdecl"):
    svn_fs_node_proplist = _libs["svn_fs-1"].get("svn_fs_node_proplist", "cdecl")
    svn_fs_node_proplist.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_proplist.restype = POINTER(svn_error_t)
    svn_fs_node_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2008
if _libs["svn_fs-1"].has("svn_fs_node_has_props", "cdecl"):
    svn_fs_node_has_props = _libs["svn_fs-1"].get("svn_fs_node_has_props", "cdecl")
    svn_fs_node_has_props.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_node_has_props.restype = POINTER(svn_error_t)
    svn_fs_node_has_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2024
if _libs["svn_fs-1"].has("svn_fs_change_node_prop", "cdecl"):
    svn_fs_change_node_prop = _libs["svn_fs-1"].get("svn_fs_change_node_prop", "cdecl")
    svn_fs_change_node_prop.argtypes = [POINTER(svn_fs_root_t), String, String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_fs_change_node_prop.restype = POINTER(svn_error_t)
    svn_fs_change_node_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2051
if _libs["svn_fs-1"].has("svn_fs_props_different", "cdecl"):
    svn_fs_props_different = _libs["svn_fs-1"].get("svn_fs_props_different", "cdecl")
    svn_fs_props_different.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_props_different.restype = POINTER(svn_error_t)
    svn_fs_props_different.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2082
if _libs["svn_fs-1"].has("svn_fs_props_changed", "cdecl"):
    svn_fs_props_changed = _libs["svn_fs-1"].get("svn_fs_props_changed", "cdecl")
    svn_fs_props_changed.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_props_changed.restype = POINTER(svn_error_t)
    svn_fs_props_changed.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2135
if _libs["svn_fs-1"].has("svn_fs_copied_from", "cdecl"):
    svn_fs_copied_from = _libs["svn_fs-1"].get("svn_fs_copied_from", "cdecl")
    svn_fs_copied_from.argtypes = [POINTER(svn_revnum_t), POINTER(POINTER(c_char)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_copied_from.restype = POINTER(svn_error_t)
    svn_fs_copied_from.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2158
if _libs["svn_fs-1"].has("svn_fs_closest_copy", "cdecl"):
    svn_fs_closest_copy = _libs["svn_fs-1"].get("svn_fs_closest_copy", "cdecl")
    svn_fs_closest_copy.argtypes = [POINTER(POINTER(svn_fs_root_t)), POINTER(POINTER(c_char)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_closest_copy.restype = POINTER(svn_error_t)
    svn_fs_closest_copy.errcheck = _svn_errcheck

svn_fs_mergeinfo_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, svn_mergeinfo_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2172

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2212
if _libs["svn_fs-1"].has("svn_fs_get_mergeinfo3", "cdecl"):
    svn_fs_get_mergeinfo3 = _libs["svn_fs-1"].get("svn_fs_get_mergeinfo3", "cdecl")
    svn_fs_get_mergeinfo3.argtypes = [POINTER(svn_fs_root_t), POINTER(apr_array_header_t), svn_mergeinfo_inheritance_t, svn_boolean_t, svn_boolean_t, svn_fs_mergeinfo_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_get_mergeinfo3.restype = POINTER(svn_error_t)
    svn_fs_get_mergeinfo3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2231
if _libs["svn_fs-1"].has("svn_fs_get_mergeinfo2", "cdecl"):
    svn_fs_get_mergeinfo2 = _libs["svn_fs-1"].get("svn_fs_get_mergeinfo2", "cdecl")
    svn_fs_get_mergeinfo2.argtypes = [POINTER(svn_mergeinfo_catalog_t), POINTER(svn_fs_root_t), POINTER(apr_array_header_t), svn_mergeinfo_inheritance_t, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_get_mergeinfo2.restype = POINTER(svn_error_t)
    svn_fs_get_mergeinfo2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2248
if _libs["svn_fs-1"].has("svn_fs_get_mergeinfo", "cdecl"):
    svn_fs_get_mergeinfo = _libs["svn_fs-1"].get("svn_fs_get_mergeinfo", "cdecl")
    svn_fs_get_mergeinfo.argtypes = [POINTER(svn_mergeinfo_catalog_t), POINTER(svn_fs_root_t), POINTER(apr_array_header_t), svn_mergeinfo_inheritance_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_get_mergeinfo.restype = POINTER(svn_error_t)
    svn_fs_get_mergeinfo.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2283
if _libs["svn_fs-1"].has("svn_fs_merge", "cdecl"):
    svn_fs_merge = _libs["svn_fs-1"].get("svn_fs_merge", "cdecl")
    svn_fs_merge.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_merge.restype = POINTER(svn_error_t)
    svn_fs_merge.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2311
class struct_svn_fs_dirent_t(Structure):
    pass

struct_svn_fs_dirent_t.__slots__ = [
    'name',
    'id',
    'kind',
]
struct_svn_fs_dirent_t._fields_ = [
    ('name', String),
    ('id', POINTER(svn_fs_id_t)),
    ('kind', svn_node_kind_t),
]

svn_fs_dirent_t = struct_svn_fs_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2311

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2320
if _libs["svn_fs-1"].has("svn_fs_dir_entries", "cdecl"):
    svn_fs_dir_entries = _libs["svn_fs-1"].get("svn_fs_dir_entries", "cdecl")
    svn_fs_dir_entries.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_dir_entries.restype = POINTER(svn_error_t)
    svn_fs_dir_entries.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2335
if _libs["svn_fs-1"].has("svn_fs_dir_optimal_order", "cdecl"):
    svn_fs_dir_optimal_order = _libs["svn_fs-1"].get("svn_fs_dir_optimal_order", "cdecl")
    svn_fs_dir_optimal_order.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_fs_root_t), POINTER(apr_hash_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_dir_optimal_order.restype = POINTER(svn_error_t)
    svn_fs_dir_optimal_order.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2348
if _libs["svn_fs-1"].has("svn_fs_make_dir", "cdecl"):
    svn_fs_make_dir = _libs["svn_fs-1"].get("svn_fs_make_dir", "cdecl")
    svn_fs_make_dir.argtypes = [POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_make_dir.restype = POINTER(svn_error_t)
    svn_fs_make_dir.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2366
if _libs["svn_fs-1"].has("svn_fs_delete", "cdecl"):
    svn_fs_delete = _libs["svn_fs-1"].get("svn_fs_delete", "cdecl")
    svn_fs_delete.argtypes = [POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_delete.restype = POINTER(svn_error_t)
    svn_fs_delete.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2393
if _libs["svn_fs-1"].has("svn_fs_copy", "cdecl"):
    svn_fs_copy = _libs["svn_fs-1"].get("svn_fs_copy", "cdecl")
    svn_fs_copy.argtypes = [POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_copy.restype = POINTER(svn_error_t)
    svn_fs_copy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2409
if _libs["svn_fs-1"].has("svn_fs_revision_link", "cdecl"):
    svn_fs_revision_link = _libs["svn_fs-1"].get("svn_fs_revision_link", "cdecl")
    svn_fs_revision_link.argtypes = [POINTER(svn_fs_root_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_revision_link.restype = POINTER(svn_error_t)
    svn_fs_revision_link.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2421
if _libs["svn_fs-1"].has("svn_fs_file_length", "cdecl"):
    svn_fs_file_length = _libs["svn_fs-1"].get("svn_fs_file_length", "cdecl")
    svn_fs_file_length.argtypes = [POINTER(svn_filesize_t), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_file_length.restype = POINTER(svn_error_t)
    svn_fs_file_length.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2461
if _libs["svn_fs-1"].has("svn_fs_file_checksum", "cdecl"):
    svn_fs_file_checksum = _libs["svn_fs-1"].get("svn_fs_file_checksum", "cdecl")
    svn_fs_file_checksum.argtypes = [POINTER(POINTER(svn_checksum_t)), svn_checksum_kind_t, POINTER(svn_fs_root_t), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_file_checksum.restype = POINTER(svn_error_t)
    svn_fs_file_checksum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2477
if _libs["svn_fs-1"].has("svn_fs_file_md5_checksum", "cdecl"):
    svn_fs_file_md5_checksum = _libs["svn_fs-1"].get("svn_fs_file_md5_checksum", "cdecl")
    svn_fs_file_md5_checksum.argtypes = [POINTER(c_ubyte), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_file_md5_checksum.restype = POINTER(svn_error_t)
    svn_fs_file_md5_checksum.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2499
if _libs["svn_fs-1"].has("svn_fs_file_contents", "cdecl"):
    svn_fs_file_contents = _libs["svn_fs-1"].get("svn_fs_file_contents", "cdecl")
    svn_fs_file_contents.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_file_contents.restype = POINTER(svn_error_t)
    svn_fs_file_contents.errcheck = _svn_errcheck

svn_fs_process_contents_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(c_ubyte), apr_size_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2514

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2535
if _libs["svn_fs-1"].has("svn_fs_try_process_file_contents", "cdecl"):
    svn_fs_try_process_file_contents = _libs["svn_fs-1"].get("svn_fs_try_process_file_contents", "cdecl")
    svn_fs_try_process_file_contents.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, svn_fs_process_contents_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_try_process_file_contents.restype = POINTER(svn_error_t)
    svn_fs_try_process_file_contents.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2549
if _libs["svn_fs-1"].has("svn_fs_make_file", "cdecl"):
    svn_fs_make_file = _libs["svn_fs-1"].get("svn_fs_make_file", "cdecl")
    svn_fs_make_file.argtypes = [POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_make_file.restype = POINTER(svn_error_t)
    svn_fs_make_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2589
if _libs["svn_fs-1"].has("svn_fs_apply_textdelta", "cdecl"):
    svn_fs_apply_textdelta = _libs["svn_fs-1"].get("svn_fs_apply_textdelta", "cdecl")
    svn_fs_apply_textdelta.argtypes = [POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(svn_fs_root_t), String, String, String, POINTER(apr_pool_t)]
    svn_fs_apply_textdelta.restype = POINTER(svn_error_t)
    svn_fs_apply_textdelta.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2622
if _libs["svn_fs-1"].has("svn_fs_apply_text", "cdecl"):
    svn_fs_apply_text = _libs["svn_fs-1"].get("svn_fs_apply_text", "cdecl")
    svn_fs_apply_text.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(svn_fs_root_t), String, String, POINTER(apr_pool_t)]
    svn_fs_apply_text.restype = POINTER(svn_error_t)
    svn_fs_apply_text.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2650
if _libs["svn_fs-1"].has("svn_fs_contents_different", "cdecl"):
    svn_fs_contents_different = _libs["svn_fs-1"].get("svn_fs_contents_different", "cdecl")
    svn_fs_contents_different.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_contents_different.restype = POINTER(svn_error_t)
    svn_fs_contents_different.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2679
if _libs["svn_fs-1"].has("svn_fs_contents_changed", "cdecl"):
    svn_fs_contents_changed = _libs["svn_fs-1"].get("svn_fs_contents_changed", "cdecl")
    svn_fs_contents_changed.argtypes = [POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_contents_changed.restype = POINTER(svn_error_t)
    svn_fs_contents_changed.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2697
if _libs["svn_fs-1"].has("svn_fs_youngest_rev", "cdecl"):
    svn_fs_youngest_rev = _libs["svn_fs-1"].get("svn_fs_youngest_rev", "cdecl")
    svn_fs_youngest_rev.argtypes = [POINTER(svn_revnum_t), POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_youngest_rev.restype = POINTER(svn_error_t)
    svn_fs_youngest_rev.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2717
if _libs["svn_fs-1"].has("svn_fs_info_format", "cdecl"):
    svn_fs_info_format = _libs["svn_fs-1"].get("svn_fs_info_format", "cdecl")
    svn_fs_info_format.argtypes = [POINTER(c_int), POINTER(POINTER(svn_version_t)), POINTER(svn_fs_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_info_format.restype = POINTER(svn_error_t)
    svn_fs_info_format.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2730
if _libs["svn_fs-1"].has("svn_fs_info_config_files", "cdecl"):
    svn_fs_info_config_files = _libs["svn_fs-1"].get("svn_fs_info_config_files", "cdecl")
    svn_fs_info_config_files.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_fs_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_info_config_files.restype = POINTER(svn_error_t)
    svn_fs_info_config_files.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2746
if _libs["svn_fs-1"].has("svn_fs_deltify_revision", "cdecl"):
    svn_fs_deltify_revision = _libs["svn_fs-1"].get("svn_fs_deltify_revision", "cdecl")
    svn_fs_deltify_revision.argtypes = [POINTER(svn_fs_t), svn_revnum_t, POINTER(apr_pool_t)]
    svn_fs_deltify_revision.restype = POINTER(svn_error_t)
    svn_fs_deltify_revision.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2778
if _libs["svn_fs-1"].has("svn_fs_refresh_revision_props", "cdecl"):
    svn_fs_refresh_revision_props = _libs["svn_fs-1"].get("svn_fs_refresh_revision_props", "cdecl")
    svn_fs_refresh_revision_props.argtypes = [POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_refresh_revision_props.restype = POINTER(svn_error_t)
    svn_fs_refresh_revision_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2798
if _libs["svn_fs-1"].has("svn_fs_revision_prop2", "cdecl"):
    svn_fs_revision_prop2 = _libs["svn_fs-1"].get("svn_fs_revision_prop2", "cdecl")
    svn_fs_revision_prop2.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_fs_t), svn_revnum_t, String, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_revision_prop2.restype = POINTER(svn_error_t)
    svn_fs_revision_prop2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2815
if _libs["svn_fs-1"].has("svn_fs_revision_prop", "cdecl"):
    svn_fs_revision_prop = _libs["svn_fs-1"].get("svn_fs_revision_prop", "cdecl")
    svn_fs_revision_prop.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_fs_t), svn_revnum_t, String, POINTER(apr_pool_t)]
    svn_fs_revision_prop.restype = POINTER(svn_error_t)
    svn_fs_revision_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2839
if _libs["svn_fs-1"].has("svn_fs_revision_proplist2", "cdecl"):
    svn_fs_revision_proplist2 = _libs["svn_fs-1"].get("svn_fs_revision_proplist2", "cdecl")
    svn_fs_revision_proplist2.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_t), svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_revision_proplist2.restype = POINTER(svn_error_t)
    svn_fs_revision_proplist2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2855
if _libs["svn_fs-1"].has("svn_fs_revision_proplist", "cdecl"):
    svn_fs_revision_proplist = _libs["svn_fs-1"].get("svn_fs_revision_proplist", "cdecl")
    svn_fs_revision_proplist.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_fs_t), svn_revnum_t, POINTER(apr_pool_t)]
    svn_fs_revision_proplist.restype = POINTER(svn_error_t)
    svn_fs_revision_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2882
if _libs["svn_fs-1"].has("svn_fs_change_rev_prop2", "cdecl"):
    svn_fs_change_rev_prop2 = _libs["svn_fs-1"].get("svn_fs_change_rev_prop2", "cdecl")
    svn_fs_change_rev_prop2.argtypes = [POINTER(svn_fs_t), svn_revnum_t, String, POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_fs_change_rev_prop2.restype = POINTER(svn_error_t)
    svn_fs_change_rev_prop2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2898
if _libs["svn_fs-1"].has("svn_fs_change_rev_prop", "cdecl"):
    svn_fs_change_rev_prop = _libs["svn_fs-1"].get("svn_fs_change_rev_prop", "cdecl")
    svn_fs_change_rev_prop.argtypes = [POINTER(svn_fs_t), svn_revnum_t, String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_fs_change_rev_prop.restype = POINTER(svn_error_t)
    svn_fs_change_rev_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2919
if _libs["svn_fs-1"].has("svn_fs_get_file_delta_stream", "cdecl"):
    svn_fs_get_file_delta_stream = _libs["svn_fs-1"].get("svn_fs_get_file_delta_stream", "cdecl")
    svn_fs_get_file_delta_stream.argtypes = [POINTER(POINTER(svn_txdelta_stream_t)), POINTER(svn_fs_root_t), String, POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_fs_get_file_delta_stream.restype = POINTER(svn_error_t)
    svn_fs_get_file_delta_stream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2933
if _libs["svn_fs-1"].has("svn_fs_get_uuid", "cdecl"):
    svn_fs_get_uuid = _libs["svn_fs-1"].get("svn_fs_get_uuid", "cdecl")
    svn_fs_get_uuid.argtypes = [POINTER(svn_fs_t), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_fs_get_uuid.restype = POINTER(svn_error_t)
    svn_fs_get_uuid.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2943
if _libs["svn_fs-1"].has("svn_fs_set_uuid", "cdecl"):
    svn_fs_set_uuid = _libs["svn_fs-1"].get("svn_fs_set_uuid", "cdecl")
    svn_fs_set_uuid.argtypes = [POINTER(svn_fs_t), String, POINTER(apr_pool_t)]
    svn_fs_set_uuid.restype = POINTER(svn_error_t)
    svn_fs_set_uuid.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2983
class struct_svn_fs_lock_target_t(Structure):
    pass

svn_fs_lock_target_t = struct_svn_fs_lock_target_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2983

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2993
if _libs["svn_fs-1"].has("svn_fs_lock_target_create", "cdecl"):
    svn_fs_lock_target_create = _libs["svn_fs-1"].get("svn_fs_lock_target_create", "cdecl")
    svn_fs_lock_target_create.argtypes = [String, svn_revnum_t, POINTER(apr_pool_t)]
    svn_fs_lock_target_create.restype = POINTER(svn_fs_lock_target_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3004
if _libs["svn_fs-1"].has("svn_fs_lock_target_set_token", "cdecl"):
    svn_fs_lock_target_set_token = _libs["svn_fs-1"].get("svn_fs_lock_target_set_token", "cdecl")
    svn_fs_lock_target_set_token.argtypes = [POINTER(svn_fs_lock_target_t), String]
    svn_fs_lock_target_set_token.restype = None

svn_fs_lock_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_lock_t), POINTER(svn_error_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3024

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3084
if _libs["svn_fs-1"].has("svn_fs_lock_many", "cdecl"):
    svn_fs_lock_many = _libs["svn_fs-1"].get("svn_fs_lock_many", "cdecl")
    svn_fs_lock_many.argtypes = [POINTER(svn_fs_t), POINTER(apr_hash_t), String, svn_boolean_t, apr_time_t, svn_boolean_t, svn_fs_lock_callback_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_lock_many.restype = POINTER(svn_error_t)
    svn_fs_lock_many.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3101
if _libs["svn_fs-1"].has("svn_fs_lock", "cdecl"):
    svn_fs_lock = _libs["svn_fs-1"].get("svn_fs_lock", "cdecl")
    svn_fs_lock.argtypes = [POINTER(POINTER(svn_lock_t)), POINTER(svn_fs_t), String, String, String, svn_boolean_t, apr_time_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_lock.restype = POINTER(svn_error_t)
    svn_fs_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3120
if _libs["svn_fs-1"].has("svn_fs_generate_lock_token", "cdecl"):
    svn_fs_generate_lock_token = _libs["svn_fs-1"].get("svn_fs_generate_lock_token", "cdecl")
    svn_fs_generate_lock_token.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_fs_t), POINTER(apr_pool_t)]
    svn_fs_generate_lock_token.restype = POINTER(svn_error_t)
    svn_fs_generate_lock_token.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3160
if _libs["svn_fs-1"].has("svn_fs_unlock_many", "cdecl"):
    svn_fs_unlock_many = _libs["svn_fs-1"].get("svn_fs_unlock_many", "cdecl")
    svn_fs_unlock_many.argtypes = [POINTER(svn_fs_t), POINTER(apr_hash_t), svn_boolean_t, svn_fs_lock_callback_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_unlock_many.restype = POINTER(svn_error_t)
    svn_fs_unlock_many.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3173
if _libs["svn_fs-1"].has("svn_fs_unlock", "cdecl"):
    svn_fs_unlock = _libs["svn_fs-1"].get("svn_fs_unlock", "cdecl")
    svn_fs_unlock.argtypes = [POINTER(svn_fs_t), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_fs_unlock.restype = POINTER(svn_error_t)
    svn_fs_unlock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3186
if _libs["svn_fs-1"].has("svn_fs_get_lock", "cdecl"):
    svn_fs_get_lock = _libs["svn_fs-1"].get("svn_fs_get_lock", "cdecl")
    svn_fs_get_lock.argtypes = [POINTER(POINTER(svn_lock_t)), POINTER(svn_fs_t), String, POINTER(apr_pool_t)]
    svn_fs_get_lock.restype = POINTER(svn_error_t)
    svn_fs_get_lock.errcheck = _svn_errcheck

svn_fs_get_locks_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_lock_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3199

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3224
if _libs["svn_fs-1"].has("svn_fs_get_locks2", "cdecl"):
    svn_fs_get_locks2 = _libs["svn_fs-1"].get("svn_fs_get_locks2", "cdecl")
    svn_fs_get_locks2.argtypes = [POINTER(svn_fs_t), String, svn_depth_t, svn_fs_get_locks_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_get_locks2.restype = POINTER(svn_error_t)
    svn_fs_get_locks2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3247
if _libs["svn_fs-1"].has("svn_fs_get_locks", "cdecl"):
    svn_fs_get_locks = _libs["svn_fs-1"].get("svn_fs_get_locks", "cdecl")
    svn_fs_get_locks.argtypes = [POINTER(svn_fs_t), String, svn_fs_get_locks_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_get_locks.restype = POINTER(svn_error_t)
    svn_fs_get_locks.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3263
if _libs["svn_fs-1"].has("svn_fs_print_modules", "cdecl"):
    svn_fs_print_modules = _libs["svn_fs-1"].get("svn_fs_print_modules", "cdecl")
    svn_fs_print_modules.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_fs_print_modules.restype = POINTER(svn_error_t)
    svn_fs_print_modules.errcheck = _svn_errcheck

enum_svn_fs_pack_notify_action_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_start = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_end = (svn_fs_pack_notify_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_start_revprop = (svn_fs_pack_notify_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_end_revprop = (svn_fs_pack_notify_start_revprop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_noop = (svn_fs_pack_notify_end_revprop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_action_t = enum_svn_fs_pack_notify_action_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3291

svn_fs_pack_notify_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), c_int64, svn_fs_pack_notify_action_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3298

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3309
if _libs["svn_fs-1"].has("svn_fs_pack", "cdecl"):
    svn_fs_pack = _libs["svn_fs-1"].get("svn_fs_pack", "cdecl")
    svn_fs_pack.argtypes = [String, svn_fs_pack_notify_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_pack.restype = POINTER(svn_error_t)
    svn_fs_pack.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3360
if _libs["svn_fs-1"].has("svn_fs_verify", "cdecl"):
    svn_fs_verify = _libs["svn_fs-1"].get("svn_fs_verify", "cdecl")
    svn_fs_verify.argtypes = [String, POINTER(apr_hash_t), svn_revnum_t, svn_revnum_t, svn_fs_progress_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_fs_verify.restype = POINTER(svn_error_t)
    svn_fs_verify.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3395
if _libs["svn_fs-1"].has("svn_fs_verify_root", "cdecl"):
    svn_fs_verify_root = _libs["svn_fs-1"].get("svn_fs_verify_root", "cdecl")
    svn_fs_verify_root.argtypes = [POINTER(svn_fs_root_t), POINTER(apr_pool_t)]
    svn_fs_verify_root.restype = POINTER(svn_error_t)
    svn_fs_verify_root.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3435
class struct_svn_fs_fsfs_info_t(Structure):
    pass

struct_svn_fs_fsfs_info_t.__slots__ = [
    'fs_type',
    'shard_size',
    'min_unpacked_rev',
    'log_addressing',
]
struct_svn_fs_fsfs_info_t._fields_ = [
    ('fs_type', String),
    ('shard_size', c_int),
    ('min_unpacked_rev', svn_revnum_t),
    ('log_addressing', svn_boolean_t),
]

svn_fs_fsfs_info_t = struct_svn_fs_fsfs_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3435

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3461
class struct_svn_fs_fsx_info_t(Structure):
    pass

struct_svn_fs_fsx_info_t.__slots__ = [
    'fs_type',
    'shard_size',
    'min_unpacked_rev',
]
struct_svn_fs_fsx_info_t._fields_ = [
    ('fs_type', String),
    ('shard_size', c_int),
    ('min_unpacked_rev', svn_revnum_t),
]

svn_fs_fsx_info_t = struct_svn_fs_fsx_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3461

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3471
class struct_svn_fs_info_placeholder_t(Structure):
    pass

struct_svn_fs_info_placeholder_t.__slots__ = [
    'fs_type',
]
struct_svn_fs_info_placeholder_t._fields_ = [
    ('fs_type', String),
]

svn_fs_info_placeholder_t = struct_svn_fs_info_placeholder_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3471

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3484
if _libs["svn_fs-1"].has("svn_fs_info", "cdecl"):
    svn_fs_info = _libs["svn_fs-1"].get("svn_fs_info", "cdecl")
    svn_fs_info.argtypes = [POINTER(POINTER(svn_fs_info_placeholder_t)), POINTER(svn_fs_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_info.restype = POINTER(svn_error_t)
    svn_fs_info.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3501
if _libs["svn_fs-1"].has("svn_fs_info_dup", "cdecl"):
    svn_fs_info_dup = _libs["svn_fs-1"].get("svn_fs_info_dup", "cdecl")
    svn_fs_info_dup.argtypes = [POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_info_dup.restype = POINTER(c_ubyte)
    svn_fs_info_dup.errcheck = lambda v,*a : cast(v, c_void_p)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3517
class struct_svn_fs_ioctl_code_t(Structure):
    pass

struct_svn_fs_ioctl_code_t.__slots__ = [
    'fs_type',
    'code',
]
struct_svn_fs_ioctl_code_t._fields_ = [
    ('fs_type', String),
    ('code', c_int),
]

svn_fs_ioctl_code_t = struct_svn_fs_ioctl_code_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3517

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3544
if _libs["svn_fs-1"].has("svn_fs_ioctl", "cdecl"):
    svn_fs_ioctl = _libs["svn_fs-1"].get("svn_fs_ioctl", "cdecl")
    svn_fs_ioctl.argtypes = [POINTER(svn_fs_t), svn_fs_ioctl_code_t, POINTER(None), POINTER(POINTER(None)), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_fs_ioctl.restype = POINTER(svn_error_t)
    svn_fs_ioctl.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 79
if _libs["svn_subr-1"].has("svn_hash_read2", "cdecl"):
    svn_hash_read2 = _libs["svn_subr-1"].get("svn_hash_read2", "cdecl")
    svn_hash_read2.argtypes = [POINTER(apr_hash_t), POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_hash_read2.restype = POINTER(svn_error_t)
    svn_hash_read2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 93
if _libs["svn_subr-1"].has("svn_hash_write2", "cdecl"):
    svn_hash_write2 = _libs["svn_subr-1"].get("svn_hash_write2", "cdecl")
    svn_hash_write2.argtypes = [POINTER(apr_hash_t), POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_hash_write2.restype = POINTER(svn_error_t)
    svn_hash_write2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 106
if _libs["svn_subr-1"].has("svn_hash_read_incremental", "cdecl"):
    svn_hash_read_incremental = _libs["svn_subr-1"].get("svn_hash_read_incremental", "cdecl")
    svn_hash_read_incremental.argtypes = [POINTER(apr_hash_t), POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_hash_read_incremental.restype = POINTER(svn_error_t)
    svn_hash_read_incremental.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 120
if _libs["svn_subr-1"].has("svn_hash_write_incremental", "cdecl"):
    svn_hash_write_incremental = _libs["svn_subr-1"].get("svn_hash_write_incremental", "cdecl")
    svn_hash_write_incremental.argtypes = [POINTER(apr_hash_t), POINTER(apr_hash_t), POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_hash_write_incremental.restype = POINTER(svn_error_t)
    svn_hash_write_incremental.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 136
if _libs["svn_subr-1"].has("svn_hash_read", "cdecl"):
    svn_hash_read = _libs["svn_subr-1"].get("svn_hash_read", "cdecl")
    svn_hash_read.argtypes = [POINTER(apr_hash_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_hash_read.restype = POINTER(svn_error_t)
    svn_hash_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 148
if _libs["svn_subr-1"].has("svn_hash_write", "cdecl"):
    svn_hash_write = _libs["svn_subr-1"].get("svn_hash_write", "cdecl")
    svn_hash_write.argtypes = [POINTER(apr_hash_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_hash_write.restype = POINTER(svn_error_t)
    svn_hash_write.errcheck = _svn_errcheck

enum_svn_hash_diff_key_status = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 163

svn_hash_diff_key_both = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 163

svn_hash_diff_key_a = (svn_hash_diff_key_both + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 163

svn_hash_diff_key_b = (svn_hash_diff_key_a + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 163

svn_hash_diff_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), apr_ssize_t, enum_svn_hash_diff_key_status, POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 177

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 200
if _libs["svn_subr-1"].has("svn_hash_diff", "cdecl"):
    svn_hash_diff = _libs["svn_subr-1"].get("svn_hash_diff", "cdecl")
    svn_hash_diff.argtypes = [POINTER(apr_hash_t), POINTER(apr_hash_t), svn_hash_diff_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_hash_diff.restype = POINTER(svn_error_t)
    svn_hash_diff.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 224
if _libs["svn_subr-1"].has("svn_hash_keys", "cdecl"):
    svn_hash_keys = _libs["svn_subr-1"].get("svn_hash_keys", "cdecl")
    svn_hash_keys.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_hash_keys.restype = POINTER(svn_error_t)
    svn_hash_keys.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 237
if _libs["svn_subr-1"].has("svn_hash_from_cstring_keys", "cdecl"):
    svn_hash_from_cstring_keys = _libs["svn_subr-1"].get("svn_hash_from_cstring_keys", "cdecl")
    svn_hash_from_cstring_keys.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_hash_from_cstring_keys.restype = POINTER(svn_error_t)
    svn_hash_from_cstring_keys.errcheck = _svn_errcheck

svn_iter_apr_hash_cb_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(None), apr_ssize_t, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_iter.h: 53

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_iter.h: 73
if _libs["svn_subr-1"].has("svn_iter_apr_hash", "cdecl"):
    svn_iter_apr_hash = _libs["svn_subr-1"].get("svn_iter_apr_hash", "cdecl")
    svn_iter_apr_hash.argtypes = [POINTER(svn_boolean_t), POINTER(apr_hash_t), svn_iter_apr_hash_cb_t, POINTER(None), POINTER(apr_pool_t)]
    svn_iter_apr_hash.restype = POINTER(svn_error_t)
    svn_iter_apr_hash.errcheck = _svn_errcheck

svn_iter_apr_array_cb_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_iter.h: 90

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_iter.h: 109
if _libs["svn_subr-1"].has("svn_iter_apr_array", "cdecl"):
    svn_iter_apr_array = _libs["svn_subr-1"].get("svn_iter_apr_array", "cdecl")
    svn_iter_apr_array.argtypes = [POINTER(svn_boolean_t), POINTER(apr_array_header_t), svn_iter_apr_array_cb_t, POINTER(None), POINTER(apr_pool_t)]
    svn_iter_apr_array.restype = POINTER(svn_error_t)
    svn_iter_apr_array.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_iter.h: 119
if _libs["svn_subr-1"].has("svn_iter__break", "cdecl"):
    svn_iter__break = _libs["svn_subr-1"].get("svn_iter__break", "cdecl")
    svn_iter__break.argtypes = []
    svn_iter__break.restype = POINTER(svn_error_t)
    svn_iter__break.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_md5.h: 46
if _libs["svn_subr-1"].has("svn_md5_empty_string_digest", "cdecl"):
    svn_md5_empty_string_digest = _libs["svn_subr-1"].get("svn_md5_empty_string_digest", "cdecl")
    svn_md5_empty_string_digest.argtypes = []
    svn_md5_empty_string_digest.restype = POINTER(c_ubyte)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_md5.h: 57
if _libs["svn_subr-1"].has("svn_md5_digest_to_cstring_display", "cdecl"):
    svn_md5_digest_to_cstring_display = _libs["svn_subr-1"].get("svn_md5_digest_to_cstring_display", "cdecl")
    svn_md5_digest_to_cstring_display.argtypes = [POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_md5_digest_to_cstring_display.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_md5.h: 70
if _libs["svn_subr-1"].has("svn_md5_digest_to_cstring", "cdecl"):
    svn_md5_digest_to_cstring = _libs["svn_subr-1"].get("svn_md5_digest_to_cstring", "cdecl")
    svn_md5_digest_to_cstring.argtypes = [POINTER(c_ubyte), POINTER(apr_pool_t)]
    svn_md5_digest_to_cstring.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_md5.h: 84
if _libs["svn_subr-1"].has("svn_md5_digests_match", "cdecl"):
    svn_md5_digests_match = _libs["svn_subr-1"].get("svn_md5_digests_match", "cdecl")
    svn_md5_digests_match.argtypes = [POINTER(c_ubyte), POINTER(c_ubyte)]
    svn_md5_digests_match.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_nls.h: 49
if _libs["svn_subr-1"].has("svn_nls_init", "cdecl"):
    svn_nls_init = _libs["svn_subr-1"].get("svn_nls_init", "cdecl")
    svn_nls_init.argtypes = []
    svn_nls_init.restype = POINTER(svn_error_t)
    svn_nls_init.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 72
if _libs["svn_subr-1"].has("svn_path_internal_style", "cdecl"):
    svn_path_internal_style = _libs["svn_subr-1"].get("svn_path_internal_style", "cdecl")
    svn_path_internal_style.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_internal_style.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 81
if _libs["svn_subr-1"].has("svn_path_local_style", "cdecl"):
    svn_path_local_style = _libs["svn_subr-1"].get("svn_path_local_style", "cdecl")
    svn_path_local_style.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_local_style.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 113
if _libs["svn_subr-1"].has("svn_path_join", "cdecl"):
    svn_path_join = _libs["svn_subr-1"].get("svn_path_join", "cdecl")
    svn_path_join.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_path_join.restype = ReturnString
    else:
        svn_path_join.restype = String
        svn_path_join.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 133
if _libs["svn_subr-1"].has("svn_path_join_many", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_path_join_many", "cdecl")
    _restype = String
    _errcheck = None
    _argtypes = [POINTER(apr_pool_t), String]
    svn_path_join_many = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 156
if _libs["svn_subr-1"].has("svn_path_basename", "cdecl"):
    svn_path_basename = _libs["svn_subr-1"].get("svn_path_basename", "cdecl")
    svn_path_basename.argtypes = [String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_path_basename.restype = ReturnString
    else:
        svn_path_basename.restype = String
        svn_path_basename.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 170
if _libs["svn_subr-1"].has("svn_path_dirname", "cdecl"):
    svn_path_dirname = _libs["svn_subr-1"].get("svn_path_dirname", "cdecl")
    svn_path_dirname.argtypes = [String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_path_dirname.restype = ReturnString
    else:
        svn_path_dirname.restype = String
        svn_path_dirname.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 183
if _libs["svn_subr-1"].has("svn_path_splitext", "cdecl"):
    svn_path_splitext = _libs["svn_subr-1"].get("svn_path_splitext", "cdecl")
    svn_path_splitext.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_path_splitext.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 191
if _libs["svn_subr-1"].has("svn_path_component_count", "cdecl"):
    svn_path_component_count = _libs["svn_subr-1"].get("svn_path_component_count", "cdecl")
    svn_path_component_count.argtypes = [String]
    svn_path_component_count.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 204
if _libs["svn_subr-1"].has("svn_path_add_component", "cdecl"):
    svn_path_add_component = _libs["svn_subr-1"].get("svn_path_add_component", "cdecl")
    svn_path_add_component.argtypes = [POINTER(svn_stringbuf_t), String]
    svn_path_add_component.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 208
if _libs["svn_subr-1"].has("svn_path_remove_component", "cdecl"):
    svn_path_remove_component = _libs["svn_subr-1"].get("svn_path_remove_component", "cdecl")
    svn_path_remove_component.argtypes = [POINTER(svn_stringbuf_t)]
    svn_path_remove_component.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 216
if _libs["svn_subr-1"].has("svn_path_remove_components", "cdecl"):
    svn_path_remove_components = _libs["svn_subr-1"].get("svn_path_remove_components", "cdecl")
    svn_path_remove_components.argtypes = [POINTER(svn_stringbuf_t), apr_size_t]
    svn_path_remove_components.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 243
if _libs["svn_subr-1"].has("svn_path_split", "cdecl"):
    svn_path_split = _libs["svn_subr-1"].get("svn_path_split", "cdecl")
    svn_path_split.argtypes = [String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_path_split.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 254
if _libs["svn_subr-1"].has("svn_path_is_empty", "cdecl"):
    svn_path_is_empty = _libs["svn_subr-1"].get("svn_path_is_empty", "cdecl")
    svn_path_is_empty.argtypes = [String]
    svn_path_is_empty.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 283
if _libs["svn_subr-1"].has("svn_path_canonicalize", "cdecl"):
    svn_path_canonicalize = _libs["svn_subr-1"].get("svn_path_canonicalize", "cdecl")
    svn_path_canonicalize.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_canonicalize.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 296
if _libs["svn_subr-1"].has("svn_path_is_canonical", "cdecl"):
    svn_path_is_canonical = _libs["svn_subr-1"].get("svn_path_is_canonical", "cdecl")
    svn_path_is_canonical.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_is_canonical.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 307
if _libs["svn_subr-1"].has("svn_path_compare_paths", "cdecl"):
    svn_path_compare_paths = _libs["svn_subr-1"].get("svn_path_compare_paths", "cdecl")
    svn_path_compare_paths.argtypes = [String, String]
    svn_path_compare_paths.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 326
if _libs["svn_subr-1"].has("svn_path_get_longest_ancestor", "cdecl"):
    svn_path_get_longest_ancestor = _libs["svn_subr-1"].get("svn_path_get_longest_ancestor", "cdecl")
    svn_path_get_longest_ancestor.argtypes = [String, String, POINTER(apr_pool_t)]
    if sizeof(c_int) == sizeof(c_void_p):
        svn_path_get_longest_ancestor.restype = ReturnString
    else:
        svn_path_get_longest_ancestor.restype = String
        svn_path_get_longest_ancestor.errcheck = ReturnString

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 341
if _libs["svn_subr-1"].has("svn_path_get_absolute", "cdecl"):
    svn_path_get_absolute = _libs["svn_subr-1"].get("svn_path_get_absolute", "cdecl")
    svn_path_get_absolute.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_path_get_absolute.restype = POINTER(svn_error_t)
    svn_path_get_absolute.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 357
if _libs["svn_subr-1"].has("svn_path_split_if_file", "cdecl"):
    svn_path_split_if_file = _libs["svn_subr-1"].get("svn_path_split_if_file", "cdecl")
    svn_path_split_if_file.argtypes = [String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_path_split_if_file.restype = POINTER(svn_error_t)
    svn_path_split_if_file.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 399
if _libs["svn_subr-1"].has("svn_path_condense_targets", "cdecl"):
    svn_path_condense_targets = _libs["svn_subr-1"].get("svn_path_condense_targets", "cdecl")
    svn_path_condense_targets.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_path_condense_targets.restype = POINTER(svn_error_t)
    svn_path_condense_targets.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 444
if _libs["svn_subr-1"].has("svn_path_remove_redundancies", "cdecl"):
    svn_path_remove_redundancies = _libs["svn_subr-1"].get("svn_path_remove_redundancies", "cdecl")
    svn_path_remove_redundancies.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_path_remove_redundancies.restype = POINTER(svn_error_t)
    svn_path_remove_redundancies.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 455
if _libs["svn_subr-1"].has("svn_path_decompose", "cdecl"):
    svn_path_decompose = _libs["svn_subr-1"].get("svn_path_decompose", "cdecl")
    svn_path_decompose.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_decompose.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 467
if _libs["svn_subr-1"].has("svn_path_compose", "cdecl"):
    svn_path_compose = _libs["svn_subr-1"].get("svn_path_compose", "cdecl")
    svn_path_compose.argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_path_compose.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 476
if _libs["svn_subr-1"].has("svn_path_is_single_path_component", "cdecl"):
    svn_path_is_single_path_component = _libs["svn_subr-1"].get("svn_path_is_single_path_component", "cdecl")
    svn_path_is_single_path_component.argtypes = [String]
    svn_path_is_single_path_component.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 487
if _libs["svn_subr-1"].has("svn_path_is_backpath_present", "cdecl"):
    svn_path_is_backpath_present = _libs["svn_subr-1"].get("svn_path_is_backpath_present", "cdecl")
    svn_path_is_backpath_present.argtypes = [String]
    svn_path_is_backpath_present.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 498
if _libs["svn_subr-1"].has("svn_path_is_dotpath_present", "cdecl"):
    svn_path_is_dotpath_present = _libs["svn_subr-1"].get("svn_path_is_dotpath_present", "cdecl")
    svn_path_is_dotpath_present.argtypes = [String]
    svn_path_is_dotpath_present.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 523
if _libs["svn_subr-1"].has("svn_path_is_child", "cdecl"):
    svn_path_is_child = _libs["svn_subr-1"].get("svn_path_is_child", "cdecl")
    svn_path_is_child.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_path_is_child.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 537
if _libs["svn_subr-1"].has("svn_path_is_ancestor", "cdecl"):
    svn_path_is_ancestor = _libs["svn_subr-1"].get("svn_path_is_ancestor", "cdecl")
    svn_path_is_ancestor.argtypes = [String, String]
    svn_path_is_ancestor.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 558
if _libs["svn_subr-1"].has("svn_path_check_valid", "cdecl"):
    svn_path_check_valid = _libs["svn_subr-1"].get("svn_path_check_valid", "cdecl")
    svn_path_check_valid.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_check_valid.restype = POINTER(svn_error_t)
    svn_path_check_valid.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 570
if _libs["svn_subr-1"].has("svn_path_is_url", "cdecl"):
    svn_path_is_url = _libs["svn_subr-1"].get("svn_path_is_url", "cdecl")
    svn_path_is_url.argtypes = [String]
    svn_path_is_url.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 574
if _libs["svn_subr-1"].has("svn_path_is_uri_safe", "cdecl"):
    svn_path_is_uri_safe = _libs["svn_subr-1"].get("svn_path_is_uri_safe", "cdecl")
    svn_path_is_uri_safe.argtypes = [String]
    svn_path_is_uri_safe.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 579
if _libs["svn_subr-1"].has("svn_path_uri_encode", "cdecl"):
    svn_path_uri_encode = _libs["svn_subr-1"].get("svn_path_uri_encode", "cdecl")
    svn_path_uri_encode.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_uri_encode.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 583
if _libs["svn_subr-1"].has("svn_path_uri_decode", "cdecl"):
    svn_path_uri_decode = _libs["svn_subr-1"].get("svn_path_uri_decode", "cdecl")
    svn_path_uri_decode.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_uri_decode.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 613
if _libs["svn_subr-1"].has("svn_path_url_add_component2", "cdecl"):
    svn_path_url_add_component2 = _libs["svn_subr-1"].get("svn_path_url_add_component2", "cdecl")
    svn_path_url_add_component2.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_path_url_add_component2.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 624
if _libs["svn_subr-1"].has("svn_path_url_add_component", "cdecl"):
    svn_path_url_add_component = _libs["svn_subr-1"].get("svn_path_url_add_component", "cdecl")
    svn_path_url_add_component.argtypes = [String, String, POINTER(apr_pool_t)]
    svn_path_url_add_component.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 636
if _libs["svn_subr-1"].has("svn_path_uri_from_iri", "cdecl"):
    svn_path_uri_from_iri = _libs["svn_subr-1"].get("svn_path_uri_from_iri", "cdecl")
    svn_path_uri_from_iri.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_uri_from_iri.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 649
if _libs["svn_subr-1"].has("svn_path_uri_autoescape", "cdecl"):
    svn_path_uri_autoescape = _libs["svn_subr-1"].get("svn_path_uri_autoescape", "cdecl")
    svn_path_uri_autoescape.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_uri_autoescape.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 661
if _libs["svn_subr-1"].has("svn_path_cstring_from_utf8", "cdecl"):
    svn_path_cstring_from_utf8 = _libs["svn_subr-1"].get("svn_path_cstring_from_utf8", "cdecl")
    svn_path_cstring_from_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_path_cstring_from_utf8.restype = POINTER(svn_error_t)
    svn_path_cstring_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 667
if _libs["svn_subr-1"].has("svn_path_cstring_to_utf8", "cdecl"):
    svn_path_cstring_to_utf8 = _libs["svn_subr-1"].get("svn_path_cstring_to_utf8", "cdecl")
    svn_path_cstring_to_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_path_cstring_to_utf8.restype = POINTER(svn_error_t)
    svn_path_cstring_to_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 694
if _libs["svn_subr-1"].has("svn_path_is_repos_relative_url", "cdecl"):
    svn_path_is_repos_relative_url = _libs["svn_subr-1"].get("svn_path_is_repos_relative_url", "cdecl")
    svn_path_is_repos_relative_url.argtypes = [String]
    svn_path_is_repos_relative_url.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 715
if _libs["svn_subr-1"].has("svn_path_resolve_repos_relative_url", "cdecl"):
    svn_path_resolve_repos_relative_url = _libs["svn_subr-1"].get("svn_path_resolve_repos_relative_url", "cdecl")
    svn_path_resolve_repos_relative_url.argtypes = [POINTER(POINTER(c_char)), String, String, POINTER(apr_pool_t)]
    svn_path_resolve_repos_relative_url.restype = POINTER(svn_error_t)
    svn_path_resolve_repos_relative_url.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_path.h: 726
if _libs["svn_subr-1"].has("svn_path_illegal_path_escape", "cdecl"):
    svn_path_illegal_path_escape = _libs["svn_subr-1"].get("svn_path_illegal_path_escape", "cdecl")
    svn_path_illegal_path_escape.argtypes = [String, POINTER(apr_pool_t)]
    svn_path_illegal_path_escape.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 54
if _libs["svn_subr-1"].has("svn_pool_create_ex", "cdecl"):
    svn_pool_create_ex = _libs["svn_subr-1"].get("svn_pool_create_ex", "cdecl")
    svn_pool_create_ex.argtypes = [POINTER(apr_pool_t), POINTER(apr_allocator_t)]
    svn_pool_create_ex.restype = POINTER(apr_pool_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 59
if _libs["svn_subr-1"].has("svn_pool_create_ex_debug", "cdecl"):
    svn_pool_create_ex_debug = _libs["svn_subr-1"].get("svn_pool_create_ex_debug", "cdecl")
    svn_pool_create_ex_debug.argtypes = [POINTER(apr_pool_t), POINTER(apr_allocator_t), String]
    svn_pool_create_ex_debug.restype = POINTER(apr_pool_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 107
if _libs["svn_subr-1"].has("svn_pool_create_allocator", "cdecl"):
    svn_pool_create_allocator = _libs["svn_subr-1"].get("svn_pool_create_allocator", "cdecl")
    svn_pool_create_allocator.argtypes = [svn_boolean_t]
    svn_pool_create_allocator.restype = POINTER(apr_allocator_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 64
class struct_svn_prop_t(Structure):
    pass

struct_svn_prop_t.__slots__ = [
    'name',
    'value',
]
struct_svn_prop_t._fields_ = [
    ('name', String),
    ('value', POINTER(svn_string_t)),
]

svn_prop_t = struct_svn_prop_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 64

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 73
if _libs["svn_subr-1"].has("svn_prop_dup", "cdecl"):
    svn_prop_dup = _libs["svn_subr-1"].get("svn_prop_dup", "cdecl")
    svn_prop_dup.argtypes = [POINTER(svn_prop_t), POINTER(apr_pool_t)]
    svn_prop_dup.restype = POINTER(svn_prop_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 83
if _libs["svn_subr-1"].has("svn_prop_array_dup", "cdecl"):
    svn_prop_array_dup = _libs["svn_subr-1"].get("svn_prop_array_dup", "cdecl")
    svn_prop_array_dup.argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_prop_array_dup.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 105
class struct_svn_prop_inherited_item_t(Structure):
    pass

struct_svn_prop_inherited_item_t.__slots__ = [
    'path_or_url',
    'prop_hash',
]
struct_svn_prop_inherited_item_t._fields_ = [
    ('path_or_url', String),
    ('prop_hash', POINTER(apr_hash_t)),
]

svn_prop_inherited_item_t = struct_svn_prop_inherited_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 105

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 115
if _libs["svn_subr-1"].has("svn_prop_hash_to_array", "cdecl"):
    svn_prop_hash_to_array = _libs["svn_subr-1"].get("svn_prop_hash_to_array", "cdecl")
    svn_prop_hash_to_array.argtypes = [POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_prop_hash_to_array.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 128
if _libs["svn_subr-1"].has("svn_prop_array_to_hash", "cdecl"):
    svn_prop_array_to_hash = _libs["svn_subr-1"].get("svn_prop_array_to_hash", "cdecl")
    svn_prop_array_to_hash.argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_prop_array_to_hash.restype = POINTER(apr_hash_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 138
if _libs["svn_subr-1"].has("svn_prop_hash_dup", "cdecl"):
    svn_prop_hash_dup = _libs["svn_subr-1"].get("svn_prop_hash_dup", "cdecl")
    svn_prop_hash_dup.argtypes = [POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_prop_hash_dup.restype = POINTER(apr_hash_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 149
if _libs["svn_subr-1"].has("svn_prop_get_value", "cdecl"):
    svn_prop_get_value = _libs["svn_subr-1"].get("svn_prop_get_value", "cdecl")
    svn_prop_get_value.argtypes = [POINTER(apr_hash_t), String]
    svn_prop_get_value.restype = c_char_p

enum_svn_prop_kind = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 171

svn_prop_entry_kind = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 171

svn_prop_wc_kind = (svn_prop_entry_kind + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 171

svn_prop_regular_kind = (svn_prop_wc_kind + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 171

svn_prop_kind_t = enum_svn_prop_kind# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 171

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 178
if _libs["svn_subr-1"].has("svn_property_kind2", "cdecl"):
    svn_property_kind2 = _libs["svn_subr-1"].get("svn_property_kind2", "cdecl")
    svn_property_kind2.argtypes = [String]
    svn_property_kind2.restype = svn_prop_kind_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 188
if _libs["svn_subr-1"].has("svn_property_kind", "cdecl"):
    svn_property_kind = _libs["svn_subr-1"].get("svn_property_kind", "cdecl")
    svn_property_kind.argtypes = [POINTER(c_int), String]
    svn_property_kind.restype = svn_prop_kind_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 198
if _libs["svn_subr-1"].has("svn_prop_is_svn_prop", "cdecl"):
    svn_prop_is_svn_prop = _libs["svn_subr-1"].get("svn_prop_is_svn_prop", "cdecl")
    svn_prop_is_svn_prop.argtypes = [String]
    svn_prop_is_svn_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 208
if _libs["svn_subr-1"].has("svn_prop_has_svn_prop", "cdecl"):
    svn_prop_has_svn_prop = _libs["svn_subr-1"].get("svn_prop_has_svn_prop", "cdecl")
    svn_prop_has_svn_prop.argtypes = [POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_prop_has_svn_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 217
if _libs["svn_subr-1"].has("svn_prop_is_boolean", "cdecl"):
    svn_prop_is_boolean = _libs["svn_subr-1"].get("svn_prop_is_boolean", "cdecl")
    svn_prop_is_boolean.argtypes = [String]
    svn_prop_is_boolean.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 229
if _libs["svn_subr-1"].has("svn_prop_is_known_svn_rev_prop", "cdecl"):
    svn_prop_is_known_svn_rev_prop = _libs["svn_subr-1"].get("svn_prop_is_known_svn_rev_prop", "cdecl")
    svn_prop_is_known_svn_rev_prop.argtypes = [String]
    svn_prop_is_known_svn_rev_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 242
if _libs["svn_subr-1"].has("svn_prop_is_known_svn_node_prop", "cdecl"):
    svn_prop_is_known_svn_node_prop = _libs["svn_subr-1"].get("svn_prop_is_known_svn_node_prop", "cdecl")
    svn_prop_is_known_svn_node_prop.argtypes = [String]
    svn_prop_is_known_svn_node_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 255
if _libs["svn_subr-1"].has("svn_prop_is_known_svn_file_prop", "cdecl"):
    svn_prop_is_known_svn_file_prop = _libs["svn_subr-1"].get("svn_prop_is_known_svn_file_prop", "cdecl")
    svn_prop_is_known_svn_file_prop.argtypes = [String]
    svn_prop_is_known_svn_file_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 268
if _libs["svn_subr-1"].has("svn_prop_is_known_svn_dir_prop", "cdecl"):
    svn_prop_is_known_svn_dir_prop = _libs["svn_subr-1"].get("svn_prop_is_known_svn_dir_prop", "cdecl")
    svn_prop_is_known_svn_dir_prop.argtypes = [String]
    svn_prop_is_known_svn_dir_prop.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 278
if _libs["svn_subr-1"].has("svn_prop_needs_translation", "cdecl"):
    svn_prop_needs_translation = _libs["svn_subr-1"].get("svn_prop_needs_translation", "cdecl")
    svn_prop_needs_translation.argtypes = [String]
    svn_prop_needs_translation.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 292
if _libs["svn_subr-1"].has("svn_categorize_props", "cdecl"):
    svn_categorize_props = _libs["svn_subr-1"].get("svn_categorize_props", "cdecl")
    svn_categorize_props.argtypes = [POINTER(apr_array_header_t), POINTER(POINTER(apr_array_header_t)), POINTER(POINTER(apr_array_header_t)), POINTER(POINTER(apr_array_header_t)), POINTER(apr_pool_t)]
    svn_categorize_props.restype = POINTER(svn_error_t)
    svn_categorize_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 321
if _libs["svn_subr-1"].has("svn_prop_diffs", "cdecl"):
    svn_prop_diffs = _libs["svn_subr-1"].get("svn_prop_diffs", "cdecl")
    svn_prop_diffs.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(apr_hash_t), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_prop_diffs.restype = POINTER(svn_error_t)
    svn_prop_diffs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 337
if _libs["svn_subr-1"].has("svn_prop_name_is_valid", "cdecl"):
    svn_prop_name_is_valid = _libs["svn_subr-1"].get("svn_prop_name_is_valid", "cdecl")
    svn_prop_name_is_valid.argtypes = [String]
    svn_prop_name_is_valid.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_quoprint.h: 44
if _libs["svn_subr-1"].has("svn_quoprint_encode", "cdecl"):
    svn_quoprint_encode = _libs["svn_subr-1"].get("svn_quoprint_encode", "cdecl")
    svn_quoprint_encode.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_quoprint_encode.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_quoprint.h: 53
if _libs["svn_subr-1"].has("svn_quoprint_decode", "cdecl"):
    svn_quoprint_decode = _libs["svn_subr-1"].get("svn_quoprint_decode", "cdecl")
    svn_quoprint_decode.argtypes = [POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_quoprint_decode.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_quoprint.h: 61
if _libs["svn_subr-1"].has("svn_quoprint_encode_string", "cdecl"):
    svn_quoprint_encode_string = _libs["svn_subr-1"].get("svn_quoprint_encode_string", "cdecl")
    svn_quoprint_encode_string.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_quoprint_encode_string.restype = POINTER(svn_stringbuf_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_quoprint.h: 68
if _libs["svn_subr-1"].has("svn_quoprint_decode_string", "cdecl"):
    svn_quoprint_decode_string = _libs["svn_subr-1"].get("svn_quoprint_decode_string", "cdecl")
    svn_quoprint_decode_string.argtypes = [POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_quoprint_decode_string.restype = POINTER(svn_stringbuf_t)

in_addr_t = uint32_t# /usr/include/netinet/in.h: 30

# /usr/include/netinet/in.h: 31
class struct_in_addr(Structure):
    pass

struct_in_addr.__slots__ = [
    's_addr',
]
struct_in_addr._fields_ = [
    ('s_addr', in_addr_t),
]

in_port_t = uint16_t# /usr/include/netinet/in.h: 127

# /usr/include/netinet/in.h: 225
class union_anon_84(Union):
    pass

union_anon_84.__slots__ = [
    '__u6_addr8',
    '__u6_addr16',
    '__u6_addr32',
]
union_anon_84._fields_ = [
    ('__u6_addr8', uint8_t * int(16)),
    ('__u6_addr16', uint16_t * int(8)),
    ('__u6_addr32', uint32_t * int(4)),
]

# /usr/include/netinet/in.h: 223
class struct_in6_addr(Structure):
    pass

struct_in6_addr.__slots__ = [
    '__in6_u',
]
struct_in6_addr._fields_ = [
    ('__in6_u', union_anon_84),
]

# /usr/include/netinet/in.h: 249
class struct_sockaddr_in(Structure):
    pass

struct_sockaddr_in.__slots__ = [
    'sin_family',
    'sin_port',
    'sin_addr',
    'sin_zero',
]
struct_sockaddr_in._fields_ = [
    ('sin_family', sa_family_t),
    ('sin_port', in_port_t),
    ('sin_addr', struct_in_addr),
    ('sin_zero', c_ubyte * int((((sizeof(struct_sockaddr) - sizeof(c_ushort)) - sizeof(in_port_t)) - sizeof(struct_in_addr)))),
]

# /usr/include/netinet/in.h: 266
class struct_sockaddr_in6(Structure):
    pass

struct_sockaddr_in6.__slots__ = [
    'sin6_family',
    'sin6_port',
    'sin6_flowinfo',
    'sin6_addr',
    'sin6_scope_id',
]
struct_sockaddr_in6._fields_ = [
    ('sin6_family', sa_family_t),
    ('sin6_port', in_port_t),
    ('sin6_flowinfo', uint32_t),
    ('sin6_addr', struct_in6_addr),
    ('sin6_scope_id', uint32_t),
]

# /usr/include/sys/un.h: 29
class struct_sockaddr_un(Structure):
    pass

struct_sockaddr_un.__slots__ = [
    'sun_family',
    'sun_path',
]
struct_sockaddr_un._fields_ = [
    ('sun_family', sa_family_t),
    ('sun_path', c_char * int(108)),
]

enum_anon_85 = c_int# /usr/include/apr/apr_network_io.h: 119

APR_SHUTDOWN_READ = 0# /usr/include/apr/apr_network_io.h: 119

APR_SHUTDOWN_WRITE = (APR_SHUTDOWN_READ + 1)# /usr/include/apr/apr_network_io.h: 119

APR_SHUTDOWN_READWRITE = (APR_SHUTDOWN_WRITE + 1)# /usr/include/apr/apr_network_io.h: 119

apr_shutdown_how_e = enum_anon_85# /usr/include/apr/apr_network_io.h: 119

enum_anon_86 = c_int# /usr/include/apr/apr_network_io.h: 201

APR_LOCAL = 0# /usr/include/apr/apr_network_io.h: 201

APR_REMOTE = (APR_LOCAL + 1)# /usr/include/apr/apr_network_io.h: 201

apr_interface_e = enum_anon_86# /usr/include/apr/apr_network_io.h: 201

# /usr/include/apr/apr_network_io.h: 219
class struct_apr_socket_t(Structure):
    pass

apr_socket_t = struct_apr_socket_t# /usr/include/apr/apr_network_io.h: 219

# /usr/include/apr/apr_network_io.h: 293
class struct_apr_hdtr_t(Structure):
    pass

apr_hdtr_t = struct_apr_hdtr_t# /usr/include/apr/apr_network_io.h: 223

apr_in_addr_t = struct_in_addr# /usr/include/apr/apr_network_io.h: 225

# /usr/include/apr/apr_network_io.h: 227
class struct_apr_ipsubnet_t(Structure):
    pass

apr_ipsubnet_t = struct_apr_ipsubnet_t# /usr/include/apr/apr_network_io.h: 227

apr_port_t = apr_uint16_t# /usr/include/apr/apr_network_io.h: 230

# /usr/include/apr/apr_network_io.h: 239
class struct_apr_sockaddr_t(Structure):
    pass

apr_sockaddr_t = struct_apr_sockaddr_t# /usr/include/apr/apr_network_io.h: 235

# /usr/include/apr/apr_network_io.h: 264
class union_anon_87(Union):
    pass

union_anon_87.__slots__ = [
    'sin',
    'sin6',
    'sas',
    'unx',
]
union_anon_87._fields_ = [
    ('sin', struct_sockaddr_in),
    ('sin6', struct_sockaddr_in6),
    ('sas', struct_sockaddr_storage),
    ('unx', struct_sockaddr_un),
]

struct_apr_sockaddr_t.__slots__ = [
    'pool',
    'hostname',
    'servname',
    'port',
    'family',
    'salen',
    'ipaddr_len',
    'addr_str_len',
    'ipaddr_ptr',
    'next',
    'sa',
]
struct_apr_sockaddr_t._fields_ = [
    ('pool', POINTER(apr_pool_t)),
    ('hostname', String),
    ('servname', String),
    ('port', apr_port_t),
    ('family', apr_int32_t),
    ('salen', apr_socklen_t),
    ('ipaddr_len', c_int),
    ('addr_str_len', c_int),
    ('ipaddr_ptr', POINTER(None)),
    ('next', POINTER(apr_sockaddr_t)),
    ('sa', union_anon_87),
]

struct_apr_hdtr_t.__slots__ = [
    'headers',
    'numheaders',
    'trailers',
    'numtrailers',
]
struct_apr_hdtr_t._fields_ = [
    ('headers', POINTER(struct_iovec)),
    ('numheaders', c_int),
    ('trailers', POINTER(struct_iovec)),
    ('numtrailers', c_int),
]

# /usr/include/apr/apr_network_io.h: 317
if _libs["apr-1"].has("apr_socket_create", "cdecl"):
    apr_socket_create = _libs["apr-1"].get("apr_socket_create", "cdecl")
    apr_socket_create.argtypes = [POINTER(POINTER(apr_socket_t)), c_int, c_int, c_int, POINTER(apr_pool_t)]
    apr_socket_create.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 335
if _libs["apr-1"].has("apr_socket_shutdown", "cdecl"):
    apr_socket_shutdown = _libs["apr-1"].get("apr_socket_shutdown", "cdecl")
    apr_socket_shutdown.argtypes = [POINTER(apr_socket_t), apr_shutdown_how_e]
    apr_socket_shutdown.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 342
if _libs["apr-1"].has("apr_socket_close", "cdecl"):
    apr_socket_close = _libs["apr-1"].get("apr_socket_close", "cdecl")
    apr_socket_close.argtypes = [POINTER(apr_socket_t)]
    apr_socket_close.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 351
if _libs["apr-1"].has("apr_socket_bind", "cdecl"):
    apr_socket_bind = _libs["apr-1"].get("apr_socket_bind", "cdecl")
    apr_socket_bind.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t)]
    apr_socket_bind.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 361
if _libs["apr-1"].has("apr_socket_listen", "cdecl"):
    apr_socket_listen = _libs["apr-1"].get("apr_socket_listen", "cdecl")
    apr_socket_listen.argtypes = [POINTER(apr_socket_t), apr_int32_t]
    apr_socket_listen.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 375
if _libs["apr-1"].has("apr_socket_accept", "cdecl"):
    apr_socket_accept = _libs["apr-1"].get("apr_socket_accept", "cdecl")
    apr_socket_accept.argtypes = [POINTER(POINTER(apr_socket_t)), POINTER(apr_socket_t), POINTER(apr_pool_t)]
    apr_socket_accept.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 385
if _libs["apr-1"].has("apr_socket_connect", "cdecl"):
    apr_socket_connect = _libs["apr-1"].get("apr_socket_connect", "cdecl")
    apr_socket_connect.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t)]
    apr_socket_connect.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 400
if _libs["apr-1"].has("apr_socket_atreadeof", "cdecl"):
    apr_socket_atreadeof = _libs["apr-1"].get("apr_socket_atreadeof", "cdecl")
    apr_socket_atreadeof.argtypes = [POINTER(apr_socket_t), POINTER(c_int)]
    apr_socket_atreadeof.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 427
if _libs["apr-1"].has("apr_sockaddr_info_get", "cdecl"):
    apr_sockaddr_info_get = _libs["apr-1"].get("apr_sockaddr_info_get", "cdecl")
    apr_sockaddr_info_get.argtypes = [POINTER(POINTER(apr_sockaddr_t)), String, apr_int32_t, apr_port_t, apr_int32_t, POINTER(apr_pool_t)]
    apr_sockaddr_info_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 440
if _libs["apr-1"].has("apr_sockaddr_info_copy", "cdecl"):
    apr_sockaddr_info_copy = _libs["apr-1"].get("apr_sockaddr_info_copy", "cdecl")
    apr_sockaddr_info_copy.argtypes = [POINTER(POINTER(apr_sockaddr_t)), POINTER(apr_sockaddr_t), POINTER(apr_pool_t)]
    apr_sockaddr_info_copy.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 451
if _libs["apr-1"].has("apr_sockaddr_zone_set", "cdecl"):
    apr_sockaddr_zone_set = _libs["apr-1"].get("apr_sockaddr_zone_set", "cdecl")
    apr_sockaddr_zone_set.argtypes = [POINTER(apr_sockaddr_t), String]
    apr_sockaddr_zone_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 466
if _libs["apr-1"].has("apr_sockaddr_zone_get", "cdecl"):
    apr_sockaddr_zone_get = _libs["apr-1"].get("apr_sockaddr_zone_get", "cdecl")
    apr_sockaddr_zone_get.argtypes = [POINTER(apr_sockaddr_t), POINTER(POINTER(c_char)), POINTER(apr_uint32_t), POINTER(apr_pool_t)]
    apr_sockaddr_zone_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 479
if _libs["apr-1"].has("apr_getnameinfo", "cdecl"):
    apr_getnameinfo = _libs["apr-1"].get("apr_getnameinfo", "cdecl")
    apr_getnameinfo.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_sockaddr_t), apr_int32_t]
    apr_getnameinfo.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 513
if _libs["apr-1"].has("apr_parse_addr_port", "cdecl"):
    apr_parse_addr_port = _libs["apr-1"].get("apr_parse_addr_port", "cdecl")
    apr_parse_addr_port.argtypes = [POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(apr_port_t), String, POINTER(apr_pool_t)]
    apr_parse_addr_port.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 527
if _libs["apr-1"].has("apr_gethostname", "cdecl"):
    apr_gethostname = _libs["apr-1"].get("apr_gethostname", "cdecl")
    apr_gethostname.argtypes = [String, c_int, POINTER(apr_pool_t)]
    apr_gethostname.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 535
if _libs["apr-1"].has("apr_socket_data_get", "cdecl"):
    apr_socket_data_get = _libs["apr-1"].get("apr_socket_data_get", "cdecl")
    apr_socket_data_get.argtypes = [POINTER(POINTER(None)), String, POINTER(apr_socket_t)]
    apr_socket_data_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 545
if _libs["apr-1"].has("apr_socket_data_set", "cdecl"):
    apr_socket_data_set = _libs["apr-1"].get("apr_socket_data_set", "cdecl")
    apr_socket_data_set.argtypes = [POINTER(apr_socket_t), POINTER(None), String, CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None))]
    apr_socket_data_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 566
if _libs["apr-1"].has("apr_socket_send", "cdecl"):
    apr_socket_send = _libs["apr-1"].get("apr_socket_send", "cdecl")
    apr_socket_send.argtypes = [POINTER(apr_socket_t), String, POINTER(apr_size_t)]
    apr_socket_send.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 587
if _libs["apr-1"].has("apr_socket_sendv", "cdecl"):
    apr_socket_sendv = _libs["apr-1"].get("apr_socket_sendv", "cdecl")
    apr_socket_sendv.argtypes = [POINTER(apr_socket_t), POINTER(struct_iovec), apr_int32_t, POINTER(apr_size_t)]
    apr_socket_sendv.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 598
if _libs["apr-1"].has("apr_socket_sendto", "cdecl"):
    apr_socket_sendto = _libs["apr-1"].get("apr_socket_sendto", "cdecl")
    apr_socket_sendto.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t), apr_int32_t, String, POINTER(apr_size_t)]
    apr_socket_sendto.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 616
if _libs["apr-1"].has("apr_socket_recvfrom", "cdecl"):
    apr_socket_recvfrom = _libs["apr-1"].get("apr_socket_recvfrom", "cdecl")
    apr_socket_recvfrom.argtypes = [POINTER(apr_sockaddr_t), POINTER(apr_socket_t), apr_int32_t, String, POINTER(apr_size_t)]
    apr_socket_recvfrom.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 641
if _libs["apr-1"].has("apr_socket_sendfile", "cdecl"):
    apr_socket_sendfile = _libs["apr-1"].get("apr_socket_sendfile", "cdecl")
    apr_socket_sendfile.argtypes = [POINTER(apr_socket_t), POINTER(apr_file_t), POINTER(apr_hdtr_t), POINTER(apr_off_t), POINTER(apr_size_t), apr_int32_t]
    apr_socket_sendfile.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 669
if _libs["apr-1"].has("apr_socket_recv", "cdecl"):
    apr_socket_recv = _libs["apr-1"].get("apr_socket_recv", "cdecl")
    apr_socket_recv.argtypes = [POINTER(apr_socket_t), String, POINTER(apr_size_t)]
    apr_socket_recv.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 695
if _libs["apr-1"].has("apr_socket_opt_set", "cdecl"):
    apr_socket_opt_set = _libs["apr-1"].get("apr_socket_opt_set", "cdecl")
    apr_socket_opt_set.argtypes = [POINTER(apr_socket_t), apr_int32_t, apr_int32_t]
    apr_socket_opt_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 709
if _libs["apr-1"].has("apr_socket_timeout_set", "cdecl"):
    apr_socket_timeout_set = _libs["apr-1"].get("apr_socket_timeout_set", "cdecl")
    apr_socket_timeout_set.argtypes = [POINTER(apr_socket_t), apr_interval_time_t]
    apr_socket_timeout_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 731
if _libs["apr-1"].has("apr_socket_opt_get", "cdecl"):
    apr_socket_opt_get = _libs["apr-1"].get("apr_socket_opt_get", "cdecl")
    apr_socket_opt_get.argtypes = [POINTER(apr_socket_t), apr_int32_t, POINTER(apr_int32_t)]
    apr_socket_opt_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 739
if _libs["apr-1"].has("apr_socket_timeout_get", "cdecl"):
    apr_socket_timeout_get = _libs["apr-1"].get("apr_socket_timeout_get", "cdecl")
    apr_socket_timeout_get.argtypes = [POINTER(apr_socket_t), POINTER(apr_interval_time_t)]
    apr_socket_timeout_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 748
if _libs["apr-1"].has("apr_socket_atmark", "cdecl"):
    apr_socket_atmark = _libs["apr-1"].get("apr_socket_atmark", "cdecl")
    apr_socket_atmark.argtypes = [POINTER(apr_socket_t), POINTER(c_int)]
    apr_socket_atmark.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 759
if _libs["apr-1"].has("apr_socket_addr_get", "cdecl"):
    apr_socket_addr_get = _libs["apr-1"].get("apr_socket_addr_get", "cdecl")
    apr_socket_addr_get.argtypes = [POINTER(POINTER(apr_sockaddr_t)), apr_interface_e, POINTER(apr_socket_t)]
    apr_socket_addr_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 770
if _libs["apr-1"].has("apr_sockaddr_ip_get", "cdecl"):
    apr_sockaddr_ip_get = _libs["apr-1"].get("apr_sockaddr_ip_get", "cdecl")
    apr_sockaddr_ip_get.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_sockaddr_t)]
    apr_sockaddr_ip_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 778
if _libs["apr-1"].has("apr_sockaddr_ip_getbuf", "cdecl"):
    apr_sockaddr_ip_getbuf = _libs["apr-1"].get("apr_sockaddr_ip_getbuf", "cdecl")
    apr_sockaddr_ip_getbuf.argtypes = [String, apr_size_t, POINTER(apr_sockaddr_t)]
    apr_sockaddr_ip_getbuf.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 791
if _libs["apr-1"].has("apr_sockaddr_equal", "cdecl"):
    apr_sockaddr_equal = _libs["apr-1"].get("apr_sockaddr_equal", "cdecl")
    apr_sockaddr_equal.argtypes = [POINTER(apr_sockaddr_t), POINTER(apr_sockaddr_t)]
    apr_sockaddr_equal.restype = c_int

# /usr/include/apr/apr_network_io.h: 802
if _libs["apr-1"].has("apr_sockaddr_is_wildcard", "cdecl"):
    apr_sockaddr_is_wildcard = _libs["apr-1"].get("apr_sockaddr_is_wildcard", "cdecl")
    apr_sockaddr_is_wildcard.argtypes = [POINTER(apr_sockaddr_t)]
    apr_sockaddr_is_wildcard.restype = c_int

# /usr/include/apr/apr_network_io.h: 809
if _libs["apr-1"].has("apr_socket_type_get", "cdecl"):
    apr_socket_type_get = _libs["apr-1"].get("apr_socket_type_get", "cdecl")
    apr_socket_type_get.argtypes = [POINTER(apr_socket_t), POINTER(c_int)]
    apr_socket_type_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 817
if _libs["apr-1"].has("apr_getservbyname", "cdecl"):
    apr_getservbyname = _libs["apr-1"].get("apr_getservbyname", "cdecl")
    apr_getservbyname.argtypes = [POINTER(apr_sockaddr_t), String]
    apr_getservbyname.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 827
if _libs["apr-1"].has("apr_ipsubnet_create", "cdecl"):
    apr_ipsubnet_create = _libs["apr-1"].get("apr_ipsubnet_create", "cdecl")
    apr_ipsubnet_create.argtypes = [POINTER(POINTER(apr_ipsubnet_t)), String, String, POINTER(apr_pool_t)]
    apr_ipsubnet_create.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 839
if _libs["apr-1"].has("apr_ipsubnet_test", "cdecl"):
    apr_ipsubnet_test = _libs["apr-1"].get("apr_ipsubnet_test", "cdecl")
    apr_ipsubnet_test.argtypes = [POINTER(apr_ipsubnet_t), POINTER(apr_sockaddr_t)]
    apr_ipsubnet_test.restype = c_int

# /usr/include/apr/apr_network_io.h: 860
if _libs["apr-1"].has("apr_socket_protocol_get", "cdecl"):
    apr_socket_protocol_get = _libs["apr-1"].get("apr_socket_protocol_get", "cdecl")
    apr_socket_protocol_get.argtypes = [POINTER(apr_socket_t), POINTER(c_int)]
    apr_socket_protocol_get.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 866
if _libs["apr-1"].has("apr_socket_pool_get", "cdecl"):
    apr_socket_pool_get = _libs["apr-1"].get("apr_socket_pool_get", "cdecl")
    apr_socket_pool_get.argtypes = [POINTER(apr_socket_t)]
    apr_socket_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_network_io.h: 871
if _libs["apr-1"].has("apr_socket_inherit_set", "cdecl"):
    apr_socket_inherit_set = _libs["apr-1"].get("apr_socket_inherit_set", "cdecl")
    apr_socket_inherit_set.argtypes = [POINTER(apr_socket_t)]
    apr_socket_inherit_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 876
if _libs["apr-1"].has("apr_socket_inherit_unset", "cdecl"):
    apr_socket_inherit_unset = _libs["apr-1"].get("apr_socket_inherit_unset", "cdecl")
    apr_socket_inherit_unset.argtypes = [POINTER(apr_socket_t)]
    apr_socket_inherit_unset.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 881
if _libs["apr-1"].has("apr_socket_perms_set", "cdecl"):
    apr_socket_perms_set = _libs["apr-1"].get("apr_socket_perms_set", "cdecl")
    apr_socket_perms_set.argtypes = [POINTER(None), apr_fileperms_t, apr_uid_t, apr_gid_t]
    apr_socket_perms_set.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 897
if _libs["apr-1"].has("apr_mcast_join", "cdecl"):
    apr_mcast_join = _libs["apr-1"].get("apr_mcast_join", "cdecl")
    apr_mcast_join.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t), POINTER(apr_sockaddr_t), POINTER(apr_sockaddr_t)]
    apr_mcast_join.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 912
if _libs["apr-1"].has("apr_mcast_leave", "cdecl"):
    apr_mcast_leave = _libs["apr-1"].get("apr_mcast_leave", "cdecl")
    apr_mcast_leave.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t), POINTER(apr_sockaddr_t), POINTER(apr_sockaddr_t)]
    apr_mcast_leave.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 924
if _libs["apr-1"].has("apr_mcast_hops", "cdecl"):
    apr_mcast_hops = _libs["apr-1"].get("apr_mcast_hops", "cdecl")
    apr_mcast_hops.argtypes = [POINTER(apr_socket_t), apr_byte_t]
    apr_mcast_hops.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 932
if _libs["apr-1"].has("apr_mcast_loopback", "cdecl"):
    apr_mcast_loopback = _libs["apr-1"].get("apr_mcast_loopback", "cdecl")
    apr_mcast_loopback.argtypes = [POINTER(apr_socket_t), apr_byte_t]
    apr_mcast_loopback.restype = apr_status_t

# /usr/include/apr/apr_network_io.h: 941
if _libs["apr-1"].has("apr_mcast_interface", "cdecl"):
    apr_mcast_interface = _libs["apr-1"].get("apr_mcast_interface", "cdecl")
    apr_mcast_interface.argtypes = [POINTER(apr_socket_t), POINTER(apr_sockaddr_t)]
    apr_mcast_interface.restype = apr_status_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 124
class struct_svn_ra_svn_conn_st(Structure):
    pass

svn_ra_svn_conn_t = struct_svn_ra_svn_conn_st# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 124

svn_ra_svn_command_handler = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(apr_array_header_t), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 127

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 145
class struct_svn_ra_svn_cmd_entry_t(Structure):
    pass

struct_svn_ra_svn_cmd_entry_t.__slots__ = [
    'cmdname',
    'handler',
    'terminate',
]
struct_svn_ra_svn_cmd_entry_t._fields_ = [
    ('cmdname', String),
    ('handler', svn_ra_svn_command_handler),
    ('terminate', svn_boolean_t),
]

svn_ra_svn_cmd_entry_t = struct_svn_ra_svn_cmd_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 145

enum_anon_88 = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

SVN_RA_SVN_NUMBER = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

SVN_RA_SVN_STRING = (SVN_RA_SVN_NUMBER + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

SVN_RA_SVN_WORD = (SVN_RA_SVN_STRING + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

SVN_RA_SVN_LIST = (SVN_RA_SVN_WORD + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

svn_ra_svn_item_kind_t = enum_anon_88# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 156

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 165
class union_anon_89(Union):
    pass

union_anon_89.__slots__ = [
    'number',
    'string',
    'word',
    'list',
]
union_anon_89._fields_ = [
    ('number', apr_uint64_t),
    ('string', POINTER(svn_string_t)),
    ('word', String),
    ('list', POINTER(apr_array_header_t)),
]

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 173
class struct_svn_ra_svn_item_t(Structure):
    pass

struct_svn_ra_svn_item_t.__slots__ = [
    'kind',
    'u',
]
struct_svn_ra_svn_item_t._fields_ = [
    ('kind', svn_ra_svn_item_kind_t),
    ('u', union_anon_89),
]

svn_ra_svn_item_t = struct_svn_ra_svn_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 173

svn_ra_svn_edit_callback = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 175

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 213
if _libs["svn_ra-1"].has("svn_ra_svn_create_conn5", "cdecl"):
    svn_ra_svn_create_conn5 = _libs["svn_ra-1"].get("svn_ra_svn_create_conn5", "cdecl")
    svn_ra_svn_create_conn5.argtypes = [POINTER(apr_socket_t), POINTER(svn_stream_t), POINTER(svn_stream_t), c_int, apr_size_t, apr_size_t, apr_uint64_t, apr_uint64_t, POINTER(apr_pool_t)]
    svn_ra_svn_create_conn5.restype = POINTER(svn_ra_svn_conn_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 231
if _libs["svn_ra-1"].has("svn_ra_svn_create_conn4", "cdecl"):
    svn_ra_svn_create_conn4 = _libs["svn_ra-1"].get("svn_ra_svn_create_conn4", "cdecl")
    svn_ra_svn_create_conn4.argtypes = [POINTER(apr_socket_t), POINTER(svn_stream_t), POINTER(svn_stream_t), c_int, apr_size_t, apr_size_t, POINTER(apr_pool_t)]
    svn_ra_svn_create_conn4.restype = POINTER(svn_ra_svn_conn_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 247
if _libs["svn_ra-1"].has("svn_ra_svn_create_conn3", "cdecl"):
    svn_ra_svn_create_conn3 = _libs["svn_ra-1"].get("svn_ra_svn_create_conn3", "cdecl")
    svn_ra_svn_create_conn3.argtypes = [POINTER(apr_socket_t), POINTER(apr_file_t), POINTER(apr_file_t), c_int, apr_size_t, apr_size_t, POINTER(apr_pool_t)]
    svn_ra_svn_create_conn3.restype = POINTER(svn_ra_svn_conn_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 263
if _libs["svn_ra-1"].has("svn_ra_svn_create_conn2", "cdecl"):
    svn_ra_svn_create_conn2 = _libs["svn_ra-1"].get("svn_ra_svn_create_conn2", "cdecl")
    svn_ra_svn_create_conn2.argtypes = [POINTER(apr_socket_t), POINTER(apr_file_t), POINTER(apr_file_t), c_int, POINTER(apr_pool_t)]
    svn_ra_svn_create_conn2.restype = POINTER(svn_ra_svn_conn_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 277
if _libs["svn_ra-1"].has("svn_ra_svn_create_conn", "cdecl"):
    svn_ra_svn_create_conn = _libs["svn_ra-1"].get("svn_ra_svn_create_conn", "cdecl")
    svn_ra_svn_create_conn.argtypes = [POINTER(apr_socket_t), POINTER(apr_file_t), POINTER(apr_file_t), POINTER(apr_pool_t)]
    svn_ra_svn_create_conn.restype = POINTER(svn_ra_svn_conn_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 290
if _libs["svn_ra-1"].has("svn_ra_svn_set_capabilities", "cdecl"):
    svn_ra_svn_set_capabilities = _libs["svn_ra-1"].get("svn_ra_svn_set_capabilities", "cdecl")
    svn_ra_svn_set_capabilities.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_array_header_t)]
    svn_ra_svn_set_capabilities.restype = POINTER(svn_error_t)
    svn_ra_svn_set_capabilities.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 297
if _libs["svn_ra-1"].has("svn_ra_svn_has_capability", "cdecl"):
    svn_ra_svn_has_capability = _libs["svn_ra-1"].get("svn_ra_svn_has_capability", "cdecl")
    svn_ra_svn_has_capability.argtypes = [POINTER(svn_ra_svn_conn_t), String]
    svn_ra_svn_has_capability.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 305
if _libs["svn_ra-1"].has("svn_ra_svn_compression_level", "cdecl"):
    svn_ra_svn_compression_level = _libs["svn_ra-1"].get("svn_ra_svn_compression_level", "cdecl")
    svn_ra_svn_compression_level.argtypes = [POINTER(svn_ra_svn_conn_t)]
    svn_ra_svn_compression_level.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 315
if _libs["svn_ra-1"].has("svn_ra_svn_zero_copy_limit", "cdecl"):
    svn_ra_svn_zero_copy_limit = _libs["svn_ra-1"].get("svn_ra_svn_zero_copy_limit", "cdecl")
    svn_ra_svn_zero_copy_limit.argtypes = [POINTER(svn_ra_svn_conn_t)]
    svn_ra_svn_zero_copy_limit.restype = apr_size_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 319
if _libs["svn_ra-1"].has("svn_ra_svn_conn_remote_host", "cdecl"):
    svn_ra_svn_conn_remote_host = _libs["svn_ra-1"].get("svn_ra_svn_conn_remote_host", "cdecl")
    svn_ra_svn_conn_remote_host.argtypes = [POINTER(svn_ra_svn_conn_t)]
    svn_ra_svn_conn_remote_host.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 335
if _libs["svn_ra-1"].has("svn_ra_svn_get_editor", "cdecl"):
    svn_ra_svn_get_editor = _libs["svn_ra-1"].get("svn_ra_svn_get_editor", "cdecl")
    svn_ra_svn_get_editor.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), svn_ra_svn_edit_callback, POINTER(None)]
    svn_ra_svn_get_editor.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 356
if _libs["svn_ra-1"].has("svn_ra_svn_drive_editor2", "cdecl"):
    svn_ra_svn_drive_editor2 = _libs["svn_ra-1"].get("svn_ra_svn_drive_editor2", "cdecl")
    svn_ra_svn_drive_editor2.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_delta_editor_t), POINTER(None), POINTER(svn_boolean_t), svn_boolean_t]
    svn_ra_svn_drive_editor2.restype = POINTER(svn_error_t)
    svn_ra_svn_drive_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 369
if _libs["svn_ra-1"].has("svn_ra_svn_drive_editor", "cdecl"):
    svn_ra_svn_drive_editor = _libs["svn_ra-1"].get("svn_ra_svn_drive_editor", "cdecl")
    svn_ra_svn_drive_editor.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_delta_editor_t), POINTER(None), POINTER(svn_boolean_t)]
    svn_ra_svn_drive_editor.restype = POINTER(svn_error_t)
    svn_ra_svn_drive_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 384
if _libs["svn_ra-1"].has("svn_ra_svn_cram_server", "cdecl"):
    svn_ra_svn_cram_server = _libs["svn_ra-1"].get("svn_ra_svn_cram_server", "cdecl")
    svn_ra_svn_cram_server.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_config_t), POINTER(POINTER(c_char)), POINTER(svn_boolean_t)]
    svn_ra_svn_cram_server.restype = POINTER(svn_error_t)
    svn_ra_svn_cram_server.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 395
if _libs["svn_ra-1"].has("svn_ra_svn_version", "cdecl"):
    svn_ra_svn_version = _libs["svn_ra-1"].get("svn_ra_svn_version", "cdecl")
    svn_ra_svn_version.argtypes = []
    svn_ra_svn_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 411
if _libs["svn_ra-1"].has("svn_ra_svn_write_number", "cdecl"):
    svn_ra_svn_write_number = _libs["svn_ra-1"].get("svn_ra_svn_write_number", "cdecl")
    svn_ra_svn_write_number.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), apr_uint64_t]
    svn_ra_svn_write_number.restype = POINTER(svn_error_t)
    svn_ra_svn_write_number.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 424
if _libs["svn_ra-1"].has("svn_ra_svn_write_string", "cdecl"):
    svn_ra_svn_write_string = _libs["svn_ra-1"].get("svn_ra_svn_write_string", "cdecl")
    svn_ra_svn_write_string.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_string_t)]
    svn_ra_svn_write_string.restype = POINTER(svn_error_t)
    svn_ra_svn_write_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 437
if _libs["svn_ra-1"].has("svn_ra_svn_write_cstring", "cdecl"):
    svn_ra_svn_write_cstring = _libs["svn_ra-1"].get("svn_ra_svn_write_cstring", "cdecl")
    svn_ra_svn_write_cstring.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_write_cstring.restype = POINTER(svn_error_t)
    svn_ra_svn_write_cstring.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 450
if _libs["svn_ra-1"].has("svn_ra_svn_write_word", "cdecl"):
    svn_ra_svn_write_word = _libs["svn_ra-1"].get("svn_ra_svn_write_word", "cdecl")
    svn_ra_svn_write_word.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_write_word.restype = POINTER(svn_error_t)
    svn_ra_svn_write_word.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 464
if _libs["svn_ra-1"].has("svn_ra_svn_write_proplist", "cdecl"):
    svn_ra_svn_write_proplist = _libs["svn_ra-1"].get("svn_ra_svn_write_proplist", "cdecl")
    svn_ra_svn_write_proplist.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(apr_hash_t)]
    svn_ra_svn_write_proplist.restype = POINTER(svn_error_t)
    svn_ra_svn_write_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 475
if _libs["svn_ra-1"].has("svn_ra_svn_start_list", "cdecl"):
    svn_ra_svn_start_list = _libs["svn_ra-1"].get("svn_ra_svn_start_list", "cdecl")
    svn_ra_svn_start_list.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t)]
    svn_ra_svn_start_list.restype = POINTER(svn_error_t)
    svn_ra_svn_start_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 485
if _libs["svn_ra-1"].has("svn_ra_svn_end_list", "cdecl"):
    svn_ra_svn_end_list = _libs["svn_ra-1"].get("svn_ra_svn_end_list", "cdecl")
    svn_ra_svn_end_list.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t)]
    svn_ra_svn_end_list.restype = POINTER(svn_error_t)
    svn_ra_svn_end_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 498
if _libs["svn_ra-1"].has("svn_ra_svn_flush", "cdecl"):
    svn_ra_svn_flush = _libs["svn_ra-1"].get("svn_ra_svn_flush", "cdecl")
    svn_ra_svn_flush.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t)]
    svn_ra_svn_flush.restype = POINTER(svn_error_t)
    svn_ra_svn_flush.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 545
if _libs["svn_ra-1"].has("svn_ra_svn_write_tuple", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_write_tuple", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_write_tuple = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 556
if _libs["svn_ra-1"].has("svn_ra_svn_read_item", "cdecl"):
    svn_ra_svn_read_item = _libs["svn_ra-1"].get("svn_ra_svn_read_item", "cdecl")
    svn_ra_svn_read_item.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(POINTER(svn_ra_svn_item_t))]
    svn_ra_svn_read_item.restype = POINTER(svn_error_t)
    svn_ra_svn_read_item.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 572
if _libs["svn_ra-1"].has("svn_ra_svn_skip_leading_garbage", "cdecl"):
    svn_ra_svn_skip_leading_garbage = _libs["svn_ra-1"].get("svn_ra_svn_skip_leading_garbage", "cdecl")
    svn_ra_svn_skip_leading_garbage.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t)]
    svn_ra_svn_skip_leading_garbage.restype = POINTER(svn_error_t)
    svn_ra_svn_skip_leading_garbage.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 612
if _libs["svn_ra-1"].has("svn_ra_svn_parse_tuple", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_parse_tuple", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t), String]
    svn_ra_svn_parse_tuple = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 624
if _libs["svn_ra-1"].has("svn_ra_svn_read_tuple", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_read_tuple", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_read_tuple = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 638
if _libs["svn_ra-1"].has("svn_ra_svn_parse_proplist", "cdecl"):
    svn_ra_svn_parse_proplist = _libs["svn_ra-1"].get("svn_ra_svn_parse_proplist", "cdecl")
    svn_ra_svn_parse_proplist.argtypes = [POINTER(apr_array_header_t), POINTER(apr_pool_t), POINTER(POINTER(apr_hash_t))]
    svn_ra_svn_parse_proplist.restype = POINTER(svn_error_t)
    svn_ra_svn_parse_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 650
if _libs["svn_ra-1"].has("svn_ra_svn_read_cmd_response", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_read_cmd_response", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_read_cmd_response = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 672
if _libs["svn_ra-1"].has("svn_ra_svn_handle_commands2", "cdecl"):
    svn_ra_svn_handle_commands2 = _libs["svn_ra-1"].get("svn_ra_svn_handle_commands2", "cdecl")
    svn_ra_svn_handle_commands2.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_ra_svn_cmd_entry_t), POINTER(None), svn_boolean_t]
    svn_ra_svn_handle_commands2.restype = POINTER(svn_error_t)
    svn_ra_svn_handle_commands2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 685
if _libs["svn_ra-1"].has("svn_ra_svn_handle_commands", "cdecl"):
    svn_ra_svn_handle_commands = _libs["svn_ra-1"].get("svn_ra_svn_handle_commands", "cdecl")
    svn_ra_svn_handle_commands.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_ra_svn_cmd_entry_t), POINTER(None)]
    svn_ra_svn_handle_commands.restype = POINTER(svn_error_t)
    svn_ra_svn_handle_commands.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 698
if _libs["svn_ra-1"].has("svn_ra_svn_write_cmd", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_write_cmd", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String, String]
    svn_ra_svn_write_cmd = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 713
if _libs["svn_ra-1"].has("svn_ra_svn_write_cmd_response", "cdecl"):
    _func = _libs["svn_ra-1"].get("svn_ra_svn_write_cmd_response", "cdecl")
    _restype = POINTER(svn_error_t)
    _errcheck = None
    _argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), String]
    svn_ra_svn_write_cmd_response = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 724
if _libs["svn_ra-1"].has("svn_ra_svn_write_cmd_failure", "cdecl"):
    svn_ra_svn_write_cmd_failure = _libs["svn_ra-1"].get("svn_ra_svn_write_cmd_failure", "cdecl")
    svn_ra_svn_write_cmd_failure.argtypes = [POINTER(svn_ra_svn_conn_t), POINTER(apr_pool_t), POINTER(svn_error_t)]
    svn_ra_svn_write_cmd_failure.restype = POINTER(svn_error_t)
    svn_ra_svn_write_cmd_failure.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 54
if _libs["svn_repos-1"].has("svn_repos_version", "cdecl"):
    svn_repos_version = _libs["svn_repos-1"].get("svn_repos_version", "cdecl")
    svn_repos_version.argtypes = []
    svn_repos_version.restype = POINTER(svn_version_t)

enum_svn_node_action = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 61

svn_node_action_change = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 61

svn_node_action_add = (svn_node_action_change + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 61

svn_node_action_delete = (svn_node_action_add + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 61

svn_node_action_replace = (svn_node_action_delete + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 61

svn_repos_authz_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 93

enum_svn_repos_authz_access_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_authz_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_authz_read = 1# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_authz_write = 2# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_authz_recursive = 4# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_repos_authz_access_t = enum_svn_repos_authz_access_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 117

svn_repos_authz_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), svn_repos_authz_access_t, POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 154

enum_svn_repos_notify_action_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_warning = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_dump_rev_end = (svn_repos_notify_warning + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_verify_rev_end = (svn_repos_notify_dump_rev_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_dump_end = (svn_repos_notify_verify_rev_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_verify_end = (svn_repos_notify_dump_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_shard_start = (svn_repos_notify_verify_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_shard_end = (svn_repos_notify_pack_shard_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_shard_start_revprop = (svn_repos_notify_pack_shard_end + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_shard_end_revprop = (svn_repos_notify_pack_shard_start_revprop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_txn_start = (svn_repos_notify_pack_shard_end_revprop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_txn_committed = (svn_repos_notify_load_txn_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_node_start = (svn_repos_notify_load_txn_committed + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_node_done = (svn_repos_notify_load_node_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_copied_node = (svn_repos_notify_load_node_done + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_normalized_mergeinfo = (svn_repos_notify_load_copied_node + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_mutex_acquired = (svn_repos_notify_load_normalized_mergeinfo + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_recover_start = (svn_repos_notify_mutex_acquired + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_upgrade_start = (svn_repos_notify_recover_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_skipped_rev = (svn_repos_notify_upgrade_start + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_verify_rev_structure = (svn_repos_notify_load_skipped_rev + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_revprops = (svn_repos_notify_verify_rev_structure + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_cleanup_revprops = (svn_repos_notify_pack_revprops + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_format_bumped = (svn_repos_notify_cleanup_revprops + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_hotcopy_rev_range = (svn_repos_notify_format_bumped + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_pack_noop = (svn_repos_notify_hotcopy_rev_range + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_load_revprop_set = (svn_repos_notify_pack_noop + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

svn_repos_notify_action_t = enum_svn_repos_notify_action_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 254

enum_svn_repos_notify_warning_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_found_old_reference = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_found_old_mergeinfo = (svn_repos_notify_warning_found_old_reference + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_invalid_fspath = (svn_repos_notify_warning_found_old_mergeinfo + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_name_collision = (svn_repos_notify_warning_invalid_fspath + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_mergeinfo_collision = (svn_repos_notify_warning_name_collision + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_invalid_mergeinfo = (svn_repos_notify_warning_mergeinfo_collision + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

svn_repos_notify_warning_t = enum_svn_repos_notify_warning_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 301

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 367
class struct_svn_repos_notify_t(Structure):
    pass

struct_svn_repos_notify_t.__slots__ = [
    'action',
    'revision',
    'warning_str',
    'warning',
    'shard',
    'new_revision',
    'old_revision',
    'node_action',
    'path',
    'start_revision',
    'end_revision',
]
struct_svn_repos_notify_t._fields_ = [
    ('action', svn_repos_notify_action_t),
    ('revision', svn_revnum_t),
    ('warning_str', String),
    ('warning', svn_repos_notify_warning_t),
    ('shard', c_int64),
    ('new_revision', svn_revnum_t),
    ('old_revision', svn_revnum_t),
    ('node_action', enum_svn_node_action),
    ('path', String),
    ('start_revision', svn_revnum_t),
    ('end_revision', svn_revnum_t),
]

svn_repos_notify_t = struct_svn_repos_notify_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 367

svn_repos_notify_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(svn_repos_notify_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 374

svn_repos_dump_filter_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_boolean_t), POINTER(svn_fs_root_t), String, POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 389

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 402
if _libs["svn_repos-1"].has("svn_repos_notify_create", "cdecl"):
    svn_repos_notify_create = _libs["svn_repos-1"].get("svn_repos_notify_create", "cdecl")
    svn_repos_notify_create.argtypes = [svn_repos_notify_action_t, POINTER(apr_pool_t)]
    svn_repos_notify_create.restype = POINTER(svn_repos_notify_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 410
class struct_svn_repos_t(Structure):
    pass

svn_repos_t = struct_svn_repos_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 410

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 421
if _libs["svn_repos-1"].has("svn_repos_find_root_path", "cdecl"):
    svn_repos_find_root_path = _libs["svn_repos-1"].get("svn_repos_find_root_path", "cdecl")
    svn_repos_find_root_path.argtypes = [String, POINTER(apr_pool_t)]
    svn_repos_find_root_path.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 439
if _libs["svn_repos-1"].has("svn_repos_open3", "cdecl"):
    svn_repos_open3 = _libs["svn_repos-1"].get("svn_repos_open3", "cdecl")
    svn_repos_open3.argtypes = [POINTER(POINTER(svn_repos_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_open3.restype = POINTER(svn_error_t)
    svn_repos_open3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 452
if _libs["svn_repos-1"].has("svn_repos_open2", "cdecl"):
    svn_repos_open2 = _libs["svn_repos-1"].get("svn_repos_open2", "cdecl")
    svn_repos_open2.argtypes = [POINTER(POINTER(svn_repos_t)), String, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_repos_open2.restype = POINTER(svn_error_t)
    svn_repos_open2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 463
if _libs["svn_repos-1"].has("svn_repos_open", "cdecl"):
    svn_repos_open = _libs["svn_repos-1"].get("svn_repos_open", "cdecl")
    svn_repos_open.argtypes = [POINTER(POINTER(svn_repos_t)), String, POINTER(apr_pool_t)]
    svn_repos_open.restype = POINTER(svn_error_t)
    svn_repos_open.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 479
if _libs["svn_repos-1"].has("svn_repos_create", "cdecl"):
    svn_repos_create = _libs["svn_repos-1"].get("svn_repos_create", "cdecl")
    svn_repos_create.argtypes = [POINTER(POINTER(svn_repos_t)), String, String, String, POINTER(apr_hash_t), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_repos_create.restype = POINTER(svn_error_t)
    svn_repos_create.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 525
if _libs["svn_repos-1"].has("svn_repos_upgrade2", "cdecl"):
    svn_repos_upgrade2 = _libs["svn_repos-1"].get("svn_repos_upgrade2", "cdecl")
    svn_repos_upgrade2.argtypes = [String, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_upgrade2.restype = POINTER(svn_error_t)
    svn_repos_upgrade2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 540
if _libs["svn_repos-1"].has("svn_repos_upgrade", "cdecl"):
    svn_repos_upgrade = _libs["svn_repos-1"].get("svn_repos_upgrade", "cdecl")
    svn_repos_upgrade.argtypes = [String, svn_boolean_t, CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None)), POINTER(None), POINTER(apr_pool_t)]
    svn_repos_upgrade.restype = POINTER(svn_error_t)
    svn_repos_upgrade.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 550
if _libs["svn_repos-1"].has("svn_repos_delete", "cdecl"):
    svn_repos_delete = _libs["svn_repos-1"].get("svn_repos_delete", "cdecl")
    svn_repos_delete.argtypes = [String, POINTER(apr_pool_t)]
    svn_repos_delete.restype = POINTER(svn_error_t)
    svn_repos_delete.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 571
if _libs["svn_repos-1"].has("svn_repos_has_capability", "cdecl"):
    svn_repos_has_capability = _libs["svn_repos-1"].get("svn_repos_has_capability", "cdecl")
    svn_repos_has_capability.argtypes = [POINTER(svn_repos_t), POINTER(svn_boolean_t), String, POINTER(apr_pool_t)]
    svn_repos_has_capability.restype = POINTER(svn_error_t)
    svn_repos_has_capability.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 593
if _libs["svn_repos-1"].has("svn_repos_capabilities", "cdecl"):
    svn_repos_capabilities = _libs["svn_repos-1"].get("svn_repos_capabilities", "cdecl")
    svn_repos_capabilities.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_repos_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_capabilities.restype = POINTER(svn_error_t)
    svn_repos_capabilities.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 638
if _libs["svn_repos-1"].has("svn_repos_remember_client_capabilities", "cdecl"):
    svn_repos_remember_client_capabilities = _libs["svn_repos-1"].get("svn_repos_remember_client_capabilities", "cdecl")
    svn_repos_remember_client_capabilities.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t)]
    svn_repos_remember_client_capabilities.restype = POINTER(svn_error_t)
    svn_repos_remember_client_capabilities.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 644
if _libs["svn_repos-1"].has("svn_repos_fs", "cdecl"):
    svn_repos_fs = _libs["svn_repos-1"].get("svn_repos_fs", "cdecl")
    svn_repos_fs.argtypes = [POINTER(svn_repos_t)]
    svn_repos_fs.restype = POINTER(svn_fs_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 654
if _libs["svn_repos-1"].has("svn_repos_fs_type", "cdecl"):
    svn_repos_fs_type = _libs["svn_repos-1"].get("svn_repos_fs_type", "cdecl")
    svn_repos_fs_type.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_fs_type.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 687
if _libs["svn_repos-1"].has("svn_repos_hotcopy3", "cdecl"):
    svn_repos_hotcopy3 = _libs["svn_repos-1"].get("svn_repos_hotcopy3", "cdecl")
    svn_repos_hotcopy3.argtypes = [String, String, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_hotcopy3.restype = POINTER(svn_error_t)
    svn_repos_hotcopy3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 706
if _libs["svn_repos-1"].has("svn_repos_hotcopy2", "cdecl"):
    svn_repos_hotcopy2 = _libs["svn_repos-1"].get("svn_repos_hotcopy2", "cdecl")
    svn_repos_hotcopy2.argtypes = [String, String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_hotcopy2.restype = POINTER(svn_error_t)
    svn_repos_hotcopy2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 722
if _libs["svn_repos-1"].has("svn_repos_hotcopy", "cdecl"):
    svn_repos_hotcopy = _libs["svn_repos-1"].get("svn_repos_hotcopy", "cdecl")
    svn_repos_hotcopy.argtypes = [String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_hotcopy.restype = POINTER(svn_error_t)
    svn_repos_hotcopy.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 735
if _libs["svn_repos-1"].has("svn_repos_fs_pack2", "cdecl"):
    svn_repos_fs_pack2 = _libs["svn_repos-1"].get("svn_repos_fs_pack2", "cdecl")
    svn_repos_fs_pack2.argtypes = [POINTER(svn_repos_t), svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_pack2.restype = POINTER(svn_error_t)
    svn_repos_fs_pack2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 751
if _libs["svn_repos-1"].has("svn_repos_fs_pack", "cdecl"):
    svn_repos_fs_pack = _libs["svn_repos-1"].get("svn_repos_fs_pack", "cdecl")
    svn_repos_fs_pack.argtypes = [POINTER(svn_repos_t), svn_fs_pack_notify_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_pack.restype = POINTER(svn_error_t)
    svn_repos_fs_pack.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 786
if _libs["svn_repos-1"].has("svn_repos_recover4", "cdecl"):
    svn_repos_recover4 = _libs["svn_repos-1"].get("svn_repos_recover4", "cdecl")
    svn_repos_recover4.argtypes = [String, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_recover4.restype = POINTER(svn_error_t)
    svn_repos_recover4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 803
if _libs["svn_repos-1"].has("svn_repos_recover3", "cdecl"):
    svn_repos_recover3 = _libs["svn_repos-1"].get("svn_repos_recover3", "cdecl")
    svn_repos_recover3.argtypes = [String, svn_boolean_t, CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None)), POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_recover3.restype = POINTER(svn_error_t)
    svn_repos_recover3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 818
if _libs["svn_repos-1"].has("svn_repos_recover2", "cdecl"):
    svn_repos_recover2 = _libs["svn_repos-1"].get("svn_repos_recover2", "cdecl")
    svn_repos_recover2.argtypes = [String, svn_boolean_t, CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None)), POINTER(None), POINTER(apr_pool_t)]
    svn_repos_recover2.restype = POINTER(svn_error_t)
    svn_repos_recover2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 832
if _libs["svn_repos-1"].has("svn_repos_recover", "cdecl"):
    svn_repos_recover = _libs["svn_repos-1"].get("svn_repos_recover", "cdecl")
    svn_repos_recover.argtypes = [String, POINTER(apr_pool_t)]
    svn_repos_recover.restype = POINTER(svn_error_t)
    svn_repos_recover.errcheck = _svn_errcheck

svn_repos_freeze_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 841

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 863
if _libs["svn_repos-1"].has("svn_repos_freeze", "cdecl"):
    svn_repos_freeze = _libs["svn_repos-1"].get("svn_repos_freeze", "cdecl")
    svn_repos_freeze.argtypes = [POINTER(apr_array_header_t), svn_repos_freeze_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_freeze.restype = POINTER(svn_error_t)
    svn_repos_freeze.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 874
if _libs["svn_repos-1"].has("svn_repos_db_logfiles", "cdecl"):
    svn_repos_db_logfiles = _libs["svn_repos-1"].get("svn_repos_db_logfiles", "cdecl")
    svn_repos_db_logfiles.argtypes = [POINTER(POINTER(apr_array_header_t)), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_db_logfiles.restype = POINTER(svn_error_t)
    svn_repos_db_logfiles.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 885
if _libs["svn_repos-1"].has("svn_repos_path", "cdecl"):
    svn_repos_path = _libs["svn_repos-1"].get("svn_repos_path", "cdecl")
    svn_repos_path.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_path.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 892
if _libs["svn_repos-1"].has("svn_repos_db_env", "cdecl"):
    svn_repos_db_env = _libs["svn_repos-1"].get("svn_repos_db_env", "cdecl")
    svn_repos_db_env.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_db_env.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 897
if _libs["svn_repos-1"].has("svn_repos_conf_dir", "cdecl"):
    svn_repos_conf_dir = _libs["svn_repos-1"].get("svn_repos_conf_dir", "cdecl")
    svn_repos_conf_dir.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_conf_dir.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 902
if _libs["svn_repos-1"].has("svn_repos_svnserve_conf", "cdecl"):
    svn_repos_svnserve_conf = _libs["svn_repos-1"].get("svn_repos_svnserve_conf", "cdecl")
    svn_repos_svnserve_conf.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_svnserve_conf.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 907
if _libs["svn_repos-1"].has("svn_repos_lock_dir", "cdecl"):
    svn_repos_lock_dir = _libs["svn_repos-1"].get("svn_repos_lock_dir", "cdecl")
    svn_repos_lock_dir.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_lock_dir.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 912
if _libs["svn_repos-1"].has("svn_repos_db_lockfile", "cdecl"):
    svn_repos_db_lockfile = _libs["svn_repos-1"].get("svn_repos_db_lockfile", "cdecl")
    svn_repos_db_lockfile.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_db_lockfile.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 917
if _libs["svn_repos-1"].has("svn_repos_db_logs_lockfile", "cdecl"):
    svn_repos_db_logs_lockfile = _libs["svn_repos-1"].get("svn_repos_db_logs_lockfile", "cdecl")
    svn_repos_db_logs_lockfile.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_db_logs_lockfile.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 922
if _libs["svn_repos-1"].has("svn_repos_hook_dir", "cdecl"):
    svn_repos_hook_dir = _libs["svn_repos-1"].get("svn_repos_hook_dir", "cdecl")
    svn_repos_hook_dir.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_hook_dir.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 927
if _libs["svn_repos-1"].has("svn_repos_start_commit_hook", "cdecl"):
    svn_repos_start_commit_hook = _libs["svn_repos-1"].get("svn_repos_start_commit_hook", "cdecl")
    svn_repos_start_commit_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_start_commit_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 932
if _libs["svn_repos-1"].has("svn_repos_pre_commit_hook", "cdecl"):
    svn_repos_pre_commit_hook = _libs["svn_repos-1"].get("svn_repos_pre_commit_hook", "cdecl")
    svn_repos_pre_commit_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_pre_commit_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 937
if _libs["svn_repos-1"].has("svn_repos_post_commit_hook", "cdecl"):
    svn_repos_post_commit_hook = _libs["svn_repos-1"].get("svn_repos_post_commit_hook", "cdecl")
    svn_repos_post_commit_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_post_commit_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 944
if _libs["svn_repos-1"].has("svn_repos_pre_revprop_change_hook", "cdecl"):
    svn_repos_pre_revprop_change_hook = _libs["svn_repos-1"].get("svn_repos_pre_revprop_change_hook", "cdecl")
    svn_repos_pre_revprop_change_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_pre_revprop_change_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 951
if _libs["svn_repos-1"].has("svn_repos_post_revprop_change_hook", "cdecl"):
    svn_repos_post_revprop_change_hook = _libs["svn_repos-1"].get("svn_repos_post_revprop_change_hook", "cdecl")
    svn_repos_post_revprop_change_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_post_revprop_change_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 961
if _libs["svn_repos-1"].has("svn_repos_pre_lock_hook", "cdecl"):
    svn_repos_pre_lock_hook = _libs["svn_repos-1"].get("svn_repos_pre_lock_hook", "cdecl")
    svn_repos_pre_lock_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_pre_lock_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 966
if _libs["svn_repos-1"].has("svn_repos_post_lock_hook", "cdecl"):
    svn_repos_post_lock_hook = _libs["svn_repos-1"].get("svn_repos_post_lock_hook", "cdecl")
    svn_repos_post_lock_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_post_lock_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 971
if _libs["svn_repos-1"].has("svn_repos_pre_unlock_hook", "cdecl"):
    svn_repos_pre_unlock_hook = _libs["svn_repos-1"].get("svn_repos_pre_unlock_hook", "cdecl")
    svn_repos_pre_unlock_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_pre_unlock_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 976
if _libs["svn_repos-1"].has("svn_repos_post_unlock_hook", "cdecl"):
    svn_repos_post_unlock_hook = _libs["svn_repos-1"].get("svn_repos_post_unlock_hook", "cdecl")
    svn_repos_post_unlock_hook.argtypes = [POINTER(svn_repos_t), POINTER(apr_pool_t)]
    svn_repos_post_unlock_hook.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 996
if _libs["svn_repos-1"].has("svn_repos_hooks_setenv", "cdecl"):
    svn_repos_hooks_setenv = _libs["svn_repos-1"].get("svn_repos_hooks_setenv", "cdecl")
    svn_repos_hooks_setenv.argtypes = [POINTER(svn_repos_t), String, POINTER(apr_pool_t)]
    svn_repos_hooks_setenv.restype = POINTER(svn_error_t)
    svn_repos_hooks_setenv.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1094
if _libs["svn_repos-1"].has("svn_repos_begin_report3", "cdecl"):
    svn_repos_begin_report3 = _libs["svn_repos-1"].get("svn_repos_begin_report3", "cdecl")
    svn_repos_begin_report3.argtypes = [POINTER(POINTER(None)), svn_revnum_t, POINTER(svn_repos_t), String, String, String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), apr_size_t, POINTER(apr_pool_t)]
    svn_repos_begin_report3.restype = POINTER(svn_error_t)
    svn_repos_begin_report3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1120
if _libs["svn_repos-1"].has("svn_repos_begin_report2", "cdecl"):
    svn_repos_begin_report2 = _libs["svn_repos-1"].get("svn_repos_begin_report2", "cdecl")
    svn_repos_begin_report2.argtypes = [POINTER(POINTER(None)), svn_revnum_t, POINTER(svn_repos_t), String, String, String, svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_begin_report2.restype = POINTER(svn_error_t)
    svn_repos_begin_report2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1151
if _libs["svn_repos-1"].has("svn_repos_begin_report", "cdecl"):
    svn_repos_begin_report = _libs["svn_repos-1"].get("svn_repos_begin_report", "cdecl")
    svn_repos_begin_report.argtypes = [POINTER(POINTER(None)), svn_revnum_t, String, POINTER(svn_repos_t), String, String, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_begin_report.restype = POINTER(svn_error_t)
    svn_repos_begin_report.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1203
if _libs["svn_repos-1"].has("svn_repos_set_path3", "cdecl"):
    svn_repos_set_path3 = _libs["svn_repos-1"].get("svn_repos_set_path3", "cdecl")
    svn_repos_set_path3.argtypes = [POINTER(None), String, svn_revnum_t, svn_depth_t, svn_boolean_t, String, POINTER(apr_pool_t)]
    svn_repos_set_path3.restype = POINTER(svn_error_t)
    svn_repos_set_path3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1219
if _libs["svn_repos-1"].has("svn_repos_set_path2", "cdecl"):
    svn_repos_set_path2 = _libs["svn_repos-1"].get("svn_repos_set_path2", "cdecl")
    svn_repos_set_path2.argtypes = [POINTER(None), String, svn_revnum_t, svn_boolean_t, String, POINTER(apr_pool_t)]
    svn_repos_set_path2.restype = POINTER(svn_error_t)
    svn_repos_set_path2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1233
if _libs["svn_repos-1"].has("svn_repos_set_path", "cdecl"):
    svn_repos_set_path = _libs["svn_repos-1"].get("svn_repos_set_path", "cdecl")
    svn_repos_set_path.argtypes = [POINTER(None), String, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_set_path.restype = POINTER(svn_error_t)
    svn_repos_set_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1267
if _libs["svn_repos-1"].has("svn_repos_link_path3", "cdecl"):
    svn_repos_link_path3 = _libs["svn_repos-1"].get("svn_repos_link_path3", "cdecl")
    svn_repos_link_path3.argtypes = [POINTER(None), String, String, svn_revnum_t, svn_depth_t, svn_boolean_t, String, POINTER(apr_pool_t)]
    svn_repos_link_path3.restype = POINTER(svn_error_t)
    svn_repos_link_path3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1284
if _libs["svn_repos-1"].has("svn_repos_link_path2", "cdecl"):
    svn_repos_link_path2 = _libs["svn_repos-1"].get("svn_repos_link_path2", "cdecl")
    svn_repos_link_path2.argtypes = [POINTER(None), String, String, svn_revnum_t, svn_boolean_t, String, POINTER(apr_pool_t)]
    svn_repos_link_path2.restype = POINTER(svn_error_t)
    svn_repos_link_path2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1299
if _libs["svn_repos-1"].has("svn_repos_link_path", "cdecl"):
    svn_repos_link_path = _libs["svn_repos-1"].get("svn_repos_link_path", "cdecl")
    svn_repos_link_path.argtypes = [POINTER(None), String, String, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_link_path.restype = POINTER(svn_error_t)
    svn_repos_link_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1318
if _libs["svn_repos-1"].has("svn_repos_delete_path", "cdecl"):
    svn_repos_delete_path = _libs["svn_repos-1"].get("svn_repos_delete_path", "cdecl")
    svn_repos_delete_path.argtypes = [POINTER(None), String, POINTER(apr_pool_t)]
    svn_repos_delete_path.restype = POINTER(svn_error_t)
    svn_repos_delete_path.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1335
if _libs["svn_repos-1"].has("svn_repos_finish_report", "cdecl"):
    svn_repos_finish_report = _libs["svn_repos-1"].get("svn_repos_finish_report", "cdecl")
    svn_repos_finish_report.argtypes = [POINTER(None), POINTER(apr_pool_t)]
    svn_repos_finish_report.restype = POINTER(svn_error_t)
    svn_repos_finish_report.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1347
if _libs["svn_repos-1"].has("svn_repos_abort_report", "cdecl"):
    svn_repos_abort_report = _libs["svn_repos-1"].get("svn_repos_abort_report", "cdecl")
    svn_repos_abort_report.argtypes = [POINTER(None), POINTER(apr_pool_t)]
    svn_repos_abort_report.restype = POINTER(svn_error_t)
    svn_repos_abort_report.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1424
if _libs["svn_repos-1"].has("svn_repos_dir_delta2", "cdecl"):
    svn_repos_dir_delta2 = _libs["svn_repos-1"].get("svn_repos_dir_delta2", "cdecl")
    svn_repos_dir_delta2.argtypes = [POINTER(svn_fs_root_t), String, String, POINTER(svn_fs_root_t), String, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), svn_boolean_t, svn_depth_t, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_dir_delta2.restype = POINTER(svn_error_t)
    svn_repos_dir_delta2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1448
if _libs["svn_repos-1"].has("svn_repos_dir_delta", "cdecl"):
    svn_repos_dir_delta = _libs["svn_repos-1"].get("svn_repos_dir_delta", "cdecl")
    svn_repos_dir_delta.argtypes = [POINTER(svn_fs_root_t), String, String, POINTER(svn_fs_root_t), String, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_dir_delta.restype = POINTER(svn_error_t)
    svn_repos_dir_delta.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1497
if _libs["svn_repos-1"].has("svn_repos_replay2", "cdecl"):
    svn_repos_replay2 = _libs["svn_repos-1"].get("svn_repos_replay2", "cdecl")
    svn_repos_replay2.argtypes = [POINTER(svn_fs_root_t), String, svn_revnum_t, svn_boolean_t, POINTER(svn_delta_editor_t), POINTER(None), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_replay2.restype = POINTER(svn_error_t)
    svn_repos_replay2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1517
if _libs["svn_repos-1"].has("svn_repos_replay", "cdecl"):
    svn_repos_replay = _libs["svn_repos-1"].get("svn_repos_replay", "cdecl")
    svn_repos_replay.argtypes = [POINTER(svn_fs_root_t), POINTER(svn_delta_editor_t), POINTER(None), POINTER(apr_pool_t)]
    svn_repos_replay.restype = POINTER(svn_error_t)
    svn_repos_replay.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1578
if _libs["svn_repos-1"].has("svn_repos_get_commit_editor5", "cdecl"):
    svn_repos_get_commit_editor5 = _libs["svn_repos-1"].get("svn_repos_get_commit_editor5", "cdecl")
    svn_repos_get_commit_editor5.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), POINTER(svn_fs_txn_t), String, String, POINTER(apr_hash_t), svn_commit_callback2_t, POINTER(None), svn_repos_authz_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_commit_editor5.restype = POINTER(svn_error_t)
    svn_repos_get_commit_editor5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1603
if _libs["svn_repos-1"].has("svn_repos_get_commit_editor4", "cdecl"):
    svn_repos_get_commit_editor4 = _libs["svn_repos-1"].get("svn_repos_get_commit_editor4", "cdecl")
    svn_repos_get_commit_editor4.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), POINTER(svn_fs_txn_t), String, String, String, String, svn_commit_callback2_t, POINTER(None), svn_repos_authz_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_commit_editor4.restype = POINTER(svn_error_t)
    svn_repos_get_commit_editor4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1627
if _libs["svn_repos-1"].has("svn_repos_get_commit_editor3", "cdecl"):
    svn_repos_get_commit_editor3 = _libs["svn_repos-1"].get("svn_repos_get_commit_editor3", "cdecl")
    svn_repos_get_commit_editor3.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), POINTER(svn_fs_txn_t), String, String, String, String, svn_commit_callback_t, POINTER(None), svn_repos_authz_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_commit_editor3.restype = POINTER(svn_error_t)
    svn_repos_get_commit_editor3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1649
if _libs["svn_repos-1"].has("svn_repos_get_commit_editor2", "cdecl"):
    svn_repos_get_commit_editor2 = _libs["svn_repos-1"].get("svn_repos_get_commit_editor2", "cdecl")
    svn_repos_get_commit_editor2.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), POINTER(svn_fs_txn_t), String, String, String, String, svn_commit_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_commit_editor2.restype = POINTER(svn_error_t)
    svn_repos_get_commit_editor2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1670
if _libs["svn_repos-1"].has("svn_repos_get_commit_editor", "cdecl"):
    svn_repos_get_commit_editor = _libs["svn_repos-1"].get("svn_repos_get_commit_editor", "cdecl")
    svn_repos_get_commit_editor.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), String, String, String, String, svn_commit_callback_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_commit_editor.restype = POINTER(svn_error_t)
    svn_repos_get_commit_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1689
if _libs["svn_repos-1"].has("svn_repos_dated_revision", "cdecl"):
    svn_repos_dated_revision = _libs["svn_repos-1"].get("svn_repos_dated_revision", "cdecl")
    svn_repos_dated_revision.argtypes = [POINTER(svn_revnum_t), POINTER(svn_repos_t), apr_time_t, POINTER(apr_pool_t)]
    svn_repos_dated_revision.restype = POINTER(svn_error_t)
    svn_repos_dated_revision.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1709
if _libs["svn_repos-1"].has("svn_repos_get_committed_info", "cdecl"):
    svn_repos_get_committed_info = _libs["svn_repos-1"].get("svn_repos_get_committed_info", "cdecl")
    svn_repos_get_committed_info.argtypes = [POINTER(svn_revnum_t), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_repos_get_committed_info.restype = POINTER(svn_error_t)
    svn_repos_get_committed_info.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1725
if _libs["svn_repos-1"].has("svn_repos_stat", "cdecl"):
    svn_repos_stat = _libs["svn_repos-1"].get("svn_repos_stat", "cdecl")
    svn_repos_stat.argtypes = [POINTER(POINTER(svn_dirent_t)), POINTER(svn_fs_root_t), String, POINTER(apr_pool_t)]
    svn_repos_stat.restype = POINTER(svn_error_t)
    svn_repos_stat.errcheck = _svn_errcheck

svn_repos_dirent_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(svn_dirent_t), POINTER(None), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1745

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1780
if _libs["svn_repos-1"].has("svn_repos_list", "cdecl"):
    svn_repos_list = _libs["svn_repos-1"].get("svn_repos_list", "cdecl")
    svn_repos_list.argtypes = [POINTER(svn_fs_root_t), String, POINTER(apr_array_header_t), svn_depth_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), svn_repos_dirent_receiver_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_list.restype = POINTER(svn_error_t)
    svn_repos_list.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1804
if _libs["svn_repos-1"].has("svn_repos_deleted_rev", "cdecl"):
    svn_repos_deleted_rev = _libs["svn_repos-1"].get("svn_repos_deleted_rev", "cdecl")
    svn_repos_deleted_rev.argtypes = [POINTER(svn_fs_t), String, svn_revnum_t, svn_revnum_t, POINTER(svn_revnum_t), POINTER(apr_pool_t)]
    svn_repos_deleted_rev.restype = POINTER(svn_error_t)
    svn_repos_deleted_rev.errcheck = _svn_errcheck

svn_repos_history_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1825

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1850
if _libs["svn_repos-1"].has("svn_repos_history2", "cdecl"):
    svn_repos_history2 = _libs["svn_repos-1"].get("svn_repos_history2", "cdecl")
    svn_repos_history2.argtypes = [POINTER(svn_fs_t), String, svn_repos_history_func_t, POINTER(None), svn_repos_authz_func_t, POINTER(None), svn_revnum_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_history2.restype = POINTER(svn_error_t)
    svn_repos_history2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1869
if _libs["svn_repos-1"].has("svn_repos_history", "cdecl"):
    svn_repos_history = _libs["svn_repos-1"].get("svn_repos_history", "cdecl")
    svn_repos_history.argtypes = [POINTER(svn_fs_t), String, svn_repos_history_func_t, POINTER(None), svn_revnum_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_history.restype = POINTER(svn_error_t)
    svn_repos_history.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1900
if _libs["svn_repos-1"].has("svn_repos_trace_node_locations", "cdecl"):
    svn_repos_trace_node_locations = _libs["svn_repos-1"].get("svn_repos_trace_node_locations", "cdecl")
    svn_repos_trace_node_locations.argtypes = [POINTER(svn_fs_t), POINTER(POINTER(apr_hash_t)), String, svn_revnum_t, POINTER(apr_array_header_t), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_trace_node_locations.restype = POINTER(svn_error_t)
    svn_repos_trace_node_locations.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1939
if _libs["svn_repos-1"].has("svn_repos_node_location_segments", "cdecl"):
    svn_repos_node_location_segments = _libs["svn_repos-1"].get("svn_repos_node_location_segments", "cdecl")
    svn_repos_node_location_segments.argtypes = [POINTER(svn_repos_t), String, svn_revnum_t, svn_revnum_t, svn_revnum_t, svn_location_segment_receiver_t, POINTER(None), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_node_location_segments.restype = POINTER(svn_error_t)
    svn_repos_node_location_segments.errcheck = _svn_errcheck

svn_repos_path_change_t = svn_fs_path_change3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1969

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1981
if _libs["svn_repos-1"].has("svn_repos_path_change_create", "cdecl"):
    svn_repos_path_change_create = _libs["svn_repos-1"].get("svn_repos_path_change_create", "cdecl")
    svn_repos_path_change_create.argtypes = [POINTER(apr_pool_t)]
    svn_repos_path_change_create.restype = POINTER(svn_repos_path_change_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 1989
if _libs["svn_repos-1"].has("svn_repos_path_change_dup", "cdecl"):
    svn_repos_path_change_dup = _libs["svn_repos-1"].get("svn_repos_path_change_dup", "cdecl")
    svn_repos_path_change_dup.argtypes = [POINTER(svn_repos_path_change_t), POINTER(apr_pool_t)]
    svn_repos_path_change_dup.restype = POINTER(svn_repos_path_change_t)

svn_repos_path_change_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_repos_path_change_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2010

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2066
class struct_svn_repos_log_entry_t(Structure):
    pass

struct_svn_repos_log_entry_t.__slots__ = [
    'revision',
    'revprops',
    'has_children',
    'non_inheritable',
    'subtractive_merge',
]
struct_svn_repos_log_entry_t._fields_ = [
    ('revision', svn_revnum_t),
    ('revprops', POINTER(apr_hash_t)),
    ('has_children', svn_boolean_t),
    ('non_inheritable', svn_boolean_t),
    ('subtractive_merge', svn_boolean_t),
]

svn_repos_log_entry_t = struct_svn_repos_log_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2066

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2078
if _libs["svn_repos-1"].has("svn_repos_log_entry_create", "cdecl"):
    svn_repos_log_entry_create = _libs["svn_repos-1"].get("svn_repos_log_entry_create", "cdecl")
    svn_repos_log_entry_create.argtypes = [POINTER(apr_pool_t)]
    svn_repos_log_entry_create.restype = POINTER(svn_repos_log_entry_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2085
if _libs["svn_repos-1"].has("svn_repos_log_entry_dup", "cdecl"):
    svn_repos_log_entry_dup = _libs["svn_repos-1"].get("svn_repos_log_entry_dup", "cdecl")
    svn_repos_log_entry_dup.argtypes = [POINTER(svn_repos_log_entry_t), POINTER(apr_pool_t)]
    svn_repos_log_entry_dup.restype = POINTER(svn_repos_log_entry_t)

svn_repos_log_entry_receiver_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), POINTER(svn_repos_log_entry_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2109

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2181
if _libs["svn_repos-1"].has("svn_repos_get_logs5", "cdecl"):
    svn_repos_get_logs5 = _libs["svn_repos-1"].get("svn_repos_get_logs5", "cdecl")
    svn_repos_get_logs5.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, c_int, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_repos_authz_func_t, POINTER(None), svn_repos_path_change_receiver_t, POINTER(None), svn_repos_log_entry_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_logs5.restype = POINTER(svn_error_t)
    svn_repos_get_logs5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2215
if _libs["svn_repos-1"].has("svn_repos_get_logs4", "cdecl"):
    svn_repos_get_logs4 = _libs["svn_repos-1"].get("svn_repos_get_logs4", "cdecl")
    svn_repos_get_logs4.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, c_int, svn_boolean_t, svn_boolean_t, svn_boolean_t, POINTER(apr_array_header_t), svn_repos_authz_func_t, POINTER(None), svn_log_entry_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_logs4.restype = POINTER(svn_error_t)
    svn_repos_get_logs4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2242
if _libs["svn_repos-1"].has("svn_repos_get_logs3", "cdecl"):
    svn_repos_get_logs3 = _libs["svn_repos-1"].get("svn_repos_get_logs3", "cdecl")
    svn_repos_get_logs3.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, c_int, svn_boolean_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_logs3.restype = POINTER(svn_error_t)
    svn_repos_get_logs3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2263
if _libs["svn_repos-1"].has("svn_repos_get_logs2", "cdecl"):
    svn_repos_get_logs2 = _libs["svn_repos-1"].get("svn_repos_get_logs2", "cdecl")
    svn_repos_get_logs2.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_logs2.restype = POINTER(svn_error_t)
    svn_repos_get_logs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2283
if _libs["svn_repos-1"].has("svn_repos_get_logs", "cdecl"):
    svn_repos_get_logs = _libs["svn_repos-1"].get("svn_repos_get_logs", "cdecl")
    svn_repos_get_logs.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_log_message_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_logs.restype = POINTER(svn_error_t)
    svn_repos_get_logs.errcheck = _svn_errcheck

svn_repos_mergeinfo_receiver_t = svn_fs_mergeinfo_receiver_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2307

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2336
if _libs["svn_repos-1"].has("svn_repos_fs_get_mergeinfo2", "cdecl"):
    svn_repos_fs_get_mergeinfo2 = _libs["svn_repos-1"].get("svn_repos_fs_get_mergeinfo2", "cdecl")
    svn_repos_fs_get_mergeinfo2.argtypes = [POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_mergeinfo_inheritance_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), svn_repos_mergeinfo_receiver_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_get_mergeinfo2.restype = POINTER(svn_error_t)
    svn_repos_fs_get_mergeinfo2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2357
if _libs["svn_repos-1"].has("svn_repos_fs_get_mergeinfo", "cdecl"):
    svn_repos_fs_get_mergeinfo = _libs["svn_repos-1"].get("svn_repos_fs_get_mergeinfo", "cdecl")
    svn_repos_fs_get_mergeinfo.argtypes = [POINTER(svn_mergeinfo_catalog_t), POINTER(svn_repos_t), POINTER(apr_array_header_t), svn_revnum_t, svn_mergeinfo_inheritance_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_get_mergeinfo.restype = POINTER(svn_error_t)
    svn_repos_fs_get_mergeinfo.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2415
if _libs["svn_repos-1"].has("svn_repos_get_file_revs2", "cdecl"):
    svn_repos_get_file_revs2 = _libs["svn_repos-1"].get("svn_repos_get_file_revs2", "cdecl")
    svn_repos_get_file_revs2.argtypes = [POINTER(svn_repos_t), String, svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), svn_file_rev_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_file_revs2.restype = POINTER(svn_error_t)
    svn_repos_get_file_revs2.errcheck = _svn_errcheck

svn_repos_file_rev_handler_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, svn_revnum_t, POINTER(apr_hash_t), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(apr_array_header_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2434

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2452
if _libs["svn_repos-1"].has("svn_repos_get_file_revs", "cdecl"):
    svn_repos_get_file_revs = _libs["svn_repos-1"].get("svn_repos_get_file_revs", "cdecl")
    svn_repos_get_file_revs.argtypes = [POINTER(svn_repos_t), String, svn_revnum_t, svn_revnum_t, svn_repos_authz_func_t, POINTER(None), svn_repos_file_rev_handler_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_file_revs.restype = POINTER(svn_error_t)
    svn_repos_get_file_revs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2496
if _libs["svn_repos-1"].has("svn_repos_fs_commit_txn", "cdecl"):
    svn_repos_fs_commit_txn = _libs["svn_repos-1"].get("svn_repos_fs_commit_txn", "cdecl")
    svn_repos_fs_commit_txn.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_repos_t), POINTER(svn_revnum_t), POINTER(svn_fs_txn_t), POINTER(apr_pool_t)]
    svn_repos_fs_commit_txn.restype = POINTER(svn_error_t)
    svn_repos_fs_commit_txn.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2519
if _libs["svn_repos-1"].has("svn_repos_fs_begin_txn_for_commit2", "cdecl"):
    svn_repos_fs_begin_txn_for_commit2 = _libs["svn_repos-1"].get("svn_repos_fs_begin_txn_for_commit2", "cdecl")
    svn_repos_fs_begin_txn_for_commit2.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_repos_t), svn_revnum_t, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_repos_fs_begin_txn_for_commit2.restype = POINTER(svn_error_t)
    svn_repos_fs_begin_txn_for_commit2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2536
if _libs["svn_repos-1"].has("svn_repos_fs_begin_txn_for_commit", "cdecl"):
    svn_repos_fs_begin_txn_for_commit = _libs["svn_repos-1"].get("svn_repos_fs_begin_txn_for_commit", "cdecl")
    svn_repos_fs_begin_txn_for_commit.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_repos_t), svn_revnum_t, String, String, POINTER(apr_pool_t)]
    svn_repos_fs_begin_txn_for_commit.restype = POINTER(svn_error_t)
    svn_repos_fs_begin_txn_for_commit.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2557
if _libs["svn_repos-1"].has("svn_repos_fs_begin_txn_for_update", "cdecl"):
    svn_repos_fs_begin_txn_for_update = _libs["svn_repos-1"].get("svn_repos_fs_begin_txn_for_update", "cdecl")
    svn_repos_fs_begin_txn_for_update.argtypes = [POINTER(POINTER(svn_fs_txn_t)), POINTER(svn_repos_t), svn_revnum_t, String, POINTER(apr_pool_t)]
    svn_repos_fs_begin_txn_for_update.restype = POINTER(svn_error_t)
    svn_repos_fs_begin_txn_for_update.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2602
if _libs["svn_repos-1"].has("svn_repos_fs_lock_many", "cdecl"):
    svn_repos_fs_lock_many = _libs["svn_repos-1"].get("svn_repos_fs_lock_many", "cdecl")
    svn_repos_fs_lock_many.argtypes = [POINTER(svn_repos_t), POINTER(apr_hash_t), String, svn_boolean_t, apr_time_t, svn_boolean_t, svn_fs_lock_callback_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_fs_lock_many.restype = POINTER(svn_error_t)
    svn_repos_fs_lock_many.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2618
if _libs["svn_repos-1"].has("svn_repos_fs_lock", "cdecl"):
    svn_repos_fs_lock = _libs["svn_repos-1"].get("svn_repos_fs_lock", "cdecl")
    svn_repos_fs_lock.argtypes = [POINTER(POINTER(svn_lock_t)), POINTER(svn_repos_t), String, String, String, svn_boolean_t, apr_time_t, svn_revnum_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_fs_lock.restype = POINTER(svn_error_t)
    svn_repos_fs_lock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2661
if _libs["svn_repos-1"].has("svn_repos_fs_unlock_many", "cdecl"):
    svn_repos_fs_unlock_many = _libs["svn_repos-1"].get("svn_repos_fs_unlock_many", "cdecl")
    svn_repos_fs_unlock_many.argtypes = [POINTER(svn_repos_t), POINTER(apr_hash_t), svn_boolean_t, svn_fs_lock_callback_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_fs_unlock_many.restype = POINTER(svn_error_t)
    svn_repos_fs_unlock_many.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2674
if _libs["svn_repos-1"].has("svn_repos_fs_unlock", "cdecl"):
    svn_repos_fs_unlock = _libs["svn_repos-1"].get("svn_repos_fs_unlock", "cdecl")
    svn_repos_fs_unlock.argtypes = [POINTER(svn_repos_t), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_fs_unlock.restype = POINTER(svn_error_t)
    svn_repos_fs_unlock.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2697
if _libs["svn_repos-1"].has("svn_repos_fs_get_locks2", "cdecl"):
    svn_repos_fs_get_locks2 = _libs["svn_repos-1"].get("svn_repos_fs_get_locks2", "cdecl")
    svn_repos_fs_get_locks2.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_repos_t), String, svn_depth_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_get_locks2.restype = POINTER(svn_error_t)
    svn_repos_fs_get_locks2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2714
if _libs["svn_repos-1"].has("svn_repos_fs_get_locks", "cdecl"):
    svn_repos_fs_get_locks = _libs["svn_repos-1"].get("svn_repos_fs_get_locks", "cdecl")
    svn_repos_fs_get_locks.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_repos_t), String, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_get_locks.restype = POINTER(svn_error_t)
    svn_repos_fs_get_locks.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2755
if _libs["svn_repos-1"].has("svn_repos_fs_change_rev_prop4", "cdecl"):
    svn_repos_fs_change_rev_prop4 = _libs["svn_repos-1"].get("svn_repos_fs_change_rev_prop4", "cdecl")
    svn_repos_fs_change_rev_prop4.argtypes = [POINTER(svn_repos_t), svn_revnum_t, String, String, POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), svn_boolean_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_change_rev_prop4.restype = POINTER(svn_error_t)
    svn_repos_fs_change_rev_prop4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2777
if _libs["svn_repos-1"].has("svn_repos_fs_change_rev_prop3", "cdecl"):
    svn_repos_fs_change_rev_prop3 = _libs["svn_repos-1"].get("svn_repos_fs_change_rev_prop3", "cdecl")
    svn_repos_fs_change_rev_prop3.argtypes = [POINTER(svn_repos_t), svn_revnum_t, String, String, POINTER(svn_string_t), svn_boolean_t, svn_boolean_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_change_rev_prop3.restype = POINTER(svn_error_t)
    svn_repos_fs_change_rev_prop3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2797
if _libs["svn_repos-1"].has("svn_repos_fs_change_rev_prop2", "cdecl"):
    svn_repos_fs_change_rev_prop2 = _libs["svn_repos-1"].get("svn_repos_fs_change_rev_prop2", "cdecl")
    svn_repos_fs_change_rev_prop2.argtypes = [POINTER(svn_repos_t), svn_revnum_t, String, String, POINTER(svn_string_t), svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_change_rev_prop2.restype = POINTER(svn_error_t)
    svn_repos_fs_change_rev_prop2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2814
if _libs["svn_repos-1"].has("svn_repos_fs_change_rev_prop", "cdecl"):
    svn_repos_fs_change_rev_prop = _libs["svn_repos-1"].get("svn_repos_fs_change_rev_prop", "cdecl")
    svn_repos_fs_change_rev_prop.argtypes = [POINTER(svn_repos_t), svn_revnum_t, String, String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_repos_fs_change_rev_prop.restype = POINTER(svn_error_t)
    svn_repos_fs_change_rev_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2839
if _libs["svn_repos-1"].has("svn_repos_fs_revision_prop", "cdecl"):
    svn_repos_fs_revision_prop = _libs["svn_repos-1"].get("svn_repos_fs_revision_prop", "cdecl")
    svn_repos_fs_revision_prop.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_repos_t), svn_revnum_t, String, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_revision_prop.restype = POINTER(svn_error_t)
    svn_repos_fs_revision_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2865
if _libs["svn_repos-1"].has("svn_repos_fs_revision_proplist", "cdecl"):
    svn_repos_fs_revision_proplist = _libs["svn_repos-1"].get("svn_repos_fs_revision_proplist", "cdecl")
    svn_repos_fs_revision_proplist.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(svn_repos_t), svn_revnum_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_fs_revision_proplist.restype = POINTER(svn_error_t)
    svn_repos_fs_revision_proplist.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2885
if _libs["svn_repos-1"].has("svn_repos_fs_change_node_prop", "cdecl"):
    svn_repos_fs_change_node_prop = _libs["svn_repos-1"].get("svn_repos_fs_change_node_prop", "cdecl")
    svn_repos_fs_change_node_prop.argtypes = [POINTER(svn_fs_root_t), String, String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_repos_fs_change_node_prop.restype = POINTER(svn_error_t)
    svn_repos_fs_change_node_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2912
if _libs["svn_repos-1"].has("svn_repos_fs_get_inherited_props", "cdecl"):
    svn_repos_fs_get_inherited_props = _libs["svn_repos-1"].get("svn_repos_fs_get_inherited_props", "cdecl")
    svn_repos_fs_get_inherited_props.argtypes = [POINTER(POINTER(apr_array_header_t)), POINTER(svn_fs_root_t), String, String, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_fs_get_inherited_props.restype = POINTER(svn_error_t)
    svn_repos_fs_get_inherited_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2926
if _libs["svn_repos-1"].has("svn_repos_fs_change_txn_prop", "cdecl"):
    svn_repos_fs_change_txn_prop = _libs["svn_repos-1"].get("svn_repos_fs_change_txn_prop", "cdecl")
    svn_repos_fs_change_txn_prop.argtypes = [POINTER(svn_fs_txn_t), String, POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_repos_fs_change_txn_prop.restype = POINTER(svn_error_t)
    svn_repos_fs_change_txn_prop.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2938
if _libs["svn_repos-1"].has("svn_repos_fs_change_txn_props", "cdecl"):
    svn_repos_fs_change_txn_props = _libs["svn_repos-1"].get("svn_repos_fs_change_txn_props", "cdecl")
    svn_repos_fs_change_txn_props.argtypes = [POINTER(svn_fs_txn_t), POINTER(apr_array_header_t), POINTER(apr_pool_t)]
    svn_repos_fs_change_txn_props.restype = POINTER(svn_error_t)
    svn_repos_fs_change_txn_props.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2966
class struct_svn_repos_node_t(Structure):
    pass

struct_svn_repos_node_t.__slots__ = [
    'kind',
    'action',
    'text_mod',
    'prop_mod',
    'name',
    'copyfrom_rev',
    'copyfrom_path',
    'sibling',
    'child',
    'parent',
]
struct_svn_repos_node_t._fields_ = [
    ('kind', svn_node_kind_t),
    ('action', c_char),
    ('text_mod', svn_boolean_t),
    ('prop_mod', svn_boolean_t),
    ('name', String),
    ('copyfrom_rev', svn_revnum_t),
    ('copyfrom_path', String),
    ('sibling', POINTER(struct_svn_repos_node_t)),
    ('child', POINTER(struct_svn_repos_node_t)),
    ('parent', POINTER(struct_svn_repos_node_t)),
]

svn_repos_node_t = struct_svn_repos_node_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2998

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3019
if _libs["svn_repos-1"].has("svn_repos_node_editor", "cdecl"):
    svn_repos_node_editor = _libs["svn_repos-1"].get("svn_repos_node_editor", "cdecl")
    svn_repos_node_editor.argtypes = [POINTER(POINTER(svn_delta_editor_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), POINTER(svn_fs_root_t), POINTER(svn_fs_root_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_node_editor.restype = POINTER(svn_error_t)
    svn_repos_node_editor.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3032
if _libs["svn_repos-1"].has("svn_repos_node_from_baton", "cdecl"):
    svn_repos_node_from_baton = _libs["svn_repos-1"].get("svn_repos_node_from_baton", "cdecl")
    svn_repos_node_from_baton.argtypes = [POINTER(None)]
    svn_repos_node_from_baton.restype = POINTER(svn_repos_node_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3050
if _libs["svn_repos-1"].has("svn_repos_info_format", "cdecl"):
    svn_repos_info_format = _libs["svn_repos-1"].get("svn_repos_info_format", "cdecl")
    svn_repos_info_format.argtypes = [POINTER(c_int), POINTER(POINTER(svn_version_t)), POINTER(svn_repos_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_info_format.restype = POINTER(svn_error_t)
    svn_repos_info_format.errcheck = _svn_errcheck

enum_svn_repos_load_uuid = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3127

svn_repos_load_uuid_default = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3127

svn_repos_load_uuid_ignore = (svn_repos_load_uuid_default + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3127

svn_repos_load_uuid_force = (svn_repos_load_uuid_ignore + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3127

svn_repos_verify_callback_t = CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), svn_revnum_t, POINTER(svn_error_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3154

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3229
if _libs["svn_repos-1"].has("svn_repos_verify_fs3", "cdecl"):
    svn_repos_verify_fs3 = _libs["svn_repos-1"].get("svn_repos_verify_fs3", "cdecl")
    svn_repos_verify_fs3.argtypes = [POINTER(svn_repos_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_repos_verify_callback_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_verify_fs3.restype = POINTER(svn_error_t)
    svn_repos_verify_fs3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3252
if _libs["svn_repos-1"].has("svn_repos_verify_fs2", "cdecl"):
    svn_repos_verify_fs2 = _libs["svn_repos-1"].get("svn_repos_verify_fs2", "cdecl")
    svn_repos_verify_fs2.argtypes = [POINTER(svn_repos_t), svn_revnum_t, svn_revnum_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_verify_fs2.restype = POINTER(svn_error_t)
    svn_repos_verify_fs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3273
if _libs["svn_repos-1"].has("svn_repos_verify_fs", "cdecl"):
    svn_repos_verify_fs = _libs["svn_repos-1"].get("svn_repos_verify_fs", "cdecl")
    svn_repos_verify_fs.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_verify_fs.restype = POINTER(svn_error_t)
    svn_repos_verify_fs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3345
if _libs["svn_repos-1"].has("svn_repos_dump_fs4", "cdecl"):
    svn_repos_dump_fs4 = _libs["svn_repos-1"].get("svn_repos_dump_fs4", "cdecl")
    svn_repos_dump_fs4.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_repos_dump_filter_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_dump_fs4.restype = POINTER(svn_error_t)
    svn_repos_dump_fs4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3371
if _libs["svn_repos-1"].has("svn_repos_dump_fs3", "cdecl"):
    svn_repos_dump_fs3 = _libs["svn_repos-1"].get("svn_repos_dump_fs3", "cdecl")
    svn_repos_dump_fs3.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_dump_fs3.restype = POINTER(svn_error_t)
    svn_repos_dump_fs3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3392
if _libs["svn_repos-1"].has("svn_repos_dump_fs2", "cdecl"):
    svn_repos_dump_fs2 = _libs["svn_repos-1"].get("svn_repos_dump_fs2", "cdecl")
    svn_repos_dump_fs2.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_dump_fs2.restype = POINTER(svn_error_t)
    svn_repos_dump_fs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3411
if _libs["svn_repos-1"].has("svn_repos_dump_fs", "cdecl"):
    svn_repos_dump_fs = _libs["svn_repos-1"].get("svn_repos_dump_fs", "cdecl")
    svn_repos_dump_fs.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_dump_fs.restype = POINTER(svn_error_t)
    svn_repos_dump_fs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3484
if _libs["svn_repos-1"].has("svn_repos_load_fs6", "cdecl"):
    svn_repos_load_fs6 = _libs["svn_repos-1"].get("svn_repos_load_fs6", "cdecl")
    svn_repos_load_fs6.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs6.restype = POINTER(svn_error_t)
    svn_repos_load_fs6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3510
if _libs["svn_repos-1"].has("svn_repos_load_fs5", "cdecl"):
    svn_repos_load_fs5 = _libs["svn_repos-1"].get("svn_repos_load_fs5", "cdecl")
    svn_repos_load_fs5.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs5.restype = POINTER(svn_error_t)
    svn_repos_load_fs5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3534
if _libs["svn_repos-1"].has("svn_repos_load_fs4", "cdecl"):
    svn_repos_load_fs4 = _libs["svn_repos-1"].get("svn_repos_load_fs4", "cdecl")
    svn_repos_load_fs4.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs4.restype = POINTER(svn_error_t)
    svn_repos_load_fs4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3557
if _libs["svn_repos-1"].has("svn_repos_load_fs3", "cdecl"):
    svn_repos_load_fs3 = _libs["svn_repos-1"].get("svn_repos_load_fs3", "cdecl")
    svn_repos_load_fs3.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs3.restype = POINTER(svn_error_t)
    svn_repos_load_fs3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3580
if _libs["svn_repos-1"].has("svn_repos_load_fs2", "cdecl"):
    svn_repos_load_fs2 = _libs["svn_repos-1"].get("svn_repos_load_fs2", "cdecl")
    svn_repos_load_fs2.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), POINTER(svn_stream_t), enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs2.restype = POINTER(svn_error_t)
    svn_repos_load_fs2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3599
if _libs["svn_repos-1"].has("svn_repos_load_fs", "cdecl"):
    svn_repos_load_fs = _libs["svn_repos-1"].get("svn_repos_load_fs", "cdecl")
    svn_repos_load_fs.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), POINTER(svn_stream_t), enum_svn_repos_load_uuid, String, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs.restype = POINTER(svn_error_t)
    svn_repos_load_fs.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3652
if _libs["svn_repos-1"].has("svn_repos_load_fs_revprops", "cdecl"):
    svn_repos_load_fs_revprops = _libs["svn_repos-1"].get("svn_repos_load_fs_revprops", "cdecl")
    svn_repos_load_fs_revprops.argtypes = [POINTER(svn_repos_t), POINTER(svn_stream_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_load_fs_revprops.restype = POINTER(svn_error_t)
    svn_repos_load_fs_revprops.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3765
class struct_svn_repos_parse_fns3_t(Structure):
    pass

struct_svn_repos_parse_fns3_t.__slots__ = [
    'magic_header_record',
    'uuid_record',
    'new_revision_record',
    'new_node_record',
    'set_revision_property',
    'set_node_property',
    'delete_node_property',
    'remove_node_props',
    'set_fulltext',
    'apply_textdelta',
    'close_node',
    'close_revision',
]
struct_svn_repos_parse_fns3_t._fields_ = [
    ('magic_header_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), c_int, POINTER(None), POINTER(apr_pool_t))),
    ('uuid_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), POINTER(apr_pool_t))),
    ('new_revision_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('new_node_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('set_revision_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('set_node_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('delete_node_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String)),
    ('remove_node_props', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('set_fulltext', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_stream_t)), POINTER(None))),
    ('apply_textdelta', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(None))),
    ('close_node', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('close_revision', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
]

svn_repos_parse_fns3_t = struct_svn_repos_parse_fns3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3765

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3812
if _libs["svn_repos-1"].has("svn_repos_parse_dumpstream3", "cdecl"):
    svn_repos_parse_dumpstream3 = _libs["svn_repos-1"].get("svn_repos_parse_dumpstream3", "cdecl")
    svn_repos_parse_dumpstream3.argtypes = [POINTER(svn_stream_t), POINTER(svn_repos_parse_fns3_t), POINTER(None), svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_parse_dumpstream3.restype = POINTER(svn_error_t)
    svn_repos_parse_dumpstream3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3878
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser6", "cdecl"):
    svn_repos_get_fs_build_parser6 = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser6", "cdecl")
    svn_repos_get_fs_build_parser6.argtypes = [POINTER(POINTER(svn_repos_parse_fns3_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser6.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser6.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3904
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser5", "cdecl"):
    svn_repos_get_fs_build_parser5 = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser5", "cdecl")
    svn_repos_get_fs_build_parser5.argtypes = [POINTER(POINTER(svn_repos_parse_fns3_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, enum_svn_repos_load_uuid, String, svn_boolean_t, svn_boolean_t, svn_boolean_t, svn_repos_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser5.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser5.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3930
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser4", "cdecl"):
    svn_repos_get_fs_build_parser4 = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser4", "cdecl")
    svn_repos_get_fs_build_parser4.argtypes = [POINTER(POINTER(svn_repos_parse_fns3_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_revnum_t, svn_revnum_t, svn_boolean_t, svn_boolean_t, enum_svn_repos_load_uuid, String, svn_repos_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser4.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3993
class struct_svn_repos_parse_fns2_t(Structure):
    pass

struct_svn_repos_parse_fns2_t.__slots__ = [
    'new_revision_record',
    'uuid_record',
    'new_node_record',
    'set_revision_property',
    'set_node_property',
    'delete_node_property',
    'remove_node_props',
    'set_fulltext',
    'apply_textdelta',
    'close_node',
    'close_revision',
]
struct_svn_repos_parse_fns2_t._fields_ = [
    ('new_revision_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('uuid_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), POINTER(apr_pool_t))),
    ('new_node_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('set_revision_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('set_node_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('delete_node_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String)),
    ('remove_node_props', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('set_fulltext', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_stream_t)), POINTER(None))),
    ('apply_textdelta', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(svn_txdelta_window_handler_t), POINTER(POINTER(None)), POINTER(None))),
    ('close_node', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('close_revision', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
]

svn_repos_parse_fns2_t = struct_svn_repos_parse_fns2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3993

svn_repos_parser_fns2_t = svn_repos_parse_fns2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3996

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4039
class struct_svn_repos_parse_fns_t(Structure):
    pass

struct_svn_repos_parse_fns_t.__slots__ = [
    'new_revision_record',
    'uuid_record',
    'new_node_record',
    'set_revision_property',
    'set_node_property',
    'remove_node_props',
    'set_fulltext',
    'close_node',
    'close_revision',
]
struct_svn_repos_parse_fns_t._fields_ = [
    ('new_revision_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('uuid_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), String, POINTER(None), POINTER(apr_pool_t))),
    ('new_node_record', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(None)), POINTER(apr_hash_t), POINTER(None), POINTER(apr_pool_t))),
    ('set_revision_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('set_node_property', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None), String, POINTER(svn_string_t))),
    ('remove_node_props', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('set_fulltext', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(POINTER(svn_stream_t)), POINTER(None))),
    ('close_node', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
    ('close_revision', CFUNCTYPE(UNCHECKED(POINTER(svn_error_t)), POINTER(None))),
]

svn_repos_parser_fns_t = struct_svn_repos_parse_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4039

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4049
if _libs["svn_repos-1"].has("svn_repos_parse_dumpstream2", "cdecl"):
    svn_repos_parse_dumpstream2 = _libs["svn_repos-1"].get("svn_repos_parse_dumpstream2", "cdecl")
    svn_repos_parse_dumpstream2.argtypes = [POINTER(svn_stream_t), POINTER(svn_repos_parser_fns2_t), POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_parse_dumpstream2.restype = POINTER(svn_error_t)
    svn_repos_parse_dumpstream2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4064
if _libs["svn_repos-1"].has("svn_repos_parse_dumpstream", "cdecl"):
    svn_repos_parse_dumpstream = _libs["svn_repos-1"].get("svn_repos_parse_dumpstream", "cdecl")
    svn_repos_parse_dumpstream.argtypes = [POINTER(svn_stream_t), POINTER(svn_repos_parser_fns_t), POINTER(None), svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_parse_dumpstream.restype = POINTER(svn_error_t)
    svn_repos_parse_dumpstream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4081
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser3", "cdecl"):
    svn_repos_get_fs_build_parser3 = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser3", "cdecl")
    svn_repos_get_fs_build_parser3.argtypes = [POINTER(POINTER(svn_repos_parse_fns2_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_boolean_t, svn_boolean_t, enum_svn_repos_load_uuid, String, svn_repos_notify_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser3.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4102
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser2", "cdecl"):
    svn_repos_get_fs_build_parser2 = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser2", "cdecl")
    svn_repos_get_fs_build_parser2.argtypes = [POINTER(POINTER(svn_repos_parse_fns2_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_boolean_t, enum_svn_repos_load_uuid, POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser2.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4119
if _libs["svn_repos-1"].has("svn_repos_get_fs_build_parser", "cdecl"):
    svn_repos_get_fs_build_parser = _libs["svn_repos-1"].get("svn_repos_get_fs_build_parser", "cdecl")
    svn_repos_get_fs_build_parser.argtypes = [POINTER(POINTER(svn_repos_parser_fns_t)), POINTER(POINTER(None)), POINTER(svn_repos_t), svn_boolean_t, enum_svn_repos_load_uuid, POINTER(svn_stream_t), String, POINTER(apr_pool_t)]
    svn_repos_get_fs_build_parser.restype = POINTER(svn_error_t)
    svn_repos_get_fs_build_parser.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4136
class struct_svn_authz_t(Structure):
    pass

svn_authz_t = struct_svn_authz_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4136

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4146
if _libs["svn_repos-1"].has("svn_repos_authz_initialize", "cdecl"):
    svn_repos_authz_initialize = _libs["svn_repos-1"].get("svn_repos_authz_initialize", "cdecl")
    svn_repos_authz_initialize.argtypes = [POINTER(apr_pool_t)]
    svn_repos_authz_initialize.restype = POINTER(svn_error_t)
    svn_repos_authz_initialize.errcheck = _svn_errcheck

svn_repos_authz_warning_func_t = CFUNCTYPE(UNCHECKED(None), POINTER(None), POINTER(svn_error_t), POINTER(apr_pool_t))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4158

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4186
if _libs["svn_repos-1"].has("svn_repos_authz_read4", "cdecl"):
    svn_repos_authz_read4 = _libs["svn_repos-1"].get("svn_repos_authz_read4", "cdecl")
    svn_repos_authz_read4.argtypes = [POINTER(POINTER(svn_authz_t)), String, String, svn_boolean_t, POINTER(svn_repos_t), svn_repos_authz_warning_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_authz_read4.restype = POINTER(svn_error_t)
    svn_repos_authz_read4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4205
if _libs["svn_repos-1"].has("svn_repos_authz_read3", "cdecl"):
    svn_repos_authz_read3 = _libs["svn_repos-1"].get("svn_repos_authz_read3", "cdecl")
    svn_repos_authz_read3.argtypes = [POINTER(POINTER(svn_authz_t)), String, String, svn_boolean_t, POINTER(svn_repos_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_authz_read3.restype = POINTER(svn_error_t)
    svn_repos_authz_read3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4221
if _libs["svn_repos-1"].has("svn_repos_authz_read2", "cdecl"):
    svn_repos_authz_read2 = _libs["svn_repos-1"].get("svn_repos_authz_read2", "cdecl")
    svn_repos_authz_read2.argtypes = [POINTER(POINTER(svn_authz_t)), String, String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_authz_read2.restype = POINTER(svn_error_t)
    svn_repos_authz_read2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4237
if _libs["svn_repos-1"].has("svn_repos_authz_read", "cdecl"):
    svn_repos_authz_read = _libs["svn_repos-1"].get("svn_repos_authz_read", "cdecl")
    svn_repos_authz_read.argtypes = [POINTER(POINTER(svn_authz_t)), String, svn_boolean_t, POINTER(apr_pool_t)]
    svn_repos_authz_read.restype = POINTER(svn_error_t)
    svn_repos_authz_read.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4257
if _libs["svn_repos-1"].has("svn_repos_authz_parse2", "cdecl"):
    svn_repos_authz_parse2 = _libs["svn_repos-1"].get("svn_repos_authz_parse2", "cdecl")
    svn_repos_authz_parse2.argtypes = [POINTER(POINTER(svn_authz_t)), POINTER(svn_stream_t), POINTER(svn_stream_t), svn_repos_authz_warning_func_t, POINTER(None), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_repos_authz_parse2.restype = POINTER(svn_error_t)
    svn_repos_authz_parse2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4274
if _libs["svn_repos-1"].has("svn_repos_authz_parse", "cdecl"):
    svn_repos_authz_parse = _libs["svn_repos-1"].get("svn_repos_authz_parse", "cdecl")
    svn_repos_authz_parse.argtypes = [POINTER(POINTER(svn_authz_t)), POINTER(svn_stream_t), POINTER(svn_stream_t), POINTER(apr_pool_t)]
    svn_repos_authz_parse.restype = POINTER(svn_error_t)
    svn_repos_authz_parse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4300
if _libs["svn_repos-1"].has("svn_repos_authz_check_access", "cdecl"):
    svn_repos_authz_check_access = _libs["svn_repos-1"].get("svn_repos_authz_check_access", "cdecl")
    svn_repos_authz_check_access.argtypes = [POINTER(svn_authz_t), String, String, String, svn_repos_authz_access_t, POINTER(svn_boolean_t), POINTER(apr_pool_t)]
    svn_repos_authz_check_access.restype = POINTER(svn_error_t)
    svn_repos_authz_check_access.errcheck = _svn_errcheck

enum_svn_repos_revision_access_level_t = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4377

svn_repos_revision_access_none = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4377

svn_repos_revision_access_partial = (svn_repos_revision_access_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4377

svn_repos_revision_access_full = (svn_repos_revision_access_partial + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4377

svn_repos_revision_access_level_t = enum_svn_repos_revision_access_level_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4377

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4390
if _libs["svn_repos-1"].has("svn_repos_check_revision_access", "cdecl"):
    svn_repos_check_revision_access = _libs["svn_repos-1"].get("svn_repos_check_revision_access", "cdecl")
    svn_repos_check_revision_access.argtypes = [POINTER(svn_repos_revision_access_level_t), POINTER(svn_repos_t), svn_revnum_t, svn_repos_authz_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_repos_check_revision_access.restype = POINTER(svn_error_t)
    svn_repos_check_revision_access.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 55
class struct_svn_sort__item_t(Structure):
    pass

svn_sort__item_t = struct_svn_sort__item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 55

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 83
if _libs["svn_subr-1"].has("svn_sort_compare_items_as_paths", "cdecl"):
    svn_sort_compare_items_as_paths = _libs["svn_subr-1"].get("svn_sort_compare_items_as_paths", "cdecl")
    svn_sort_compare_items_as_paths.argtypes = [POINTER(svn_sort__item_t), POINTER(svn_sort__item_t)]
    svn_sort_compare_items_as_paths.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 93
if _libs["svn_subr-1"].has("svn_sort_compare_items_lexically", "cdecl"):
    svn_sort_compare_items_lexically = _libs["svn_subr-1"].get("svn_sort_compare_items_lexically", "cdecl")
    svn_sort_compare_items_lexically.argtypes = [POINTER(svn_sort__item_t), POINTER(svn_sort__item_t)]
    svn_sort_compare_items_lexically.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 108
if _libs["svn_subr-1"].has("svn_sort_compare_revisions", "cdecl"):
    svn_sort_compare_revisions = _libs["svn_subr-1"].get("svn_sort_compare_revisions", "cdecl")
    svn_sort_compare_revisions.argtypes = [POINTER(None), POINTER(None)]
    svn_sort_compare_revisions.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 122
if _libs["svn_subr-1"].has("svn_sort_compare_paths", "cdecl"):
    svn_sort_compare_paths = _libs["svn_subr-1"].get("svn_sort_compare_paths", "cdecl")
    svn_sort_compare_paths.argtypes = [POINTER(None), POINTER(None)]
    svn_sort_compare_paths.restype = c_int

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 140
if _libs["svn_subr-1"].has("svn_sort_compare_ranges", "cdecl"):
    svn_sort_compare_ranges = _libs["svn_subr-1"].get("svn_sort_compare_ranges", "cdecl")
    svn_sort_compare_ranges.argtypes = [POINTER(None), POINTER(None)]
    svn_sort_compare_ranges.restype = c_int

enum_svn_subst_eol_style = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

svn_subst_eol_style_unknown = 0# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

svn_subst_eol_style_none = (svn_subst_eol_style_unknown + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

svn_subst_eol_style_native = (svn_subst_eol_style_none + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

svn_subst_eol_style_fixed = (svn_subst_eol_style_native + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

svn_subst_eol_style_t = enum_svn_subst_eol_style# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 67

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 85
if _libs["svn_subr-1"].has("svn_subst_eol_style_from_value", "cdecl"):
    svn_subst_eol_style_from_value = _libs["svn_subr-1"].get("svn_subst_eol_style_from_value", "cdecl")
    svn_subst_eol_style_from_value.argtypes = [POINTER(svn_subst_eol_style_t), POINTER(POINTER(c_char)), String]
    svn_subst_eol_style_from_value.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 98
if _libs["svn_subr-1"].has("svn_subst_translation_required", "cdecl"):
    svn_subst_translation_required = _libs["svn_subr-1"].get("svn_subst_translation_required", "cdecl")
    svn_subst_translation_required.argtypes = [svn_subst_eol_style_t, String, POINTER(apr_hash_t), svn_boolean_t, svn_boolean_t]
    svn_subst_translation_required.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 123
class struct_svn_subst_keywords_t(Structure):
    pass

struct_svn_subst_keywords_t.__slots__ = [
    'revision',
    'date',
    'author',
    'url',
    'id',
]
struct_svn_subst_keywords_t._fields_ = [
    ('revision', POINTER(svn_string_t)),
    ('date', POINTER(svn_string_t)),
    ('author', POINTER(svn_string_t)),
    ('url', POINTER(svn_string_t)),
    ('id', POINTER(svn_string_t)),
]

svn_subst_keywords_t = struct_svn_subst_keywords_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 123

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 166
if _libs["svn_subr-1"].has("svn_subst_build_keywords3", "cdecl"):
    svn_subst_build_keywords3 = _libs["svn_subr-1"].get("svn_subst_build_keywords3", "cdecl")
    svn_subst_build_keywords3.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, String, String, apr_time_t, String, POINTER(apr_pool_t)]
    svn_subst_build_keywords3.restype = POINTER(svn_error_t)
    svn_subst_build_keywords3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 184
if _libs["svn_subr-1"].has("svn_subst_build_keywords2", "cdecl"):
    svn_subst_build_keywords2 = _libs["svn_subr-1"].get("svn_subst_build_keywords2", "cdecl")
    svn_subst_build_keywords2.argtypes = [POINTER(POINTER(apr_hash_t)), String, String, String, apr_time_t, String, POINTER(apr_pool_t)]
    svn_subst_build_keywords2.restype = POINTER(svn_error_t)
    svn_subst_build_keywords2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 199
if _libs["svn_subr-1"].has("svn_subst_build_keywords", "cdecl"):
    svn_subst_build_keywords = _libs["svn_subr-1"].get("svn_subst_build_keywords", "cdecl")
    svn_subst_build_keywords.argtypes = [POINTER(svn_subst_keywords_t), String, String, String, apr_time_t, String, POINTER(apr_pool_t)]
    svn_subst_build_keywords.restype = POINTER(svn_error_t)
    svn_subst_build_keywords.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 226
if _libs["svn_subr-1"].has("svn_subst_keywords_differ2", "cdecl"):
    svn_subst_keywords_differ2 = _libs["svn_subr-1"].get("svn_subst_keywords_differ2", "cdecl")
    svn_subst_keywords_differ2.argtypes = [POINTER(apr_hash_t), POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_keywords_differ2.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 238
if _libs["svn_subr-1"].has("svn_subst_keywords_differ", "cdecl"):
    svn_subst_keywords_differ = _libs["svn_subr-1"].get("svn_subst_keywords_differ", "cdecl")
    svn_subst_keywords_differ.argtypes = [POINTER(svn_subst_keywords_t), POINTER(svn_subst_keywords_t), svn_boolean_t]
    svn_subst_keywords_differ.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 272
if _libs["svn_subr-1"].has("svn_subst_translate_stream3", "cdecl"):
    svn_subst_translate_stream3 = _libs["svn_subr-1"].get("svn_subst_translate_stream3", "cdecl")
    svn_subst_translate_stream3.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_translate_stream3.restype = POINTER(svn_error_t)
    svn_subst_translate_stream3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 288
if _libs["svn_subr-1"].has("svn_subst_translate_stream2", "cdecl"):
    svn_subst_translate_stream2 = _libs["svn_subr-1"].get("svn_subst_translate_stream2", "cdecl")
    svn_subst_translate_stream2.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), String, svn_boolean_t, POINTER(svn_subst_keywords_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_translate_stream2.restype = POINTER(svn_error_t)
    svn_subst_translate_stream2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 306
if _libs["svn_subr-1"].has("svn_subst_translate_stream", "cdecl"):
    svn_subst_translate_stream = _libs["svn_subr-1"].get("svn_subst_translate_stream", "cdecl")
    svn_subst_translate_stream.argtypes = [POINTER(svn_stream_t), POINTER(svn_stream_t), String, svn_boolean_t, POINTER(svn_subst_keywords_t), svn_boolean_t]
    svn_subst_translate_stream.restype = POINTER(svn_error_t)
    svn_subst_translate_stream.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 358
if _libs["svn_subr-1"].has("svn_subst_stream_translated", "cdecl"):
    svn_subst_stream_translated = _libs["svn_subr-1"].get("svn_subst_stream_translated", "cdecl")
    svn_subst_stream_translated.argtypes = [POINTER(svn_stream_t), String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_stream_translated.restype = POINTER(svn_stream_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 384
if _libs["svn_subr-1"].has("svn_subst_stream_translated_to_normal_form", "cdecl"):
    svn_subst_stream_translated_to_normal_form = _libs["svn_subr-1"].get("svn_subst_stream_translated_to_normal_form", "cdecl")
    svn_subst_stream_translated_to_normal_form.argtypes = [POINTER(POINTER(svn_stream_t)), POINTER(svn_stream_t), svn_subst_eol_style_t, String, svn_boolean_t, POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_subst_stream_translated_to_normal_form.restype = POINTER(svn_error_t)
    svn_subst_stream_translated_to_normal_form.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 406
if _libs["svn_subr-1"].has("svn_subst_read_specialfile", "cdecl"):
    svn_subst_read_specialfile = _libs["svn_subr-1"].get("svn_subst_read_specialfile", "cdecl")
    svn_subst_read_specialfile.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_subst_read_specialfile.restype = POINTER(svn_error_t)
    svn_subst_read_specialfile.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 429
if _libs["svn_subr-1"].has("svn_subst_create_specialfile", "cdecl"):
    svn_subst_create_specialfile = _libs["svn_subr-1"].get("svn_subst_create_specialfile", "cdecl")
    svn_subst_create_specialfile.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_subst_create_specialfile.restype = POINTER(svn_error_t)
    svn_subst_create_specialfile.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 448
if _libs["svn_subr-1"].has("svn_subst_stream_from_specialfile", "cdecl"):
    svn_subst_stream_from_specialfile = _libs["svn_subr-1"].get("svn_subst_stream_from_specialfile", "cdecl")
    svn_subst_stream_from_specialfile.argtypes = [POINTER(POINTER(svn_stream_t)), String, POINTER(apr_pool_t)]
    svn_subst_stream_from_specialfile.restype = POINTER(svn_error_t)
    svn_subst_stream_from_specialfile.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 476
if _libs["svn_subr-1"].has("svn_subst_copy_and_translate4", "cdecl"):
    svn_subst_copy_and_translate4 = _libs["svn_subr-1"].get("svn_subst_copy_and_translate4", "cdecl")
    svn_subst_copy_and_translate4.argtypes = [String, String, String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, svn_boolean_t, svn_cancel_func_t, POINTER(None), POINTER(apr_pool_t)]
    svn_subst_copy_and_translate4.restype = POINTER(svn_error_t)
    svn_subst_copy_and_translate4.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 497
if _libs["svn_subr-1"].has("svn_subst_copy_and_translate3", "cdecl"):
    svn_subst_copy_and_translate3 = _libs["svn_subr-1"].get("svn_subst_copy_and_translate3", "cdecl")
    svn_subst_copy_and_translate3.argtypes = [String, String, String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_copy_and_translate3.restype = POINTER(svn_error_t)
    svn_subst_copy_and_translate3.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 516
if _libs["svn_subr-1"].has("svn_subst_copy_and_translate2", "cdecl"):
    svn_subst_copy_and_translate2 = _libs["svn_subr-1"].get("svn_subst_copy_and_translate2", "cdecl")
    svn_subst_copy_and_translate2.argtypes = [String, String, String, svn_boolean_t, POINTER(svn_subst_keywords_t), svn_boolean_t, svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_copy_and_translate2.restype = POINTER(svn_error_t)
    svn_subst_copy_and_translate2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 533
if _libs["svn_subr-1"].has("svn_subst_copy_and_translate", "cdecl"):
    svn_subst_copy_and_translate = _libs["svn_subr-1"].get("svn_subst_copy_and_translate", "cdecl")
    svn_subst_copy_and_translate.argtypes = [String, String, String, svn_boolean_t, POINTER(svn_subst_keywords_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_copy_and_translate.restype = POINTER(svn_error_t)
    svn_subst_copy_and_translate.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 558
if _libs["svn_subr-1"].has("svn_subst_translate_cstring2", "cdecl"):
    svn_subst_translate_cstring2 = _libs["svn_subr-1"].get("svn_subst_translate_cstring2", "cdecl")
    svn_subst_translate_cstring2.argtypes = [String, POINTER(POINTER(c_char)), String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_translate_cstring2.restype = POINTER(svn_error_t)
    svn_subst_translate_cstring2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 574
if _libs["svn_subr-1"].has("svn_subst_translate_cstring", "cdecl"):
    svn_subst_translate_cstring = _libs["svn_subr-1"].get("svn_subst_translate_cstring", "cdecl")
    svn_subst_translate_cstring.argtypes = [String, POINTER(POINTER(c_char)), String, svn_boolean_t, POINTER(svn_subst_keywords_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_translate_cstring.restype = POINTER(svn_error_t)
    svn_subst_translate_cstring.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 604
if _libs["svn_subr-1"].has("svn_subst_translate_to_normal_form", "cdecl"):
    svn_subst_translate_to_normal_form = _libs["svn_subr-1"].get("svn_subst_translate_to_normal_form", "cdecl")
    svn_subst_translate_to_normal_form.argtypes = [String, String, svn_subst_eol_style_t, String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_translate_to_normal_form.restype = POINTER(svn_error_t)
    svn_subst_translate_to_normal_form.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 635
if _libs["svn_subr-1"].has("svn_subst_stream_detranslated", "cdecl"):
    svn_subst_stream_detranslated = _libs["svn_subr-1"].get("svn_subst_stream_detranslated", "cdecl")
    svn_subst_stream_detranslated.argtypes = [POINTER(POINTER(svn_stream_t)), String, svn_subst_eol_style_t, String, svn_boolean_t, POINTER(apr_hash_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_stream_detranslated.restype = POINTER(svn_error_t)
    svn_subst_stream_detranslated.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 671
if _libs["svn_subr-1"].has("svn_subst_translate_string2", "cdecl"):
    svn_subst_translate_string2 = _libs["svn_subr-1"].get("svn_subst_translate_string2", "cdecl")
    svn_subst_translate_string2.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_boolean_t), POINTER(svn_boolean_t), POINTER(svn_string_t), String, svn_boolean_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_subst_translate_string2.restype = POINTER(svn_error_t)
    svn_subst_translate_string2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 687
if _libs["svn_subr-1"].has("svn_subst_translate_string", "cdecl"):
    svn_subst_translate_string = _libs["svn_subr-1"].get("svn_subst_translate_string", "cdecl")
    svn_subst_translate_string.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), String, POINTER(apr_pool_t)]
    svn_subst_translate_string.restype = POINTER(svn_error_t)
    svn_subst_translate_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 699
if _libs["svn_subr-1"].has("svn_subst_detranslate_string", "cdecl"):
    svn_subst_detranslate_string = _libs["svn_subr-1"].get("svn_subst_detranslate_string", "cdecl")
    svn_subst_detranslate_string.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), svn_boolean_t, POINTER(apr_pool_t)]
    svn_subst_detranslate_string.restype = POINTER(svn_error_t)
    svn_subst_detranslate_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_time.h: 45
if _libs["svn_subr-1"].has("svn_time_to_cstring", "cdecl"):
    svn_time_to_cstring = _libs["svn_subr-1"].get("svn_time_to_cstring", "cdecl")
    svn_time_to_cstring.argtypes = [apr_time_t, POINTER(apr_pool_t)]
    svn_time_to_cstring.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_time.h: 58
if _libs["svn_subr-1"].has("svn_time_from_cstring", "cdecl"):
    svn_time_from_cstring = _libs["svn_subr-1"].get("svn_time_from_cstring", "cdecl")
    svn_time_from_cstring.argtypes = [POINTER(apr_time_t), String, POINTER(apr_pool_t)]
    svn_time_from_cstring.restype = POINTER(svn_error_t)
    svn_time_from_cstring.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_time.h: 66
if _libs["svn_subr-1"].has("svn_time_to_human_cstring", "cdecl"):
    svn_time_to_human_cstring = _libs["svn_subr-1"].get("svn_time_to_human_cstring", "cdecl")
    svn_time_to_human_cstring.argtypes = [apr_time_t, POINTER(apr_pool_t)]
    svn_time_to_human_cstring.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_time.h: 79
if _libs["svn_subr-1"].has("svn_parse_date", "cdecl"):
    svn_parse_date = _libs["svn_subr-1"].get("svn_parse_date", "cdecl")
    svn_parse_date.argtypes = [POINTER(svn_boolean_t), POINTER(apr_time_t), String, apr_time_t, POINTER(apr_pool_t)]
    svn_parse_date.restype = POINTER(svn_error_t)
    svn_parse_date.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_time.h: 95
if _libs["svn_subr-1"].has("svn_sleep_for_timestamps", "cdecl"):
    svn_sleep_for_timestamps = _libs["svn_subr-1"].get("svn_sleep_for_timestamps", "cdecl")
    svn_sleep_for_timestamps.argtypes = []
    svn_sleep_for_timestamps.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_user.h: 41
if _libs["svn_subr-1"].has("svn_user_get_name", "cdecl"):
    svn_user_get_name = _libs["svn_subr-1"].get("svn_user_get_name", "cdecl")
    svn_user_get_name.argtypes = [POINTER(apr_pool_t)]
    svn_user_get_name.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_user.h: 52
if _libs["svn_subr-1"].has("svn_user_get_homedir", "cdecl"):
    svn_user_get_homedir = _libs["svn_subr-1"].get("svn_user_get_homedir", "cdecl")
    svn_user_get_homedir.argtypes = [POINTER(apr_pool_t)]
    svn_user_get_homedir.restype = c_char_p

# /usr/include/apr-util/apr_xlate.h: 39
class struct_apr_xlate_t(Structure):
    pass

apr_xlate_t = struct_apr_xlate_t# /usr/include/apr-util/apr_xlate.h: 39

# /usr/include/apr-util/apr_xlate.h: 66
if _libs["aprutil-1"].has("apr_xlate_open", "cdecl"):
    apr_xlate_open = _libs["aprutil-1"].get("apr_xlate_open", "cdecl")
    apr_xlate_open.argtypes = [POINTER(POINTER(apr_xlate_t)), String, String, POINTER(apr_pool_t)]
    apr_xlate_open.restype = apr_status_t

# /usr/include/apr-util/apr_xlate.h: 93
if _libs["aprutil-1"].has("apr_xlate_sb_get", "cdecl"):
    apr_xlate_sb_get = _libs["aprutil-1"].get("apr_xlate_sb_get", "cdecl")
    apr_xlate_sb_get.argtypes = [POINTER(apr_xlate_t), POINTER(c_int)]
    apr_xlate_sb_get.restype = apr_status_t

# /usr/include/apr-util/apr_xlate.h: 117
if _libs["aprutil-1"].has("apr_xlate_conv_buffer", "cdecl"):
    apr_xlate_conv_buffer = _libs["aprutil-1"].get("apr_xlate_conv_buffer", "cdecl")
    apr_xlate_conv_buffer.argtypes = [POINTER(apr_xlate_t), String, POINTER(apr_size_t), String, POINTER(apr_size_t)]
    apr_xlate_conv_buffer.restype = apr_status_t

# /usr/include/apr-util/apr_xlate.h: 146
if _libs["aprutil-1"].has("apr_xlate_conv_byte", "cdecl"):
    apr_xlate_conv_byte = _libs["aprutil-1"].get("apr_xlate_conv_byte", "cdecl")
    apr_xlate_conv_byte.argtypes = [POINTER(apr_xlate_t), c_ubyte]
    apr_xlate_conv_byte.restype = apr_int32_t

# /usr/include/apr-util/apr_xlate.h: 156
if _libs["aprutil-1"].has("apr_xlate_close", "cdecl"):
    apr_xlate_close = _libs["aprutil-1"].get("apr_xlate_close", "cdecl")
    apr_xlate_close.argtypes = [POINTER(apr_xlate_t)]
    apr_xlate_close.restype = apr_status_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 66
if _libs["svn_subr-1"].has("svn_utf_initialize2", "cdecl"):
    svn_utf_initialize2 = _libs["svn_subr-1"].get("svn_utf_initialize2", "cdecl")
    svn_utf_initialize2.argtypes = [svn_boolean_t, POINTER(apr_pool_t)]
    svn_utf_initialize2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 77
if _libs["svn_subr-1"].has("svn_utf_initialize", "cdecl"):
    svn_utf_initialize = _libs["svn_subr-1"].get("svn_utf_initialize", "cdecl")
    svn_utf_initialize.argtypes = [POINTER(apr_pool_t)]
    svn_utf_initialize.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 82
if _libs["svn_subr-1"].has("svn_utf_stringbuf_to_utf8", "cdecl"):
    svn_utf_stringbuf_to_utf8 = _libs["svn_subr-1"].get("svn_utf_stringbuf_to_utf8", "cdecl")
    svn_utf_stringbuf_to_utf8.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_utf_stringbuf_to_utf8.restype = POINTER(svn_error_t)
    svn_utf_stringbuf_to_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 91
if _libs["svn_subr-1"].has("svn_utf_string_to_utf8", "cdecl"):
    svn_utf_string_to_utf8 = _libs["svn_subr-1"].get("svn_utf_string_to_utf8", "cdecl")
    svn_utf_string_to_utf8.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_utf_string_to_utf8.restype = POINTER(svn_error_t)
    svn_utf_string_to_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 100
if _libs["svn_subr-1"].has("svn_utf_cstring_to_utf8", "cdecl"):
    svn_utf_cstring_to_utf8 = _libs["svn_subr-1"].get("svn_utf_cstring_to_utf8", "cdecl")
    svn_utf_cstring_to_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_utf_cstring_to_utf8.restype = POINTER(svn_error_t)
    svn_utf_cstring_to_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 111
if _libs["svn_subr-1"].has("svn_utf_cstring_to_utf8_ex2", "cdecl"):
    svn_utf_cstring_to_utf8_ex2 = _libs["svn_subr-1"].get("svn_utf_cstring_to_utf8_ex2", "cdecl")
    svn_utf_cstring_to_utf8_ex2.argtypes = [POINTER(POINTER(c_char)), String, String, POINTER(apr_pool_t)]
    svn_utf_cstring_to_utf8_ex2.restype = POINTER(svn_error_t)
    svn_utf_cstring_to_utf8_ex2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 124
if _libs["svn_subr-1"].has("svn_utf_cstring_to_utf8_ex", "cdecl"):
    svn_utf_cstring_to_utf8_ex = _libs["svn_subr-1"].get("svn_utf_cstring_to_utf8_ex", "cdecl")
    svn_utf_cstring_to_utf8_ex.argtypes = [POINTER(POINTER(c_char)), String, String, String, POINTER(apr_pool_t)]
    svn_utf_cstring_to_utf8_ex.restype = POINTER(svn_error_t)
    svn_utf_cstring_to_utf8_ex.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 135
if _libs["svn_subr-1"].has("svn_utf_stringbuf_from_utf8", "cdecl"):
    svn_utf_stringbuf_from_utf8 = _libs["svn_subr-1"].get("svn_utf_stringbuf_from_utf8", "cdecl")
    svn_utf_stringbuf_from_utf8.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_utf_stringbuf_from_utf8.restype = POINTER(svn_error_t)
    svn_utf_stringbuf_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 144
if _libs["svn_subr-1"].has("svn_utf_string_from_utf8", "cdecl"):
    svn_utf_string_from_utf8 = _libs["svn_subr-1"].get("svn_utf_string_from_utf8", "cdecl")
    svn_utf_string_from_utf8.argtypes = [POINTER(POINTER(svn_string_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_utf_string_from_utf8.restype = POINTER(svn_error_t)
    svn_utf_string_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 153
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8", "cdecl"):
    svn_utf_cstring_from_utf8 = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8", "cdecl")
    svn_utf_cstring_from_utf8.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8.restype = POINTER(svn_error_t)
    svn_utf_cstring_from_utf8.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 164
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8_ex2", "cdecl"):
    svn_utf_cstring_from_utf8_ex2 = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8_ex2", "cdecl")
    svn_utf_cstring_from_utf8_ex2.argtypes = [POINTER(POINTER(c_char)), String, String, POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8_ex2.restype = POINTER(svn_error_t)
    svn_utf_cstring_from_utf8_ex2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 177
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8_ex", "cdecl"):
    svn_utf_cstring_from_utf8_ex = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8_ex", "cdecl")
    svn_utf_cstring_from_utf8_ex.argtypes = [POINTER(POINTER(c_char)), String, String, String, POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8_ex.restype = POINTER(svn_error_t)
    svn_utf_cstring_from_utf8_ex.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 218
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8_fuzzy", "cdecl"):
    svn_utf_cstring_from_utf8_fuzzy = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8_fuzzy", "cdecl")
    svn_utf_cstring_from_utf8_fuzzy.argtypes = [String, POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8_fuzzy.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 226
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8_stringbuf", "cdecl"):
    svn_utf_cstring_from_utf8_stringbuf = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8_stringbuf", "cdecl")
    svn_utf_cstring_from_utf8_stringbuf.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8_stringbuf.restype = POINTER(svn_error_t)
    svn_utf_cstring_from_utf8_stringbuf.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 235
if _libs["svn_subr-1"].has("svn_utf_cstring_from_utf8_string", "cdecl"):
    svn_utf_cstring_from_utf8_string = _libs["svn_subr-1"].get("svn_utf_cstring_from_utf8_string", "cdecl")
    svn_utf_cstring_from_utf8_string.argtypes = [POINTER(POINTER(c_char)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_utf_cstring_from_utf8_string.restype = POINTER(svn_error_t)
    svn_utf_cstring_from_utf8_string.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 246
if _libs["svn_subr-1"].has("svn_utf_cstring_utf8_width", "cdecl"):
    svn_utf_cstring_utf8_width = _libs["svn_subr-1"].get("svn_utf_cstring_utf8_width", "cdecl")
    svn_utf_cstring_utf8_width.argtypes = [String]
    svn_utf_cstring_utf8_width.restype = c_int

struct_svn_version_t.__slots__ = [
    'major',
    'minor',
    'patch',
    'tag',
]
struct_svn_version_t._fields_ = [
    ('major', c_int),
    ('minor', c_int),
    ('patch', c_int),
    ('tag', String),
]

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 213
if _libs["svn_subr-1"].has("svn_ver_compatible", "cdecl"):
    svn_ver_compatible = _libs["svn_subr-1"].get("svn_ver_compatible", "cdecl")
    svn_ver_compatible.argtypes = [POINTER(svn_version_t), POINTER(svn_version_t)]
    svn_ver_compatible.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 224
if _libs["svn_subr-1"].has("svn_ver_equal", "cdecl"):
    svn_ver_equal = _libs["svn_subr-1"].get("svn_ver_equal", "cdecl")
    svn_ver_equal.argtypes = [POINTER(svn_version_t), POINTER(svn_version_t)]
    svn_ver_equal.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 240
class struct_svn_version_checklist_t(Structure):
    pass

struct_svn_version_checklist_t.__slots__ = [
    'label',
    'version_query',
]
struct_svn_version_checklist_t._fields_ = [
    ('label', String),
    ('version_query', CFUNCTYPE(UNCHECKED(POINTER(svn_version_t)), )),
]

svn_version_checklist_t = struct_svn_version_checklist_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 240

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 261
if _libs["svn_subr-1"].has("svn_ver_check_list2", "cdecl"):
    svn_ver_check_list2 = _libs["svn_subr-1"].get("svn_ver_check_list2", "cdecl")
    svn_ver_check_list2.argtypes = [POINTER(svn_version_t), POINTER(svn_version_checklist_t), CFUNCTYPE(UNCHECKED(svn_boolean_t), POINTER(svn_version_t), POINTER(svn_version_t))]
    svn_ver_check_list2.restype = POINTER(svn_error_t)
    svn_ver_check_list2.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 273
if _libs["svn_subr-1"].has("svn_ver_check_list", "cdecl"):
    svn_ver_check_list = _libs["svn_subr-1"].get("svn_ver_check_list", "cdecl")
    svn_ver_check_list.argtypes = [POINTER(svn_version_t), POINTER(svn_version_checklist_t)]
    svn_ver_check_list.restype = POINTER(svn_error_t)
    svn_ver_check_list.errcheck = _svn_errcheck

svn_version_func_t = CFUNCTYPE(UNCHECKED(POINTER(svn_version_t)), )# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 283

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 292
if _libs["svn_subr-1"].has("svn_subr_version", "cdecl"):
    svn_subr_version = _libs["svn_subr-1"].get("svn_subr_version", "cdecl")
    svn_subr_version.argtypes = []
    svn_subr_version.restype = POINTER(svn_version_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 301
class struct_svn_version_extended_t(Structure):
    pass

svn_version_extended_t = struct_svn_version_extended_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 301

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 316
if _libs["svn_subr-1"].has("svn_version_extended", "cdecl"):
    svn_version_extended = _libs["svn_subr-1"].get("svn_version_extended", "cdecl")
    svn_version_extended.argtypes = [svn_boolean_t, POINTER(apr_pool_t)]
    svn_version_extended.restype = POINTER(svn_version_extended_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 329
if _libs["svn_subr-1"].has("svn_version_ext_build_date", "cdecl"):
    svn_version_ext_build_date = _libs["svn_subr-1"].get("svn_version_ext_build_date", "cdecl")
    svn_version_ext_build_date.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_build_date.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 340
if _libs["svn_subr-1"].has("svn_version_ext_build_time", "cdecl"):
    svn_version_ext_build_time = _libs["svn_subr-1"].get("svn_version_ext_build_time", "cdecl")
    svn_version_ext_build_time.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_build_time.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 354
if _libs["svn_subr-1"].has("svn_version_ext_build_host", "cdecl"):
    svn_version_ext_build_host = _libs["svn_subr-1"].get("svn_version_ext_build_host", "cdecl")
    svn_version_ext_build_host.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_build_host.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 364
if _libs["svn_subr-1"].has("svn_version_ext_copyright", "cdecl"):
    svn_version_ext_copyright = _libs["svn_subr-1"].get("svn_version_ext_copyright", "cdecl")
    svn_version_ext_copyright.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_copyright.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 378
if _libs["svn_subr-1"].has("svn_version_ext_runtime_host", "cdecl"):
    svn_version_ext_runtime_host = _libs["svn_subr-1"].get("svn_version_ext_runtime_host", "cdecl")
    svn_version_ext_runtime_host.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_runtime_host.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 390
if _libs["svn_subr-1"].has("svn_version_ext_runtime_osname", "cdecl"):
    svn_version_ext_runtime_osname = _libs["svn_subr-1"].get("svn_version_ext_runtime_osname", "cdecl")
    svn_version_ext_runtime_osname.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_runtime_osname.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 405
class struct_svn_version_ext_linked_lib_t(Structure):
    pass

struct_svn_version_ext_linked_lib_t.__slots__ = [
    'name',
    'compiled_version',
    'runtime_version',
]
struct_svn_version_ext_linked_lib_t._fields_ = [
    ('name', String),
    ('compiled_version', String),
    ('runtime_version', String),
]

svn_version_ext_linked_lib_t = struct_svn_version_ext_linked_lib_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 405

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 415
if _libs["svn_subr-1"].has("svn_version_ext_linked_libs", "cdecl"):
    svn_version_ext_linked_libs = _libs["svn_subr-1"].get("svn_version_ext_linked_libs", "cdecl")
    svn_version_ext_linked_libs.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_linked_libs.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 430
class struct_svn_version_ext_loaded_lib_t(Structure):
    pass

struct_svn_version_ext_loaded_lib_t.__slots__ = [
    'name',
    'version',
]
struct_svn_version_ext_loaded_lib_t._fields_ = [
    ('name', String),
    ('version', String),
]

svn_version_ext_loaded_lib_t = struct_svn_version_ext_loaded_lib_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 430

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 444
if _libs["svn_subr-1"].has("svn_version_ext_loaded_libs", "cdecl"):
    svn_version_ext_loaded_libs = _libs["svn_subr-1"].get("svn_version_ext_loaded_libs", "cdecl")
    svn_version_ext_loaded_libs.argtypes = [POINTER(svn_version_extended_t)]
    svn_version_ext_loaded_libs.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 54
class struct_svn_x509_certinfo_t(Structure):
    pass

svn_x509_certinfo_t = struct_svn_x509_certinfo_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 54

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 61
class struct_svn_x509_name_attr_t(Structure):
    pass

svn_x509_name_attr_t = struct_svn_x509_name_attr_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 61

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 79
if _libs["svn_subr-1"].has("svn_x509_parse_cert", "cdecl"):
    svn_x509_parse_cert = _libs["svn_subr-1"].get("svn_x509_parse_cert", "cdecl")
    svn_x509_parse_cert.argtypes = [POINTER(POINTER(svn_x509_certinfo_t)), String, apr_size_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_x509_parse_cert.restype = POINTER(svn_error_t)
    svn_x509_parse_cert.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 91
if _libs["svn_subr-1"].has("svn_x509_name_attr_dup", "cdecl"):
    svn_x509_name_attr_dup = _libs["svn_subr-1"].get("svn_x509_name_attr_dup", "cdecl")
    svn_x509_name_attr_dup.argtypes = [POINTER(svn_x509_name_attr_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_x509_name_attr_dup.restype = POINTER(svn_x509_name_attr_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 101
if _libs["svn_subr-1"].has("svn_x509_name_attr_get_oid", "cdecl"):
    svn_x509_name_attr_get_oid = _libs["svn_subr-1"].get("svn_x509_name_attr_get_oid", "cdecl")
    svn_x509_name_attr_get_oid.argtypes = [POINTER(svn_x509_name_attr_t), POINTER(apr_size_t)]
    svn_x509_name_attr_get_oid.restype = POINTER(c_ubyte)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 108
if _libs["svn_subr-1"].has("svn_x509_name_attr_get_value", "cdecl"):
    svn_x509_name_attr_get_value = _libs["svn_subr-1"].get("svn_x509_name_attr_get_value", "cdecl")
    svn_x509_name_attr_get_value.argtypes = [POINTER(svn_x509_name_attr_t)]
    svn_x509_name_attr_get_value.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 117
if _libs["svn_subr-1"].has("svn_x509_certinfo_dup", "cdecl"):
    svn_x509_certinfo_dup = _libs["svn_subr-1"].get("svn_x509_certinfo_dup", "cdecl")
    svn_x509_certinfo_dup.argtypes = [POINTER(svn_x509_certinfo_t), POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_x509_certinfo_dup.restype = POINTER(svn_x509_certinfo_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 126
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_subject", "cdecl"):
    svn_x509_certinfo_get_subject = _libs["svn_subr-1"].get("svn_x509_certinfo_get_subject", "cdecl")
    svn_x509_certinfo_get_subject.argtypes = [POINTER(svn_x509_certinfo_t), POINTER(apr_pool_t)]
    svn_x509_certinfo_get_subject.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 136
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_subject_attrs", "cdecl"):
    svn_x509_certinfo_get_subject_attrs = _libs["svn_subr-1"].get("svn_x509_certinfo_get_subject_attrs", "cdecl")
    svn_x509_certinfo_get_subject_attrs.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_subject_attrs.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 143
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_issuer", "cdecl"):
    svn_x509_certinfo_get_issuer = _libs["svn_subr-1"].get("svn_x509_certinfo_get_issuer", "cdecl")
    svn_x509_certinfo_get_issuer.argtypes = [POINTER(svn_x509_certinfo_t), POINTER(apr_pool_t)]
    svn_x509_certinfo_get_issuer.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 153
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_issuer_attrs", "cdecl"):
    svn_x509_certinfo_get_issuer_attrs = _libs["svn_subr-1"].get("svn_x509_certinfo_get_issuer_attrs", "cdecl")
    svn_x509_certinfo_get_issuer_attrs.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_issuer_attrs.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 162
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_valid_from", "cdecl"):
    svn_x509_certinfo_get_valid_from = _libs["svn_subr-1"].get("svn_x509_certinfo_get_valid_from", "cdecl")
    svn_x509_certinfo_get_valid_from.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_valid_from.restype = apr_time_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 170
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_valid_to", "cdecl"):
    svn_x509_certinfo_get_valid_to = _libs["svn_subr-1"].get("svn_x509_certinfo_get_valid_to", "cdecl")
    svn_x509_certinfo_get_valid_to.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_valid_to.restype = apr_time_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 176
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_digest", "cdecl"):
    svn_x509_certinfo_get_digest = _libs["svn_subr-1"].get("svn_x509_certinfo_get_digest", "cdecl")
    svn_x509_certinfo_get_digest.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_digest.restype = POINTER(svn_checksum_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 184
if _libs["svn_subr-1"].has("svn_x509_certinfo_get_hostnames", "cdecl"):
    svn_x509_certinfo_get_hostnames = _libs["svn_subr-1"].get("svn_x509_certinfo_get_hostnames", "cdecl")
    svn_x509_certinfo_get_hostnames.argtypes = [POINTER(svn_x509_certinfo_t)]
    svn_x509_certinfo_get_hostnames.restype = POINTER(apr_array_header_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 194
if _libs["svn_subr-1"].has("svn_x509_oid_to_string", "cdecl"):
    svn_x509_oid_to_string = _libs["svn_subr-1"].get("svn_x509_oid_to_string", "cdecl")
    svn_x509_oid_to_string.argtypes = [POINTER(c_ubyte), apr_size_t, POINTER(apr_pool_t), POINTER(apr_pool_t)]
    svn_x509_oid_to_string.restype = c_char_p

enum_svn_xml_open_tag_style = c_int# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 45

svn_xml_normal = 1# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 45

svn_xml_protect_pcdata = (svn_xml_normal + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 45

svn_xml_self_closing = (svn_xml_protect_pcdata + 1)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 45

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 71
if _libs["svn_subr-1"].has("svn_xml_is_xml_safe", "cdecl"):
    svn_xml_is_xml_safe = _libs["svn_subr-1"].get("svn_xml_is_xml_safe", "cdecl")
    svn_xml_is_xml_safe.argtypes = [String, apr_size_t]
    svn_xml_is_xml_safe.restype = svn_boolean_t

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 81
if _libs["svn_subr-1"].has("svn_xml_escape_cdata_stringbuf", "cdecl"):
    svn_xml_escape_cdata_stringbuf = _libs["svn_subr-1"].get("svn_xml_escape_cdata_stringbuf", "cdecl")
    svn_xml_escape_cdata_stringbuf.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_xml_escape_cdata_stringbuf.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 89
if _libs["svn_subr-1"].has("svn_xml_escape_cdata_string", "cdecl"):
    svn_xml_escape_cdata_string = _libs["svn_subr-1"].get("svn_xml_escape_cdata_string", "cdecl")
    svn_xml_escape_cdata_string.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_xml_escape_cdata_string.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 97
if _libs["svn_subr-1"].has("svn_xml_escape_cdata_cstring", "cdecl"):
    svn_xml_escape_cdata_cstring = _libs["svn_subr-1"].get("svn_xml_escape_cdata_cstring", "cdecl")
    svn_xml_escape_cdata_cstring.argtypes = [POINTER(POINTER(svn_stringbuf_t)), String, POINTER(apr_pool_t)]
    svn_xml_escape_cdata_cstring.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 109
if _libs["svn_subr-1"].has("svn_xml_escape_attr_stringbuf", "cdecl"):
    svn_xml_escape_attr_stringbuf = _libs["svn_subr-1"].get("svn_xml_escape_attr_stringbuf", "cdecl")
    svn_xml_escape_attr_stringbuf.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_stringbuf_t), POINTER(apr_pool_t)]
    svn_xml_escape_attr_stringbuf.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 117
if _libs["svn_subr-1"].has("svn_xml_escape_attr_string", "cdecl"):
    svn_xml_escape_attr_string = _libs["svn_subr-1"].get("svn_xml_escape_attr_string", "cdecl")
    svn_xml_escape_attr_string.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(svn_string_t), POINTER(apr_pool_t)]
    svn_xml_escape_attr_string.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 125
if _libs["svn_subr-1"].has("svn_xml_escape_attr_cstring", "cdecl"):
    svn_xml_escape_attr_cstring = _libs["svn_subr-1"].get("svn_xml_escape_attr_cstring", "cdecl")
    svn_xml_escape_attr_cstring.argtypes = [POINTER(POINTER(svn_stringbuf_t)), String, POINTER(apr_pool_t)]
    svn_xml_escape_attr_cstring.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 148
if _libs["svn_subr-1"].has("svn_xml_fuzzy_escape", "cdecl"):
    svn_xml_fuzzy_escape = _libs["svn_subr-1"].get("svn_xml_fuzzy_escape", "cdecl")
    svn_xml_fuzzy_escape.argtypes = [String, POINTER(apr_pool_t)]
    svn_xml_fuzzy_escape.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 158
class struct_svn_xml_parser_t(Structure):
    pass

svn_xml_parser_t = struct_svn_xml_parser_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 158

svn_xml_start_elem = CFUNCTYPE(UNCHECKED(None), POINTER(None), String, POINTER(POINTER(c_char)))# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 160

svn_xml_end_elem = CFUNCTYPE(UNCHECKED(None), POINTER(None), String)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 164

svn_xml_char_data = CFUNCTYPE(UNCHECKED(None), POINTER(None), String, apr_size_t)# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 167

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 181
if _libs["svn_subr-1"].has("svn_xml_make_parser", "cdecl"):
    svn_xml_make_parser = _libs["svn_subr-1"].get("svn_xml_make_parser", "cdecl")
    svn_xml_make_parser.argtypes = [POINTER(None), svn_xml_start_elem, svn_xml_end_elem, svn_xml_char_data, POINTER(apr_pool_t)]
    svn_xml_make_parser.restype = POINTER(svn_xml_parser_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 191
if _libs["svn_subr-1"].has("svn_xml_free_parser", "cdecl"):
    svn_xml_free_parser = _libs["svn_subr-1"].get("svn_xml_free_parser", "cdecl")
    svn_xml_free_parser.argtypes = [POINTER(svn_xml_parser_t)]
    svn_xml_free_parser.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 205
if _libs["svn_subr-1"].has("svn_xml_parse", "cdecl"):
    svn_xml_parse = _libs["svn_subr-1"].get("svn_xml_parse", "cdecl")
    svn_xml_parse.argtypes = [POINTER(svn_xml_parser_t), String, apr_size_t, svn_boolean_t]
    svn_xml_parse.restype = POINTER(svn_error_t)
    svn_xml_parse.errcheck = _svn_errcheck

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 218
if _libs["svn_subr-1"].has("svn_xml_signal_bailout", "cdecl"):
    svn_xml_signal_bailout = _libs["svn_subr-1"].get("svn_xml_signal_bailout", "cdecl")
    svn_xml_signal_bailout.argtypes = [POINTER(svn_error_t), POINTER(svn_xml_parser_t)]
    svn_xml_signal_bailout.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 237
if _libs["svn_subr-1"].has("svn_xml_get_attr_value", "cdecl"):
    svn_xml_get_attr_value = _libs["svn_subr-1"].get("svn_xml_get_attr_value", "cdecl")
    svn_xml_get_attr_value.argtypes = [String, POINTER(POINTER(c_char))]
    svn_xml_get_attr_value.restype = c_char_p

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 252
if _libs["svn_subr-1"].has("svn_xml_ap_to_hash", "cdecl"):
    svn_xml_ap_to_hash = _libs["svn_subr-1"].get("svn_xml_ap_to_hash", "cdecl")
    svn_xml_ap_to_hash.argtypes = [c_void_p, POINTER(apr_pool_t)]
    svn_xml_ap_to_hash.restype = POINTER(apr_hash_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 263
if _libs["svn_subr-1"].has("svn_xml_make_att_hash", "cdecl"):
    svn_xml_make_att_hash = _libs["svn_subr-1"].get("svn_xml_make_att_hash", "cdecl")
    svn_xml_make_att_hash.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_pool_t)]
    svn_xml_make_att_hash.restype = POINTER(apr_hash_t)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 272
if _libs["svn_subr-1"].has("svn_xml_hash_atts_preserving", "cdecl"):
    svn_xml_hash_atts_preserving = _libs["svn_subr-1"].get("svn_xml_hash_atts_preserving", "cdecl")
    svn_xml_hash_atts_preserving.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_xml_hash_atts_preserving.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 280
if _libs["svn_subr-1"].has("svn_xml_hash_atts_overlaying", "cdecl"):
    svn_xml_hash_atts_overlaying = _libs["svn_subr-1"].get("svn_xml_hash_atts_overlaying", "cdecl")
    svn_xml_hash_atts_overlaying.argtypes = [POINTER(POINTER(c_char)), POINTER(apr_hash_t), POINTER(apr_pool_t)]
    svn_xml_hash_atts_overlaying.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 304
if _libs["svn_subr-1"].has("svn_xml_make_header2", "cdecl"):
    svn_xml_make_header2 = _libs["svn_subr-1"].get("svn_xml_make_header2", "cdecl")
    svn_xml_make_header2.argtypes = [POINTER(POINTER(svn_stringbuf_t)), String, POINTER(apr_pool_t)]
    svn_xml_make_header2.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 314
if _libs["svn_subr-1"].has("svn_xml_make_header", "cdecl"):
    svn_xml_make_header = _libs["svn_subr-1"].get("svn_xml_make_header", "cdecl")
    svn_xml_make_header.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_pool_t)]
    svn_xml_make_header.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 330
if _libs["svn_subr-1"].has("svn_xml_make_open_tag", "cdecl"):
    _func = _libs["svn_subr-1"].get("svn_xml_make_open_tag", "cdecl")
    _restype = None
    _errcheck = None
    _argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_pool_t), enum_svn_xml_open_tag_style, String]
    svn_xml_make_open_tag = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 341
if _libs["svn_subr-1"].has("svn_xml_make_open_tag_v", "cdecl"):
    svn_xml_make_open_tag_v = _libs["svn_subr-1"].get("svn_xml_make_open_tag_v", "cdecl")
    svn_xml_make_open_tag_v.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_pool_t), enum_svn_xml_open_tag_style, String, c_void_p]
    svn_xml_make_open_tag_v.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 367
if _libs["svn_subr-1"].has("svn_xml_make_open_tag_hash", "cdecl"):
    svn_xml_make_open_tag_hash = _libs["svn_subr-1"].get("svn_xml_make_open_tag_hash", "cdecl")
    svn_xml_make_open_tag_hash.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_pool_t), enum_svn_xml_open_tag_style, String, POINTER(apr_hash_t)]
    svn_xml_make_open_tag_hash.restype = None

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 380
if _libs["svn_subr-1"].has("svn_xml_make_close_tag", "cdecl"):
    svn_xml_make_close_tag = _libs["svn_subr-1"].get("svn_xml_make_close_tag", "cdecl")
    svn_xml_make_close_tag.argtypes = [POINTER(POINTER(svn_stringbuf_t)), POINTER(apr_pool_t), String]
    svn_xml_make_close_tag.restype = None

# /usr/include/apr/apr_atomic.h: 47
if _libs["apr-1"].has("apr_atomic_init", "cdecl"):
    apr_atomic_init = _libs["apr-1"].get("apr_atomic_init", "cdecl")
    apr_atomic_init.argtypes = [POINTER(apr_pool_t)]
    apr_atomic_init.restype = apr_status_t

# /usr/include/apr/apr_atomic.h: 59
if _libs["apr-1"].has("apr_atomic_read32", "cdecl"):
    apr_atomic_read32 = _libs["apr-1"].get("apr_atomic_read32", "cdecl")
    apr_atomic_read32.argtypes = [POINTER(apr_uint32_t)]
    apr_atomic_read32.restype = apr_uint32_t

# /usr/include/apr/apr_atomic.h: 66
if _libs["apr-1"].has("apr_atomic_set32", "cdecl"):
    apr_atomic_set32 = _libs["apr-1"].get("apr_atomic_set32", "cdecl")
    apr_atomic_set32.argtypes = [POINTER(apr_uint32_t), apr_uint32_t]
    apr_atomic_set32.restype = None

# /usr/include/apr/apr_atomic.h: 74
if _libs["apr-1"].has("apr_atomic_add32", "cdecl"):
    apr_atomic_add32 = _libs["apr-1"].get("apr_atomic_add32", "cdecl")
    apr_atomic_add32.argtypes = [POINTER(apr_uint32_t), apr_uint32_t]
    apr_atomic_add32.restype = apr_uint32_t

# /usr/include/apr/apr_atomic.h: 81
if _libs["apr-1"].has("apr_atomic_sub32", "cdecl"):
    apr_atomic_sub32 = _libs["apr-1"].get("apr_atomic_sub32", "cdecl")
    apr_atomic_sub32.argtypes = [POINTER(apr_uint32_t), apr_uint32_t]
    apr_atomic_sub32.restype = None

# /usr/include/apr/apr_atomic.h: 88
if _libs["apr-1"].has("apr_atomic_inc32", "cdecl"):
    apr_atomic_inc32 = _libs["apr-1"].get("apr_atomic_inc32", "cdecl")
    apr_atomic_inc32.argtypes = [POINTER(apr_uint32_t)]
    apr_atomic_inc32.restype = apr_uint32_t

# /usr/include/apr/apr_atomic.h: 95
if _libs["apr-1"].has("apr_atomic_dec32", "cdecl"):
    apr_atomic_dec32 = _libs["apr-1"].get("apr_atomic_dec32", "cdecl")
    apr_atomic_dec32.argtypes = [POINTER(apr_uint32_t)]
    apr_atomic_dec32.restype = c_int

# /usr/include/apr/apr_atomic.h: 105
if _libs["apr-1"].has("apr_atomic_cas32", "cdecl"):
    apr_atomic_cas32 = _libs["apr-1"].get("apr_atomic_cas32", "cdecl")
    apr_atomic_cas32.argtypes = [POINTER(apr_uint32_t), apr_uint32_t, apr_uint32_t]
    apr_atomic_cas32.restype = apr_uint32_t

# /usr/include/apr/apr_atomic.h: 114
if _libs["apr-1"].has("apr_atomic_xchg32", "cdecl"):
    apr_atomic_xchg32 = _libs["apr-1"].get("apr_atomic_xchg32", "cdecl")
    apr_atomic_xchg32.argtypes = [POINTER(apr_uint32_t), apr_uint32_t]
    apr_atomic_xchg32.restype = apr_uint32_t

# /usr/include/apr/apr_atomic.h: 126
if _libs["apr-1"].has("apr_atomic_read64", "cdecl"):
    apr_atomic_read64 = _libs["apr-1"].get("apr_atomic_read64", "cdecl")
    apr_atomic_read64.argtypes = [POINTER(apr_uint64_t)]
    apr_atomic_read64.restype = apr_uint64_t

# /usr/include/apr/apr_atomic.h: 133
if _libs["apr-1"].has("apr_atomic_set64", "cdecl"):
    apr_atomic_set64 = _libs["apr-1"].get("apr_atomic_set64", "cdecl")
    apr_atomic_set64.argtypes = [POINTER(apr_uint64_t), apr_uint64_t]
    apr_atomic_set64.restype = None

# /usr/include/apr/apr_atomic.h: 141
if _libs["apr-1"].has("apr_atomic_add64", "cdecl"):
    apr_atomic_add64 = _libs["apr-1"].get("apr_atomic_add64", "cdecl")
    apr_atomic_add64.argtypes = [POINTER(apr_uint64_t), apr_uint64_t]
    apr_atomic_add64.restype = apr_uint64_t

# /usr/include/apr/apr_atomic.h: 148
if _libs["apr-1"].has("apr_atomic_sub64", "cdecl"):
    apr_atomic_sub64 = _libs["apr-1"].get("apr_atomic_sub64", "cdecl")
    apr_atomic_sub64.argtypes = [POINTER(apr_uint64_t), apr_uint64_t]
    apr_atomic_sub64.restype = None

# /usr/include/apr/apr_atomic.h: 155
if _libs["apr-1"].has("apr_atomic_inc64", "cdecl"):
    apr_atomic_inc64 = _libs["apr-1"].get("apr_atomic_inc64", "cdecl")
    apr_atomic_inc64.argtypes = [POINTER(apr_uint64_t)]
    apr_atomic_inc64.restype = apr_uint64_t

# /usr/include/apr/apr_atomic.h: 162
if _libs["apr-1"].has("apr_atomic_dec64", "cdecl"):
    apr_atomic_dec64 = _libs["apr-1"].get("apr_atomic_dec64", "cdecl")
    apr_atomic_dec64.argtypes = [POINTER(apr_uint64_t)]
    apr_atomic_dec64.restype = c_int

# /usr/include/apr/apr_atomic.h: 172
if _libs["apr-1"].has("apr_atomic_cas64", "cdecl"):
    apr_atomic_cas64 = _libs["apr-1"].get("apr_atomic_cas64", "cdecl")
    apr_atomic_cas64.argtypes = [POINTER(apr_uint64_t), apr_uint64_t, apr_uint64_t]
    apr_atomic_cas64.restype = apr_uint64_t

# /usr/include/apr/apr_atomic.h: 181
if _libs["apr-1"].has("apr_atomic_xchg64", "cdecl"):
    apr_atomic_xchg64 = _libs["apr-1"].get("apr_atomic_xchg64", "cdecl")
    apr_atomic_xchg64.argtypes = [POINTER(apr_uint64_t), apr_uint64_t]
    apr_atomic_xchg64.restype = apr_uint64_t

# /usr/include/apr/apr_atomic.h: 191
if _libs["apr-1"].has("apr_atomic_casptr", "cdecl"):
    apr_atomic_casptr = _libs["apr-1"].get("apr_atomic_casptr", "cdecl")
    apr_atomic_casptr.argtypes = [POINTER(POINTER(None)), POINTER(None), POINTER(None)]
    apr_atomic_casptr.restype = POINTER(c_ubyte)
    apr_atomic_casptr.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_atomic.h: 199
if _libs["apr-1"].has("apr_atomic_xchgptr", "cdecl"):
    apr_atomic_xchgptr = _libs["apr-1"].get("apr_atomic_xchgptr", "cdecl")
    apr_atomic_xchgptr.argtypes = [POINTER(POINTER(None)), POINTER(None)]
    apr_atomic_xchgptr.restype = POINTER(c_ubyte)
    apr_atomic_xchgptr.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_cstr.h: 81
if _libs["apr-1"].has("apr_cstr_split", "cdecl"):
    apr_cstr_split = _libs["apr-1"].get("apr_cstr_split", "cdecl")
    apr_cstr_split.argtypes = [String, String, c_int, POINTER(apr_pool_t)]
    apr_cstr_split.restype = POINTER(apr_array_header_t)

# /usr/include/apr/apr_cstr.h: 92
if _libs["apr-1"].has("apr_cstr_split_append", "cdecl"):
    apr_cstr_split_append = _libs["apr-1"].get("apr_cstr_split_append", "cdecl")
    apr_cstr_split_append.argtypes = [POINTER(apr_array_header_t), String, String, c_int, POINTER(apr_pool_t)]
    apr_cstr_split_append.restype = None

# /usr/include/apr/apr_cstr.h: 104
if _libs["apr-1"].has("apr_cstr_match_glob_list", "cdecl"):
    apr_cstr_match_glob_list = _libs["apr-1"].get("apr_cstr_match_glob_list", "cdecl")
    apr_cstr_match_glob_list.argtypes = [String, POINTER(apr_array_header_t)]
    apr_cstr_match_glob_list.restype = c_int

# /usr/include/apr/apr_cstr.h: 111
if _libs["apr-1"].has("apr_cstr_match_list", "cdecl"):
    apr_cstr_match_list = _libs["apr-1"].get("apr_cstr_match_list", "cdecl")
    apr_cstr_match_list.argtypes = [String, POINTER(apr_array_header_t)]
    apr_cstr_match_list.restype = c_int

# /usr/include/apr/apr_cstr.h: 125
if _libs["apr-1"].has("apr_cstr_tokenize", "cdecl"):
    apr_cstr_tokenize = _libs["apr-1"].get("apr_cstr_tokenize", "cdecl")
    apr_cstr_tokenize.argtypes = [String, POINTER(POINTER(c_char))]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_cstr_tokenize.restype = ReturnString
    else:
        apr_cstr_tokenize.restype = String
        apr_cstr_tokenize.errcheck = ReturnString

# /usr/include/apr/apr_cstr.h: 133
if _libs["apr-1"].has("apr_cstr_count_newlines", "cdecl"):
    apr_cstr_count_newlines = _libs["apr-1"].get("apr_cstr_count_newlines", "cdecl")
    apr_cstr_count_newlines.argtypes = [String]
    apr_cstr_count_newlines.restype = c_int

# /usr/include/apr/apr_cstr.h: 161
if _libs["apr-1"].has("apr_cstr_casecmp", "cdecl"):
    apr_cstr_casecmp = _libs["apr-1"].get("apr_cstr_casecmp", "cdecl")
    apr_cstr_casecmp.argtypes = [String, String]
    apr_cstr_casecmp.restype = c_int

# /usr/include/apr/apr_cstr.h: 175
if _libs["apr-1"].has("apr_cstr_casecmpn", "cdecl"):
    apr_cstr_casecmpn = _libs["apr-1"].get("apr_cstr_casecmpn", "cdecl")
    apr_cstr_casecmpn.argtypes = [String, String, apr_size_t]
    apr_cstr_casecmpn.restype = c_int

# /usr/include/apr/apr_cstr.h: 198
if _libs["apr-1"].has("apr_cstr_strtoi64", "cdecl"):
    apr_cstr_strtoi64 = _libs["apr-1"].get("apr_cstr_strtoi64", "cdecl")
    apr_cstr_strtoi64.argtypes = [POINTER(c_int64), String, c_int64, c_int64, c_int]
    apr_cstr_strtoi64.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 212
if _libs["apr-1"].has("apr_cstr_atoi64", "cdecl"):
    apr_cstr_atoi64 = _libs["apr-1"].get("apr_cstr_atoi64", "cdecl")
    apr_cstr_atoi64.argtypes = [POINTER(c_int64), String]
    apr_cstr_atoi64.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 223
if _libs["apr-1"].has("apr_cstr_atoi", "cdecl"):
    apr_cstr_atoi = _libs["apr-1"].get("apr_cstr_atoi", "cdecl")
    apr_cstr_atoi.argtypes = [POINTER(c_int), String]
    apr_cstr_atoi.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 247
if _libs["apr-1"].has("apr_cstr_strtoui64", "cdecl"):
    apr_cstr_strtoui64 = _libs["apr-1"].get("apr_cstr_strtoui64", "cdecl")
    apr_cstr_strtoui64.argtypes = [POINTER(apr_uint64_t), String, apr_uint64_t, apr_uint64_t, c_int]
    apr_cstr_strtoui64.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 262
if _libs["apr-1"].has("apr_cstr_atoui64", "cdecl"):
    apr_cstr_atoui64 = _libs["apr-1"].get("apr_cstr_atoui64", "cdecl")
    apr_cstr_atoui64.argtypes = [POINTER(apr_uint64_t), String]
    apr_cstr_atoui64.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 274
if _libs["apr-1"].has("apr_cstr_atoui", "cdecl"):
    apr_cstr_atoui = _libs["apr-1"].get("apr_cstr_atoui", "cdecl")
    apr_cstr_atoui.argtypes = [POINTER(c_uint), String]
    apr_cstr_atoui.restype = apr_status_t

# /usr/include/apr/apr_cstr.h: 283
if _libs["apr-1"].has("apr_cstr_skip_prefix", "cdecl"):
    apr_cstr_skip_prefix = _libs["apr-1"].get("apr_cstr_skip_prefix", "cdecl")
    apr_cstr_skip_prefix.argtypes = [String, String]
    apr_cstr_skip_prefix.restype = c_char_p

# /usr/include/apr/apr_encode.h: 167
if _libs["apr-1"].has("apr_encode_base64", "cdecl"):
    apr_encode_base64 = _libs["apr-1"].get("apr_encode_base64", "cdecl")
    apr_encode_base64.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base64.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 188
if _libs["apr-1"].has("apr_encode_base64_binary", "cdecl"):
    apr_encode_base64_binary = _libs["apr-1"].get("apr_encode_base64_binary", "cdecl")
    apr_encode_base64_binary.argtypes = [String, POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base64_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 207
if _libs["apr-1"].has("apr_pencode_base64", "cdecl"):
    apr_pencode_base64 = _libs["apr-1"].get("apr_pencode_base64", "cdecl")
    apr_pencode_base64.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base64.restype = c_char_p

# /usr/include/apr/apr_encode.h: 225
if _libs["apr-1"].has("apr_pencode_base64_binary", "cdecl"):
    apr_pencode_base64_binary = _libs["apr-1"].get("apr_pencode_base64_binary", "cdecl")
    apr_pencode_base64_binary.argtypes = [POINTER(apr_pool_t), POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base64_binary.restype = c_char_p

# /usr/include/apr/apr_encode.h: 250
if _libs["apr-1"].has("apr_decode_base64", "cdecl"):
    apr_decode_base64 = _libs["apr-1"].get("apr_decode_base64", "cdecl")
    apr_decode_base64.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base64.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 275
if _libs["apr-1"].has("apr_decode_base64_binary", "cdecl"):
    apr_decode_base64_binary = _libs["apr-1"].get("apr_decode_base64_binary", "cdecl")
    apr_decode_base64_binary.argtypes = [POINTER(c_ubyte), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base64_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 294
if _libs["apr-1"].has("apr_pdecode_base64", "cdecl"):
    apr_pdecode_base64 = _libs["apr-1"].get("apr_pdecode_base64", "cdecl")
    apr_pdecode_base64.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base64.restype = c_char_p

# /usr/include/apr/apr_encode.h: 314
if _libs["apr-1"].has("apr_pdecode_base64_binary", "cdecl"):
    apr_pdecode_base64_binary = _libs["apr-1"].get("apr_pdecode_base64_binary", "cdecl")
    apr_pdecode_base64_binary.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base64_binary.restype = POINTER(c_ubyte)

# /usr/include/apr/apr_encode.h: 337
if _libs["apr-1"].has("apr_encode_base32", "cdecl"):
    apr_encode_base32 = _libs["apr-1"].get("apr_encode_base32", "cdecl")
    apr_encode_base32.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base32.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 357
if _libs["apr-1"].has("apr_encode_base32_binary", "cdecl"):
    apr_encode_base32_binary = _libs["apr-1"].get("apr_encode_base32_binary", "cdecl")
    apr_encode_base32_binary.argtypes = [String, POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base32_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 375
if _libs["apr-1"].has("apr_pencode_base32", "cdecl"):
    apr_pencode_base32 = _libs["apr-1"].get("apr_pencode_base32", "cdecl")
    apr_pencode_base32.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base32.restype = c_char_p

# /usr/include/apr/apr_encode.h: 393
if _libs["apr-1"].has("apr_pencode_base32_binary", "cdecl"):
    apr_pencode_base32_binary = _libs["apr-1"].get("apr_pencode_base32_binary", "cdecl")
    apr_pencode_base32_binary.argtypes = [POINTER(apr_pool_t), POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base32_binary.restype = c_char_p

# /usr/include/apr/apr_encode.h: 418
if _libs["apr-1"].has("apr_decode_base32", "cdecl"):
    apr_decode_base32 = _libs["apr-1"].get("apr_decode_base32", "cdecl")
    apr_decode_base32.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base32.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 442
if _libs["apr-1"].has("apr_decode_base32_binary", "cdecl"):
    apr_decode_base32_binary = _libs["apr-1"].get("apr_decode_base32_binary", "cdecl")
    apr_decode_base32_binary.argtypes = [POINTER(c_ubyte), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base32_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 460
if _libs["apr-1"].has("apr_pdecode_base32", "cdecl"):
    apr_pdecode_base32 = _libs["apr-1"].get("apr_pdecode_base32", "cdecl")
    apr_pdecode_base32.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base32.restype = c_char_p

# /usr/include/apr/apr_encode.h: 479
if _libs["apr-1"].has("apr_pdecode_base32_binary", "cdecl"):
    apr_pdecode_base32_binary = _libs["apr-1"].get("apr_pdecode_base32_binary", "cdecl")
    apr_pdecode_base32_binary.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base32_binary.restype = POINTER(c_ubyte)

# /usr/include/apr/apr_encode.h: 501
if _libs["apr-1"].has("apr_encode_base16", "cdecl"):
    apr_encode_base16 = _libs["apr-1"].get("apr_encode_base16", "cdecl")
    apr_encode_base16.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base16.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 520
if _libs["apr-1"].has("apr_encode_base16_binary", "cdecl"):
    apr_encode_base16_binary = _libs["apr-1"].get("apr_encode_base16_binary", "cdecl")
    apr_encode_base16_binary.argtypes = [String, POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_encode_base16_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 539
if _libs["apr-1"].has("apr_pencode_base16", "cdecl"):
    apr_pencode_base16 = _libs["apr-1"].get("apr_pencode_base16", "cdecl")
    apr_pencode_base16.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base16.restype = c_char_p

# /usr/include/apr/apr_encode.h: 557
if _libs["apr-1"].has("apr_pencode_base16_binary", "cdecl"):
    apr_pencode_base16_binary = _libs["apr-1"].get("apr_pencode_base16_binary", "cdecl")
    apr_pencode_base16_binary.argtypes = [POINTER(apr_pool_t), POINTER(c_ubyte), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pencode_base16_binary.restype = c_char_p

# /usr/include/apr/apr_encode.h: 582
if _libs["apr-1"].has("apr_decode_base16", "cdecl"):
    apr_decode_base16 = _libs["apr-1"].get("apr_decode_base16", "cdecl")
    apr_decode_base16.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base16.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 606
if _libs["apr-1"].has("apr_decode_base16_binary", "cdecl"):
    apr_decode_base16_binary = _libs["apr-1"].get("apr_decode_base16_binary", "cdecl")
    apr_decode_base16_binary.argtypes = [POINTER(c_ubyte), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_decode_base16_binary.restype = apr_status_t

# /usr/include/apr/apr_encode.h: 623
if _libs["apr-1"].has("apr_pdecode_base16", "cdecl"):
    apr_pdecode_base16 = _libs["apr-1"].get("apr_pdecode_base16", "cdecl")
    apr_pdecode_base16.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base16.restype = c_char_p

# /usr/include/apr/apr_encode.h: 641
if _libs["apr-1"].has("apr_pdecode_base16_binary", "cdecl"):
    apr_pdecode_base16_binary = _libs["apr-1"].get("apr_pdecode_base16_binary", "cdecl")
    apr_pdecode_base16_binary.argtypes = [POINTER(apr_pool_t), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_pdecode_base16_binary.restype = POINTER(c_ubyte)

# /usr/include/apr/apr_env.h: 42
if _libs["apr-1"].has("apr_env_get", "cdecl"):
    apr_env_get = _libs["apr-1"].get("apr_env_get", "cdecl")
    apr_env_get.argtypes = [POINTER(POINTER(c_char)), String, POINTER(apr_pool_t)]
    apr_env_get.restype = apr_status_t

# /usr/include/apr/apr_env.h: 51
if _libs["apr-1"].has("apr_env_set", "cdecl"):
    apr_env_set = _libs["apr-1"].get("apr_env_set", "cdecl")
    apr_env_set.argtypes = [String, String, POINTER(apr_pool_t)]
    apr_env_set.restype = apr_status_t

# /usr/include/apr/apr_env.h: 59
if _libs["apr-1"].has("apr_env_delete", "cdecl"):
    apr_env_delete = _libs["apr-1"].get("apr_env_delete", "cdecl")
    apr_env_delete.argtypes = [String, POINTER(apr_pool_t)]
    apr_env_delete.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 85
if _libs["apr-1"].has("apr_escape_shell", "cdecl"):
    apr_escape_shell = _libs["apr-1"].get("apr_escape_shell", "cdecl")
    apr_escape_shell.argtypes = [String, String, apr_ssize_t, POINTER(apr_size_t)]
    apr_escape_shell.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 100
if _libs["apr-1"].has("apr_pescape_shell", "cdecl"):
    apr_pescape_shell = _libs["apr-1"].get("apr_pescape_shell", "cdecl")
    apr_pescape_shell.argtypes = [POINTER(apr_pool_t), String]
    apr_pescape_shell.restype = c_char_p

# /usr/include/apr/apr_escape.h: 120
if _libs["apr-1"].has("apr_unescape_url", "cdecl"):
    apr_unescape_url = _libs["apr-1"].get("apr_unescape_url", "cdecl")
    apr_unescape_url.argtypes = [String, String, apr_ssize_t, String, String, c_int, POINTER(apr_size_t)]
    apr_unescape_url.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 140
if _libs["apr-1"].has("apr_punescape_url", "cdecl"):
    apr_punescape_url = _libs["apr-1"].get("apr_punescape_url", "cdecl")
    apr_punescape_url.argtypes = [POINTER(apr_pool_t), String, String, String, c_int]
    apr_punescape_url.restype = c_char_p

# /usr/include/apr/apr_escape.h: 154
if _libs["apr-1"].has("apr_escape_path_segment", "cdecl"):
    apr_escape_path_segment = _libs["apr-1"].get("apr_escape_path_segment", "cdecl")
    apr_escape_path_segment.argtypes = [String, String, apr_ssize_t, POINTER(apr_size_t)]
    apr_escape_path_segment.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 165
if _libs["apr-1"].has("apr_pescape_path_segment", "cdecl"):
    apr_pescape_path_segment = _libs["apr-1"].get("apr_pescape_path_segment", "cdecl")
    apr_pescape_path_segment.argtypes = [POINTER(apr_pool_t), String]
    apr_pescape_path_segment.restype = c_char_p

# /usr/include/apr/apr_escape.h: 187
if _libs["apr-1"].has("apr_escape_path", "cdecl"):
    apr_escape_path = _libs["apr-1"].get("apr_escape_path", "cdecl")
    apr_escape_path.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_escape_path.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 208
if _libs["apr-1"].has("apr_pescape_path", "cdecl"):
    apr_pescape_path = _libs["apr-1"].get("apr_pescape_path", "cdecl")
    apr_pescape_path.argtypes = [POINTER(apr_pool_t), String, c_int]
    apr_pescape_path.restype = c_char_p

# /usr/include/apr/apr_escape.h: 222
if _libs["apr-1"].has("apr_escape_urlencoded", "cdecl"):
    apr_escape_urlencoded = _libs["apr-1"].get("apr_escape_urlencoded", "cdecl")
    apr_escape_urlencoded.argtypes = [String, String, apr_ssize_t, POINTER(apr_size_t)]
    apr_escape_urlencoded.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 234
if _libs["apr-1"].has("apr_pescape_urlencoded", "cdecl"):
    apr_pescape_urlencoded = _libs["apr-1"].get("apr_pescape_urlencoded", "cdecl")
    apr_pescape_urlencoded.argtypes = [POINTER(apr_pool_t), String]
    apr_pescape_urlencoded.restype = c_char_p

# /usr/include/apr/apr_escape.h: 253
if _libs["apr-1"].has("apr_escape_entity", "cdecl"):
    apr_escape_entity = _libs["apr-1"].get("apr_escape_entity", "cdecl")
    apr_escape_entity.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_escape_entity.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 267
if _libs["apr-1"].has("apr_pescape_entity", "cdecl"):
    apr_pescape_entity = _libs["apr-1"].get("apr_pescape_entity", "cdecl")
    apr_pescape_entity.argtypes = [POINTER(apr_pool_t), String, c_int]
    apr_pescape_entity.restype = c_char_p

# /usr/include/apr/apr_escape.h: 285
if _libs["apr-1"].has("apr_unescape_entity", "cdecl"):
    apr_unescape_entity = _libs["apr-1"].get("apr_unescape_entity", "cdecl")
    apr_unescape_entity.argtypes = [String, String, apr_ssize_t, POINTER(apr_size_t)]
    apr_unescape_entity.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 300
if _libs["apr-1"].has("apr_punescape_entity", "cdecl"):
    apr_punescape_entity = _libs["apr-1"].get("apr_punescape_entity", "cdecl")
    apr_punescape_entity.argtypes = [POINTER(apr_pool_t), String]
    apr_punescape_entity.restype = c_char_p

# /usr/include/apr/apr_escape.h: 322
if _libs["apr-1"].has("apr_escape_echo", "cdecl"):
    apr_escape_echo = _libs["apr-1"].get("apr_escape_echo", "cdecl")
    apr_escape_echo.argtypes = [String, String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_escape_echo.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 342
if _libs["apr-1"].has("apr_pescape_echo", "cdecl"):
    apr_pescape_echo = _libs["apr-1"].get("apr_pescape_echo", "cdecl")
    apr_pescape_echo.argtypes = [POINTER(apr_pool_t), String, c_int]
    apr_pescape_echo.restype = c_char_p

# /usr/include/apr/apr_escape.h: 354
if _libs["apr-1"].has("apr_escape_hex", "cdecl"):
    apr_escape_hex = _libs["apr-1"].get("apr_escape_hex", "cdecl")
    apr_escape_hex.argtypes = [String, POINTER(None), apr_size_t, c_int, POINTER(apr_size_t)]
    apr_escape_hex.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 367
if _libs["apr-1"].has("apr_pescape_hex", "cdecl"):
    apr_pescape_hex = _libs["apr-1"].get("apr_pescape_hex", "cdecl")
    apr_pescape_hex.argtypes = [POINTER(apr_pool_t), POINTER(None), apr_size_t, c_int]
    apr_pescape_hex.restype = c_char_p

# /usr/include/apr/apr_escape.h: 380
if _libs["apr-1"].has("apr_unescape_hex", "cdecl"):
    apr_unescape_hex = _libs["apr-1"].get("apr_unescape_hex", "cdecl")
    apr_unescape_hex.argtypes = [POINTER(None), String, apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_unescape_hex.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 394
if _libs["apr-1"].has("apr_punescape_hex", "cdecl"):
    apr_punescape_hex = _libs["apr-1"].get("apr_punescape_hex", "cdecl")
    apr_punescape_hex.argtypes = [POINTER(apr_pool_t), String, c_int, POINTER(apr_size_t)]
    apr_punescape_hex.restype = POINTER(c_ubyte)
    apr_punescape_hex.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_escape.h: 408
if _libs["apr-1"].has("apr_escape_ldap", "cdecl"):
    apr_escape_ldap = _libs["apr-1"].get("apr_escape_ldap", "cdecl")
    apr_escape_ldap.argtypes = [String, POINTER(None), apr_ssize_t, c_int, POINTER(apr_size_t)]
    apr_escape_ldap.restype = apr_status_t

# /usr/include/apr/apr_escape.h: 423
if _libs["apr-1"].has("apr_pescape_ldap", "cdecl"):
    apr_pescape_ldap = _libs["apr-1"].get("apr_pescape_ldap", "cdecl")
    apr_pescape_ldap.argtypes = [POINTER(apr_pool_t), POINTER(None), apr_ssize_t, c_int]
    apr_pescape_ldap.restype = c_char_p

# /usr/include/apr/apr_fnmatch.h: 120
if _libs["apr-1"].has("apr_fnmatch", "cdecl"):
    apr_fnmatch = _libs["apr-1"].get("apr_fnmatch", "cdecl")
    apr_fnmatch.argtypes = [String, String, c_int]
    apr_fnmatch.restype = apr_status_t

# /usr/include/apr/apr_fnmatch.h: 128
if _libs["apr-1"].has("apr_fnmatch_test", "cdecl"):
    apr_fnmatch_test = _libs["apr-1"].get("apr_fnmatch_test", "cdecl")
    apr_fnmatch_test.argtypes = [String]
    apr_fnmatch_test.restype = c_int

# /usr/include/apr/apr_fnmatch.h: 143
if _libs["apr-1"].has("apr_match_glob", "cdecl"):
    apr_match_glob = _libs["apr-1"].get("apr_match_glob", "cdecl")
    apr_match_glob.argtypes = [String, POINTER(POINTER(apr_array_header_t)), POINTER(apr_pool_t)]
    apr_match_glob.restype = apr_status_t

enum_anon_90 = c_int# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_FCNTL = 0# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_FLOCK = (APR_LOCK_FCNTL + 1)# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_SYSVSEM = (APR_LOCK_FLOCK + 1)# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_PROC_PTHREAD = (APR_LOCK_SYSVSEM + 1)# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_POSIXSEM = (APR_LOCK_PROC_PTHREAD + 1)# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_DEFAULT = (APR_LOCK_POSIXSEM + 1)# /usr/include/apr/apr_proc_mutex.h: 54

APR_LOCK_DEFAULT_TIMED = (APR_LOCK_DEFAULT + 1)# /usr/include/apr/apr_proc_mutex.h: 54

apr_lockmech_e = enum_anon_90# /usr/include/apr/apr_proc_mutex.h: 54

# /usr/include/apr/apr_proc_mutex.h: 57
class struct_apr_proc_mutex_t(Structure):
    pass

apr_proc_mutex_t = struct_apr_proc_mutex_t# /usr/include/apr/apr_proc_mutex.h: 57

# /usr/include/apr/apr_proc_mutex.h: 82
if _libs["apr-1"].has("apr_proc_mutex_create", "cdecl"):
    apr_proc_mutex_create = _libs["apr-1"].get("apr_proc_mutex_create", "cdecl")
    apr_proc_mutex_create.argtypes = [POINTER(POINTER(apr_proc_mutex_t)), String, apr_lockmech_e, POINTER(apr_pool_t)]
    apr_proc_mutex_create.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 98
if _libs["apr-1"].has("apr_proc_mutex_child_init", "cdecl"):
    apr_proc_mutex_child_init = _libs["apr-1"].get("apr_proc_mutex_child_init", "cdecl")
    apr_proc_mutex_child_init.argtypes = [POINTER(POINTER(apr_proc_mutex_t)), String, POINTER(apr_pool_t)]
    apr_proc_mutex_child_init.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 107
if _libs["apr-1"].has("apr_proc_mutex_lock", "cdecl"):
    apr_proc_mutex_lock = _libs["apr-1"].get("apr_proc_mutex_lock", "cdecl")
    apr_proc_mutex_lock.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_lock.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 116
if _libs["apr-1"].has("apr_proc_mutex_trylock", "cdecl"):
    apr_proc_mutex_trylock = _libs["apr-1"].get("apr_proc_mutex_trylock", "cdecl")
    apr_proc_mutex_trylock.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_trylock.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 126
if _libs["apr-1"].has("apr_proc_mutex_timedlock", "cdecl"):
    apr_proc_mutex_timedlock = _libs["apr-1"].get("apr_proc_mutex_timedlock", "cdecl")
    apr_proc_mutex_timedlock.argtypes = [POINTER(apr_proc_mutex_t), apr_interval_time_t]
    apr_proc_mutex_timedlock.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 133
if _libs["apr-1"].has("apr_proc_mutex_unlock", "cdecl"):
    apr_proc_mutex_unlock = _libs["apr-1"].get("apr_proc_mutex_unlock", "cdecl")
    apr_proc_mutex_unlock.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_unlock.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 139
if _libs["apr-1"].has("apr_proc_mutex_destroy", "cdecl"):
    apr_proc_mutex_destroy = _libs["apr-1"].get("apr_proc_mutex_destroy", "cdecl")
    apr_proc_mutex_destroy.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_destroy.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 147
if _libs["apr-1"].has("apr_proc_mutex_cleanup", "cdecl"):
    apr_proc_mutex_cleanup = _libs["apr-1"].get("apr_proc_mutex_cleanup", "cdecl")
    apr_proc_mutex_cleanup.argtypes = [POINTER(None)]
    apr_proc_mutex_cleanup.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 154
if _libs["apr-1"].has("apr_proc_mutex_lockfile", "cdecl"):
    apr_proc_mutex_lockfile = _libs["apr-1"].get("apr_proc_mutex_lockfile", "cdecl")
    apr_proc_mutex_lockfile.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_lockfile.restype = c_char_p

# /usr/include/apr/apr_proc_mutex.h: 161
if _libs["apr-1"].has("apr_proc_mutex_mech", "cdecl"):
    apr_proc_mutex_mech = _libs["apr-1"].get("apr_proc_mutex_mech", "cdecl")
    apr_proc_mutex_mech.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_mech.restype = apr_lockmech_e

# /usr/include/apr/apr_proc_mutex.h: 168
if _libs["apr-1"].has("apr_proc_mutex_name", "cdecl"):
    apr_proc_mutex_name = _libs["apr-1"].get("apr_proc_mutex_name", "cdecl")
    apr_proc_mutex_name.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_name.restype = c_char_p

# /usr/include/apr/apr_proc_mutex.h: 173
if _libs["apr-1"].has("apr_proc_mutex_defname", "cdecl"):
    apr_proc_mutex_defname = _libs["apr-1"].get("apr_proc_mutex_defname", "cdecl")
    apr_proc_mutex_defname.argtypes = []
    apr_proc_mutex_defname.restype = c_char_p

# /usr/include/apr/apr_proc_mutex.h: 178
if _libs["apr-1"].has("apr_proc_mutex_perms_set", "cdecl"):
    apr_proc_mutex_perms_set = _libs["apr-1"].get("apr_proc_mutex_perms_set", "cdecl")
    apr_proc_mutex_perms_set.argtypes = [POINTER(None), apr_fileperms_t, apr_uid_t, apr_gid_t]
    apr_proc_mutex_perms_set.restype = apr_status_t

# /usr/include/apr/apr_proc_mutex.h: 184
if _libs["apr-1"].has("apr_proc_mutex_pool_get", "cdecl"):
    apr_proc_mutex_pool_get = _libs["apr-1"].get("apr_proc_mutex_pool_get", "cdecl")
    apr_proc_mutex_pool_get.argtypes = [POINTER(apr_proc_mutex_t)]
    apr_proc_mutex_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_global_mutex.h: 47
class struct_apr_global_mutex_t(Structure):
    pass

apr_global_mutex_t = struct_apr_global_mutex_t# /usr/include/apr/apr_global_mutex.h: 47

# /usr/include/apr/apr_global_mutex.h: 76
if _libs["apr-1"].has("apr_global_mutex_create", "cdecl"):
    apr_global_mutex_create = _libs["apr-1"].get("apr_global_mutex_create", "cdecl")
    apr_global_mutex_create.argtypes = [POINTER(POINTER(apr_global_mutex_t)), String, apr_lockmech_e, POINTER(apr_pool_t)]
    apr_global_mutex_create.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 92
if _libs["apr-1"].has("apr_global_mutex_child_init", "cdecl"):
    apr_global_mutex_child_init = _libs["apr-1"].get("apr_global_mutex_child_init", "cdecl")
    apr_global_mutex_child_init.argtypes = [POINTER(POINTER(apr_global_mutex_t)), String, POINTER(apr_pool_t)]
    apr_global_mutex_child_init.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 102
if _libs["apr-1"].has("apr_global_mutex_lock", "cdecl"):
    apr_global_mutex_lock = _libs["apr-1"].get("apr_global_mutex_lock", "cdecl")
    apr_global_mutex_lock.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_lock.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 111
if _libs["apr-1"].has("apr_global_mutex_trylock", "cdecl"):
    apr_global_mutex_trylock = _libs["apr-1"].get("apr_global_mutex_trylock", "cdecl")
    apr_global_mutex_trylock.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_trylock.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 121
if _libs["apr-1"].has("apr_global_mutex_timedlock", "cdecl"):
    apr_global_mutex_timedlock = _libs["apr-1"].get("apr_global_mutex_timedlock", "cdecl")
    apr_global_mutex_timedlock.argtypes = [POINTER(apr_global_mutex_t), apr_interval_time_t]
    apr_global_mutex_timedlock.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 128
if _libs["apr-1"].has("apr_global_mutex_unlock", "cdecl"):
    apr_global_mutex_unlock = _libs["apr-1"].get("apr_global_mutex_unlock", "cdecl")
    apr_global_mutex_unlock.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_unlock.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 134
if _libs["apr-1"].has("apr_global_mutex_destroy", "cdecl"):
    apr_global_mutex_destroy = _libs["apr-1"].get("apr_global_mutex_destroy", "cdecl")
    apr_global_mutex_destroy.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_destroy.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 140
if _libs["apr-1"].has("apr_global_mutex_lockfile", "cdecl"):
    apr_global_mutex_lockfile = _libs["apr-1"].get("apr_global_mutex_lockfile", "cdecl")
    apr_global_mutex_lockfile.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_lockfile.restype = c_char_p

# /usr/include/apr/apr_global_mutex.h: 147
if _libs["apr-1"].has("apr_global_mutex_mech", "cdecl"):
    apr_global_mutex_mech = _libs["apr-1"].get("apr_global_mutex_mech", "cdecl")
    apr_global_mutex_mech.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_mech.restype = apr_lockmech_e

# /usr/include/apr/apr_global_mutex.h: 154
if _libs["apr-1"].has("apr_global_mutex_name", "cdecl"):
    apr_global_mutex_name = _libs["apr-1"].get("apr_global_mutex_name", "cdecl")
    apr_global_mutex_name.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_name.restype = c_char_p

# /usr/include/apr/apr_global_mutex.h: 159
if _libs["apr-1"].has("apr_global_mutex_perms_set", "cdecl"):
    apr_global_mutex_perms_set = _libs["apr-1"].get("apr_global_mutex_perms_set", "cdecl")
    apr_global_mutex_perms_set.argtypes = [POINTER(None), apr_fileperms_t, apr_uid_t, apr_gid_t]
    apr_global_mutex_perms_set.restype = apr_status_t

# /usr/include/apr/apr_global_mutex.h: 165
if _libs["apr-1"].has("apr_global_mutex_pool_get", "cdecl"):
    apr_global_mutex_pool_get = _libs["apr-1"].get("apr_global_mutex_pool_get", "cdecl")
    apr_global_mutex_pool_get.argtypes = [POINTER(apr_global_mutex_t)]
    apr_global_mutex_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/ctype.h: 108
if _libs["apr-1"].has("isalnum", "cdecl"):
    isalnum = _libs["apr-1"].get("isalnum", "cdecl")
    isalnum.argtypes = [c_int]
    isalnum.restype = c_int

# /usr/include/ctype.h: 109
if _libs["apr-1"].has("isalpha", "cdecl"):
    isalpha = _libs["apr-1"].get("isalpha", "cdecl")
    isalpha.argtypes = [c_int]
    isalpha.restype = c_int

# /usr/include/ctype.h: 110
if _libs["apr-1"].has("iscntrl", "cdecl"):
    iscntrl = _libs["apr-1"].get("iscntrl", "cdecl")
    iscntrl.argtypes = [c_int]
    iscntrl.restype = c_int

# /usr/include/ctype.h: 111
if _libs["apr-1"].has("isdigit", "cdecl"):
    isdigit = _libs["apr-1"].get("isdigit", "cdecl")
    isdigit.argtypes = [c_int]
    isdigit.restype = c_int

# /usr/include/ctype.h: 112
if _libs["apr-1"].has("islower", "cdecl"):
    islower = _libs["apr-1"].get("islower", "cdecl")
    islower.argtypes = [c_int]
    islower.restype = c_int

# /usr/include/ctype.h: 113
if _libs["apr-1"].has("isgraph", "cdecl"):
    isgraph = _libs["apr-1"].get("isgraph", "cdecl")
    isgraph.argtypes = [c_int]
    isgraph.restype = c_int

# /usr/include/ctype.h: 114
if _libs["apr-1"].has("isprint", "cdecl"):
    isprint = _libs["apr-1"].get("isprint", "cdecl")
    isprint.argtypes = [c_int]
    isprint.restype = c_int

# /usr/include/ctype.h: 115
if _libs["apr-1"].has("ispunct", "cdecl"):
    ispunct = _libs["apr-1"].get("ispunct", "cdecl")
    ispunct.argtypes = [c_int]
    ispunct.restype = c_int

# /usr/include/ctype.h: 116
if _libs["apr-1"].has("isspace", "cdecl"):
    isspace = _libs["apr-1"].get("isspace", "cdecl")
    isspace.argtypes = [c_int]
    isspace.restype = c_int

# /usr/include/ctype.h: 117
if _libs["apr-1"].has("isupper", "cdecl"):
    isupper = _libs["apr-1"].get("isupper", "cdecl")
    isupper.argtypes = [c_int]
    isupper.restype = c_int

# /usr/include/ctype.h: 118
if _libs["apr-1"].has("isxdigit", "cdecl"):
    isxdigit = _libs["apr-1"].get("isxdigit", "cdecl")
    isxdigit.argtypes = [c_int]
    isxdigit.restype = c_int

# /usr/include/ctype.h: 122
if _libs["apr-1"].has("tolower", "cdecl"):
    tolower = _libs["apr-1"].get("tolower", "cdecl")
    tolower.argtypes = [c_int]
    tolower.restype = c_int

# /usr/include/ctype.h: 125
if _libs["apr-1"].has("toupper", "cdecl"):
    toupper = _libs["apr-1"].get("toupper", "cdecl")
    toupper.argtypes = [c_int]
    toupper.restype = c_int

# /usr/include/ctype.h: 142
if _libs["apr-1"].has("isascii", "cdecl"):
    isascii = _libs["apr-1"].get("isascii", "cdecl")
    isascii.argtypes = [c_int]
    isascii.restype = c_int

# /usr/include/apr/apr_lib.h: 64
class struct_apr_vformatter_buff_t(Structure):
    pass

apr_vformatter_buff_t = struct_apr_vformatter_buff_t# /usr/include/apr/apr_lib.h: 59

struct_apr_vformatter_buff_t.__slots__ = [
    'curpos',
    'endpos',
]
struct_apr_vformatter_buff_t._fields_ = [
    ('curpos', String),
    ('endpos', String),
]

# /usr/include/apr/apr_lib.h: 84
if _libs["apr-1"].has("apr_filepath_name_get", "cdecl"):
    apr_filepath_name_get = _libs["apr-1"].get("apr_filepath_name_get", "cdecl")
    apr_filepath_name_get.argtypes = [String]
    apr_filepath_name_get.restype = c_char_p

# /usr/include/apr/apr_lib.h: 174
if _libs["apr-1"].has("apr_vformatter", "cdecl"):
    apr_vformatter = _libs["apr-1"].get("apr_vformatter", "cdecl")
    apr_vformatter.argtypes = [CFUNCTYPE(UNCHECKED(c_int), POINTER(apr_vformatter_buff_t)), POINTER(apr_vformatter_buff_t), String, c_void_p]
    apr_vformatter.restype = c_int

# /usr/include/apr/apr_lib.h: 189
if _libs["apr-1"].has("apr_password_get", "cdecl"):
    apr_password_get = _libs["apr-1"].get("apr_password_get", "cdecl")
    apr_password_get.argtypes = [String, String, POINTER(apr_size_t)]
    apr_password_get.restype = apr_status_t

# /usr/include/apr/apr_mmap.h: 62
class struct_apr_mmap_t(Structure):
    pass

apr_mmap_t = struct_apr_mmap_t# /usr/include/apr/apr_mmap.h: 51

# /usr/include/apr/apr_mmap.h: 85
class struct_anon_92(Structure):
    pass

struct_anon_92.__slots__ = [
    'next',
    'prev',
]
struct_anon_92._fields_ = [
    ('next', POINTER(struct_apr_mmap_t)),
    ('prev', POINTER(struct_apr_mmap_t)),
]

struct_apr_mmap_t.__slots__ = [
    'cntxt',
    'mm',
    'size',
    'link',
]
struct_apr_mmap_t._fields_ = [
    ('cntxt', POINTER(apr_pool_t)),
    ('mm', POINTER(None)),
    ('size', apr_size_t),
    ('link', struct_anon_92),
]

# /usr/include/apr/apr_mmap.h: 133
if _libs["apr-1"].has("apr_mmap_create", "cdecl"):
    apr_mmap_create = _libs["apr-1"].get("apr_mmap_create", "cdecl")
    apr_mmap_create.argtypes = [POINTER(POINTER(apr_mmap_t)), POINTER(apr_file_t), apr_off_t, apr_size_t, apr_int32_t, POINTER(apr_pool_t)]
    apr_mmap_create.restype = apr_status_t

# /usr/include/apr/apr_mmap.h: 144
if _libs["apr-1"].has("apr_mmap_dup", "cdecl"):
    apr_mmap_dup = _libs["apr-1"].get("apr_mmap_dup", "cdecl")
    apr_mmap_dup.argtypes = [POINTER(POINTER(apr_mmap_t)), POINTER(apr_mmap_t), POINTER(apr_pool_t)]
    apr_mmap_dup.restype = apr_status_t

# /usr/include/apr/apr_mmap.h: 152
if _libs["apr-1"].has("apr_mmap_delete", "cdecl"):
    apr_mmap_delete = _libs["apr-1"].get("apr_mmap_delete", "cdecl")
    apr_mmap_delete.argtypes = [POINTER(apr_mmap_t)]
    apr_mmap_delete.restype = apr_status_t

# /usr/include/apr/apr_mmap.h: 160
if _libs["apr-1"].has("apr_mmap_offset", "cdecl"):
    apr_mmap_offset = _libs["apr-1"].get("apr_mmap_offset", "cdecl")
    apr_mmap_offset.argtypes = [POINTER(POINTER(None)), POINTER(apr_mmap_t), apr_off_t]
    apr_mmap_offset.restype = apr_status_t

enum_anon_93 = c_int# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_DEFAULT = 0# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_SELECT = (APR_POLLSET_DEFAULT + 1)# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_KQUEUE = (APR_POLLSET_SELECT + 1)# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_PORT = (APR_POLLSET_KQUEUE + 1)# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_EPOLL = (APR_POLLSET_PORT + 1)# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_POLL = (APR_POLLSET_EPOLL + 1)# /usr/include/apr/apr_poll.h: 88

APR_POLLSET_AIO_MSGQ = (APR_POLLSET_POLL + 1)# /usr/include/apr/apr_poll.h: 88

apr_pollset_method_e = enum_anon_93# /usr/include/apr/apr_poll.h: 88

enum_anon_94 = c_int# /usr/include/apr/apr_poll.h: 96

APR_NO_DESC = 0# /usr/include/apr/apr_poll.h: 96

APR_POLL_SOCKET = (APR_NO_DESC + 1)# /usr/include/apr/apr_poll.h: 96

APR_POLL_FILE = (APR_POLL_SOCKET + 1)# /usr/include/apr/apr_poll.h: 96

APR_POLL_LASTDESC = (APR_POLL_FILE + 1)# /usr/include/apr/apr_poll.h: 96

apr_datatype_e = enum_anon_94# /usr/include/apr/apr_poll.h: 96

# /usr/include/apr/apr_poll.h: 102
class union_anon_95(Union):
    pass

union_anon_95.__slots__ = [
    'f',
    's',
]
union_anon_95._fields_ = [
    ('f', POINTER(apr_file_t)),
    ('s', POINTER(apr_socket_t)),
]

apr_descriptor = union_anon_95# /usr/include/apr/apr_poll.h: 102

# /usr/include/apr/apr_poll.h: 108
class struct_apr_pollfd_t(Structure):
    pass

apr_pollfd_t = struct_apr_pollfd_t# /usr/include/apr/apr_poll.h: 105

struct_apr_pollfd_t.__slots__ = [
    'p',
    'desc_type',
    'reqevents',
    'rtnevents',
    'desc',
    'client_data',
]
struct_apr_pollfd_t._fields_ = [
    ('p', POINTER(apr_pool_t)),
    ('desc_type', apr_datatype_e),
    ('reqevents', apr_int16_t),
    ('rtnevents', apr_int16_t),
    ('desc', apr_descriptor),
    ('client_data', POINTER(None)),
]

# /usr/include/apr/apr_poll.h: 123
class struct_apr_pollset_t(Structure):
    pass

apr_pollset_t = struct_apr_pollset_t# /usr/include/apr/apr_poll.h: 123

# /usr/include/apr/apr_poll.h: 154
if _libs["apr-1"].has("apr_pollset_create", "cdecl"):
    apr_pollset_create = _libs["apr-1"].get("apr_pollset_create", "cdecl")
    apr_pollset_create.argtypes = [POINTER(POINTER(apr_pollset_t)), apr_uint32_t, POINTER(apr_pool_t), apr_uint32_t]
    apr_pollset_create.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 191
if _libs["apr-1"].has("apr_pollset_create_ex", "cdecl"):
    apr_pollset_create_ex = _libs["apr-1"].get("apr_pollset_create_ex", "cdecl")
    apr_pollset_create_ex.argtypes = [POINTER(POINTER(apr_pollset_t)), apr_uint32_t, POINTER(apr_pool_t), apr_uint32_t, apr_pollset_method_e]
    apr_pollset_create_ex.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 201
if _libs["apr-1"].has("apr_pollset_destroy", "cdecl"):
    apr_pollset_destroy = _libs["apr-1"].get("apr_pollset_destroy", "cdecl")
    apr_pollset_destroy.argtypes = [POINTER(apr_pollset_t)]
    apr_pollset_destroy.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 229
if _libs["apr-1"].has("apr_pollset_add", "cdecl"):
    apr_pollset_add = _libs["apr-1"].get("apr_pollset_add", "cdecl")
    apr_pollset_add.argtypes = [POINTER(apr_pollset_t), POINTER(apr_pollfd_t)]
    apr_pollset_add.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 250
if _libs["apr-1"].has("apr_pollset_remove", "cdecl"):
    apr_pollset_remove = _libs["apr-1"].get("apr_pollset_remove", "cdecl")
    apr_pollset_remove.argtypes = [POINTER(apr_pollset_t), POINTER(apr_pollfd_t)]
    apr_pollset_remove.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 271
if _libs["apr-1"].has("apr_pollset_poll", "cdecl"):
    apr_pollset_poll = _libs["apr-1"].get("apr_pollset_poll", "cdecl")
    apr_pollset_poll.argtypes = [POINTER(apr_pollset_t), apr_interval_time_t, POINTER(apr_int32_t), POINTER(POINTER(apr_pollfd_t))]
    apr_pollset_poll.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 282
if _libs["apr-1"].has("apr_pollset_wakeup", "cdecl"):
    apr_pollset_wakeup = _libs["apr-1"].get("apr_pollset_wakeup", "cdecl")
    apr_pollset_wakeup.argtypes = [POINTER(apr_pollset_t)]
    apr_pollset_wakeup.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 300
if _libs["apr-1"].has("apr_poll", "cdecl"):
    apr_poll = _libs["apr-1"].get("apr_poll", "cdecl")
    apr_poll.argtypes = [POINTER(apr_pollfd_t), apr_int32_t, POINTER(apr_int32_t), apr_interval_time_t]
    apr_poll.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 308
if _libs["apr-1"].has("apr_pollset_method_name", "cdecl"):
    apr_pollset_method_name = _libs["apr-1"].get("apr_pollset_method_name", "cdecl")
    apr_pollset_method_name.argtypes = [POINTER(apr_pollset_t)]
    apr_pollset_method_name.restype = c_char_p

# /usr/include/apr/apr_poll.h: 314
if _libs["apr-1"].has("apr_poll_method_defname", "cdecl"):
    apr_poll_method_defname = _libs["apr-1"].get("apr_poll_method_defname", "cdecl")
    apr_poll_method_defname.argtypes = []
    apr_poll_method_defname.restype = c_char_p

# /usr/include/apr/apr_poll.h: 317
class struct_apr_pollcb_t(Structure):
    pass

apr_pollcb_t = struct_apr_pollcb_t# /usr/include/apr/apr_poll.h: 317

# /usr/include/apr/apr_poll.h: 333
if _libs["apr-1"].has("apr_pollcb_create", "cdecl"):
    apr_pollcb_create = _libs["apr-1"].get("apr_pollcb_create", "cdecl")
    apr_pollcb_create.argtypes = [POINTER(POINTER(apr_pollcb_t)), apr_uint32_t, POINTER(apr_pool_t), apr_uint32_t]
    apr_pollcb_create.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 355
if _libs["apr-1"].has("apr_pollcb_create_ex", "cdecl"):
    apr_pollcb_create_ex = _libs["apr-1"].get("apr_pollcb_create_ex", "cdecl")
    apr_pollcb_create_ex.argtypes = [POINTER(POINTER(apr_pollcb_t)), apr_uint32_t, POINTER(apr_pool_t), apr_uint32_t, apr_pollset_method_e]
    apr_pollcb_create_ex.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 378
if _libs["apr-1"].has("apr_pollcb_add", "cdecl"):
    apr_pollcb_add = _libs["apr-1"].get("apr_pollcb_add", "cdecl")
    apr_pollcb_add.argtypes = [POINTER(apr_pollcb_t), POINTER(apr_pollfd_t)]
    apr_pollcb_add.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 389
if _libs["apr-1"].has("apr_pollcb_remove", "cdecl"):
    apr_pollcb_remove = _libs["apr-1"].get("apr_pollcb_remove", "cdecl")
    apr_pollcb_remove.argtypes = [POINTER(apr_pollcb_t), POINTER(apr_pollfd_t)]
    apr_pollcb_remove.restype = apr_status_t

apr_pollcb_cb_t = CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None), POINTER(apr_pollfd_t))# /usr/include/apr/apr_poll.h: 401

# /usr/include/apr/apr_poll.h: 420
if _libs["apr-1"].has("apr_pollcb_poll", "cdecl"):
    apr_pollcb_poll = _libs["apr-1"].get("apr_pollcb_poll", "cdecl")
    apr_pollcb_poll.argtypes = [POINTER(apr_pollcb_t), apr_interval_time_t, apr_pollcb_cb_t, POINTER(None)]
    apr_pollcb_poll.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 431
if _libs["apr-1"].has("apr_pollcb_wakeup", "cdecl"):
    apr_pollcb_wakeup = _libs["apr-1"].get("apr_pollcb_wakeup", "cdecl")
    apr_pollcb_wakeup.argtypes = [POINTER(apr_pollcb_t)]
    apr_pollcb_wakeup.restype = apr_status_t

# /usr/include/apr/apr_poll.h: 437
if _libs["apr-1"].has("apr_pollcb_method_name", "cdecl"):
    apr_pollcb_method_name = _libs["apr-1"].get("apr_pollcb_method_name", "cdecl")
    apr_pollcb_method_name.argtypes = [POINTER(apr_pollcb_t)]
    apr_pollcb_method_name.restype = c_char_p

# /usr/include/apr/apr_shm.h: 44
class struct_apr_shm_t(Structure):
    pass

apr_shm_t = struct_apr_shm_t# /usr/include/apr/apr_shm.h: 44

# /usr/include/apr/apr_shm.h: 70
if _libs["apr-1"].has("apr_shm_create", "cdecl"):
    apr_shm_create = _libs["apr-1"].get("apr_shm_create", "cdecl")
    apr_shm_create.argtypes = [POINTER(POINTER(apr_shm_t)), apr_size_t, String, POINTER(apr_pool_t)]
    apr_shm_create.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 115
if _libs["apr-1"].has("apr_shm_create_ex", "cdecl"):
    apr_shm_create_ex = _libs["apr-1"].get("apr_shm_create_ex", "cdecl")
    apr_shm_create_ex.argtypes = [POINTER(POINTER(apr_shm_t)), apr_size_t, String, POINTER(apr_pool_t), apr_int32_t]
    apr_shm_create_ex.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 136
if _libs["apr-1"].has("apr_shm_remove", "cdecl"):
    apr_shm_remove = _libs["apr-1"].get("apr_shm_remove", "cdecl")
    apr_shm_remove.argtypes = [String, POINTER(apr_pool_t)]
    apr_shm_remove.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 152
if _libs["apr-1"].has("apr_shm_delete", "cdecl"):
    apr_shm_delete = _libs["apr-1"].get("apr_shm_delete", "cdecl")
    apr_shm_delete.argtypes = [POINTER(apr_shm_t)]
    apr_shm_delete.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 158
if _libs["apr-1"].has("apr_shm_destroy", "cdecl"):
    apr_shm_destroy = _libs["apr-1"].get("apr_shm_destroy", "cdecl")
    apr_shm_destroy.argtypes = [POINTER(apr_shm_t)]
    apr_shm_destroy.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 169
if _libs["apr-1"].has("apr_shm_attach", "cdecl"):
    apr_shm_attach = _libs["apr-1"].get("apr_shm_attach", "cdecl")
    apr_shm_attach.argtypes = [POINTER(POINTER(apr_shm_t)), String, POINTER(apr_pool_t)]
    apr_shm_attach.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 183
if _libs["apr-1"].has("apr_shm_attach_ex", "cdecl"):
    apr_shm_attach_ex = _libs["apr-1"].get("apr_shm_attach_ex", "cdecl")
    apr_shm_attach_ex.argtypes = [POINTER(POINTER(apr_shm_t)), String, POINTER(apr_pool_t), apr_int32_t]
    apr_shm_attach_ex.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 193
if _libs["apr-1"].has("apr_shm_detach", "cdecl"):
    apr_shm_detach = _libs["apr-1"].get("apr_shm_detach", "cdecl")
    apr_shm_detach.argtypes = [POINTER(apr_shm_t)]
    apr_shm_detach.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 204
if _libs["apr-1"].has("apr_shm_baseaddr_get", "cdecl"):
    apr_shm_baseaddr_get = _libs["apr-1"].get("apr_shm_baseaddr_get", "cdecl")
    apr_shm_baseaddr_get.argtypes = [POINTER(apr_shm_t)]
    apr_shm_baseaddr_get.restype = POINTER(c_ubyte)
    apr_shm_baseaddr_get.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_shm.h: 211
if _libs["apr-1"].has("apr_shm_size_get", "cdecl"):
    apr_shm_size_get = _libs["apr-1"].get("apr_shm_size_get", "cdecl")
    apr_shm_size_get.argtypes = [POINTER(apr_shm_t)]
    apr_shm_size_get.restype = apr_size_t

# /usr/include/apr/apr_shm.h: 216
if _libs["apr-1"].has("apr_shm_perms_set", "cdecl"):
    apr_shm_perms_set = _libs["apr-1"].get("apr_shm_perms_set", "cdecl")
    apr_shm_perms_set.argtypes = [POINTER(None), apr_fileperms_t, apr_uid_t, apr_gid_t]
    apr_shm_perms_set.restype = apr_status_t

# /usr/include/apr/apr_shm.h: 221
if _libs["apr-1"].has("apr_shm_pool_get", "cdecl"):
    apr_shm_pool_get = _libs["apr-1"].get("apr_shm_pool_get", "cdecl")
    apr_shm_pool_get.argtypes = [POINTER(apr_shm_t)]
    apr_shm_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/dirent.h: 127
class struct___dirstream(Structure):
    pass

DIR = struct___dirstream# /usr/include/dirent.h: 127

# /usr/include/bits/types/struct_tm.h: 7
class struct_tm(Structure):
    pass

struct_tm.__slots__ = [
    'tm_sec',
    'tm_min',
    'tm_hour',
    'tm_mday',
    'tm_mon',
    'tm_year',
    'tm_wday',
    'tm_yday',
    'tm_isdst',
    'tm_gmtoff',
    'tm_zone',
]
struct_tm._fields_ = [
    ('tm_sec', c_int),
    ('tm_min', c_int),
    ('tm_hour', c_int),
    ('tm_mday', c_int),
    ('tm_mon', c_int),
    ('tm_year', c_int),
    ('tm_wday', c_int),
    ('tm_yday', c_int),
    ('tm_isdst', c_int),
    ('tm_gmtoff', c_long),
    ('tm_zone', String),
]

# /usr/include/bits/semaphore.h: 39
class union_anon_109(Union):
    pass

union_anon_109.__slots__ = [
    '__size',
    '__align',
]
union_anon_109._fields_ = [
    ('__size', c_char * int(16)),
    ('__align', c_long),
]

sem_t = union_anon_109# /usr/include/bits/semaphore.h: 39

# /usr/include/apr/apr_portable.h: 130
class struct_apr_os_proc_mutex_t(Structure):
    pass

struct_apr_os_proc_mutex_t.__slots__ = [
    'crossproc',
    'pthread_interproc',
    'intraproc',
    'psem_interproc',
]
struct_apr_os_proc_mutex_t._fields_ = [
    ('crossproc', c_int),
    ('pthread_interproc', POINTER(pthread_mutex_t)),
    ('intraproc', POINTER(pthread_mutex_t)),
    ('psem_interproc', POINTER(sem_t)),
]

apr_os_file_t = c_int# /usr/include/apr/apr_portable.h: 152

apr_os_dir_t = DIR# /usr/include/apr/apr_portable.h: 153

apr_os_sock_t = c_int# /usr/include/apr/apr_portable.h: 154

apr_os_proc_mutex_t = struct_apr_os_proc_mutex_t# /usr/include/apr/apr_portable.h: 155

apr_os_thread_t = pthread_t# /usr/include/apr/apr_portable.h: 159

apr_os_threadkey_t = pthread_key_t# /usr/include/apr/apr_portable.h: 160

apr_os_proc_t = pid_t# /usr/include/apr/apr_portable.h: 163

apr_os_imp_time_t = struct_timeval# /usr/include/apr/apr_portable.h: 164

apr_os_exp_time_t = struct_tm# /usr/include/apr/apr_portable.h: 165

apr_os_dso_handle_t = POINTER(None)# /usr/include/apr/apr_portable.h: 176

apr_os_shm_t = POINTER(None)# /usr/include/apr/apr_portable.h: 178

# /usr/include/apr/apr_portable.h: 190
class struct_apr_os_sock_info_t(Structure):
    pass

struct_apr_os_sock_info_t.__slots__ = [
    'os_sock',
    'local',
    'remote',
    'family',
    'type',
    'protocol',
]
struct_apr_os_sock_info_t._fields_ = [
    ('os_sock', POINTER(apr_os_sock_t)),
    ('local', POINTER(struct_sockaddr)),
    ('remote', POINTER(struct_sockaddr)),
    ('family', c_int),
    ('type', c_int),
    ('protocol', c_int),
]

apr_os_sock_info_t = struct_apr_os_sock_info_t# /usr/include/apr/apr_portable.h: 199

# /usr/include/apr/apr_portable.h: 210
class struct_apr_os_global_mutex_t(Structure):
    pass

struct_apr_os_global_mutex_t.__slots__ = [
    'pool',
    'proc_mutex',
    'thread_mutex',
]
struct_apr_os_global_mutex_t._fields_ = [
    ('pool', POINTER(apr_pool_t)),
    ('proc_mutex', POINTER(apr_proc_mutex_t)),
    ('thread_mutex', POINTER(apr_thread_mutex_t)),
]

apr_os_global_mutex_t = struct_apr_os_global_mutex_t# /usr/include/apr/apr_portable.h: 217

# /usr/include/apr/apr_portable.h: 219
if _libs["apr-1"].has("apr_os_global_mutex_get", "cdecl"):
    apr_os_global_mutex_get = _libs["apr-1"].get("apr_os_global_mutex_get", "cdecl")
    apr_os_global_mutex_get.argtypes = [POINTER(apr_os_global_mutex_t), POINTER(apr_global_mutex_t)]
    apr_os_global_mutex_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 231
if _libs["apr-1"].has("apr_os_file_get", "cdecl"):
    apr_os_file_get = _libs["apr-1"].get("apr_os_file_get", "cdecl")
    apr_os_file_get.argtypes = [POINTER(apr_os_file_t), POINTER(apr_file_t)]
    apr_os_file_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 239
if _libs["apr-1"].has("apr_os_dir_get", "cdecl"):
    apr_os_dir_get = _libs["apr-1"].get("apr_os_dir_get", "cdecl")
    apr_os_dir_get.argtypes = [POINTER(POINTER(apr_os_dir_t)), POINTER(apr_dir_t)]
    apr_os_dir_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 247
if _libs["apr-1"].has("apr_os_sock_get", "cdecl"):
    apr_os_sock_get = _libs["apr-1"].get("apr_os_sock_get", "cdecl")
    apr_os_sock_get.argtypes = [POINTER(apr_os_sock_t), POINTER(apr_socket_t)]
    apr_os_sock_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 255
if _libs["apr-1"].has("apr_os_proc_mutex_get", "cdecl"):
    apr_os_proc_mutex_get = _libs["apr-1"].get("apr_os_proc_mutex_get", "cdecl")
    apr_os_proc_mutex_get.argtypes = [POINTER(apr_os_proc_mutex_t), POINTER(apr_proc_mutex_t)]
    apr_os_proc_mutex_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 267
if _libs["apr-1"].has("apr_os_proc_mutex_get_ex", "cdecl"):
    apr_os_proc_mutex_get_ex = _libs["apr-1"].get("apr_os_proc_mutex_get_ex", "cdecl")
    apr_os_proc_mutex_get_ex.argtypes = [POINTER(apr_os_proc_mutex_t), POINTER(apr_proc_mutex_t), POINTER(apr_lockmech_e)]
    apr_os_proc_mutex_get_ex.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 276
if _libs["apr-1"].has("apr_os_exp_time_get", "cdecl"):
    apr_os_exp_time_get = _libs["apr-1"].get("apr_os_exp_time_get", "cdecl")
    apr_os_exp_time_get.argtypes = [POINTER(POINTER(apr_os_exp_time_t)), POINTER(apr_time_exp_t)]
    apr_os_exp_time_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 284
if _libs["apr-1"].has("apr_os_imp_time_get", "cdecl"):
    apr_os_imp_time_get = _libs["apr-1"].get("apr_os_imp_time_get", "cdecl")
    apr_os_imp_time_get.argtypes = [POINTER(POINTER(apr_os_imp_time_t)), POINTER(apr_time_t)]
    apr_os_imp_time_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 292
if _libs["apr-1"].has("apr_os_shm_get", "cdecl"):
    apr_os_shm_get = _libs["apr-1"].get("apr_os_shm_get", "cdecl")
    apr_os_shm_get.argtypes = [POINTER(apr_os_shm_t), POINTER(apr_shm_t)]
    apr_os_shm_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 305
if _libs["apr-1"].has("apr_os_thread_get", "cdecl"):
    apr_os_thread_get = _libs["apr-1"].get("apr_os_thread_get", "cdecl")
    apr_os_thread_get.argtypes = [POINTER(POINTER(apr_os_thread_t)), POINTER(apr_thread_t)]
    apr_os_thread_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 313
if _libs["apr-1"].has("apr_os_threadkey_get", "cdecl"):
    apr_os_threadkey_get = _libs["apr-1"].get("apr_os_threadkey_get", "cdecl")
    apr_os_threadkey_get.argtypes = [POINTER(apr_os_threadkey_t), POINTER(apr_threadkey_t)]
    apr_os_threadkey_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 322
if _libs["apr-1"].has("apr_os_thread_put", "cdecl"):
    apr_os_thread_put = _libs["apr-1"].get("apr_os_thread_put", "cdecl")
    apr_os_thread_put.argtypes = [POINTER(POINTER(apr_thread_t)), POINTER(apr_os_thread_t), POINTER(apr_pool_t)]
    apr_os_thread_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 332
if _libs["apr-1"].has("apr_os_threadkey_put", "cdecl"):
    apr_os_threadkey_put = _libs["apr-1"].get("apr_os_threadkey_put", "cdecl")
    apr_os_threadkey_put.argtypes = [POINTER(POINTER(apr_threadkey_t)), POINTER(apr_os_threadkey_t), POINTER(apr_pool_t)]
    apr_os_threadkey_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 338
if _libs["apr-1"].has("apr_os_thread_current", "cdecl"):
    apr_os_thread_current = _libs["apr-1"].get("apr_os_thread_current", "cdecl")
    apr_os_thread_current.argtypes = []
    apr_os_thread_current.restype = apr_os_thread_t

# /usr/include/apr/apr_portable.h: 346
if _libs["apr-1"].has("apr_os_thread_equal", "cdecl"):
    apr_os_thread_equal = _libs["apr-1"].get("apr_os_thread_equal", "cdecl")
    apr_os_thread_equal.argtypes = [apr_os_thread_t, apr_os_thread_t]
    apr_os_thread_equal.restype = c_int

# /usr/include/apr/apr_portable.h: 361
if _libs["apr-1"].has("apr_os_file_put", "cdecl"):
    apr_os_file_put = _libs["apr-1"].get("apr_os_file_put", "cdecl")
    apr_os_file_put.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_os_file_t), apr_int32_t, POINTER(apr_pool_t)]
    apr_os_file_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 373
if _libs["apr-1"].has("apr_os_pipe_put", "cdecl"):
    apr_os_pipe_put = _libs["apr-1"].get("apr_os_pipe_put", "cdecl")
    apr_os_pipe_put.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_os_file_t), POINTER(apr_pool_t)]
    apr_os_pipe_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 387
if _libs["apr-1"].has("apr_os_pipe_put_ex", "cdecl"):
    apr_os_pipe_put_ex = _libs["apr-1"].get("apr_os_pipe_put_ex", "cdecl")
    apr_os_pipe_put_ex.argtypes = [POINTER(POINTER(apr_file_t)), POINTER(apr_os_file_t), c_int, POINTER(apr_pool_t)]
    apr_os_pipe_put_ex.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 398
if _libs["apr-1"].has("apr_os_dir_put", "cdecl"):
    apr_os_dir_put = _libs["apr-1"].get("apr_os_dir_put", "cdecl")
    apr_os_dir_put.argtypes = [POINTER(POINTER(apr_dir_t)), POINTER(apr_os_dir_t), POINTER(apr_pool_t)]
    apr_os_dir_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 413
if _libs["apr-1"].has("apr_os_sock_put", "cdecl"):
    apr_os_sock_put = _libs["apr-1"].get("apr_os_sock_put", "cdecl")
    apr_os_sock_put.argtypes = [POINTER(POINTER(apr_socket_t)), POINTER(apr_os_sock_t), POINTER(apr_pool_t)]
    apr_os_sock_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 427
if _libs["apr-1"].has("apr_os_sock_make", "cdecl"):
    apr_os_sock_make = _libs["apr-1"].get("apr_os_sock_make", "cdecl")
    apr_os_sock_make.argtypes = [POINTER(POINTER(apr_socket_t)), POINTER(apr_os_sock_info_t), POINTER(apr_pool_t)]
    apr_os_sock_make.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 437
if _libs["apr-1"].has("apr_os_proc_mutex_put", "cdecl"):
    apr_os_proc_mutex_put = _libs["apr-1"].get("apr_os_proc_mutex_put", "cdecl")
    apr_os_proc_mutex_put.argtypes = [POINTER(POINTER(apr_proc_mutex_t)), POINTER(apr_os_proc_mutex_t), POINTER(apr_pool_t)]
    apr_os_proc_mutex_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 453
if _libs["apr-1"].has("apr_os_proc_mutex_put_ex", "cdecl"):
    apr_os_proc_mutex_put_ex = _libs["apr-1"].get("apr_os_proc_mutex_put_ex", "cdecl")
    apr_os_proc_mutex_put_ex.argtypes = [POINTER(POINTER(apr_proc_mutex_t)), POINTER(apr_os_proc_mutex_t), apr_lockmech_e, c_int, POINTER(apr_pool_t)]
    apr_os_proc_mutex_put_ex.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 465
if _libs["apr-1"].has("apr_os_imp_time_put", "cdecl"):
    apr_os_imp_time_put = _libs["apr-1"].get("apr_os_imp_time_put", "cdecl")
    apr_os_imp_time_put.argtypes = [POINTER(apr_time_t), POINTER(POINTER(apr_os_imp_time_t)), POINTER(apr_pool_t)]
    apr_os_imp_time_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 475
if _libs["apr-1"].has("apr_os_exp_time_put", "cdecl"):
    apr_os_exp_time_put = _libs["apr-1"].get("apr_os_exp_time_put", "cdecl")
    apr_os_exp_time_put.argtypes = [POINTER(apr_time_exp_t), POINTER(POINTER(apr_os_exp_time_t)), POINTER(apr_pool_t)]
    apr_os_exp_time_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 488
if _libs["apr-1"].has("apr_os_shm_put", "cdecl"):
    apr_os_shm_put = _libs["apr-1"].get("apr_os_shm_put", "cdecl")
    apr_os_shm_put.argtypes = [POINTER(POINTER(apr_shm_t)), POINTER(apr_os_shm_t), POINTER(apr_pool_t)]
    apr_os_shm_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 504
if _libs["apr-1"].has("apr_os_dso_handle_put", "cdecl"):
    apr_os_dso_handle_put = _libs["apr-1"].get("apr_os_dso_handle_put", "cdecl")
    apr_os_dso_handle_put.argtypes = [POINTER(POINTER(apr_dso_handle_t)), apr_os_dso_handle_t, POINTER(apr_pool_t)]
    apr_os_dso_handle_put.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 513
if _libs["apr-1"].has("apr_os_dso_handle_get", "cdecl"):
    apr_os_dso_handle_get = _libs["apr-1"].get("apr_os_dso_handle_get", "cdecl")
    apr_os_dso_handle_get.argtypes = [POINTER(apr_os_dso_handle_t), POINTER(apr_dso_handle_t)]
    apr_os_dso_handle_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 524
if _libs["apr-1"].has("apr_os_uuid_get", "cdecl"):
    apr_os_uuid_get = _libs["apr-1"].get("apr_os_uuid_get", "cdecl")
    apr_os_uuid_get.argtypes = [POINTER(c_ubyte)]
    apr_os_uuid_get.restype = apr_status_t

# /usr/include/apr/apr_portable.h: 532
if _libs["apr-1"].has("apr_os_default_encoding", "cdecl"):
    apr_os_default_encoding = _libs["apr-1"].get("apr_os_default_encoding", "cdecl")
    apr_os_default_encoding.argtypes = [POINTER(apr_pool_t)]
    apr_os_default_encoding.restype = c_char_p

# /usr/include/apr/apr_portable.h: 541
if _libs["apr-1"].has("apr_os_locale_encoding", "cdecl"):
    apr_os_locale_encoding = _libs["apr-1"].get("apr_os_locale_encoding", "cdecl")
    apr_os_locale_encoding.argtypes = [POINTER(apr_pool_t)]
    apr_os_locale_encoding.restype = c_char_p

# /usr/include/apr/apr_random.h: 48
class struct_apr_crypto_hash_t(Structure):
    pass

apr_crypto_hash_t = struct_apr_crypto_hash_t# /usr/include/apr/apr_random.h: 38

apr_crypto_hash_init_t = CFUNCTYPE(UNCHECKED(None), POINTER(apr_crypto_hash_t))# /usr/include/apr/apr_random.h: 40

apr_crypto_hash_add_t = CFUNCTYPE(UNCHECKED(None), POINTER(apr_crypto_hash_t), POINTER(None), apr_size_t)# /usr/include/apr/apr_random.h: 41

apr_crypto_hash_finish_t = CFUNCTYPE(UNCHECKED(None), POINTER(apr_crypto_hash_t), POINTER(c_ubyte))# /usr/include/apr/apr_random.h: 43

struct_apr_crypto_hash_t.__slots__ = [
    'init',
    'add',
    'finish',
    'size',
    'data',
]
struct_apr_crypto_hash_t._fields_ = [
    ('init', POINTER(apr_crypto_hash_init_t)),
    ('add', POINTER(apr_crypto_hash_add_t)),
    ('finish', POINTER(apr_crypto_hash_finish_t)),
    ('size', apr_size_t),
    ('data', POINTER(None)),
]

# /usr/include/apr/apr_random.h: 60
if _libs["apr-1"].has("apr_crypto_sha256_new", "cdecl"):
    apr_crypto_sha256_new = _libs["apr-1"].get("apr_crypto_sha256_new", "cdecl")
    apr_crypto_sha256_new.argtypes = [POINTER(apr_pool_t)]
    apr_crypto_sha256_new.restype = POINTER(apr_crypto_hash_t)

# /usr/include/apr/apr_random.h: 63
class struct_apr_random_t(Structure):
    pass

apr_random_t = struct_apr_random_t# /usr/include/apr/apr_random.h: 63

# /usr/include/apr/apr_random.h: 73
if _libs["apr-1"].has("apr_random_init", "cdecl"):
    apr_random_init = _libs["apr-1"].get("apr_random_init", "cdecl")
    apr_random_init.argtypes = [POINTER(apr_random_t), POINTER(apr_pool_t), POINTER(apr_crypto_hash_t), POINTER(apr_crypto_hash_t), POINTER(apr_crypto_hash_t)]
    apr_random_init.restype = None

# /usr/include/apr/apr_random.h: 81
if _libs["apr-1"].has("apr_random_standard_new", "cdecl"):
    apr_random_standard_new = _libs["apr-1"].get("apr_random_standard_new", "cdecl")
    apr_random_standard_new.argtypes = [POINTER(apr_pool_t)]
    apr_random_standard_new.restype = POINTER(apr_random_t)

# /usr/include/apr/apr_random.h: 89
if _libs["apr-1"].has("apr_random_add_entropy", "cdecl"):
    apr_random_add_entropy = _libs["apr-1"].get("apr_random_add_entropy", "cdecl")
    apr_random_add_entropy.argtypes = [POINTER(apr_random_t), POINTER(None), apr_size_t]
    apr_random_add_entropy.restype = None

# /usr/include/apr/apr_random.h: 98
if _libs["apr-1"].has("apr_random_insecure_bytes", "cdecl"):
    apr_random_insecure_bytes = _libs["apr-1"].get("apr_random_insecure_bytes", "cdecl")
    apr_random_insecure_bytes.argtypes = [POINTER(apr_random_t), POINTER(None), apr_size_t]
    apr_random_insecure_bytes.restype = apr_status_t

# /usr/include/apr/apr_random.h: 108
if _libs["apr-1"].has("apr_random_secure_bytes", "cdecl"):
    apr_random_secure_bytes = _libs["apr-1"].get("apr_random_secure_bytes", "cdecl")
    apr_random_secure_bytes.argtypes = [POINTER(apr_random_t), POINTER(None), apr_size_t]
    apr_random_secure_bytes.restype = apr_status_t

# /usr/include/apr/apr_random.h: 116
if _libs["apr-1"].has("apr_random_barrier", "cdecl"):
    apr_random_barrier = _libs["apr-1"].get("apr_random_barrier", "cdecl")
    apr_random_barrier.argtypes = [POINTER(apr_random_t)]
    apr_random_barrier.restype = None

# /usr/include/apr/apr_random.h: 123
if _libs["apr-1"].has("apr_random_secure_ready", "cdecl"):
    apr_random_secure_ready = _libs["apr-1"].get("apr_random_secure_ready", "cdecl")
    apr_random_secure_ready.argtypes = [POINTER(apr_random_t)]
    apr_random_secure_ready.restype = apr_status_t

# /usr/include/apr/apr_random.h: 130
if _libs["apr-1"].has("apr_random_insecure_ready", "cdecl"):
    apr_random_insecure_ready = _libs["apr-1"].get("apr_random_insecure_ready", "cdecl")
    apr_random_insecure_ready.argtypes = [POINTER(apr_random_t)]
    apr_random_insecure_ready.restype = apr_status_t

# /usr/include/apr/apr_random.h: 145
if _libs["apr-1"].has("apr_random_after_fork", "cdecl"):
    apr_random_after_fork = _libs["apr-1"].get("apr_random_after_fork", "cdecl")
    apr_random_after_fork.argtypes = [POINTER(apr_proc_t)]
    apr_random_after_fork.restype = None

apr_sigfunc_t = CFUNCTYPE(UNCHECKED(None), c_int)# /usr/include/apr/apr_signal.h: 57

# /usr/include/apr/apr_signal.h: 64
if _libs["apr-1"].has("apr_signal", "cdecl"):
    apr_signal = _libs["apr-1"].get("apr_signal", "cdecl")
    apr_signal.argtypes = [c_int, POINTER(apr_sigfunc_t)]
    apr_signal.restype = POINTER(apr_sigfunc_t)

# /usr/include/apr/apr_signal.h: 80
if _libs["apr-1"].has("apr_signal_description_get", "cdecl"):
    apr_signal_description_get = _libs["apr-1"].get("apr_signal_description_get", "cdecl")
    apr_signal_description_get.argtypes = [c_int]
    apr_signal_description_get.restype = c_char_p

# /usr/include/apr/apr_signal.h: 87
if _libs["apr-1"].has("apr_signal_init", "cdecl"):
    apr_signal_init = _libs["apr-1"].get("apr_signal_init", "cdecl")
    apr_signal_init.argtypes = [POINTER(apr_pool_t)]
    apr_signal_init.restype = None

# /usr/include/apr/apr_signal.h: 94
if _libs["apr-1"].has("apr_signal_block", "cdecl"):
    apr_signal_block = _libs["apr-1"].get("apr_signal_block", "cdecl")
    apr_signal_block.argtypes = [c_int]
    apr_signal_block.restype = apr_status_t

# /usr/include/apr/apr_signal.h: 101
if _libs["apr-1"].has("apr_signal_unblock", "cdecl"):
    apr_signal_unblock = _libs["apr-1"].get("apr_signal_unblock", "cdecl")
    apr_signal_unblock.argtypes = [c_int]
    apr_signal_unblock.restype = apr_status_t

apr_skiplist_compare = CFUNCTYPE(UNCHECKED(c_int), POINTER(None), POINTER(None))# /usr/include/apr/apr_skiplist.h: 45

apr_skiplist_freefunc = CFUNCTYPE(UNCHECKED(None), POINTER(None))# /usr/include/apr/apr_skiplist.h: 51

# /usr/include/apr/apr_skiplist.h: 54
class struct_apr_skiplist(Structure):
    pass

apr_skiplist = struct_apr_skiplist# /usr/include/apr/apr_skiplist.h: 56

# /usr/include/apr/apr_skiplist.h: 63
class struct_apr_skiplistnode(Structure):
    pass

apr_skiplistnode = struct_apr_skiplistnode# /usr/include/apr/apr_skiplist.h: 65

# /usr/include/apr/apr_skiplist.h: 76
if _libs["apr-1"].has("apr_skiplist_alloc", "cdecl"):
    apr_skiplist_alloc = _libs["apr-1"].get("apr_skiplist_alloc", "cdecl")
    apr_skiplist_alloc.argtypes = [POINTER(apr_skiplist), c_size_t]
    apr_skiplist_alloc.restype = POINTER(c_ubyte)
    apr_skiplist_alloc.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 88
if _libs["apr-1"].has("apr_skiplist_free", "cdecl"):
    apr_skiplist_free = _libs["apr-1"].get("apr_skiplist_free", "cdecl")
    apr_skiplist_free.argtypes = [POINTER(apr_skiplist), POINTER(None)]
    apr_skiplist_free.restype = None

# /usr/include/apr/apr_skiplist.h: 97
if _libs["apr-1"].has("apr_skiplist_init", "cdecl"):
    apr_skiplist_init = _libs["apr-1"].get("apr_skiplist_init", "cdecl")
    apr_skiplist_init.argtypes = [POINTER(POINTER(apr_skiplist)), POINTER(apr_pool_t)]
    apr_skiplist_init.restype = apr_status_t

# /usr/include/apr/apr_skiplist.h: 109
if _libs["apr-1"].has("apr_skiplist_set_compare", "cdecl"):
    apr_skiplist_set_compare = _libs["apr-1"].get("apr_skiplist_set_compare", "cdecl")
    apr_skiplist_set_compare.argtypes = [POINTER(apr_skiplist), apr_skiplist_compare, apr_skiplist_compare]
    apr_skiplist_set_compare.restype = None

# /usr/include/apr/apr_skiplist.h: 122
if _libs["apr-1"].has("apr_skiplist_add_index", "cdecl"):
    apr_skiplist_add_index = _libs["apr-1"].get("apr_skiplist_add_index", "cdecl")
    apr_skiplist_add_index.argtypes = [POINTER(apr_skiplist), apr_skiplist_compare, apr_skiplist_compare]
    apr_skiplist_add_index.restype = None

# /usr/include/apr/apr_skiplist.h: 129
if _libs["apr-1"].has("apr_skiplist_getlist", "cdecl"):
    apr_skiplist_getlist = _libs["apr-1"].get("apr_skiplist_getlist", "cdecl")
    apr_skiplist_getlist.argtypes = [POINTER(apr_skiplist)]
    apr_skiplist_getlist.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 140
if _libs["apr-1"].has("apr_skiplist_find_compare", "cdecl"):
    apr_skiplist_find_compare = _libs["apr-1"].get("apr_skiplist_find_compare", "cdecl")
    apr_skiplist_find_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), POINTER(POINTER(apr_skiplistnode)), apr_skiplist_compare]
    apr_skiplist_find_compare.restype = POINTER(c_ubyte)
    apr_skiplist_find_compare.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 153
if _libs["apr-1"].has("apr_skiplist_find", "cdecl"):
    apr_skiplist_find = _libs["apr-1"].get("apr_skiplist_find", "cdecl")
    apr_skiplist_find.argtypes = [POINTER(apr_skiplist), POINTER(None), POINTER(POINTER(apr_skiplistnode))]
    apr_skiplist_find.restype = POINTER(c_ubyte)
    apr_skiplist_find.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 164
if _libs["apr-1"].has("apr_skiplist_last_compare", "cdecl"):
    apr_skiplist_last_compare = _libs["apr-1"].get("apr_skiplist_last_compare", "cdecl")
    apr_skiplist_last_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), POINTER(POINTER(apr_skiplistnode)), apr_skiplist_compare]
    apr_skiplist_last_compare.restype = POINTER(c_ubyte)
    apr_skiplist_last_compare.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 176
if _libs["apr-1"].has("apr_skiplist_last", "cdecl"):
    apr_skiplist_last = _libs["apr-1"].get("apr_skiplist_last", "cdecl")
    apr_skiplist_last.argtypes = [POINTER(apr_skiplist), POINTER(None), POINTER(POINTER(apr_skiplistnode))]
    apr_skiplist_last.restype = POINTER(c_ubyte)
    apr_skiplist_last.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 186
if _libs["apr-1"].has("apr_skiplist_next", "cdecl"):
    apr_skiplist_next = _libs["apr-1"].get("apr_skiplist_next", "cdecl")
    apr_skiplist_next.argtypes = [POINTER(apr_skiplist), POINTER(POINTER(apr_skiplistnode))]
    apr_skiplist_next.restype = POINTER(c_ubyte)
    apr_skiplist_next.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 195
if _libs["apr-1"].has("apr_skiplist_previous", "cdecl"):
    apr_skiplist_previous = _libs["apr-1"].get("apr_skiplist_previous", "cdecl")
    apr_skiplist_previous.argtypes = [POINTER(apr_skiplist), POINTER(POINTER(apr_skiplistnode))]
    apr_skiplist_previous.restype = POINTER(c_ubyte)
    apr_skiplist_previous.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 201
if _libs["apr-1"].has("apr_skiplist_element", "cdecl"):
    apr_skiplist_element = _libs["apr-1"].get("apr_skiplist_element", "cdecl")
    apr_skiplist_element.argtypes = [POINTER(apr_skiplistnode)]
    apr_skiplist_element.restype = POINTER(c_ubyte)
    apr_skiplist_element.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 210
if _libs["apr-1"].has("apr_skiplist_insert_compare", "cdecl"):
    apr_skiplist_insert_compare = _libs["apr-1"].get("apr_skiplist_insert_compare", "cdecl")
    apr_skiplist_insert_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_compare]
    apr_skiplist_insert_compare.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 221
if _libs["apr-1"].has("apr_skiplist_insert", "cdecl"):
    apr_skiplist_insert = _libs["apr-1"].get("apr_skiplist_insert", "cdecl")
    apr_skiplist_insert.argtypes = [POINTER(apr_skiplist), POINTER(None)]
    apr_skiplist_insert.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 230
if _libs["apr-1"].has("apr_skiplist_add_compare", "cdecl"):
    apr_skiplist_add_compare = _libs["apr-1"].get("apr_skiplist_add_compare", "cdecl")
    apr_skiplist_add_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_compare]
    apr_skiplist_add_compare.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 241
if _libs["apr-1"].has("apr_skiplist_add", "cdecl"):
    apr_skiplist_add = _libs["apr-1"].get("apr_skiplist_add", "cdecl")
    apr_skiplist_add.argtypes = [POINTER(apr_skiplist), POINTER(None)]
    apr_skiplist_add.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 253
if _libs["apr-1"].has("apr_skiplist_replace_compare", "cdecl"):
    apr_skiplist_replace_compare = _libs["apr-1"].get("apr_skiplist_replace_compare", "cdecl")
    apr_skiplist_replace_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_freefunc, apr_skiplist_compare]
    apr_skiplist_replace_compare.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 266
if _libs["apr-1"].has("apr_skiplist_replace", "cdecl"):
    apr_skiplist_replace = _libs["apr-1"].get("apr_skiplist_replace", "cdecl")
    apr_skiplist_replace.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_freefunc]
    apr_skiplist_replace.restype = POINTER(apr_skiplistnode)

# /usr/include/apr/apr_skiplist.h: 275
if _libs["apr-1"].has("apr_skiplist_remove_node", "cdecl"):
    apr_skiplist_remove_node = _libs["apr-1"].get("apr_skiplist_remove_node", "cdecl")
    apr_skiplist_remove_node.argtypes = [POINTER(apr_skiplist), POINTER(apr_skiplistnode), apr_skiplist_freefunc]
    apr_skiplist_remove_node.restype = c_int

# /usr/include/apr/apr_skiplist.h: 289
if _libs["apr-1"].has("apr_skiplist_remove_compare", "cdecl"):
    apr_skiplist_remove_compare = _libs["apr-1"].get("apr_skiplist_remove_compare", "cdecl")
    apr_skiplist_remove_compare.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_freefunc, apr_skiplist_compare]
    apr_skiplist_remove_compare.restype = c_int

# /usr/include/apr/apr_skiplist.h: 303
if _libs["apr-1"].has("apr_skiplist_remove", "cdecl"):
    apr_skiplist_remove = _libs["apr-1"].get("apr_skiplist_remove", "cdecl")
    apr_skiplist_remove.argtypes = [POINTER(apr_skiplist), POINTER(None), apr_skiplist_freefunc]
    apr_skiplist_remove.restype = c_int

# /usr/include/apr/apr_skiplist.h: 310
if _libs["apr-1"].has("apr_skiplist_remove_all", "cdecl"):
    apr_skiplist_remove_all = _libs["apr-1"].get("apr_skiplist_remove_all", "cdecl")
    apr_skiplist_remove_all.argtypes = [POINTER(apr_skiplist), apr_skiplist_freefunc]
    apr_skiplist_remove_all.restype = None

# /usr/include/apr/apr_skiplist.h: 317
if _libs["apr-1"].has("apr_skiplist_destroy", "cdecl"):
    apr_skiplist_destroy = _libs["apr-1"].get("apr_skiplist_destroy", "cdecl")
    apr_skiplist_destroy.argtypes = [POINTER(apr_skiplist), apr_skiplist_freefunc]
    apr_skiplist_destroy.restype = None

# /usr/include/apr/apr_skiplist.h: 325
if _libs["apr-1"].has("apr_skiplist_pop", "cdecl"):
    apr_skiplist_pop = _libs["apr-1"].get("apr_skiplist_pop", "cdecl")
    apr_skiplist_pop.argtypes = [POINTER(apr_skiplist), apr_skiplist_freefunc]
    apr_skiplist_pop.restype = POINTER(c_ubyte)
    apr_skiplist_pop.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 332
if _libs["apr-1"].has("apr_skiplist_peek", "cdecl"):
    apr_skiplist_peek = _libs["apr-1"].get("apr_skiplist_peek", "cdecl")
    apr_skiplist_peek.argtypes = [POINTER(apr_skiplist)]
    apr_skiplist_peek.restype = POINTER(c_ubyte)
    apr_skiplist_peek.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr/apr_skiplist.h: 338
if _libs["apr-1"].has("apr_skiplist_size", "cdecl"):
    apr_skiplist_size = _libs["apr-1"].get("apr_skiplist_size", "cdecl")
    apr_skiplist_size.argtypes = [POINTER(apr_skiplist)]
    apr_skiplist_size.restype = c_size_t

# /usr/include/apr/apr_skiplist.h: 344
if _libs["apr-1"].has("apr_skiplist_height", "cdecl"):
    apr_skiplist_height = _libs["apr-1"].get("apr_skiplist_height", "cdecl")
    apr_skiplist_height.argtypes = [POINTER(apr_skiplist)]
    apr_skiplist_height.restype = c_int

# /usr/include/apr/apr_skiplist.h: 350
if _libs["apr-1"].has("apr_skiplist_preheight", "cdecl"):
    apr_skiplist_preheight = _libs["apr-1"].get("apr_skiplist_preheight", "cdecl")
    apr_skiplist_preheight.argtypes = [POINTER(apr_skiplist)]
    apr_skiplist_preheight.restype = c_int

# /usr/include/apr/apr_skiplist.h: 366
if _libs["apr-1"].has("apr_skiplist_set_preheight", "cdecl"):
    apr_skiplist_set_preheight = _libs["apr-1"].get("apr_skiplist_set_preheight", "cdecl")
    apr_skiplist_set_preheight.argtypes = [POINTER(apr_skiplist), c_int]
    apr_skiplist_set_preheight.restype = None

# /usr/include/apr/apr_skiplist.h: 373
if _libs["apr-1"].has("apr_skiplist_merge", "cdecl"):
    apr_skiplist_merge = _libs["apr-1"].get("apr_skiplist_merge", "cdecl")
    apr_skiplist_merge.argtypes = [POINTER(apr_skiplist), POINTER(apr_skiplist)]
    apr_skiplist_merge.restype = POINTER(apr_skiplist)

# /usr/include/apr/apr_support.h: 48
if _libs["apr-1"].has("apr_wait_for_io_or_timeout", "cdecl"):
    apr_wait_for_io_or_timeout = _libs["apr-1"].get("apr_wait_for_io_or_timeout", "cdecl")
    apr_wait_for_io_or_timeout.argtypes = [POINTER(apr_file_t), POINTER(apr_socket_t), c_int]
    apr_wait_for_io_or_timeout.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 44
class struct_apr_thread_cond_t(Structure):
    pass

apr_thread_cond_t = struct_apr_thread_cond_t# /usr/include/apr/apr_thread_cond.h: 44

# /usr/include/apr/apr_thread_cond.h: 59
if _libs["apr-1"].has("apr_thread_cond_create", "cdecl"):
    apr_thread_cond_create = _libs["apr-1"].get("apr_thread_cond_create", "cdecl")
    apr_thread_cond_create.argtypes = [POINTER(POINTER(apr_thread_cond_t)), POINTER(apr_pool_t)]
    apr_thread_cond_create.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 77
if _libs["apr-1"].has("apr_thread_cond_wait", "cdecl"):
    apr_thread_cond_wait = _libs["apr-1"].get("apr_thread_cond_wait", "cdecl")
    apr_thread_cond_wait.argtypes = [POINTER(apr_thread_cond_t), POINTER(apr_thread_mutex_t)]
    apr_thread_cond_wait.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 96
if _libs["apr-1"].has("apr_thread_cond_timedwait", "cdecl"):
    apr_thread_cond_timedwait = _libs["apr-1"].get("apr_thread_cond_timedwait", "cdecl")
    apr_thread_cond_timedwait.argtypes = [POINTER(apr_thread_cond_t), POINTER(apr_thread_mutex_t), apr_interval_time_t]
    apr_thread_cond_timedwait.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 108
if _libs["apr-1"].has("apr_thread_cond_signal", "cdecl"):
    apr_thread_cond_signal = _libs["apr-1"].get("apr_thread_cond_signal", "cdecl")
    apr_thread_cond_signal.argtypes = [POINTER(apr_thread_cond_t)]
    apr_thread_cond_signal.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 117
if _libs["apr-1"].has("apr_thread_cond_broadcast", "cdecl"):
    apr_thread_cond_broadcast = _libs["apr-1"].get("apr_thread_cond_broadcast", "cdecl")
    apr_thread_cond_broadcast.argtypes = [POINTER(apr_thread_cond_t)]
    apr_thread_cond_broadcast.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 123
if _libs["apr-1"].has("apr_thread_cond_destroy", "cdecl"):
    apr_thread_cond_destroy = _libs["apr-1"].get("apr_thread_cond_destroy", "cdecl")
    apr_thread_cond_destroy.argtypes = [POINTER(apr_thread_cond_t)]
    apr_thread_cond_destroy.restype = apr_status_t

# /usr/include/apr/apr_thread_cond.h: 129
if _libs["apr-1"].has("apr_thread_cond_pool_get", "cdecl"):
    apr_thread_cond_pool_get = _libs["apr-1"].get("apr_thread_cond_pool_get", "cdecl")
    apr_thread_cond_pool_get.argtypes = [POINTER(apr_thread_cond_t)]
    apr_thread_cond_pool_get.restype = POINTER(apr_pool_t)

# /usr/include/apr/apr_thread_rwlock.h: 42
class struct_apr_thread_rwlock_t(Structure):
    pass

apr_thread_rwlock_t = struct_apr_thread_rwlock_t# /usr/include/apr/apr_thread_rwlock.h: 42

# /usr/include/apr/apr_thread_rwlock.h: 60
if _libs["apr-1"].has("apr_thread_rwlock_create", "cdecl"):
    apr_thread_rwlock_create = _libs["apr-1"].get("apr_thread_rwlock_create", "cdecl")
    apr_thread_rwlock_create.argtypes = [POINTER(POINTER(apr_thread_rwlock_t)), POINTER(apr_pool_t)]
    apr_thread_rwlock_create.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 68
if _libs["apr-1"].has("apr_thread_rwlock_rdlock", "cdecl"):
    apr_thread_rwlock_rdlock = _libs["apr-1"].get("apr_thread_rwlock_rdlock", "cdecl")
    apr_thread_rwlock_rdlock.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_rdlock.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 80
if _libs["apr-1"].has("apr_thread_rwlock_tryrdlock", "cdecl"):
    apr_thread_rwlock_tryrdlock = _libs["apr-1"].get("apr_thread_rwlock_tryrdlock", "cdecl")
    apr_thread_rwlock_tryrdlock.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_tryrdlock.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 89
if _libs["apr-1"].has("apr_thread_rwlock_wrlock", "cdecl"):
    apr_thread_rwlock_wrlock = _libs["apr-1"].get("apr_thread_rwlock_wrlock", "cdecl")
    apr_thread_rwlock_wrlock.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_wrlock.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 100
if _libs["apr-1"].has("apr_thread_rwlock_trywrlock", "cdecl"):
    apr_thread_rwlock_trywrlock = _libs["apr-1"].get("apr_thread_rwlock_trywrlock", "cdecl")
    apr_thread_rwlock_trywrlock.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_trywrlock.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 107
if _libs["apr-1"].has("apr_thread_rwlock_unlock", "cdecl"):
    apr_thread_rwlock_unlock = _libs["apr-1"].get("apr_thread_rwlock_unlock", "cdecl")
    apr_thread_rwlock_unlock.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_unlock.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 113
if _libs["apr-1"].has("apr_thread_rwlock_destroy", "cdecl"):
    apr_thread_rwlock_destroy = _libs["apr-1"].get("apr_thread_rwlock_destroy", "cdecl")
    apr_thread_rwlock_destroy.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_destroy.restype = apr_status_t

# /usr/include/apr/apr_thread_rwlock.h: 119
if _libs["apr-1"].has("apr_thread_rwlock_pool_get", "cdecl"):
    apr_thread_rwlock_pool_get = _libs["apr-1"].get("apr_thread_rwlock_pool_get", "cdecl")
    apr_thread_rwlock_pool_get.argtypes = [POINTER(apr_thread_rwlock_t)]
    apr_thread_rwlock_pool_get.restype = POINTER(apr_pool_t)

enum_tm_lock = c_int# /usr/include/apr-util/apr_anylock.h: 31

apr_anylock_none = 0# /usr/include/apr-util/apr_anylock.h: 31

apr_anylock_procmutex = (apr_anylock_none + 1)# /usr/include/apr-util/apr_anylock.h: 31

apr_anylock_threadmutex = (apr_anylock_procmutex + 1)# /usr/include/apr-util/apr_anylock.h: 31

apr_anylock_readlock = (apr_anylock_threadmutex + 1)# /usr/include/apr-util/apr_anylock.h: 31

apr_anylock_writelock = (apr_anylock_readlock + 1)# /usr/include/apr-util/apr_anylock.h: 31

# /usr/include/apr-util/apr_anylock.h: 39
class union_apr_anylock_u_t(Union):
    pass

union_apr_anylock_u_t.__slots__ = [
    'pm',
    'tm',
    'rw',
]
union_apr_anylock_u_t._fields_ = [
    ('pm', POINTER(apr_proc_mutex_t)),
    ('tm', POINTER(apr_thread_mutex_t)),
    ('rw', POINTER(apr_thread_rwlock_t)),
]

# /usr/include/apr-util/apr_anylock.h: 46
class struct_apr_anylock_t(Structure):
    pass

struct_apr_anylock_t.__slots__ = [
    'type',
    'lock',
]
struct_apr_anylock_t._fields_ = [
    ('type', enum_tm_lock),
    ('lock', union_apr_anylock_u_t),
]

apr_anylock_t = struct_apr_anylock_t# /usr/include/apr-util/apr_anylock.h: 46

# /usr/include/apr-util/apr_base64.h: 60
if _libs["aprutil-1"].has("apr_base64_encode_len", "cdecl"):
    apr_base64_encode_len = _libs["aprutil-1"].get("apr_base64_encode_len", "cdecl")
    apr_base64_encode_len.argtypes = [c_int]
    apr_base64_encode_len.restype = c_int

# /usr/include/apr-util/apr_base64.h: 69
if _libs["aprutil-1"].has("apr_base64_encode", "cdecl"):
    apr_base64_encode = _libs["aprutil-1"].get("apr_base64_encode", "cdecl")
    apr_base64_encode.argtypes = [String, String, c_int]
    apr_base64_encode.restype = c_int

# /usr/include/apr-util/apr_base64.h: 79
if _libs["aprutil-1"].has("apr_base64_encode_binary", "cdecl"):
    apr_base64_encode_binary = _libs["aprutil-1"].get("apr_base64_encode_binary", "cdecl")
    apr_base64_encode_binary.argtypes = [String, POINTER(c_ubyte), c_int]
    apr_base64_encode_binary.restype = c_int

# /usr/include/apr-util/apr_base64.h: 89
if _libs["aprutil-1"].has("apr_base64_decode_len", "cdecl"):
    apr_base64_decode_len = _libs["aprutil-1"].get("apr_base64_decode_len", "cdecl")
    apr_base64_decode_len.argtypes = [String]
    apr_base64_decode_len.restype = c_int

# /usr/include/apr-util/apr_base64.h: 97
if _libs["aprutil-1"].has("apr_base64_decode", "cdecl"):
    apr_base64_decode = _libs["aprutil-1"].get("apr_base64_decode", "cdecl")
    apr_base64_decode.argtypes = [String, String]
    apr_base64_decode.restype = c_int

# /usr/include/apr-util/apr_base64.h: 105
if _libs["aprutil-1"].has("apr_base64_decode_binary", "cdecl"):
    apr_base64_decode_binary = _libs["aprutil-1"].get("apr_base64_decode_binary", "cdecl")
    apr_base64_decode_binary.argtypes = [POINTER(c_ubyte), String]
    apr_base64_decode_binary.restype = c_int

enum_anon_110 = c_int# /usr/include/apr-util/apr_buckets.h: 60

APR_BLOCK_READ = 0# /usr/include/apr-util/apr_buckets.h: 60

APR_NONBLOCK_READ = (APR_BLOCK_READ + 1)# /usr/include/apr-util/apr_buckets.h: 60

apr_read_type_e = enum_anon_110# /usr/include/apr-util/apr_buckets.h: 60

# /usr/include/apr-util/apr_buckets.h: 258
class struct_apr_bucket_brigade(Structure):
    pass

apr_bucket_brigade = struct_apr_bucket_brigade# /usr/include/apr-util/apr_buckets.h: 119

# /usr/include/apr-util/apr_buckets.h: 224
class struct_apr_bucket(Structure):
    pass

apr_bucket = struct_apr_bucket# /usr/include/apr-util/apr_buckets.h: 121

# /usr/include/apr-util/apr_buckets.h: 123
class struct_apr_bucket_alloc_t(Structure):
    pass

apr_bucket_alloc_t = struct_apr_bucket_alloc_t# /usr/include/apr-util/apr_buckets.h: 123

# /usr/include/apr-util/apr_buckets.h: 131
class struct_apr_bucket_type_t(Structure):
    pass

apr_bucket_type_t = struct_apr_bucket_type_t# /usr/include/apr-util/apr_buckets.h: 126

enum_anon_111 = c_int# /usr/include/apr-util/apr_buckets.h: 151

APR_BUCKET_DATA = 0# /usr/include/apr-util/apr_buckets.h: 151

APR_BUCKET_METADATA = 1# /usr/include/apr-util/apr_buckets.h: 151

struct_apr_bucket_type_t.__slots__ = [
    'name',
    'num_func',
    'is_metadata',
    'destroy',
    'read',
    'setaside',
    'split',
    'copy',
]
struct_apr_bucket_type_t._fields_ = [
    ('name', String),
    ('num_func', c_int),
    ('is_metadata', enum_anon_111),
    ('destroy', CFUNCTYPE(UNCHECKED(None), POINTER(None))),
    ('read', CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(apr_bucket), POINTER(POINTER(c_char)), POINTER(apr_size_t), apr_read_type_e)),
    ('setaside', CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(apr_bucket), POINTER(apr_pool_t))),
    ('split', CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(apr_bucket), apr_size_t)),
    ('copy', CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(apr_bucket), POINTER(POINTER(apr_bucket)))),
]

# /usr/include/apr-util/apr_buckets.h: 226
class struct_anon_112(Structure):
    pass

struct_anon_112.__slots__ = [
    'next',
    'prev',
]
struct_anon_112._fields_ = [
    ('next', POINTER(struct_apr_bucket)),
    ('prev', POINTER(struct_apr_bucket)),
]

struct_apr_bucket.__slots__ = [
    'link',
    'type',
    'length',
    'start',
    'data',
    'free',
    'list',
]
struct_apr_bucket._fields_ = [
    ('link', struct_anon_112),
    ('type', POINTER(apr_bucket_type_t)),
    ('length', apr_size_t),
    ('start', apr_off_t),
    ('data', POINTER(None)),
    ('free', CFUNCTYPE(UNCHECKED(None), POINTER(None))),
    ('list', POINTER(apr_bucket_alloc_t)),
]

# /usr/include/apr-util/apr_buckets.h: 273
class struct_apr_bucket_list(Structure):
    pass

struct_apr_bucket_list.__slots__ = [
    'next',
    'prev',
]
struct_apr_bucket_list._fields_ = [
    ('next', POINTER(struct_apr_bucket)),
    ('prev', POINTER(struct_apr_bucket)),
]

struct_apr_bucket_brigade.__slots__ = [
    'p',
    'list',
    'bucket_alloc',
]
struct_apr_bucket_brigade._fields_ = [
    ('p', POINTER(apr_pool_t)),
    ('list', struct_apr_bucket_list),
    ('bucket_alloc', POINTER(apr_bucket_alloc_t)),
]

apr_brigade_flush = CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(apr_bucket_brigade), POINTER(None))# /usr/include/apr-util/apr_buckets.h: 282

# /usr/include/apr-util/apr_buckets.h: 531
class struct_apr_bucket_refcount(Structure):
    pass

apr_bucket_refcount = struct_apr_bucket_refcount# /usr/include/apr-util/apr_buckets.h: 524

struct_apr_bucket_refcount.__slots__ = [
    'refcount',
]
struct_apr_bucket_refcount._fields_ = [
    ('refcount', c_int),
]

# /usr/include/apr-util/apr_buckets.h: 543
class struct_apr_bucket_heap(Structure):
    pass

apr_bucket_heap = struct_apr_bucket_heap# /usr/include/apr-util/apr_buckets.h: 539

struct_apr_bucket_heap.__slots__ = [
    'refcount',
    'base',
    'alloc_len',
    'free_func',
]
struct_apr_bucket_heap._fields_ = [
    ('refcount', apr_bucket_refcount),
    ('base', String),
    ('alloc_len', apr_size_t),
    ('free_func', CFUNCTYPE(UNCHECKED(None), POINTER(None))),
]

# /usr/include/apr-util/apr_buckets.h: 561
class struct_apr_bucket_pool(Structure):
    pass

apr_bucket_pool = struct_apr_bucket_pool# /usr/include/apr-util/apr_buckets.h: 557

struct_apr_bucket_pool.__slots__ = [
    'heap',
    'base',
    'pool',
    'list',
]
struct_apr_bucket_pool._fields_ = [
    ('heap', apr_bucket_heap),
    ('base', String),
    ('pool', POINTER(apr_pool_t)),
    ('list', POINTER(apr_bucket_alloc_t)),
]

# /usr/include/apr-util/apr_buckets.h: 599
class struct_apr_bucket_mmap(Structure):
    pass

apr_bucket_mmap = struct_apr_bucket_mmap# /usr/include/apr-util/apr_buckets.h: 595

struct_apr_bucket_mmap.__slots__ = [
    'refcount',
    'mmap',
]
struct_apr_bucket_mmap._fields_ = [
    ('refcount', apr_bucket_refcount),
    ('mmap', POINTER(apr_mmap_t)),
]

# /usr/include/apr-util/apr_buckets.h: 612
class struct_apr_bucket_file(Structure):
    pass

apr_bucket_file = struct_apr_bucket_file# /usr/include/apr-util/apr_buckets.h: 608

struct_apr_bucket_file.__slots__ = [
    'refcount',
    'fd',
    'readpool',
    'can_mmap',
    'read_size',
]
struct_apr_bucket_file._fields_ = [
    ('refcount', apr_bucket_refcount),
    ('fd', POINTER(apr_file_t)),
    ('readpool', POINTER(apr_pool_t)),
    ('can_mmap', c_int),
    ('read_size', apr_size_t),
]

# /usr/include/apr-util/apr_buckets.h: 635
class union_apr_bucket_structs(Union):
    pass

apr_bucket_structs = union_apr_bucket_structs# /usr/include/apr-util/apr_buckets.h: 630

union_apr_bucket_structs.__slots__ = [
    'b',
    'heap',
    'pool',
    'mmap',
    'file',
]
union_apr_bucket_structs._fields_ = [
    ('b', apr_bucket),
    ('heap', apr_bucket_heap),
    ('pool', apr_bucket_pool),
    ('mmap', apr_bucket_mmap),
    ('file', apr_bucket_file),
]

# /usr/include/apr-util/apr_buckets.h: 660
if _libs["aprutil-1"].has("apr_brigade_create", "cdecl"):
    apr_brigade_create = _libs["aprutil-1"].get("apr_brigade_create", "cdecl")
    apr_brigade_create.argtypes = [POINTER(apr_pool_t), POINTER(apr_bucket_alloc_t)]
    apr_brigade_create.restype = POINTER(apr_bucket_brigade)

# /usr/include/apr-util/apr_buckets.h: 668
if _libs["aprutil-1"].has("apr_brigade_destroy", "cdecl"):
    apr_brigade_destroy = _libs["aprutil-1"].get("apr_brigade_destroy", "cdecl")
    apr_brigade_destroy.argtypes = [POINTER(apr_bucket_brigade)]
    apr_brigade_destroy.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 681
if _libs["aprutil-1"].has("apr_brigade_cleanup", "cdecl"):
    apr_brigade_cleanup = _libs["aprutil-1"].get("apr_brigade_cleanup", "cdecl")
    apr_brigade_cleanup.argtypes = [POINTER(None)]
    apr_brigade_cleanup.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 698
if _libs["aprutil-1"].has("apr_brigade_split_ex", "cdecl"):
    apr_brigade_split_ex = _libs["aprutil-1"].get("apr_brigade_split_ex", "cdecl")
    apr_brigade_split_ex.argtypes = [POINTER(apr_bucket_brigade), POINTER(apr_bucket), POINTER(apr_bucket_brigade)]
    apr_brigade_split_ex.restype = POINTER(apr_bucket_brigade)

# /usr/include/apr-util/apr_buckets.h: 713
if _libs["aprutil-1"].has("apr_brigade_split", "cdecl"):
    apr_brigade_split = _libs["aprutil-1"].get("apr_brigade_split", "cdecl")
    apr_brigade_split.argtypes = [POINTER(apr_bucket_brigade), POINTER(apr_bucket)]
    apr_brigade_split.restype = POINTER(apr_bucket_brigade)

# /usr/include/apr-util/apr_buckets.h: 728
if _libs["aprutil-1"].has("apr_brigade_partition", "cdecl"):
    apr_brigade_partition = _libs["aprutil-1"].get("apr_brigade_partition", "cdecl")
    apr_brigade_partition.argtypes = [POINTER(apr_bucket_brigade), apr_off_t, POINTER(POINTER(apr_bucket))]
    apr_brigade_partition.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 740
if _libs["aprutil-1"].has("apr_brigade_length", "cdecl"):
    apr_brigade_length = _libs["aprutil-1"].get("apr_brigade_length", "cdecl")
    apr_brigade_length.argtypes = [POINTER(apr_bucket_brigade), c_int, POINTER(apr_off_t)]
    apr_brigade_length.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 751
if _libs["aprutil-1"].has("apr_brigade_flatten", "cdecl"):
    apr_brigade_flatten = _libs["aprutil-1"].get("apr_brigade_flatten", "cdecl")
    apr_brigade_flatten.argtypes = [POINTER(apr_bucket_brigade), String, POINTER(apr_size_t)]
    apr_brigade_flatten.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 762
if _libs["aprutil-1"].has("apr_brigade_pflatten", "cdecl"):
    apr_brigade_pflatten = _libs["aprutil-1"].get("apr_brigade_pflatten", "cdecl")
    apr_brigade_pflatten.argtypes = [POINTER(apr_bucket_brigade), POINTER(POINTER(c_char)), POINTER(apr_size_t), POINTER(apr_pool_t)]
    apr_brigade_pflatten.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 775
if _libs["aprutil-1"].has("apr_brigade_split_line", "cdecl"):
    apr_brigade_split_line = _libs["aprutil-1"].get("apr_brigade_split_line", "cdecl")
    apr_brigade_split_line.argtypes = [POINTER(apr_bucket_brigade), POINTER(apr_bucket_brigade), apr_read_type_e, apr_off_t]
    apr_brigade_split_line.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 789
if _libs["aprutil-1"].has("apr_brigade_to_iovec", "cdecl"):
    apr_brigade_to_iovec = _libs["aprutil-1"].get("apr_brigade_to_iovec", "cdecl")
    apr_brigade_to_iovec.argtypes = [POINTER(apr_bucket_brigade), POINTER(struct_iovec), POINTER(c_int)]
    apr_brigade_to_iovec.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 800
if _libs["aprutil-1"].has("apr_brigade_vputstrs", "cdecl"):
    apr_brigade_vputstrs = _libs["aprutil-1"].get("apr_brigade_vputstrs", "cdecl")
    apr_brigade_vputstrs.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), c_void_p]
    apr_brigade_vputstrs.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 828
if _libs["aprutil-1"].has("apr_brigade_write", "cdecl"):
    apr_brigade_write = _libs["aprutil-1"].get("apr_brigade_write", "cdecl")
    apr_brigade_write.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), String, apr_size_t]
    apr_brigade_write.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 841
if _libs["aprutil-1"].has("apr_brigade_writev", "cdecl"):
    apr_brigade_writev = _libs["aprutil-1"].get("apr_brigade_writev", "cdecl")
    apr_brigade_writev.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), POINTER(struct_iovec), apr_size_t]
    apr_brigade_writev.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 855
if _libs["aprutil-1"].has("apr_brigade_puts", "cdecl"):
    apr_brigade_puts = _libs["aprutil-1"].get("apr_brigade_puts", "cdecl")
    apr_brigade_puts.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), String]
    apr_brigade_puts.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 867
if _libs["aprutil-1"].has("apr_brigade_putc", "cdecl"):
    apr_brigade_putc = _libs["aprutil-1"].get("apr_brigade_putc", "cdecl")
    apr_brigade_putc.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), c_char]
    apr_brigade_putc.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 879
if _libs["aprutil-1"].has("apr_brigade_putstrs", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_brigade_putstrs", "cdecl")
    _restype = apr_status_t
    _errcheck = None
    _argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None)]
    apr_brigade_putstrs = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_buckets.h: 893
if _libs["aprutil-1"].has("apr_brigade_printf", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_brigade_printf", "cdecl")
    _restype = apr_status_t
    _errcheck = None
    _argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), String]
    apr_brigade_printf = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_buckets.h: 909
if _libs["aprutil-1"].has("apr_brigade_vprintf", "cdecl"):
    apr_brigade_vprintf = _libs["aprutil-1"].get("apr_brigade_vprintf", "cdecl")
    apr_brigade_vprintf.argtypes = [POINTER(apr_bucket_brigade), apr_brigade_flush, POINTER(None), String, c_void_p]
    apr_brigade_vprintf.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 926
if _libs["aprutil-1"].has("apr_brigade_insert_file", "cdecl"):
    apr_brigade_insert_file = _libs["aprutil-1"].get("apr_brigade_insert_file", "cdecl")
    apr_brigade_insert_file.argtypes = [POINTER(apr_bucket_brigade), POINTER(apr_file_t), apr_off_t, apr_off_t, POINTER(apr_pool_t)]
    apr_brigade_insert_file.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 948
if _libs["aprutil-1"].has("apr_bucket_alloc_create", "cdecl"):
    apr_bucket_alloc_create = _libs["aprutil-1"].get("apr_bucket_alloc_create", "cdecl")
    apr_bucket_alloc_create.argtypes = [POINTER(apr_pool_t)]
    apr_bucket_alloc_create.restype = POINTER(apr_bucket_alloc_t)

# /usr/include/apr-util/apr_buckets.h: 958
if _libs["aprutil-1"].has("apr_bucket_alloc_create_ex", "cdecl"):
    apr_bucket_alloc_create_ex = _libs["aprutil-1"].get("apr_bucket_alloc_create_ex", "cdecl")
    apr_bucket_alloc_create_ex.argtypes = [POINTER(apr_allocator_t)]
    apr_bucket_alloc_create_ex.restype = POINTER(apr_bucket_alloc_t)

# /usr/include/apr-util/apr_buckets.h: 964
if _libs["aprutil-1"].has("apr_bucket_alloc_destroy", "cdecl"):
    apr_bucket_alloc_destroy = _libs["aprutil-1"].get("apr_bucket_alloc_destroy", "cdecl")
    apr_bucket_alloc_destroy.argtypes = [POINTER(apr_bucket_alloc_t)]
    apr_bucket_alloc_destroy.restype = None

# /usr/include/apr-util/apr_buckets.h: 974
if _libs["aprutil-1"].has("apr_bucket_alloc_aligned_floor", "cdecl"):
    apr_bucket_alloc_aligned_floor = _libs["aprutil-1"].get("apr_bucket_alloc_aligned_floor", "cdecl")
    apr_bucket_alloc_aligned_floor.argtypes = [POINTER(apr_bucket_alloc_t), apr_size_t]
    apr_bucket_alloc_aligned_floor.restype = apr_size_t

# /usr/include/apr-util/apr_buckets.h: 983
if _libs["aprutil-1"].has("apr_bucket_alloc", "cdecl"):
    apr_bucket_alloc = _libs["aprutil-1"].get("apr_bucket_alloc", "cdecl")
    apr_bucket_alloc.argtypes = [apr_size_t, POINTER(apr_bucket_alloc_t)]
    apr_bucket_alloc.restype = POINTER(c_ubyte)
    apr_bucket_alloc.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr-util/apr_buckets.h: 989
if _libs["aprutil-1"].has("apr_bucket_free", "cdecl"):
    apr_bucket_free = _libs["aprutil-1"].get("apr_bucket_free", "cdecl")
    apr_bucket_free.argtypes = [POINTER(None)]
    apr_bucket_free.restype = None

# /usr/include/apr-util/apr_buckets.h: 1129
if _libs["aprutil-1"].has("apr_bucket_setaside_noop", "cdecl"):
    apr_bucket_setaside_noop = _libs["aprutil-1"].get("apr_bucket_setaside_noop", "cdecl")
    apr_bucket_setaside_noop.argtypes = [POINTER(apr_bucket), POINTER(apr_pool_t)]
    apr_bucket_setaside_noop.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1139
if _libs["aprutil-1"].has("apr_bucket_setaside_notimpl", "cdecl"):
    apr_bucket_setaside_notimpl = _libs["aprutil-1"].get("apr_bucket_setaside_notimpl", "cdecl")
    apr_bucket_setaside_notimpl.argtypes = [POINTER(apr_bucket), POINTER(apr_pool_t)]
    apr_bucket_setaside_notimpl.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1149
if _libs["aprutil-1"].has("apr_bucket_split_notimpl", "cdecl"):
    apr_bucket_split_notimpl = _libs["aprutil-1"].get("apr_bucket_split_notimpl", "cdecl")
    apr_bucket_split_notimpl.argtypes = [POINTER(apr_bucket), apr_size_t]
    apr_bucket_split_notimpl.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1159
if _libs["aprutil-1"].has("apr_bucket_copy_notimpl", "cdecl"):
    apr_bucket_copy_notimpl = _libs["aprutil-1"].get("apr_bucket_copy_notimpl", "cdecl")
    apr_bucket_copy_notimpl.argtypes = [POINTER(apr_bucket), POINTER(POINTER(apr_bucket))]
    apr_bucket_copy_notimpl.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1171
if _libs["aprutil-1"].has("apr_bucket_destroy_noop", "cdecl"):
    apr_bucket_destroy_noop = _libs["aprutil-1"].get("apr_bucket_destroy_noop", "cdecl")
    apr_bucket_destroy_noop.argtypes = [POINTER(None)]
    apr_bucket_destroy_noop.restype = None

# /usr/include/apr-util/apr_buckets.h: 1188
try:
    apr_bucket_type_flush = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_flush")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1194
try:
    apr_bucket_type_eos = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_eos")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1198
try:
    apr_bucket_type_file = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_file")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1203
try:
    apr_bucket_type_heap = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_heap")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1208
try:
    apr_bucket_type_mmap = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_mmap")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1215
try:
    apr_bucket_type_pool = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_pool")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1219
try:
    apr_bucket_type_pipe = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_pipe")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1225
try:
    apr_bucket_type_immortal = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_immortal")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1231
try:
    apr_bucket_type_transient = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_transient")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1235
try:
    apr_bucket_type_socket = (apr_bucket_type_t).in_dll(_libs["aprutil-1"], "apr_bucket_type_socket")
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1251
if _libs["aprutil-1"].has("apr_bucket_simple_split", "cdecl"):
    apr_bucket_simple_split = _libs["aprutil-1"].get("apr_bucket_simple_split", "cdecl")
    apr_bucket_simple_split.argtypes = [POINTER(apr_bucket), apr_size_t]
    apr_bucket_simple_split.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1264
if _libs["aprutil-1"].has("apr_bucket_simple_copy", "cdecl"):
    apr_bucket_simple_copy = _libs["aprutil-1"].get("apr_bucket_simple_copy", "cdecl")
    apr_bucket_simple_copy.argtypes = [POINTER(apr_bucket), POINTER(POINTER(apr_bucket))]
    apr_bucket_simple_copy.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1284
if _libs["aprutil-1"].has("apr_bucket_shared_make", "cdecl"):
    apr_bucket_shared_make = _libs["aprutil-1"].get("apr_bucket_shared_make", "cdecl")
    apr_bucket_shared_make.argtypes = [POINTER(apr_bucket), POINTER(None), apr_off_t, apr_size_t]
    apr_bucket_shared_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1296
if _libs["aprutil-1"].has("apr_bucket_shared_destroy", "cdecl"):
    apr_bucket_shared_destroy = _libs["aprutil-1"].get("apr_bucket_shared_destroy", "cdecl")
    apr_bucket_shared_destroy.argtypes = [POINTER(None)]
    apr_bucket_shared_destroy.restype = c_int

# /usr/include/apr-util/apr_buckets.h: 1309
if _libs["aprutil-1"].has("apr_bucket_shared_split", "cdecl"):
    apr_bucket_shared_split = _libs["aprutil-1"].get("apr_bucket_shared_split", "cdecl")
    apr_bucket_shared_split.argtypes = [POINTER(apr_bucket), apr_size_t]
    apr_bucket_shared_split.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1321
if _libs["aprutil-1"].has("apr_bucket_shared_copy", "cdecl"):
    apr_bucket_shared_copy = _libs["aprutil-1"].get("apr_bucket_shared_copy", "cdecl")
    apr_bucket_shared_copy.argtypes = [POINTER(apr_bucket), POINTER(POINTER(apr_bucket))]
    apr_bucket_shared_copy.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1343
if _libs["aprutil-1"].has("apr_bucket_eos_create", "cdecl"):
    apr_bucket_eos_create = _libs["aprutil-1"].get("apr_bucket_eos_create", "cdecl")
    apr_bucket_eos_create.argtypes = [POINTER(apr_bucket_alloc_t)]
    apr_bucket_eos_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1352
if _libs["aprutil-1"].has("apr_bucket_eos_make", "cdecl"):
    apr_bucket_eos_make = _libs["aprutil-1"].get("apr_bucket_eos_make", "cdecl")
    apr_bucket_eos_make.argtypes = [POINTER(apr_bucket)]
    apr_bucket_eos_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1361
if _libs["aprutil-1"].has("apr_bucket_flush_create", "cdecl"):
    apr_bucket_flush_create = _libs["aprutil-1"].get("apr_bucket_flush_create", "cdecl")
    apr_bucket_flush_create.argtypes = [POINTER(apr_bucket_alloc_t)]
    apr_bucket_flush_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1370
if _libs["aprutil-1"].has("apr_bucket_flush_make", "cdecl"):
    apr_bucket_flush_make = _libs["aprutil-1"].get("apr_bucket_flush_make", "cdecl")
    apr_bucket_flush_make.argtypes = [POINTER(apr_bucket)]
    apr_bucket_flush_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1379
if _libs["aprutil-1"].has("apr_bucket_immortal_create", "cdecl"):
    apr_bucket_immortal_create = _libs["aprutil-1"].get("apr_bucket_immortal_create", "cdecl")
    apr_bucket_immortal_create.argtypes = [String, apr_size_t, POINTER(apr_bucket_alloc_t)]
    apr_bucket_immortal_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1390
if _libs["aprutil-1"].has("apr_bucket_immortal_make", "cdecl"):
    apr_bucket_immortal_make = _libs["aprutil-1"].get("apr_bucket_immortal_make", "cdecl")
    apr_bucket_immortal_make.argtypes = [POINTER(apr_bucket), String, apr_size_t]
    apr_bucket_immortal_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1401
if _libs["aprutil-1"].has("apr_bucket_transient_create", "cdecl"):
    apr_bucket_transient_create = _libs["aprutil-1"].get("apr_bucket_transient_create", "cdecl")
    apr_bucket_transient_create.argtypes = [String, apr_size_t, POINTER(apr_bucket_alloc_t)]
    apr_bucket_transient_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1412
if _libs["aprutil-1"].has("apr_bucket_transient_make", "cdecl"):
    apr_bucket_transient_make = _libs["aprutil-1"].get("apr_bucket_transient_make", "cdecl")
    apr_bucket_transient_make.argtypes = [POINTER(apr_bucket), String, apr_size_t]
    apr_bucket_transient_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1430
if _libs["aprutil-1"].has("apr_bucket_heap_create", "cdecl"):
    apr_bucket_heap_create = _libs["aprutil-1"].get("apr_bucket_heap_create", "cdecl")
    apr_bucket_heap_create.argtypes = [String, apr_size_t, CFUNCTYPE(UNCHECKED(None), POINTER(None)), POINTER(apr_bucket_alloc_t)]
    apr_bucket_heap_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1443
if _libs["aprutil-1"].has("apr_bucket_heap_make", "cdecl"):
    apr_bucket_heap_make = _libs["aprutil-1"].get("apr_bucket_heap_make", "cdecl")
    apr_bucket_heap_make.argtypes = [POINTER(apr_bucket), String, apr_size_t, CFUNCTYPE(UNCHECKED(None), POINTER(None))]
    apr_bucket_heap_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1456
if _libs["aprutil-1"].has("apr_bucket_pool_create", "cdecl"):
    apr_bucket_pool_create = _libs["aprutil-1"].get("apr_bucket_pool_create", "cdecl")
    apr_bucket_pool_create.argtypes = [String, apr_size_t, POINTER(apr_pool_t), POINTER(apr_bucket_alloc_t)]
    apr_bucket_pool_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1469
if _libs["aprutil-1"].has("apr_bucket_pool_make", "cdecl"):
    apr_bucket_pool_make = _libs["aprutil-1"].get("apr_bucket_pool_make", "cdecl")
    apr_bucket_pool_make.argtypes = [POINTER(apr_bucket), String, apr_size_t, POINTER(apr_pool_t)]
    apr_bucket_pool_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1483
if _libs["aprutil-1"].has("apr_bucket_mmap_create", "cdecl"):
    apr_bucket_mmap_create = _libs["aprutil-1"].get("apr_bucket_mmap_create", "cdecl")
    apr_bucket_mmap_create.argtypes = [POINTER(apr_mmap_t), apr_off_t, apr_size_t, POINTER(apr_bucket_alloc_t)]
    apr_bucket_mmap_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1497
if _libs["aprutil-1"].has("apr_bucket_mmap_make", "cdecl"):
    apr_bucket_mmap_make = _libs["aprutil-1"].get("apr_bucket_mmap_make", "cdecl")
    apr_bucket_mmap_make.argtypes = [POINTER(apr_bucket), POINTER(apr_mmap_t), apr_off_t, apr_size_t]
    apr_bucket_mmap_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1508
if _libs["aprutil-1"].has("apr_bucket_socket_create", "cdecl"):
    apr_bucket_socket_create = _libs["aprutil-1"].get("apr_bucket_socket_create", "cdecl")
    apr_bucket_socket_create.argtypes = [POINTER(apr_socket_t), POINTER(apr_bucket_alloc_t)]
    apr_bucket_socket_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1516
if _libs["aprutil-1"].has("apr_bucket_socket_make", "cdecl"):
    apr_bucket_socket_make = _libs["aprutil-1"].get("apr_bucket_socket_make", "cdecl")
    apr_bucket_socket_make.argtypes = [POINTER(apr_bucket), POINTER(apr_socket_t)]
    apr_bucket_socket_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1525
if _libs["aprutil-1"].has("apr_bucket_pipe_create", "cdecl"):
    apr_bucket_pipe_create = _libs["aprutil-1"].get("apr_bucket_pipe_create", "cdecl")
    apr_bucket_pipe_create.argtypes = [POINTER(apr_file_t), POINTER(apr_bucket_alloc_t)]
    apr_bucket_pipe_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1534
if _libs["aprutil-1"].has("apr_bucket_pipe_make", "cdecl"):
    apr_bucket_pipe_make = _libs["aprutil-1"].get("apr_bucket_pipe_make", "cdecl")
    apr_bucket_pipe_make.argtypes = [POINTER(apr_bucket), POINTER(apr_file_t)]
    apr_bucket_pipe_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1553
if _libs["aprutil-1"].has("apr_bucket_file_create", "cdecl"):
    apr_bucket_file_create = _libs["aprutil-1"].get("apr_bucket_file_create", "cdecl")
    apr_bucket_file_create.argtypes = [POINTER(apr_file_t), apr_off_t, apr_size_t, POINTER(apr_pool_t), POINTER(apr_bucket_alloc_t)]
    apr_bucket_file_create.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1569
if _libs["aprutil-1"].has("apr_bucket_file_make", "cdecl"):
    apr_bucket_file_make = _libs["aprutil-1"].get("apr_bucket_file_make", "cdecl")
    apr_bucket_file_make.argtypes = [POINTER(apr_bucket), POINTER(apr_file_t), apr_off_t, apr_size_t, POINTER(apr_pool_t)]
    apr_bucket_file_make.restype = POINTER(apr_bucket)

# /usr/include/apr-util/apr_buckets.h: 1579
if _libs["aprutil-1"].has("apr_bucket_file_enable_mmap", "cdecl"):
    apr_bucket_file_enable_mmap = _libs["aprutil-1"].get("apr_bucket_file_enable_mmap", "cdecl")
    apr_bucket_file_enable_mmap.argtypes = [POINTER(apr_bucket), c_int]
    apr_bucket_file_enable_mmap.restype = apr_status_t

# /usr/include/apr-util/apr_buckets.h: 1592
if _libs["aprutil-1"].has("apr_bucket_file_set_buf_size", "cdecl"):
    apr_bucket_file_set_buf_size = _libs["aprutil-1"].get("apr_bucket_file_set_buf_size", "cdecl")
    apr_bucket_file_set_buf_size.argtypes = [POINTER(apr_bucket), apr_size_t]
    apr_bucket_file_set_buf_size.restype = apr_status_t

# /usr/include/apr-util/apu_errno.h: 165
class struct_apu_err_t(Structure):
    pass

struct_apu_err_t.__slots__ = [
    'reason',
    'msg',
    'rc',
]
struct_apu_err_t._fields_ = [
    ('reason', String),
    ('msg', String),
    ('rc', c_int),
]

apu_err_t = struct_apu_err_t# /usr/include/apr-util/apu_errno.h: 165

enum_anon_113 = c_int# /usr/include/apr-util/apr_crypto.h: 113

APR_KEY_NONE = 0# /usr/include/apr-util/apr_crypto.h: 113

APR_KEY_3DES_192 = (APR_KEY_NONE + 1)# /usr/include/apr-util/apr_crypto.h: 113

APR_KEY_AES_128 = (APR_KEY_3DES_192 + 1)# /usr/include/apr-util/apr_crypto.h: 113

APR_KEY_AES_192 = (APR_KEY_AES_128 + 1)# /usr/include/apr-util/apr_crypto.h: 113

APR_KEY_AES_256 = (APR_KEY_AES_192 + 1)# /usr/include/apr-util/apr_crypto.h: 113

apr_crypto_block_key_type_e = enum_anon_113# /usr/include/apr-util/apr_crypto.h: 113

enum_anon_114 = c_int# /usr/include/apr-util/apr_crypto.h: 121

APR_MODE_NONE = 0# /usr/include/apr-util/apr_crypto.h: 121

APR_MODE_ECB = (APR_MODE_NONE + 1)# /usr/include/apr-util/apr_crypto.h: 121

APR_MODE_CBC = (APR_MODE_ECB + 1)# /usr/include/apr-util/apr_crypto.h: 121

apr_crypto_block_key_mode_e = enum_anon_114# /usr/include/apr-util/apr_crypto.h: 121

# /usr/include/apr-util/apr_crypto.h: 124
class struct_apr_crypto_driver_t(Structure):
    pass

apr_crypto_driver_t = struct_apr_crypto_driver_t# /usr/include/apr-util/apr_crypto.h: 124

# /usr/include/apr-util/apr_crypto.h: 125
class struct_apr_crypto_t(Structure):
    pass

apr_crypto_t = struct_apr_crypto_t# /usr/include/apr-util/apr_crypto.h: 125

# /usr/include/apr-util/apr_crypto.h: 126
class struct_apr_crypto_config_t(Structure):
    pass

apr_crypto_config_t = struct_apr_crypto_config_t# /usr/include/apr-util/apr_crypto.h: 126

# /usr/include/apr-util/apr_crypto.h: 127
class struct_apr_crypto_key_t(Structure):
    pass

apr_crypto_key_t = struct_apr_crypto_key_t# /usr/include/apr-util/apr_crypto.h: 127

# /usr/include/apr-util/apr_crypto.h: 128
class struct_apr_crypto_block_t(Structure):
    pass

apr_crypto_block_t = struct_apr_crypto_block_t# /usr/include/apr-util/apr_crypto.h: 128

# /usr/include/apr-util/apr_crypto.h: 135
class struct_apr_crypto_block_key_type_t(Structure):
    pass

struct_apr_crypto_block_key_type_t.__slots__ = [
    'type',
    'keysize',
    'blocksize',
    'ivsize',
]
struct_apr_crypto_block_key_type_t._fields_ = [
    ('type', apr_crypto_block_key_type_e),
    ('keysize', c_int),
    ('blocksize', c_int),
    ('ivsize', c_int),
]

apr_crypto_block_key_type_t = struct_apr_crypto_block_key_type_t# /usr/include/apr-util/apr_crypto.h: 135

# /usr/include/apr-util/apr_crypto.h: 139
class struct_apr_crypto_block_key_mode_t(Structure):
    pass

struct_apr_crypto_block_key_mode_t.__slots__ = [
    'mode',
]
struct_apr_crypto_block_key_mode_t._fields_ = [
    ('mode', apr_crypto_block_key_mode_e),
]

apr_crypto_block_key_mode_t = struct_apr_crypto_block_key_mode_t# /usr/include/apr-util/apr_crypto.h: 139

# /usr/include/apr-util/apr_crypto.h: 147
class struct_apr_crypto_passphrase_t(Structure):
    pass

struct_apr_crypto_passphrase_t.__slots__ = [
    'pass',
    'passLen',
    'salt',
    'saltLen',
    'iterations',
]
struct_apr_crypto_passphrase_t._fields_ = [
    ('pass', String),
    ('passLen', apr_size_t),
    ('salt', POINTER(c_ubyte)),
    ('saltLen', apr_size_t),
    ('iterations', c_int),
]

apr_crypto_passphrase_t = struct_apr_crypto_passphrase_t# /usr/include/apr-util/apr_crypto.h: 147

# /usr/include/apr-util/apr_crypto.h: 152
class struct_apr_crypto_secret_t(Structure):
    pass

struct_apr_crypto_secret_t.__slots__ = [
    'secret',
    'secretLen',
]
struct_apr_crypto_secret_t._fields_ = [
    ('secret', POINTER(c_ubyte)),
    ('secretLen', apr_size_t),
]

apr_crypto_secret_t = struct_apr_crypto_secret_t# /usr/include/apr-util/apr_crypto.h: 152

enum_anon_115 = c_int# /usr/include/apr-util/apr_crypto.h: 159

APR_CRYPTO_KTYPE_PASSPHRASE = 1# /usr/include/apr-util/apr_crypto.h: 159

APR_CRYPTO_KTYPE_SECRET = 2# /usr/include/apr-util/apr_crypto.h: 159

apr_crypto_key_type = enum_anon_115# /usr/include/apr-util/apr_crypto.h: 159

# /usr/include/apr-util/apr_crypto.h: 166
class union_anon_116(Union):
    pass

union_anon_116.__slots__ = [
    'passphrase',
    'secret',
]
union_anon_116._fields_ = [
    ('passphrase', apr_crypto_passphrase_t),
    ('secret', apr_crypto_secret_t),
]

# /usr/include/apr-util/apr_crypto.h: 170
class struct_apr_crypto_key_rec_t(Structure):
    pass

struct_apr_crypto_key_rec_t.__slots__ = [
    'ktype',
    'type',
    'mode',
    'pad',
    'k',
]
struct_apr_crypto_key_rec_t._fields_ = [
    ('ktype', apr_crypto_key_type),
    ('type', apr_crypto_block_key_type_e),
    ('mode', apr_crypto_block_key_mode_e),
    ('pad', c_int),
    ('k', union_anon_116),
]

apr_crypto_key_rec_t = struct_apr_crypto_key_rec_t# /usr/include/apr-util/apr_crypto.h: 170

# /usr/include/apr-util/apr_crypto.h: 178
if _libs["aprutil-1"].has("apr_crypto_init", "cdecl"):
    apr_crypto_init = _libs["aprutil-1"].get("apr_crypto_init", "cdecl")
    apr_crypto_init.argtypes = [POINTER(apr_pool_t)]
    apr_crypto_init.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 187
if _libs["aprutil-1"].has("apr_crypto_clear", "cdecl"):
    apr_crypto_clear = _libs["aprutil-1"].get("apr_crypto_clear", "cdecl")
    apr_crypto_clear.argtypes = [POINTER(apr_pool_t), POINTER(None), apr_size_t]
    apr_crypto_clear.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 197
if _libs["aprutil-1"].has("apr_crypto_memzero", "cdecl"):
    apr_crypto_memzero = _libs["aprutil-1"].get("apr_crypto_memzero", "cdecl")
    apr_crypto_memzero.argtypes = [POINTER(None), apr_size_t]
    apr_crypto_memzero.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 208
if _libs["aprutil-1"].has("apr_crypto_equals", "cdecl"):
    apr_crypto_equals = _libs["aprutil-1"].get("apr_crypto_equals", "cdecl")
    apr_crypto_equals.argtypes = [POINTER(None), POINTER(None), apr_size_t]
    apr_crypto_equals.restype = c_int

# /usr/include/apr-util/apr_crypto.h: 229
if _libs["aprutil-1"].has("apr_crypto_get_driver", "cdecl"):
    apr_crypto_get_driver = _libs["aprutil-1"].get("apr_crypto_get_driver", "cdecl")
    apr_crypto_get_driver.argtypes = [POINTER(POINTER(apr_crypto_driver_t)), String, String, POINTER(POINTER(apu_err_t)), POINTER(apr_pool_t)]
    apr_crypto_get_driver.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 240
if _libs["aprutil-1"].has("apr_crypto_driver_name", "cdecl"):
    apr_crypto_driver_name = _libs["aprutil-1"].get("apr_crypto_driver_name", "cdecl")
    apr_crypto_driver_name.argtypes = [POINTER(apr_crypto_driver_t)]
    apr_crypto_driver_name.restype = c_char_p

# /usr/include/apr-util/apr_crypto.h: 250
if _libs["aprutil-1"].has("apr_crypto_error", "cdecl"):
    apr_crypto_error = _libs["aprutil-1"].get("apr_crypto_error", "cdecl")
    apr_crypto_error.argtypes = [POINTER(POINTER(apu_err_t)), POINTER(apr_crypto_t)]
    apr_crypto_error.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 268
if _libs["aprutil-1"].has("apr_crypto_make", "cdecl"):
    apr_crypto_make = _libs["aprutil-1"].get("apr_crypto_make", "cdecl")
    apr_crypto_make.argtypes = [POINTER(POINTER(apr_crypto_t)), POINTER(apr_crypto_driver_t), String, POINTER(apr_pool_t)]
    apr_crypto_make.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 281
if _libs["aprutil-1"].has("apr_crypto_get_block_key_types", "cdecl"):
    apr_crypto_get_block_key_types = _libs["aprutil-1"].get("apr_crypto_get_block_key_types", "cdecl")
    apr_crypto_get_block_key_types.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(apr_crypto_t)]
    apr_crypto_get_block_key_types.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 293
if _libs["aprutil-1"].has("apr_crypto_get_block_key_modes", "cdecl"):
    apr_crypto_get_block_key_modes = _libs["aprutil-1"].get("apr_crypto_get_block_key_modes", "cdecl")
    apr_crypto_get_block_key_modes.argtypes = [POINTER(POINTER(apr_hash_t)), POINTER(apr_crypto_t)]
    apr_crypto_get_block_key_modes.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 312
if _libs["aprutil-1"].has("apr_crypto_key", "cdecl"):
    apr_crypto_key = _libs["aprutil-1"].get("apr_crypto_key", "cdecl")
    apr_crypto_key.argtypes = [POINTER(POINTER(apr_crypto_key_t)), POINTER(apr_crypto_key_rec_t), POINTER(apr_crypto_t), POINTER(apr_pool_t)]
    apr_crypto_key.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 344
if _libs["aprutil-1"].has("apr_crypto_passphrase", "cdecl"):
    apr_crypto_passphrase = _libs["aprutil-1"].get("apr_crypto_passphrase", "cdecl")
    apr_crypto_passphrase.argtypes = [POINTER(POINTER(apr_crypto_key_t)), POINTER(apr_size_t), String, apr_size_t, POINTER(c_ubyte), apr_size_t, apr_crypto_block_key_type_e, apr_crypto_block_key_mode_e, c_int, c_int, POINTER(apr_crypto_t), POINTER(apr_pool_t)]
    apr_crypto_passphrase.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 367
if _libs["aprutil-1"].has("apr_crypto_block_encrypt_init", "cdecl"):
    apr_crypto_block_encrypt_init = _libs["aprutil-1"].get("apr_crypto_block_encrypt_init", "cdecl")
    apr_crypto_block_encrypt_init.argtypes = [POINTER(POINTER(apr_crypto_block_t)), POINTER(POINTER(c_ubyte)), POINTER(apr_crypto_key_t), POINTER(apr_size_t), POINTER(apr_pool_t)]
    apr_crypto_block_encrypt_init.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 389
if _libs["aprutil-1"].has("apr_crypto_block_encrypt", "cdecl"):
    apr_crypto_block_encrypt = _libs["aprutil-1"].get("apr_crypto_block_encrypt", "cdecl")
    apr_crypto_block_encrypt.argtypes = [POINTER(POINTER(c_ubyte)), POINTER(apr_size_t), POINTER(c_ubyte), apr_size_t, POINTER(apr_crypto_block_t)]
    apr_crypto_block_encrypt.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 411
if _libs["aprutil-1"].has("apr_crypto_block_encrypt_finish", "cdecl"):
    apr_crypto_block_encrypt_finish = _libs["aprutil-1"].get("apr_crypto_block_encrypt_finish", "cdecl")
    apr_crypto_block_encrypt_finish.argtypes = [POINTER(c_ubyte), POINTER(apr_size_t), POINTER(apr_crypto_block_t)]
    apr_crypto_block_encrypt_finish.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 427
if _libs["aprutil-1"].has("apr_crypto_block_decrypt_init", "cdecl"):
    apr_crypto_block_decrypt_init = _libs["aprutil-1"].get("apr_crypto_block_decrypt_init", "cdecl")
    apr_crypto_block_decrypt_init.argtypes = [POINTER(POINTER(apr_crypto_block_t)), POINTER(apr_size_t), POINTER(c_ubyte), POINTER(apr_crypto_key_t), POINTER(apr_pool_t)]
    apr_crypto_block_decrypt_init.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 449
if _libs["aprutil-1"].has("apr_crypto_block_decrypt", "cdecl"):
    apr_crypto_block_decrypt = _libs["aprutil-1"].get("apr_crypto_block_decrypt", "cdecl")
    apr_crypto_block_decrypt.argtypes = [POINTER(POINTER(c_ubyte)), POINTER(apr_size_t), POINTER(c_ubyte), apr_size_t, POINTER(apr_crypto_block_t)]
    apr_crypto_block_decrypt.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 471
if _libs["aprutil-1"].has("apr_crypto_block_decrypt_finish", "cdecl"):
    apr_crypto_block_decrypt_finish = _libs["aprutil-1"].get("apr_crypto_block_decrypt_finish", "cdecl")
    apr_crypto_block_decrypt_finish.argtypes = [POINTER(c_ubyte), POINTER(apr_size_t), POINTER(apr_crypto_block_t)]
    apr_crypto_block_decrypt_finish.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 480
if _libs["aprutil-1"].has("apr_crypto_block_cleanup", "cdecl"):
    apr_crypto_block_cleanup = _libs["aprutil-1"].get("apr_crypto_block_cleanup", "cdecl")
    apr_crypto_block_cleanup.argtypes = [POINTER(apr_crypto_block_t)]
    apr_crypto_block_cleanup.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 488
if _libs["aprutil-1"].has("apr_crypto_cleanup", "cdecl"):
    apr_crypto_cleanup = _libs["aprutil-1"].get("apr_crypto_cleanup", "cdecl")
    apr_crypto_cleanup.argtypes = [POINTER(apr_crypto_t)]
    apr_crypto_cleanup.restype = apr_status_t

# /usr/include/apr-util/apr_crypto.h: 496
if _libs["aprutil-1"].has("apr_crypto_shutdown", "cdecl"):
    apr_crypto_shutdown = _libs["aprutil-1"].get("apr_crypto_shutdown", "cdecl")
    apr_crypto_shutdown.argtypes = [POINTER(apr_crypto_driver_t)]
    apr_crypto_shutdown.restype = apr_status_t

# /usr/include/apr-util/apr_date.h: 60
if _libs["aprutil-1"].has("apr_date_checkmask", "cdecl"):
    apr_date_checkmask = _libs["aprutil-1"].get("apr_date_checkmask", "cdecl")
    apr_date_checkmask.argtypes = [String, String]
    apr_date_checkmask.restype = c_int

# /usr/include/apr-util/apr_date.h: 73
if _libs["aprutil-1"].has("apr_date_parse_http", "cdecl"):
    apr_date_parse_http = _libs["aprutil-1"].get("apr_date_parse_http", "cdecl")
    apr_date_parse_http.argtypes = [String]
    apr_date_parse_http.restype = apr_time_t

# /usr/include/apr-util/apr_date.h: 99
if _libs["aprutil-1"].has("apr_date_parse_rfc", "cdecl"):
    apr_date_parse_rfc = _libs["aprutil-1"].get("apr_date_parse_rfc", "cdecl")
    apr_date_parse_rfc.argtypes = [String]
    apr_date_parse_rfc.restype = apr_time_t

enum_anon_117 = c_int# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_NONE = 0# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_TINY = (APR_DBD_TYPE_NONE + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_UTINY = (APR_DBD_TYPE_TINY + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_SHORT = (APR_DBD_TYPE_UTINY + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_USHORT = (APR_DBD_TYPE_SHORT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_INT = (APR_DBD_TYPE_USHORT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_UINT = (APR_DBD_TYPE_INT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_LONG = (APR_DBD_TYPE_UINT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_ULONG = (APR_DBD_TYPE_LONG + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_LONGLONG = (APR_DBD_TYPE_ULONG + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_ULONGLONG = (APR_DBD_TYPE_LONGLONG + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_FLOAT = (APR_DBD_TYPE_ULONGLONG + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_DOUBLE = (APR_DBD_TYPE_FLOAT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_STRING = (APR_DBD_TYPE_DOUBLE + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_TEXT = (APR_DBD_TYPE_STRING + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_TIME = (APR_DBD_TYPE_TEXT + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_DATE = (APR_DBD_TYPE_TIME + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_DATETIME = (APR_DBD_TYPE_DATE + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_TIMESTAMP = (APR_DBD_TYPE_DATETIME + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_ZTIMESTAMP = (APR_DBD_TYPE_TIMESTAMP + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_BLOB = (APR_DBD_TYPE_ZTIMESTAMP + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_CLOB = (APR_DBD_TYPE_BLOB + 1)# /usr/include/apr-util/apr_dbd.h: 79

APR_DBD_TYPE_NULL = (APR_DBD_TYPE_CLOB + 1)# /usr/include/apr-util/apr_dbd.h: 79

apr_dbd_type_e = enum_anon_117# /usr/include/apr-util/apr_dbd.h: 79

# /usr/include/apr-util/apr_dbd.h: 82
class struct_apr_dbd_driver_t(Structure):
    pass

apr_dbd_driver_t = struct_apr_dbd_driver_t# /usr/include/apr-util/apr_dbd.h: 82

# /usr/include/apr-util/apr_dbd.h: 83
class struct_apr_dbd_t(Structure):
    pass

apr_dbd_t = struct_apr_dbd_t# /usr/include/apr-util/apr_dbd.h: 83

# /usr/include/apr-util/apr_dbd.h: 84
class struct_apr_dbd_transaction_t(Structure):
    pass

apr_dbd_transaction_t = struct_apr_dbd_transaction_t# /usr/include/apr-util/apr_dbd.h: 84

# /usr/include/apr-util/apr_dbd.h: 85
class struct_apr_dbd_results_t(Structure):
    pass

apr_dbd_results_t = struct_apr_dbd_results_t# /usr/include/apr-util/apr_dbd.h: 85

# /usr/include/apr-util/apr_dbd.h: 86
class struct_apr_dbd_row_t(Structure):
    pass

apr_dbd_row_t = struct_apr_dbd_row_t# /usr/include/apr-util/apr_dbd.h: 86

# /usr/include/apr-util/apr_dbd.h: 87
class struct_apr_dbd_prepared_t(Structure):
    pass

apr_dbd_prepared_t = struct_apr_dbd_prepared_t# /usr/include/apr-util/apr_dbd.h: 87

# /usr/include/apr-util/apr_dbd.h: 93
if _libs["aprutil-1"].has("apr_dbd_init", "cdecl"):
    apr_dbd_init = _libs["aprutil-1"].get("apr_dbd_init", "cdecl")
    apr_dbd_init.argtypes = [POINTER(apr_pool_t)]
    apr_dbd_init.restype = apr_status_t

# /usr/include/apr-util/apr_dbd.h: 105
if _libs["aprutil-1"].has("apr_dbd_get_driver", "cdecl"):
    apr_dbd_get_driver = _libs["aprutil-1"].get("apr_dbd_get_driver", "cdecl")
    apr_dbd_get_driver.argtypes = [POINTER(apr_pool_t), String, POINTER(POINTER(apr_dbd_driver_t))]
    apr_dbd_get_driver.restype = apr_status_t

# /usr/include/apr-util/apr_dbd.h: 140
if _libs["aprutil-1"].has("apr_dbd_open_ex", "cdecl"):
    apr_dbd_open_ex = _libs["aprutil-1"].get("apr_dbd_open_ex", "cdecl")
    apr_dbd_open_ex.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), String, POINTER(POINTER(apr_dbd_t)), POINTER(POINTER(c_char))]
    apr_dbd_open_ex.restype = apr_status_t

# /usr/include/apr-util/apr_dbd.h: 155
if _libs["aprutil-1"].has("apr_dbd_open", "cdecl"):
    apr_dbd_open = _libs["aprutil-1"].get("apr_dbd_open", "cdecl")
    apr_dbd_open.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), String, POINTER(POINTER(apr_dbd_t))]
    apr_dbd_open.restype = apr_status_t

# /usr/include/apr-util/apr_dbd.h: 165
if _libs["aprutil-1"].has("apr_dbd_close", "cdecl"):
    apr_dbd_close = _libs["aprutil-1"].get("apr_dbd_close", "cdecl")
    apr_dbd_close.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_t)]
    apr_dbd_close.restype = apr_status_t

# /usr/include/apr-util/apr_dbd.h: 175
if _libs["aprutil-1"].has("apr_dbd_name", "cdecl"):
    apr_dbd_name = _libs["aprutil-1"].get("apr_dbd_name", "cdecl")
    apr_dbd_name.argtypes = [POINTER(apr_dbd_driver_t)]
    apr_dbd_name.restype = c_char_p

# /usr/include/apr-util/apr_dbd.h: 183
if _libs["aprutil-1"].has("apr_dbd_native_handle", "cdecl"):
    apr_dbd_native_handle = _libs["aprutil-1"].get("apr_dbd_native_handle", "cdecl")
    apr_dbd_native_handle.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_t)]
    apr_dbd_native_handle.restype = POINTER(c_ubyte)
    apr_dbd_native_handle.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr-util/apr_dbd.h: 193
if _libs["aprutil-1"].has("apr_dbd_check_conn", "cdecl"):
    apr_dbd_check_conn = _libs["aprutil-1"].get("apr_dbd_check_conn", "cdecl")
    apr_dbd_check_conn.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t)]
    apr_dbd_check_conn.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 204
if _libs["aprutil-1"].has("apr_dbd_set_dbname", "cdecl"):
    apr_dbd_set_dbname = _libs["aprutil-1"].get("apr_dbd_set_dbname", "cdecl")
    apr_dbd_set_dbname.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), String]
    apr_dbd_set_dbname.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 221
if _libs["aprutil-1"].has("apr_dbd_transaction_start", "cdecl"):
    apr_dbd_transaction_start = _libs["aprutil-1"].get("apr_dbd_transaction_start", "cdecl")
    apr_dbd_transaction_start.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_transaction_t))]
    apr_dbd_transaction_start.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 235
if _libs["aprutil-1"].has("apr_dbd_transaction_end", "cdecl"):
    apr_dbd_transaction_end = _libs["aprutil-1"].get("apr_dbd_transaction_end", "cdecl")
    apr_dbd_transaction_end.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_transaction_t)]
    apr_dbd_transaction_end.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 249
if _libs["aprutil-1"].has("apr_dbd_transaction_mode_get", "cdecl"):
    apr_dbd_transaction_mode_get = _libs["aprutil-1"].get("apr_dbd_transaction_mode_get", "cdecl")
    apr_dbd_transaction_mode_get.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_transaction_t)]
    apr_dbd_transaction_mode_get.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 259
if _libs["aprutil-1"].has("apr_dbd_transaction_mode_set", "cdecl"):
    apr_dbd_transaction_mode_set = _libs["aprutil-1"].get("apr_dbd_transaction_mode_set", "cdecl")
    apr_dbd_transaction_mode_set.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_transaction_t), c_int]
    apr_dbd_transaction_mode_set.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 271
if _libs["aprutil-1"].has("apr_dbd_query", "cdecl"):
    apr_dbd_query = _libs["aprutil-1"].get("apr_dbd_query", "cdecl")
    apr_dbd_query.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_t), POINTER(c_int), String]
    apr_dbd_query.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 286
if _libs["aprutil-1"].has("apr_dbd_select", "cdecl"):
    apr_dbd_select = _libs["aprutil-1"].get("apr_dbd_select", "cdecl")
    apr_dbd_select.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_results_t)), String, c_int]
    apr_dbd_select.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 296
if _libs["aprutil-1"].has("apr_dbd_num_cols", "cdecl"):
    apr_dbd_num_cols = _libs["aprutil-1"].get("apr_dbd_num_cols", "cdecl")
    apr_dbd_num_cols.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_results_t)]
    apr_dbd_num_cols.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 306
if _libs["aprutil-1"].has("apr_dbd_num_tuples", "cdecl"):
    apr_dbd_num_tuples = _libs["aprutil-1"].get("apr_dbd_num_tuples", "cdecl")
    apr_dbd_num_tuples.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_results_t)]
    apr_dbd_num_tuples.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 319
if _libs["aprutil-1"].has("apr_dbd_get_row", "cdecl"):
    apr_dbd_get_row = _libs["aprutil-1"].get("apr_dbd_get_row", "cdecl")
    apr_dbd_get_row.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_results_t), POINTER(POINTER(apr_dbd_row_t)), c_int]
    apr_dbd_get_row.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 330
if _libs["aprutil-1"].has("apr_dbd_get_entry", "cdecl"):
    apr_dbd_get_entry = _libs["aprutil-1"].get("apr_dbd_get_entry", "cdecl")
    apr_dbd_get_entry.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_row_t), c_int]
    apr_dbd_get_entry.restype = c_char_p

# /usr/include/apr-util/apr_dbd.h: 340
if _libs["aprutil-1"].has("apr_dbd_get_name", "cdecl"):
    apr_dbd_get_name = _libs["aprutil-1"].get("apr_dbd_get_name", "cdecl")
    apr_dbd_get_name.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_results_t), c_int]
    apr_dbd_get_name.restype = c_char_p

# /usr/include/apr-util/apr_dbd.h: 352
if _libs["aprutil-1"].has("apr_dbd_error", "cdecl"):
    apr_dbd_error = _libs["aprutil-1"].get("apr_dbd_error", "cdecl")
    apr_dbd_error.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_t), c_int]
    apr_dbd_error.restype = c_char_p

# /usr/include/apr-util/apr_dbd.h: 363
if _libs["aprutil-1"].has("apr_dbd_escape", "cdecl"):
    apr_dbd_escape = _libs["aprutil-1"].get("apr_dbd_escape", "cdecl")
    apr_dbd_escape.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), String, POINTER(apr_dbd_t)]
    apr_dbd_escape.restype = c_char_p

# /usr/include/apr-util/apr_dbd.h: 395
if _libs["aprutil-1"].has("apr_dbd_prepare", "cdecl"):
    apr_dbd_prepare = _libs["aprutil-1"].get("apr_dbd_prepare", "cdecl")
    apr_dbd_prepare.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), String, String, POINTER(POINTER(apr_dbd_prepared_t))]
    apr_dbd_prepare.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 412
if _libs["aprutil-1"].has("apr_dbd_pquery", "cdecl"):
    apr_dbd_pquery = _libs["aprutil-1"].get("apr_dbd_pquery", "cdecl")
    apr_dbd_pquery.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(c_int), POINTER(apr_dbd_prepared_t), c_int, POINTER(POINTER(c_char))]
    apr_dbd_pquery.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 429
if _libs["aprutil-1"].has("apr_dbd_pselect", "cdecl"):
    apr_dbd_pselect = _libs["aprutil-1"].get("apr_dbd_pselect", "cdecl")
    apr_dbd_pselect.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_results_t)), POINTER(apr_dbd_prepared_t), c_int, c_int, POINTER(POINTER(c_char))]
    apr_dbd_pselect.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 444
if _libs["aprutil-1"].has("apr_dbd_pvquery", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_dbd_pvquery", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(c_int), POINTER(apr_dbd_prepared_t)]
    apr_dbd_pvquery = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_dbd.h: 460
if _libs["aprutil-1"].has("apr_dbd_pvselect", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_dbd_pvselect", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_results_t)), POINTER(apr_dbd_prepared_t), c_int]
    apr_dbd_pvselect = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_dbd.h: 476
if _libs["aprutil-1"].has("apr_dbd_pbquery", "cdecl"):
    apr_dbd_pbquery = _libs["aprutil-1"].get("apr_dbd_pbquery", "cdecl")
    apr_dbd_pbquery.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(c_int), POINTER(apr_dbd_prepared_t), POINTER(POINTER(None))]
    apr_dbd_pbquery.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 492
if _libs["aprutil-1"].has("apr_dbd_pbselect", "cdecl"):
    apr_dbd_pbselect = _libs["aprutil-1"].get("apr_dbd_pbselect", "cdecl")
    apr_dbd_pbselect.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_results_t)), POINTER(apr_dbd_prepared_t), c_int, POINTER(POINTER(None))]
    apr_dbd_pbselect.restype = c_int

# /usr/include/apr-util/apr_dbd.h: 508
if _libs["aprutil-1"].has("apr_dbd_pvbquery", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_dbd_pvbquery", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(c_int), POINTER(apr_dbd_prepared_t)]
    apr_dbd_pvbquery = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_dbd.h: 524
if _libs["aprutil-1"].has("apr_dbd_pvbselect", "cdecl"):
    _func = _libs["aprutil-1"].get("apr_dbd_pvbselect", "cdecl")
    _restype = c_int
    _errcheck = None
    _argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_pool_t), POINTER(apr_dbd_t), POINTER(POINTER(apr_dbd_results_t)), POINTER(apr_dbd_prepared_t), c_int]
    apr_dbd_pvbselect = _variadic_function(_func,_restype,_argtypes,_errcheck)

# /usr/include/apr-util/apr_dbd.h: 539
if _libs["aprutil-1"].has("apr_dbd_datum_get", "cdecl"):
    apr_dbd_datum_get = _libs["aprutil-1"].get("apr_dbd_datum_get", "cdecl")
    apr_dbd_datum_get.argtypes = [POINTER(apr_dbd_driver_t), POINTER(apr_dbd_row_t), c_int, apr_dbd_type_e, POINTER(None)]
    apr_dbd_datum_get.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 42
class struct_apr_dbm_t(Structure):
    pass

apr_dbm_t = struct_apr_dbm_t# /usr/include/apr-util/apr_dbm.h: 42

# /usr/include/apr-util/apr_dbm.h: 53
class struct_anon_118(Structure):
    pass

struct_anon_118.__slots__ = [
    'dptr',
    'dsize',
]
struct_anon_118._fields_ = [
    ('dptr', String),
    ('dsize', apr_size_t),
]

apr_datum_t = struct_anon_118# /usr/include/apr-util/apr_dbm.h: 53

# /usr/include/apr-util/apr_dbm.h: 89
if _libs["aprutil-1"].has("apr_dbm_open_ex", "cdecl"):
    apr_dbm_open_ex = _libs["aprutil-1"].get("apr_dbm_open_ex", "cdecl")
    apr_dbm_open_ex.argtypes = [POINTER(POINTER(apr_dbm_t)), String, String, apr_int32_t, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_dbm_open_ex.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 111
if _libs["aprutil-1"].has("apr_dbm_open", "cdecl"):
    apr_dbm_open = _libs["aprutil-1"].get("apr_dbm_open", "cdecl")
    apr_dbm_open.argtypes = [POINTER(POINTER(apr_dbm_t)), String, apr_int32_t, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_dbm_open.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 119
if _libs["aprutil-1"].has("apr_dbm_close", "cdecl"):
    apr_dbm_close = _libs["aprutil-1"].get("apr_dbm_close", "cdecl")
    apr_dbm_close.argtypes = [POINTER(apr_dbm_t)]
    apr_dbm_close.restype = None

# /usr/include/apr-util/apr_dbm.h: 127
if _libs["aprutil-1"].has("apr_dbm_fetch", "cdecl"):
    apr_dbm_fetch = _libs["aprutil-1"].get("apr_dbm_fetch", "cdecl")
    apr_dbm_fetch.argtypes = [POINTER(apr_dbm_t), apr_datum_t, POINTER(apr_datum_t)]
    apr_dbm_fetch.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 135
if _libs["aprutil-1"].has("apr_dbm_store", "cdecl"):
    apr_dbm_store = _libs["aprutil-1"].get("apr_dbm_store", "cdecl")
    apr_dbm_store.argtypes = [POINTER(apr_dbm_t), apr_datum_t, apr_datum_t]
    apr_dbm_store.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 144
if _libs["aprutil-1"].has("apr_dbm_delete", "cdecl"):
    apr_dbm_delete = _libs["aprutil-1"].get("apr_dbm_delete", "cdecl")
    apr_dbm_delete.argtypes = [POINTER(apr_dbm_t), apr_datum_t]
    apr_dbm_delete.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 151
if _libs["aprutil-1"].has("apr_dbm_exists", "cdecl"):
    apr_dbm_exists = _libs["aprutil-1"].get("apr_dbm_exists", "cdecl")
    apr_dbm_exists.argtypes = [POINTER(apr_dbm_t), apr_datum_t]
    apr_dbm_exists.restype = c_int

# /usr/include/apr-util/apr_dbm.h: 158
if _libs["aprutil-1"].has("apr_dbm_firstkey", "cdecl"):
    apr_dbm_firstkey = _libs["aprutil-1"].get("apr_dbm_firstkey", "cdecl")
    apr_dbm_firstkey.argtypes = [POINTER(apr_dbm_t), POINTER(apr_datum_t)]
    apr_dbm_firstkey.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 165
if _libs["aprutil-1"].has("apr_dbm_nextkey", "cdecl"):
    apr_dbm_nextkey = _libs["aprutil-1"].get("apr_dbm_nextkey", "cdecl")
    apr_dbm_nextkey.argtypes = [POINTER(apr_dbm_t), POINTER(apr_datum_t)]
    apr_dbm_nextkey.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 172
if _libs["aprutil-1"].has("apr_dbm_freedatum", "cdecl"):
    apr_dbm_freedatum = _libs["aprutil-1"].get("apr_dbm_freedatum", "cdecl")
    apr_dbm_freedatum.argtypes = [POINTER(apr_dbm_t), apr_datum_t]
    apr_dbm_freedatum.restype = None

# /usr/include/apr-util/apr_dbm.h: 183
if _libs["aprutil-1"].has("apr_dbm_geterror", "cdecl"):
    apr_dbm_geterror = _libs["aprutil-1"].get("apr_dbm_geterror", "cdecl")
    apr_dbm_geterror.argtypes = [POINTER(apr_dbm_t), POINTER(c_int), String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_dbm_geterror.restype = ReturnString
    else:
        apr_dbm_geterror.restype = String
        apr_dbm_geterror.errcheck = ReturnString

# /usr/include/apr-util/apr_dbm.h: 199
if _libs["aprutil-1"].has("apr_dbm_get_usednames_ex", "cdecl"):
    apr_dbm_get_usednames_ex = _libs["aprutil-1"].get("apr_dbm_get_usednames_ex", "cdecl")
    apr_dbm_get_usednames_ex.argtypes = [POINTER(apr_pool_t), String, String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char))]
    apr_dbm_get_usednames_ex.restype = apr_status_t

# /usr/include/apr-util/apr_dbm.h: 217
if _libs["aprutil-1"].has("apr_dbm_get_usednames", "cdecl"):
    apr_dbm_get_usednames = _libs["aprutil-1"].get("apr_dbm_get_usednames", "cdecl")
    apr_dbm_get_usednames.argtypes = [POINTER(apr_pool_t), String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char))]
    apr_dbm_get_usednames.restype = None

# /usr/include/apr-util/apr_hooks.h: 312
try:
    apr_hook_global_pool = (POINTER(apr_pool_t)).in_dll(_libs["aprutil-1"], "apr_hook_global_pool")
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 318
try:
    apr_hook_debug_enabled = (c_int).in_dll(_libs["aprutil-1"], "apr_hook_debug_enabled")
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 323
try:
    apr_hook_debug_current = (String).in_dll(_libs["aprutil-1"], "apr_hook_debug_current")
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 330
if _libs["aprutil-1"].has("apr_hook_sort_register", "cdecl"):
    apr_hook_sort_register = _libs["aprutil-1"].get("apr_hook_sort_register", "cdecl")
    apr_hook_sort_register.argtypes = [String, POINTER(POINTER(apr_array_header_t))]
    apr_hook_sort_register.restype = None

# /usr/include/apr-util/apr_hooks.h: 335
if _libs["aprutil-1"].has("apr_hook_sort_all", "cdecl"):
    apr_hook_sort_all = _libs["aprutil-1"].get("apr_hook_sort_all", "cdecl")
    apr_hook_sort_all.argtypes = []
    apr_hook_sort_all.restype = None

# /usr/include/apr-util/apr_hooks.h: 344
if _libs["aprutil-1"].has("apr_hook_debug_show", "cdecl"):
    apr_hook_debug_show = _libs["aprutil-1"].get("apr_hook_debug_show", "cdecl")
    apr_hook_debug_show.argtypes = [String, POINTER(POINTER(c_char)), POINTER(POINTER(c_char))]
    apr_hook_debug_show.restype = None

# /usr/include/apr-util/apr_hooks.h: 351
if _libs["aprutil-1"].has("apr_hook_deregister_all", "cdecl"):
    apr_hook_deregister_all = _libs["aprutil-1"].get("apr_hook_deregister_all", "cdecl")
    apr_hook_deregister_all.argtypes = []
    apr_hook_deregister_all.restype = None

# /usr/include/ldap.h: 759
class struct_ldap(Structure):
    pass

LDAP = struct_ldap# /usr/include/ldap.h: 759

# /usr/include/apr-util/apr_ldap.h: 152
class struct_apr_ldap_err_t(Structure):
    pass

struct_apr_ldap_err_t.__slots__ = [
    'reason',
    'msg',
    'rc',
]
struct_apr_ldap_err_t._fields_ = [
    ('reason', String),
    ('msg', String),
    ('rc', c_int),
]

apr_ldap_err_t = struct_apr_ldap_err_t# /usr/include/apr-util/apr_ldap.h: 152

# /usr/include/apr-util/apr_ldap_url.h: 43
class struct_apr_ldap_url_desc_t(Structure):
    pass

struct_apr_ldap_url_desc_t.__slots__ = [
    'lud_next',
    'lud_scheme',
    'lud_host',
    'lud_port',
    'lud_dn',
    'lud_attrs',
    'lud_scope',
    'lud_filter',
    'lud_exts',
    'lud_crit_exts',
]
struct_apr_ldap_url_desc_t._fields_ = [
    ('lud_next', POINTER(struct_apr_ldap_url_desc_t)),
    ('lud_scheme', String),
    ('lud_host', String),
    ('lud_port', c_int),
    ('lud_dn', String),
    ('lud_attrs', POINTER(POINTER(c_char))),
    ('lud_scope', c_int),
    ('lud_filter', String),
    ('lud_exts', POINTER(POINTER(c_char))),
    ('lud_crit_exts', c_int),
]

apr_ldap_url_desc_t = struct_apr_ldap_url_desc_t# /usr/include/apr-util/apr_ldap_url.h: 54

# /usr/include/apr-util/apr_ldap_url.h: 74
if _libs["aprutil-1"].has("apr_ldap_is_ldap_url", "cdecl"):
    apr_ldap_is_ldap_url = _libs["aprutil-1"].get("apr_ldap_is_ldap_url", "cdecl")
    apr_ldap_is_ldap_url.argtypes = [String]
    apr_ldap_is_ldap_url.restype = c_int

# /usr/include/apr-util/apr_ldap_url.h: 80
if _libs["aprutil-1"].has("apr_ldap_is_ldaps_url", "cdecl"):
    apr_ldap_is_ldaps_url = _libs["aprutil-1"].get("apr_ldap_is_ldaps_url", "cdecl")
    apr_ldap_is_ldaps_url.argtypes = [String]
    apr_ldap_is_ldaps_url.restype = c_int

# /usr/include/apr-util/apr_ldap_url.h: 86
if _libs["aprutil-1"].has("apr_ldap_is_ldapi_url", "cdecl"):
    apr_ldap_is_ldapi_url = _libs["aprutil-1"].get("apr_ldap_is_ldapi_url", "cdecl")
    apr_ldap_is_ldapi_url.argtypes = [String]
    apr_ldap_is_ldapi_url.restype = c_int

# /usr/include/apr-util/apr_ldap_url.h: 95
if _libs["aprutil-1"].has("apr_ldap_url_parse_ext", "cdecl"):
    apr_ldap_url_parse_ext = _libs["aprutil-1"].get("apr_ldap_url_parse_ext", "cdecl")
    apr_ldap_url_parse_ext.argtypes = [POINTER(apr_pool_t), String, POINTER(POINTER(apr_ldap_url_desc_t)), POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_url_parse_ext.restype = c_int

# /usr/include/apr-util/apr_ldap_url.h: 107
if _libs["aprutil-1"].has("apr_ldap_url_parse", "cdecl"):
    apr_ldap_url_parse = _libs["aprutil-1"].get("apr_ldap_url_parse", "cdecl")
    apr_ldap_url_parse.argtypes = [POINTER(apr_pool_t), String, POINTER(POINTER(apr_ldap_url_desc_t)), POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_url_parse.restype = c_int

# /usr/include/apr-util/apr_ldap_init.h: 89
if _libs["aprutil-1"].has("apr_ldap_ssl_init", "cdecl"):
    apr_ldap_ssl_init = _libs["aprutil-1"].get("apr_ldap_ssl_init", "cdecl")
    apr_ldap_ssl_init.argtypes = [POINTER(apr_pool_t), String, c_int, POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_ssl_init.restype = c_int

# /usr/include/apr-util/apr_ldap_init.h: 103
if _libs["aprutil-1"].has("apr_ldap_ssl_deinit", "cdecl"):
    apr_ldap_ssl_deinit = _libs["aprutil-1"].get("apr_ldap_ssl_deinit", "cdecl")
    apr_ldap_ssl_deinit.argtypes = []
    apr_ldap_ssl_deinit.restype = c_int

# /usr/include/apr-util/apr_ldap_init.h: 139
if _libs["aprutil-1"].has("apr_ldap_init", "cdecl"):
    apr_ldap_init = _libs["aprutil-1"].get("apr_ldap_init", "cdecl")
    apr_ldap_init.argtypes = [POINTER(apr_pool_t), POINTER(POINTER(LDAP)), String, c_int, c_int, POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_init.restype = c_int

# /usr/include/apr-util/apr_ldap_init.h: 154
if _libs["aprutil-1"].has("apr_ldap_info", "cdecl"):
    apr_ldap_info = _libs["aprutil-1"].get("apr_ldap_info", "cdecl")
    apr_ldap_info.argtypes = [POINTER(apr_pool_t), POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_info.restype = c_int

# /usr/include/apr-util/apr_ldap_option.h: 166
class struct_apr_ldap_opt_tls_cert_t(Structure):
    pass

apr_ldap_opt_tls_cert_t = struct_apr_ldap_opt_tls_cert_t# /usr/include/apr-util/apr_ldap_option.h: 165

struct_apr_ldap_opt_tls_cert_t.__slots__ = [
    'type',
    'path',
    'password',
]
struct_apr_ldap_opt_tls_cert_t._fields_ = [
    ('type', c_int),
    ('path', String),
    ('password', String),
]

# /usr/include/apr-util/apr_ldap_option.h: 217
if _libs["aprutil-1"].has("apr_ldap_get_option", "cdecl"):
    apr_ldap_get_option = _libs["aprutil-1"].get("apr_ldap_get_option", "cdecl")
    apr_ldap_get_option.argtypes = [POINTER(apr_pool_t), POINTER(LDAP), c_int, POINTER(None), POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_get_option.restype = c_int

# /usr/include/apr-util/apr_ldap_option.h: 239
if _libs["aprutil-1"].has("apr_ldap_set_option", "cdecl"):
    apr_ldap_set_option = _libs["aprutil-1"].get("apr_ldap_set_option", "cdecl")
    apr_ldap_set_option.argtypes = [POINTER(apr_pool_t), POINTER(LDAP), c_int, POINTER(None), POINTER(POINTER(apr_ldap_err_t))]
    apr_ldap_set_option.restype = c_int

# /usr/include/apr-util/apr_ldap_rebind.h: 51
if _libs["aprutil-1"].has("apr_ldap_rebind_init", "cdecl"):
    apr_ldap_rebind_init = _libs["aprutil-1"].get("apr_ldap_rebind_init", "cdecl")
    apr_ldap_rebind_init.argtypes = [POINTER(apr_pool_t)]
    apr_ldap_rebind_init.restype = apr_status_t

# /usr/include/apr-util/apr_ldap_rebind.h: 75
if _libs["aprutil-1"].has("apr_ldap_rebind_add", "cdecl"):
    apr_ldap_rebind_add = _libs["aprutil-1"].get("apr_ldap_rebind_add", "cdecl")
    apr_ldap_rebind_add.argtypes = [POINTER(apr_pool_t), POINTER(LDAP), String, String]
    apr_ldap_rebind_add.restype = apr_status_t

# /usr/include/apr-util/apr_ldap_rebind.h: 91
if _libs["aprutil-1"].has("apr_ldap_rebind_remove", "cdecl"):
    apr_ldap_rebind_remove = _libs["aprutil-1"].get("apr_ldap_rebind_remove", "cdecl")
    apr_ldap_rebind_remove.argtypes = [POINTER(LDAP)]
    apr_ldap_rebind_remove.restype = apr_status_t

# /usr/include/apr-util/apr_md4.h: 67
class struct_apr_md4_ctx_t(Structure):
    pass

apr_md4_ctx_t = struct_apr_md4_ctx_t# /usr/include/apr-util/apr_md4.h: 64

struct_apr_md4_ctx_t.__slots__ = [
    'state',
    'count',
    'buffer',
    'xlate',
]
struct_apr_md4_ctx_t._fields_ = [
    ('state', apr_uint32_t * int(4)),
    ('count', apr_uint32_t * int(2)),
    ('buffer', c_ubyte * int(64)),
    ('xlate', POINTER(apr_xlate_t)),
]

# /usr/include/apr-util/apr_md4.h: 84
if _libs["aprutil-1"].has("apr_md4_init", "cdecl"):
    apr_md4_init = _libs["aprutil-1"].get("apr_md4_init", "cdecl")
    apr_md4_init.argtypes = [POINTER(apr_md4_ctx_t)]
    apr_md4_init.restype = apr_status_t

# /usr/include/apr-util/apr_md4.h: 93
if _libs["aprutil-1"].has("apr_md4_set_xlate", "cdecl"):
    apr_md4_set_xlate = _libs["aprutil-1"].get("apr_md4_set_xlate", "cdecl")
    apr_md4_set_xlate.argtypes = [POINTER(apr_md4_ctx_t), POINTER(apr_xlate_t)]
    apr_md4_set_xlate.restype = apr_status_t

# /usr/include/apr-util/apr_md4.h: 106
if _libs["aprutil-1"].has("apr_md4_update", "cdecl"):
    apr_md4_update = _libs["aprutil-1"].get("apr_md4_update", "cdecl")
    apr_md4_update.argtypes = [POINTER(apr_md4_ctx_t), POINTER(c_ubyte), apr_size_t]
    apr_md4_update.restype = apr_status_t

# /usr/include/apr-util/apr_md4.h: 116
if _libs["aprutil-1"].has("apr_md4_final", "cdecl"):
    apr_md4_final = _libs["aprutil-1"].get("apr_md4_final", "cdecl")
    apr_md4_final.argtypes = [c_ubyte * int(16), POINTER(apr_md4_ctx_t)]
    apr_md4_final.restype = apr_status_t

# /usr/include/apr-util/apr_md4.h: 126
if _libs["aprutil-1"].has("apr_md4", "cdecl"):
    apr_md4 = _libs["aprutil-1"].get("apr_md4", "cdecl")
    apr_md4.argtypes = [c_ubyte * int(16), POINTER(c_ubyte), apr_size_t]
    apr_md4.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 74
class struct_apr_md5_ctx_t(Structure):
    pass

apr_md5_ctx_t = struct_apr_md5_ctx_t# /usr/include/apr-util/apr_md5.h: 71

struct_apr_md5_ctx_t.__slots__ = [
    'state',
    'count',
    'buffer',
    'xlate',
]
struct_apr_md5_ctx_t._fields_ = [
    ('state', apr_uint32_t * int(4)),
    ('count', apr_uint32_t * int(2)),
    ('buffer', c_ubyte * int(64)),
    ('xlate', POINTER(apr_xlate_t)),
]

# /usr/include/apr-util/apr_md5.h: 91
if _libs["aprutil-1"].has("apr_md5_init", "cdecl"):
    apr_md5_init = _libs["aprutil-1"].get("apr_md5_init", "cdecl")
    apr_md5_init.argtypes = [POINTER(apr_md5_ctx_t)]
    apr_md5_init.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 99
if _libs["aprutil-1"].has("apr_md5_set_xlate", "cdecl"):
    apr_md5_set_xlate = _libs["aprutil-1"].get("apr_md5_set_xlate", "cdecl")
    apr_md5_set_xlate.argtypes = [POINTER(apr_md5_ctx_t), POINTER(apr_xlate_t)]
    apr_md5_set_xlate.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 109
if _libs["aprutil-1"].has("apr_md5_update", "cdecl"):
    apr_md5_update = _libs["aprutil-1"].get("apr_md5_update", "cdecl")
    apr_md5_update.argtypes = [POINTER(apr_md5_ctx_t), POINTER(None), apr_size_t]
    apr_md5_update.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 119
if _libs["aprutil-1"].has("apr_md5_final", "cdecl"):
    apr_md5_final = _libs["aprutil-1"].get("apr_md5_final", "cdecl")
    apr_md5_final.argtypes = [c_ubyte * int(16), POINTER(apr_md5_ctx_t)]
    apr_md5_final.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 128
if _libs["aprutil-1"].has("apr_md5", "cdecl"):
    apr_md5 = _libs["aprutil-1"].get("apr_md5", "cdecl")
    apr_md5.argtypes = [c_ubyte * int(16), POINTER(None), apr_size_t]
    apr_md5.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 139
if _libs["aprutil-1"].has("apr_md5_encode", "cdecl"):
    apr_md5_encode = _libs["aprutil-1"].get("apr_md5_encode", "cdecl")
    apr_md5_encode.argtypes = [String, String, String, apr_size_t]
    apr_md5_encode.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 151
if _libs["aprutil-1"].has("apr_bcrypt_encode", "cdecl"):
    apr_bcrypt_encode = _libs["aprutil-1"].get("apr_bcrypt_encode", "cdecl")
    apr_bcrypt_encode.argtypes = [String, c_uint, POINTER(c_ubyte), apr_size_t, String, apr_size_t]
    apr_bcrypt_encode.restype = apr_status_t

# /usr/include/apr-util/apr_md5.h: 167
if _libs["aprutil-1"].has("apr_password_validate", "cdecl"):
    apr_password_validate = _libs["aprutil-1"].get("apr_password_validate", "cdecl")
    apr_password_validate.argtypes = [String, String]
    apr_password_validate.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 42
class struct_apr_reslist_t(Structure):
    pass

apr_reslist_t = struct_apr_reslist_t# /usr/include/apr-util/apr_reslist.h: 42

apr_reslist_constructor = CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(POINTER(None)), POINTER(None), POINTER(apr_pool_t))# /usr/include/apr-util/apr_reslist.h: 50

apr_reslist_destructor = CFUNCTYPE(UNCHECKED(apr_status_t), POINTER(None), POINTER(None), POINTER(apr_pool_t))# /usr/include/apr-util/apr_reslist.h: 59

# /usr/include/apr-util/apr_reslist.h: 89
if _libs["aprutil-1"].has("apr_reslist_create", "cdecl"):
    apr_reslist_create = _libs["aprutil-1"].get("apr_reslist_create", "cdecl")
    apr_reslist_create.argtypes = [POINTER(POINTER(apr_reslist_t)), c_int, c_int, c_int, apr_interval_time_t, apr_reslist_constructor, apr_reslist_destructor, POINTER(None), POINTER(apr_pool_t)]
    apr_reslist_create.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 108
if _libs["aprutil-1"].has("apr_reslist_destroy", "cdecl"):
    apr_reslist_destroy = _libs["aprutil-1"].get("apr_reslist_destroy", "cdecl")
    apr_reslist_destroy.argtypes = [POINTER(apr_reslist_t)]
    apr_reslist_destroy.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 118
if _libs["aprutil-1"].has("apr_reslist_acquire", "cdecl"):
    apr_reslist_acquire = _libs["aprutil-1"].get("apr_reslist_acquire", "cdecl")
    apr_reslist_acquire.argtypes = [POINTER(apr_reslist_t), POINTER(POINTER(None))]
    apr_reslist_acquire.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 126
if _libs["aprutil-1"].has("apr_reslist_release", "cdecl"):
    apr_reslist_release = _libs["aprutil-1"].get("apr_reslist_release", "cdecl")
    apr_reslist_release.argtypes = [POINTER(apr_reslist_t), POINTER(None)]
    apr_reslist_release.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 135
if _libs["aprutil-1"].has("apr_reslist_timeout_set", "cdecl"):
    apr_reslist_timeout_set = _libs["aprutil-1"].get("apr_reslist_timeout_set", "cdecl")
    apr_reslist_timeout_set.argtypes = [POINTER(apr_reslist_t), apr_interval_time_t]
    apr_reslist_timeout_set.restype = None

# /usr/include/apr-util/apr_reslist.h: 142
if _libs["aprutil-1"].has("apr_reslist_acquired_count", "cdecl"):
    apr_reslist_acquired_count = _libs["aprutil-1"].get("apr_reslist_acquired_count", "cdecl")
    apr_reslist_acquired_count.argtypes = [POINTER(apr_reslist_t)]
    apr_reslist_acquired_count.restype = apr_uint32_t

# /usr/include/apr-util/apr_reslist.h: 151
if _libs["aprutil-1"].has("apr_reslist_invalidate", "cdecl"):
    apr_reslist_invalidate = _libs["aprutil-1"].get("apr_reslist_invalidate", "cdecl")
    apr_reslist_invalidate.argtypes = [POINTER(apr_reslist_t), POINTER(None)]
    apr_reslist_invalidate.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 159
if _libs["aprutil-1"].has("apr_reslist_maintain", "cdecl"):
    apr_reslist_maintain = _libs["aprutil-1"].get("apr_reslist_maintain", "cdecl")
    apr_reslist_maintain.argtypes = [POINTER(apr_reslist_t)]
    apr_reslist_maintain.restype = apr_status_t

# /usr/include/apr-util/apr_reslist.h: 174
if _libs["aprutil-1"].has("apr_reslist_cleanup_order_set", "cdecl"):
    apr_reslist_cleanup_order_set = _libs["aprutil-1"].get("apr_reslist_cleanup_order_set", "cdecl")
    apr_reslist_cleanup_order_set.argtypes = [POINTER(apr_reslist_t), apr_uint32_t]
    apr_reslist_cleanup_order_set.restype = None

enum_anon_120 = c_int# /usr/include/apr-util/apr_memcache.h: 53

APR_MC_SERVER_LIVE = 0# /usr/include/apr-util/apr_memcache.h: 53

APR_MC_SERVER_DEAD = (APR_MC_SERVER_LIVE + 1)# /usr/include/apr-util/apr_memcache.h: 53

apr_memcache_server_status_t = enum_anon_120# /usr/include/apr-util/apr_memcache.h: 53

# /usr/include/apr-util/apr_memcache.h: 56
class struct_apr_memcache_conn_t(Structure):
    pass

apr_memcache_conn_t = struct_apr_memcache_conn_t# /usr/include/apr-util/apr_memcache.h: 56

# /usr/include/apr-util/apr_memcache.h: 60
class struct_apr_memcache_server_t(Structure):
    pass

apr_memcache_server_t = struct_apr_memcache_server_t# /usr/include/apr-util/apr_memcache.h: 59

struct_apr_memcache_server_t.__slots__ = [
    'host',
    'port',
    'status',
    'conns',
    'p',
    'lock',
    'btime',
]
struct_apr_memcache_server_t._fields_ = [
    ('host', String),
    ('port', apr_port_t),
    ('status', apr_memcache_server_status_t),
    ('conns', POINTER(apr_reslist_t)),
    ('p', POINTER(apr_pool_t)),
    ('lock', POINTER(apr_thread_mutex_t)),
    ('btime', apr_time_t),
]

apr_memcache_hash_func = CFUNCTYPE(UNCHECKED(apr_uint32_t), POINTER(None), String, apr_size_t)# /usr/include/apr-util/apr_memcache.h: 82

# /usr/include/apr-util/apr_memcache.h: 98
class struct_apr_memcache_t(Structure):
    pass

apr_memcache_t = struct_apr_memcache_t# /usr/include/apr-util/apr_memcache.h: 86

apr_memcache_server_func = CFUNCTYPE(UNCHECKED(POINTER(apr_memcache_server_t)), POINTER(None), POINTER(apr_memcache_t), apr_uint32_t)# /usr/include/apr-util/apr_memcache.h: 93

struct_apr_memcache_t.__slots__ = [
    'flags',
    'nalloc',
    'ntotal',
    'live_servers',
    'p',
    'hash_baton',
    'hash_func',
    'server_baton',
    'server_func',
]
struct_apr_memcache_t._fields_ = [
    ('flags', apr_uint32_t),
    ('nalloc', apr_uint16_t),
    ('ntotal', apr_uint16_t),
    ('live_servers', POINTER(POINTER(apr_memcache_server_t))),
    ('p', POINTER(apr_pool_t)),
    ('hash_baton', POINTER(None)),
    ('hash_func', apr_memcache_hash_func),
    ('server_baton', POINTER(None)),
    ('server_func', apr_memcache_server_func),
]

# /usr/include/apr-util/apr_memcache.h: 119
class struct_anon_121(Structure):
    pass

struct_anon_121.__slots__ = [
    'status',
    'key',
    'len',
    'data',
    'flags',
]
struct_anon_121._fields_ = [
    ('status', apr_status_t),
    ('key', String),
    ('len', apr_size_t),
    ('data', String),
    ('flags', apr_uint16_t),
]

apr_memcache_value_t = struct_anon_121# /usr/include/apr-util/apr_memcache.h: 119

# /usr/include/apr-util/apr_memcache.h: 129
if _libs["aprutil-1"].has("apr_memcache_hash", "cdecl"):
    apr_memcache_hash = _libs["aprutil-1"].get("apr_memcache_hash", "cdecl")
    apr_memcache_hash.argtypes = [POINTER(apr_memcache_t), String, apr_size_t]
    apr_memcache_hash.restype = apr_uint32_t

# /usr/include/apr-util/apr_memcache.h: 136
if _libs["aprutil-1"].has("apr_memcache_hash_crc32", "cdecl"):
    apr_memcache_hash_crc32 = _libs["aprutil-1"].get("apr_memcache_hash_crc32", "cdecl")
    apr_memcache_hash_crc32.argtypes = [POINTER(None), String, apr_size_t]
    apr_memcache_hash_crc32.restype = apr_uint32_t

# /usr/include/apr-util/apr_memcache.h: 143
if _libs["aprutil-1"].has("apr_memcache_hash_default", "cdecl"):
    apr_memcache_hash_default = _libs["aprutil-1"].get("apr_memcache_hash_default", "cdecl")
    apr_memcache_hash_default.argtypes = [POINTER(None), String, apr_size_t]
    apr_memcache_hash_default.restype = apr_uint32_t

# /usr/include/apr-util/apr_memcache.h: 154
if _libs["aprutil-1"].has("apr_memcache_find_server_hash", "cdecl"):
    apr_memcache_find_server_hash = _libs["aprutil-1"].get("apr_memcache_find_server_hash", "cdecl")
    apr_memcache_find_server_hash.argtypes = [POINTER(apr_memcache_t), apr_uint32_t]
    apr_memcache_find_server_hash.restype = POINTER(apr_memcache_server_t)

# /usr/include/apr-util/apr_memcache.h: 160
if _libs["aprutil-1"].has("apr_memcache_find_server_hash_default", "cdecl"):
    apr_memcache_find_server_hash_default = _libs["aprutil-1"].get("apr_memcache_find_server_hash_default", "cdecl")
    apr_memcache_find_server_hash_default.argtypes = [POINTER(None), POINTER(apr_memcache_t), apr_uint32_t]
    apr_memcache_find_server_hash_default.restype = POINTER(apr_memcache_server_t)

# /usr/include/apr-util/apr_memcache.h: 172
if _libs["aprutil-1"].has("apr_memcache_add_server", "cdecl"):
    apr_memcache_add_server = _libs["aprutil-1"].get("apr_memcache_add_server", "cdecl")
    apr_memcache_add_server.argtypes = [POINTER(apr_memcache_t), POINTER(apr_memcache_server_t)]
    apr_memcache_add_server.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 183
if _libs["aprutil-1"].has("apr_memcache_find_server", "cdecl"):
    apr_memcache_find_server = _libs["aprutil-1"].get("apr_memcache_find_server", "cdecl")
    apr_memcache_find_server.argtypes = [POINTER(apr_memcache_t), String, apr_port_t]
    apr_memcache_find_server.restype = POINTER(apr_memcache_server_t)

# /usr/include/apr-util/apr_memcache.h: 192
if _libs["aprutil-1"].has("apr_memcache_enable_server", "cdecl"):
    apr_memcache_enable_server = _libs["aprutil-1"].get("apr_memcache_enable_server", "cdecl")
    apr_memcache_enable_server.argtypes = [POINTER(apr_memcache_t), POINTER(apr_memcache_server_t)]
    apr_memcache_enable_server.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 201
if _libs["aprutil-1"].has("apr_memcache_disable_server", "cdecl"):
    apr_memcache_disable_server = _libs["aprutil-1"].get("apr_memcache_disable_server", "cdecl")
    apr_memcache_disable_server.argtypes = [POINTER(apr_memcache_t), POINTER(apr_memcache_server_t)]
    apr_memcache_disable_server.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 217
if _libs["aprutil-1"].has("apr_memcache_server_create", "cdecl"):
    apr_memcache_server_create = _libs["aprutil-1"].get("apr_memcache_server_create", "cdecl")
    apr_memcache_server_create.argtypes = [POINTER(apr_pool_t), String, apr_port_t, apr_uint32_t, apr_uint32_t, apr_uint32_t, apr_uint32_t, POINTER(POINTER(apr_memcache_server_t))]
    apr_memcache_server_create.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 232
if _libs["aprutil-1"].has("apr_memcache_create", "cdecl"):
    apr_memcache_create = _libs["aprutil-1"].get("apr_memcache_create", "cdecl")
    apr_memcache_create.argtypes = [POINTER(apr_pool_t), apr_uint16_t, apr_uint32_t, POINTER(POINTER(apr_memcache_t))]
    apr_memcache_create.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 247
if _libs["aprutil-1"].has("apr_memcache_getp", "cdecl"):
    apr_memcache_getp = _libs["aprutil-1"].get("apr_memcache_getp", "cdecl")
    apr_memcache_getp.argtypes = [POINTER(apr_memcache_t), POINTER(apr_pool_t), String, POINTER(POINTER(c_char)), POINTER(apr_size_t), POINTER(apr_uint16_t)]
    apr_memcache_getp.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 263
if _libs["aprutil-1"].has("apr_memcache_add_multget_key", "cdecl"):
    apr_memcache_add_multget_key = _libs["aprutil-1"].get("apr_memcache_add_multget_key", "cdecl")
    apr_memcache_add_multget_key.argtypes = [POINTER(apr_pool_t), String, POINTER(POINTER(apr_hash_t))]
    apr_memcache_add_multget_key.restype = None

# /usr/include/apr-util/apr_memcache.h: 277
if _libs["aprutil-1"].has("apr_memcache_multgetp", "cdecl"):
    apr_memcache_multgetp = _libs["aprutil-1"].get("apr_memcache_multgetp", "cdecl")
    apr_memcache_multgetp.argtypes = [POINTER(apr_memcache_t), POINTER(apr_pool_t), POINTER(apr_pool_t), POINTER(apr_hash_t)]
    apr_memcache_multgetp.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 291
if _libs["aprutil-1"].has("apr_memcache_set", "cdecl"):
    apr_memcache_set = _libs["aprutil-1"].get("apr_memcache_set", "cdecl")
    apr_memcache_set.argtypes = [POINTER(apr_memcache_t), String, String, apr_size_t, apr_uint32_t, apr_uint16_t]
    apr_memcache_set.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 309
if _libs["aprutil-1"].has("apr_memcache_add", "cdecl"):
    apr_memcache_add = _libs["aprutil-1"].get("apr_memcache_add", "cdecl")
    apr_memcache_add.argtypes = [POINTER(apr_memcache_t), String, String, apr_size_t, apr_uint32_t, apr_uint16_t]
    apr_memcache_add.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 327
if _libs["aprutil-1"].has("apr_memcache_replace", "cdecl"):
    apr_memcache_replace = _libs["aprutil-1"].get("apr_memcache_replace", "cdecl")
    apr_memcache_replace.argtypes = [POINTER(apr_memcache_t), String, String, apr_size_t, apr_uint32_t, apr_uint16_t]
    apr_memcache_replace.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 339
if _libs["aprutil-1"].has("apr_memcache_delete", "cdecl"):
    apr_memcache_delete = _libs["aprutil-1"].get("apr_memcache_delete", "cdecl")
    apr_memcache_delete.argtypes = [POINTER(apr_memcache_t), String, apr_uint32_t]
    apr_memcache_delete.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 350
if _libs["aprutil-1"].has("apr_memcache_incr", "cdecl"):
    apr_memcache_incr = _libs["aprutil-1"].get("apr_memcache_incr", "cdecl")
    apr_memcache_incr.argtypes = [POINTER(apr_memcache_t), String, apr_int32_t, POINTER(apr_uint32_t)]
    apr_memcache_incr.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 362
if _libs["aprutil-1"].has("apr_memcache_decr", "cdecl"):
    apr_memcache_decr = _libs["aprutil-1"].get("apr_memcache_decr", "cdecl")
    apr_memcache_decr.argtypes = [POINTER(apr_memcache_t), String, apr_int32_t, POINTER(apr_uint32_t)]
    apr_memcache_decr.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 374
if _libs["aprutil-1"].has("apr_memcache_version", "cdecl"):
    apr_memcache_version = _libs["aprutil-1"].get("apr_memcache_version", "cdecl")
    apr_memcache_version.argtypes = [POINTER(apr_memcache_server_t), POINTER(apr_pool_t), POINTER(POINTER(c_char))]
    apr_memcache_version.restype = apr_status_t

# /usr/include/apr-util/apr_memcache.h: 425
class struct_anon_122(Structure):
    pass

struct_anon_122.__slots__ = [
    'version',
    'pid',
    'uptime',
    'time',
    'pointer_size',
    'rusage_user',
    'rusage_system',
    'curr_items',
    'total_items',
    'bytes',
    'curr_connections',
    'total_connections',
    'connection_structures',
    'cmd_get',
    'cmd_set',
    'get_hits',
    'get_misses',
    'evictions',
    'bytes_read',
    'bytes_written',
    'limit_maxbytes',
    'threads',
]
struct_anon_122._fields_ = [
    ('version', String),
    ('pid', apr_uint32_t),
    ('uptime', apr_uint32_t),
    ('time', apr_time_t),
    ('pointer_size', apr_uint32_t),
    ('rusage_user', apr_time_t),
    ('rusage_system', apr_time_t),
    ('curr_items', apr_uint32_t),
    ('total_items', apr_uint32_t),
    ('bytes', apr_uint64_t),
    ('curr_connections', apr_uint32_t),
    ('total_connections', apr_uint32_t),
    ('connection_structures', apr_uint32_t),
    ('cmd_get', apr_uint32_t),
    ('cmd_set', apr_uint32_t),
    ('get_hits', apr_uint32_t),
    ('get_misses', apr_uint32_t),
    ('evictions', apr_uint64_t),
    ('bytes_read', apr_uint64_t),
    ('bytes_written', apr_uint64_t),
    ('limit_maxbytes', apr_uint32_t),
    ('threads', apr_uint32_t),
]

apr_memcache_stats_t = struct_anon_122# /usr/include/apr-util/apr_memcache.h: 425

# /usr/include/apr-util/apr_memcache.h: 433
if _libs["aprutil-1"].has("apr_memcache_stats", "cdecl"):
    apr_memcache_stats = _libs["aprutil-1"].get("apr_memcache_stats", "cdecl")
    apr_memcache_stats.argtypes = [POINTER(apr_memcache_server_t), POINTER(apr_pool_t), POINTER(POINTER(apr_memcache_stats_t))]
    apr_memcache_stats.restype = apr_status_t

apr_opt_fn_t = CFUNCTYPE(UNCHECKED(None), )# /usr/include/apr-util/apr_optional.h: 59

# /usr/include/apr-util/apr_optional.h: 61
if _libs["aprutil-1"].has("apr_dynamic_fn_register", "cdecl"):
    apr_dynamic_fn_register = _libs["aprutil-1"].get("apr_dynamic_fn_register", "cdecl")
    apr_dynamic_fn_register.argtypes = [String, POINTER(apr_opt_fn_t)]
    apr_dynamic_fn_register.restype = None

# /usr/include/apr-util/apr_optional.h: 78
if _libs["aprutil-1"].has("apr_dynamic_fn_retrieve", "cdecl"):
    apr_dynamic_fn_retrieve = _libs["aprutil-1"].get("apr_dynamic_fn_retrieve", "cdecl")
    apr_dynamic_fn_retrieve.argtypes = [String]
    apr_dynamic_fn_retrieve.restype = POINTER(apr_opt_fn_t)

# /usr/include/apr-util/apr_optional_hooks.h: 48
if _libs["aprutil-1"].has("apr_optional_hook_add", "cdecl"):
    apr_optional_hook_add = _libs["aprutil-1"].get("apr_optional_hook_add", "cdecl")
    apr_optional_hook_add.argtypes = [String, CFUNCTYPE(UNCHECKED(None), ), POINTER(POINTER(c_char)), POINTER(POINTER(c_char)), c_int]
    apr_optional_hook_add.restype = None

# /usr/include/apr-util/apr_optional_hooks.h: 74
if _libs["aprutil-1"].has("apr_optional_hook_get", "cdecl"):
    apr_optional_hook_get = _libs["aprutil-1"].get("apr_optional_hook_get", "cdecl")
    apr_optional_hook_get.argtypes = [String]
    apr_optional_hook_get.restype = POINTER(apr_array_header_t)

# /usr/include/apr-util/apr_queue.h: 47
class struct_apr_queue_t(Structure):
    pass

apr_queue_t = struct_apr_queue_t# /usr/include/apr-util/apr_queue.h: 47

# /usr/include/apr-util/apr_queue.h: 55
if _libs["aprutil-1"].has("apr_queue_create", "cdecl"):
    apr_queue_create = _libs["aprutil-1"].get("apr_queue_create", "cdecl")
    apr_queue_create.argtypes = [POINTER(POINTER(apr_queue_t)), c_uint, POINTER(apr_pool_t)]
    apr_queue_create.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 68
if _libs["aprutil-1"].has("apr_queue_push", "cdecl"):
    apr_queue_push = _libs["aprutil-1"].get("apr_queue_push", "cdecl")
    apr_queue_push.argtypes = [POINTER(apr_queue_t), POINTER(None)]
    apr_queue_push.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 79
if _libs["aprutil-1"].has("apr_queue_pop", "cdecl"):
    apr_queue_pop = _libs["aprutil-1"].get("apr_queue_pop", "cdecl")
    apr_queue_pop.argtypes = [POINTER(apr_queue_t), POINTER(POINTER(None))]
    apr_queue_pop.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 91
if _libs["aprutil-1"].has("apr_queue_trypush", "cdecl"):
    apr_queue_trypush = _libs["aprutil-1"].get("apr_queue_trypush", "cdecl")
    apr_queue_trypush.argtypes = [POINTER(apr_queue_t), POINTER(None)]
    apr_queue_trypush.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 103
if _libs["aprutil-1"].has("apr_queue_trypop", "cdecl"):
    apr_queue_trypop = _libs["aprutil-1"].get("apr_queue_trypop", "cdecl")
    apr_queue_trypop.argtypes = [POINTER(apr_queue_t), POINTER(POINTER(None))]
    apr_queue_trypop.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 113
if _libs["aprutil-1"].has("apr_queue_size", "cdecl"):
    apr_queue_size = _libs["aprutil-1"].get("apr_queue_size", "cdecl")
    apr_queue_size.argtypes = [POINTER(apr_queue_t)]
    apr_queue_size.restype = c_uint

# /usr/include/apr-util/apr_queue.h: 120
if _libs["aprutil-1"].has("apr_queue_interrupt_all", "cdecl"):
    apr_queue_interrupt_all = _libs["aprutil-1"].get("apr_queue_interrupt_all", "cdecl")
    apr_queue_interrupt_all.argtypes = [POINTER(apr_queue_t)]
    apr_queue_interrupt_all.restype = apr_status_t

# /usr/include/apr-util/apr_queue.h: 128
if _libs["aprutil-1"].has("apr_queue_term", "cdecl"):
    apr_queue_term = _libs["aprutil-1"].get("apr_queue_term", "cdecl")
    apr_queue_term.argtypes = [POINTER(apr_queue_t)]
    apr_queue_term.restype = apr_status_t

enum_anon_123 = c_int# /usr/include/apr-util/apr_redis.h: 68

APR_RC_SERVER_LIVE = 0# /usr/include/apr-util/apr_redis.h: 68

APR_RC_SERVER_DEAD = (APR_RC_SERVER_LIVE + 1)# /usr/include/apr-util/apr_redis.h: 68

apr_redis_server_status_t = enum_anon_123# /usr/include/apr-util/apr_redis.h: 68

# /usr/include/apr-util/apr_redis.h: 71
class struct_apr_redis_conn_t(Structure):
    pass

apr_redis_conn_t = struct_apr_redis_conn_t# /usr/include/apr-util/apr_redis.h: 71

# /usr/include/apr-util/apr_redis.h: 75
class struct_apr_redis_server_t(Structure):
    pass

apr_redis_server_t = struct_apr_redis_server_t# /usr/include/apr-util/apr_redis.h: 74

# /usr/include/apr-util/apr_redis.h: 91
class struct_anon_124(Structure):
    pass

struct_anon_124.__slots__ = [
    'major',
    'minor',
    'patch',
    'number',
]
struct_anon_124._fields_ = [
    ('major', c_int),
    ('minor', c_int),
    ('patch', c_int),
    ('number', String),
]

struct_apr_redis_server_t.__slots__ = [
    'host',
    'port',
    'status',
    'conns',
    'p',
    'lock',
    'btime',
    'rwto',
    'version',
]
struct_apr_redis_server_t._fields_ = [
    ('host', String),
    ('port', apr_port_t),
    ('status', apr_redis_server_status_t),
    ('conns', POINTER(apr_reslist_t)),
    ('p', POINTER(apr_pool_t)),
    ('lock', POINTER(apr_thread_mutex_t)),
    ('btime', apr_time_t),
    ('rwto', apr_uint32_t),
    ('version', struct_anon_124),
]

# /usr/include/apr-util/apr_redis.h: 120
class struct_apr_redis_t(Structure):
    pass

apr_redis_t = struct_apr_redis_t# /usr/include/apr-util/apr_redis.h: 100

apr_redis_hash_func = CFUNCTYPE(UNCHECKED(apr_uint32_t), POINTER(None), String, apr_size_t)# /usr/include/apr-util/apr_redis.h: 107

apr_redis_server_func = CFUNCTYPE(UNCHECKED(POINTER(apr_redis_server_t)), POINTER(None), POINTER(apr_redis_t), apr_uint32_t)# /usr/include/apr-util/apr_redis.h: 115

struct_apr_redis_t.__slots__ = [
    'flags',
    'nalloc',
    'ntotal',
    'live_servers',
    'p',
    'hash_baton',
    'hash_func',
    'server_baton',
    'server_func',
]
struct_apr_redis_t._fields_ = [
    ('flags', apr_uint32_t),
    ('nalloc', apr_uint16_t),
    ('ntotal', apr_uint16_t),
    ('live_servers', POINTER(POINTER(apr_redis_server_t))),
    ('p', POINTER(apr_pool_t)),
    ('hash_baton', POINTER(None)),
    ('hash_func', apr_redis_hash_func),
    ('server_baton', POINTER(None)),
    ('server_func', apr_redis_server_func),
]

# /usr/include/apr-util/apr_redis.h: 141
if _libs["aprutil-1"].has("apr_redis_hash", "cdecl"):
    apr_redis_hash = _libs["aprutil-1"].get("apr_redis_hash", "cdecl")
    apr_redis_hash.argtypes = [POINTER(apr_redis_t), String, apr_size_t]
    apr_redis_hash.restype = apr_uint32_t

# /usr/include/apr-util/apr_redis.h: 148
if _libs["aprutil-1"].has("apr_redis_hash_crc32", "cdecl"):
    apr_redis_hash_crc32 = _libs["aprutil-1"].get("apr_redis_hash_crc32", "cdecl")
    apr_redis_hash_crc32.argtypes = [POINTER(None), String, apr_size_t]
    apr_redis_hash_crc32.restype = apr_uint32_t

# /usr/include/apr-util/apr_redis.h: 155
if _libs["aprutil-1"].has("apr_redis_hash_default", "cdecl"):
    apr_redis_hash_default = _libs["aprutil-1"].get("apr_redis_hash_default", "cdecl")
    apr_redis_hash_default.argtypes = [POINTER(None), String, apr_size_t]
    apr_redis_hash_default.restype = apr_uint32_t

# /usr/include/apr-util/apr_redis.h: 166
if _libs["aprutil-1"].has("apr_redis_find_server_hash", "cdecl"):
    apr_redis_find_server_hash = _libs["aprutil-1"].get("apr_redis_find_server_hash", "cdecl")
    apr_redis_find_server_hash.argtypes = [POINTER(apr_redis_t), apr_uint32_t]
    apr_redis_find_server_hash.restype = POINTER(apr_redis_server_t)

# /usr/include/apr-util/apr_redis.h: 172
if _libs["aprutil-1"].has("apr_redis_find_server_hash_default", "cdecl"):
    apr_redis_find_server_hash_default = _libs["aprutil-1"].get("apr_redis_find_server_hash_default", "cdecl")
    apr_redis_find_server_hash_default.argtypes = [POINTER(None), POINTER(apr_redis_t), apr_uint32_t]
    apr_redis_find_server_hash_default.restype = POINTER(apr_redis_server_t)

# /usr/include/apr-util/apr_redis.h: 184
if _libs["aprutil-1"].has("apr_redis_add_server", "cdecl"):
    apr_redis_add_server = _libs["aprutil-1"].get("apr_redis_add_server", "cdecl")
    apr_redis_add_server.argtypes = [POINTER(apr_redis_t), POINTER(apr_redis_server_t)]
    apr_redis_add_server.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 195
if _libs["aprutil-1"].has("apr_redis_find_server", "cdecl"):
    apr_redis_find_server = _libs["aprutil-1"].get("apr_redis_find_server", "cdecl")
    apr_redis_find_server.argtypes = [POINTER(apr_redis_t), String, apr_port_t]
    apr_redis_find_server.restype = POINTER(apr_redis_server_t)

# /usr/include/apr-util/apr_redis.h: 204
if _libs["aprutil-1"].has("apr_redis_enable_server", "cdecl"):
    apr_redis_enable_server = _libs["aprutil-1"].get("apr_redis_enable_server", "cdecl")
    apr_redis_enable_server.argtypes = [POINTER(apr_redis_t), POINTER(apr_redis_server_t)]
    apr_redis_enable_server.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 213
if _libs["aprutil-1"].has("apr_redis_disable_server", "cdecl"):
    apr_redis_disable_server = _libs["aprutil-1"].get("apr_redis_disable_server", "cdecl")
    apr_redis_disable_server.argtypes = [POINTER(apr_redis_t), POINTER(apr_redis_server_t)]
    apr_redis_disable_server.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 230
if _libs["aprutil-1"].has("apr_redis_server_create", "cdecl"):
    apr_redis_server_create = _libs["aprutil-1"].get("apr_redis_server_create", "cdecl")
    apr_redis_server_create.argtypes = [POINTER(apr_pool_t), String, apr_port_t, apr_uint32_t, apr_uint32_t, apr_uint32_t, apr_uint32_t, apr_uint32_t, POINTER(POINTER(apr_redis_server_t))]
    apr_redis_server_create.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 246
if _libs["aprutil-1"].has("apr_redis_create", "cdecl"):
    apr_redis_create = _libs["aprutil-1"].get("apr_redis_create", "cdecl")
    apr_redis_create.argtypes = [POINTER(apr_pool_t), apr_uint16_t, apr_uint32_t, POINTER(POINTER(apr_redis_t))]
    apr_redis_create.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 261
if _libs["aprutil-1"].has("apr_redis_getp", "cdecl"):
    apr_redis_getp = _libs["aprutil-1"].get("apr_redis_getp", "cdecl")
    apr_redis_getp.argtypes = [POINTER(apr_redis_t), POINTER(apr_pool_t), String, POINTER(POINTER(c_char)), POINTER(apr_size_t), POINTER(apr_uint16_t)]
    apr_redis_getp.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 276
if _libs["aprutil-1"].has("apr_redis_set", "cdecl"):
    apr_redis_set = _libs["aprutil-1"].get("apr_redis_set", "cdecl")
    apr_redis_set.argtypes = [POINTER(apr_redis_t), String, String, apr_size_t, apr_uint16_t]
    apr_redis_set.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 291
if _libs["aprutil-1"].has("apr_redis_setex", "cdecl"):
    apr_redis_setex = _libs["aprutil-1"].get("apr_redis_setex", "cdecl")
    apr_redis_setex.argtypes = [POINTER(apr_redis_t), String, String, apr_size_t, apr_uint32_t, apr_uint16_t]
    apr_redis_setex.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 304
if _libs["aprutil-1"].has("apr_redis_delete", "cdecl"):
    apr_redis_delete = _libs["aprutil-1"].get("apr_redis_delete", "cdecl")
    apr_redis_delete.argtypes = [POINTER(apr_redis_t), String, apr_uint32_t]
    apr_redis_delete.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 314
if _libs["aprutil-1"].has("apr_redis_version", "cdecl"):
    apr_redis_version = _libs["aprutil-1"].get("apr_redis_version", "cdecl")
    apr_redis_version.argtypes = [POINTER(apr_redis_server_t), POINTER(apr_pool_t), POINTER(POINTER(c_char))]
    apr_redis_version.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 324
if _libs["aprutil-1"].has("apr_redis_info", "cdecl"):
    apr_redis_info = _libs["aprutil-1"].get("apr_redis_info", "cdecl")
    apr_redis_info.argtypes = [POINTER(apr_redis_server_t), POINTER(apr_pool_t), POINTER(POINTER(c_char))]
    apr_redis_info.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 335
if _libs["aprutil-1"].has("apr_redis_incr", "cdecl"):
    apr_redis_incr = _libs["aprutil-1"].get("apr_redis_incr", "cdecl")
    apr_redis_incr.argtypes = [POINTER(apr_redis_t), String, apr_int32_t, POINTER(apr_uint32_t)]
    apr_redis_incr.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 346
if _libs["aprutil-1"].has("apr_redis_decr", "cdecl"):
    apr_redis_decr = _libs["aprutil-1"].get("apr_redis_decr", "cdecl")
    apr_redis_decr.argtypes = [POINTER(apr_redis_t), String, apr_int32_t, POINTER(apr_uint32_t)]
    apr_redis_decr.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 356
if _libs["aprutil-1"].has("apr_redis_ping", "cdecl"):
    apr_redis_ping = _libs["aprutil-1"].get("apr_redis_ping", "cdecl")
    apr_redis_ping.argtypes = [POINTER(apr_redis_server_t)]
    apr_redis_ping.restype = apr_status_t

# /usr/include/apr-util/apr_redis.h: 368
if _libs["aprutil-1"].has("apr_redis_multgetp", "cdecl"):
    apr_redis_multgetp = _libs["aprutil-1"].get("apr_redis_multgetp", "cdecl")
    apr_redis_multgetp.argtypes = [POINTER(apr_redis_t), POINTER(apr_pool_t), POINTER(apr_pool_t), POINTER(apr_hash_t)]
    apr_redis_multgetp.restype = apr_status_t

enum_anon_125 = c_int# /usr/include/apr-util/apr_redis.h: 378

APR_RS_SERVER_MASTER = 0# /usr/include/apr-util/apr_redis.h: 378

APR_RS_SERVER_SLAVE = (APR_RS_SERVER_MASTER + 1)# /usr/include/apr-util/apr_redis.h: 378

APR_RS_SERVER_UNKNOWN = (APR_RS_SERVER_SLAVE + 1)# /usr/include/apr-util/apr_redis.h: 378

apr_redis_server_role_t = enum_anon_125# /usr/include/apr-util/apr_redis.h: 378

# /usr/include/apr-util/apr_redis.h: 441
class struct_anon_126(Structure):
    pass

struct_anon_126.__slots__ = [
    'major',
    'minor',
    'patch',
    'process_id',
    'uptime_in_seconds',
    'arch_bits',
    'connected_clients',
    'blocked_clients',
    'maxmemory',
    'used_memory',
    'total_system_memory',
    'total_connections_received',
    'total_commands_processed',
    'rejected_connections',
    'total_net_input_bytes',
    'total_net_output_bytes',
    'keyspace_hits',
    'keyspace_misses',
    'role',
    'connected_slaves',
    'used_cpu_sys',
    'used_cpu_user',
    'cluster_enabled',
]
struct_anon_126._fields_ = [
    ('major', apr_uint32_t),
    ('minor', apr_uint32_t),
    ('patch', apr_uint32_t),
    ('process_id', apr_uint32_t),
    ('uptime_in_seconds', apr_uint32_t),
    ('arch_bits', apr_uint32_t),
    ('connected_clients', apr_uint32_t),
    ('blocked_clients', apr_uint32_t),
    ('maxmemory', apr_uint64_t),
    ('used_memory', apr_uint64_t),
    ('total_system_memory', apr_uint64_t),
    ('total_connections_received', apr_uint64_t),
    ('total_commands_processed', apr_uint64_t),
    ('rejected_connections', apr_uint64_t),
    ('total_net_input_bytes', apr_uint64_t),
    ('total_net_output_bytes', apr_uint64_t),
    ('keyspace_hits', apr_uint64_t),
    ('keyspace_misses', apr_uint64_t),
    ('role', apr_redis_server_role_t),
    ('connected_slaves', apr_uint32_t),
    ('used_cpu_sys', apr_uint32_t),
    ('used_cpu_user', apr_uint32_t),
    ('cluster_enabled', apr_uint32_t),
]

apr_redis_stats_t = struct_anon_126# /usr/include/apr-util/apr_redis.h: 441

# /usr/include/apr-util/apr_redis.h: 449
if _libs["aprutil-1"].has("apr_redis_stats", "cdecl"):
    apr_redis_stats = _libs["aprutil-1"].get("apr_redis_stats", "cdecl")
    apr_redis_stats.argtypes = [POINTER(apr_redis_server_t), POINTER(apr_pool_t), POINTER(POINTER(apr_redis_stats_t))]
    apr_redis_stats.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 40
class struct_apr_rmm_t(Structure):
    pass

apr_rmm_t = struct_apr_rmm_t# /usr/include/apr-util/apr_rmm.h: 40

apr_rmm_off_t = apr_size_t# /usr/include/apr-util/apr_rmm.h: 43

# /usr/include/apr-util/apr_rmm.h: 56
if _libs["aprutil-1"].has("apr_rmm_init", "cdecl"):
    apr_rmm_init = _libs["aprutil-1"].get("apr_rmm_init", "cdecl")
    apr_rmm_init.argtypes = [POINTER(POINTER(apr_rmm_t)), POINTER(apr_anylock_t), POINTER(None), apr_size_t, POINTER(apr_pool_t)]
    apr_rmm_init.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 64
if _libs["aprutil-1"].has("apr_rmm_destroy", "cdecl"):
    apr_rmm_destroy = _libs["aprutil-1"].get("apr_rmm_destroy", "cdecl")
    apr_rmm_destroy.argtypes = [POINTER(apr_rmm_t)]
    apr_rmm_destroy.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 73
if _libs["aprutil-1"].has("apr_rmm_attach", "cdecl"):
    apr_rmm_attach = _libs["aprutil-1"].get("apr_rmm_attach", "cdecl")
    apr_rmm_attach.argtypes = [POINTER(POINTER(apr_rmm_t)), POINTER(apr_anylock_t), POINTER(None), POINTER(apr_pool_t)]
    apr_rmm_attach.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 80
if _libs["aprutil-1"].has("apr_rmm_detach", "cdecl"):
    apr_rmm_detach = _libs["aprutil-1"].get("apr_rmm_detach", "cdecl")
    apr_rmm_detach.argtypes = [POINTER(apr_rmm_t)]
    apr_rmm_detach.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 87
if _libs["aprutil-1"].has("apr_rmm_malloc", "cdecl"):
    apr_rmm_malloc = _libs["aprutil-1"].get("apr_rmm_malloc", "cdecl")
    apr_rmm_malloc.argtypes = [POINTER(apr_rmm_t), apr_size_t]
    apr_rmm_malloc.restype = apr_rmm_off_t

# /usr/include/apr-util/apr_rmm.h: 95
if _libs["aprutil-1"].has("apr_rmm_realloc", "cdecl"):
    apr_rmm_realloc = _libs["aprutil-1"].get("apr_rmm_realloc", "cdecl")
    apr_rmm_realloc.argtypes = [POINTER(apr_rmm_t), POINTER(None), apr_size_t]
    apr_rmm_realloc.restype = apr_rmm_off_t

# /usr/include/apr-util/apr_rmm.h: 102
if _libs["aprutil-1"].has("apr_rmm_calloc", "cdecl"):
    apr_rmm_calloc = _libs["aprutil-1"].get("apr_rmm_calloc", "cdecl")
    apr_rmm_calloc.argtypes = [POINTER(apr_rmm_t), apr_size_t]
    apr_rmm_calloc.restype = apr_rmm_off_t

# /usr/include/apr-util/apr_rmm.h: 109
if _libs["aprutil-1"].has("apr_rmm_free", "cdecl"):
    apr_rmm_free = _libs["aprutil-1"].get("apr_rmm_free", "cdecl")
    apr_rmm_free.argtypes = [POINTER(apr_rmm_t), apr_rmm_off_t]
    apr_rmm_free.restype = apr_status_t

# /usr/include/apr-util/apr_rmm.h: 117
if _libs["aprutil-1"].has("apr_rmm_addr_get", "cdecl"):
    apr_rmm_addr_get = _libs["aprutil-1"].get("apr_rmm_addr_get", "cdecl")
    apr_rmm_addr_get.argtypes = [POINTER(apr_rmm_t), apr_rmm_off_t]
    apr_rmm_addr_get.restype = POINTER(c_ubyte)
    apr_rmm_addr_get.errcheck = lambda v,*a : cast(v, c_void_p)

# /usr/include/apr-util/apr_rmm.h: 124
if _libs["aprutil-1"].has("apr_rmm_offset_get", "cdecl"):
    apr_rmm_offset_get = _libs["aprutil-1"].get("apr_rmm_offset_get", "cdecl")
    apr_rmm_offset_get.argtypes = [POINTER(apr_rmm_t), POINTER(None)]
    apr_rmm_offset_get.restype = apr_rmm_off_t

# /usr/include/apr-util/apr_rmm.h: 130
if _libs["aprutil-1"].has("apr_rmm_overhead_get", "cdecl"):
    apr_rmm_overhead_get = _libs["aprutil-1"].get("apr_rmm_overhead_get", "cdecl")
    apr_rmm_overhead_get.argtypes = [c_int]
    apr_rmm_overhead_get.restype = apr_size_t

# /usr/include/apr-util/apr_sdbm.h: 44
class struct_apr_sdbm_t(Structure):
    pass

apr_sdbm_t = struct_apr_sdbm_t# /usr/include/apr-util/apr_sdbm.h: 44

# /usr/include/apr-util/apr_sdbm.h: 55
class struct_anon_127(Structure):
    pass

struct_anon_127.__slots__ = [
    'dptr',
    'dsize',
]
struct_anon_127._fields_ = [
    ('dptr', String),
    ('dsize', c_int),
]

apr_sdbm_datum_t = struct_anon_127# /usr/include/apr-util/apr_sdbm.h: 55

# /usr/include/apr-util/apr_sdbm.h: 86
if _libs["aprutil-1"].has("apr_sdbm_open", "cdecl"):
    apr_sdbm_open = _libs["aprutil-1"].get("apr_sdbm_open", "cdecl")
    apr_sdbm_open.argtypes = [POINTER(POINTER(apr_sdbm_t)), String, apr_int32_t, apr_fileperms_t, POINTER(apr_pool_t)]
    apr_sdbm_open.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 94
if _libs["aprutil-1"].has("apr_sdbm_close", "cdecl"):
    apr_sdbm_close = _libs["aprutil-1"].get("apr_sdbm_close", "cdecl")
    apr_sdbm_close.argtypes = [POINTER(apr_sdbm_t)]
    apr_sdbm_close.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 111
if _libs["aprutil-1"].has("apr_sdbm_lock", "cdecl"):
    apr_sdbm_lock = _libs["aprutil-1"].get("apr_sdbm_lock", "cdecl")
    apr_sdbm_lock.argtypes = [POINTER(apr_sdbm_t), c_int]
    apr_sdbm_lock.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 117
if _libs["aprutil-1"].has("apr_sdbm_unlock", "cdecl"):
    apr_sdbm_unlock = _libs["aprutil-1"].get("apr_sdbm_unlock", "cdecl")
    apr_sdbm_unlock.argtypes = [POINTER(apr_sdbm_t)]
    apr_sdbm_unlock.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 125
if _libs["aprutil-1"].has("apr_sdbm_fetch", "cdecl"):
    apr_sdbm_fetch = _libs["aprutil-1"].get("apr_sdbm_fetch", "cdecl")
    apr_sdbm_fetch.argtypes = [POINTER(apr_sdbm_t), POINTER(apr_sdbm_datum_t), apr_sdbm_datum_t]
    apr_sdbm_fetch.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 140
if _libs["aprutil-1"].has("apr_sdbm_store", "cdecl"):
    apr_sdbm_store = _libs["aprutil-1"].get("apr_sdbm_store", "cdecl")
    apr_sdbm_store.argtypes = [POINTER(apr_sdbm_t), apr_sdbm_datum_t, apr_sdbm_datum_t, c_int]
    apr_sdbm_store.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 149
if _libs["aprutil-1"].has("apr_sdbm_delete", "cdecl"):
    apr_sdbm_delete = _libs["aprutil-1"].get("apr_sdbm_delete", "cdecl")
    apr_sdbm_delete.argtypes = [POINTER(apr_sdbm_t), apr_sdbm_datum_t]
    apr_sdbm_delete.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 161
if _libs["aprutil-1"].has("apr_sdbm_firstkey", "cdecl"):
    apr_sdbm_firstkey = _libs["aprutil-1"].get("apr_sdbm_firstkey", "cdecl")
    apr_sdbm_firstkey.argtypes = [POINTER(apr_sdbm_t), POINTER(apr_sdbm_datum_t)]
    apr_sdbm_firstkey.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 168
if _libs["aprutil-1"].has("apr_sdbm_nextkey", "cdecl"):
    apr_sdbm_nextkey = _libs["aprutil-1"].get("apr_sdbm_nextkey", "cdecl")
    apr_sdbm_nextkey.argtypes = [POINTER(apr_sdbm_t), POINTER(apr_sdbm_datum_t)]
    apr_sdbm_nextkey.restype = apr_status_t

# /usr/include/apr-util/apr_sdbm.h: 174
if _libs["aprutil-1"].has("apr_sdbm_rdonly", "cdecl"):
    apr_sdbm_rdonly = _libs["aprutil-1"].get("apr_sdbm_rdonly", "cdecl")
    apr_sdbm_rdonly.argtypes = [POINTER(apr_sdbm_t)]
    apr_sdbm_rdonly.restype = c_int

# /usr/include/apr-util/apr_sha1.h: 56
class struct_apr_sha1_ctx_t(Structure):
    pass

apr_sha1_ctx_t = struct_apr_sha1_ctx_t# /usr/include/apr-util/apr_sha1.h: 51

struct_apr_sha1_ctx_t.__slots__ = [
    'digest',
    'count_lo',
    'count_hi',
    'data',
    'local',
]
struct_apr_sha1_ctx_t._fields_ = [
    ('digest', apr_uint32_t * int(5)),
    ('count_lo', apr_uint32_t),
    ('count_hi', apr_uint32_t),
    ('data', apr_uint32_t * int(16)),
    ('local', c_int),
]

# /usr/include/apr-util/apr_sha1.h: 82
if _libs["aprutil-1"].has("apr_sha1_base64", "cdecl"):
    apr_sha1_base64 = _libs["aprutil-1"].get("apr_sha1_base64", "cdecl")
    apr_sha1_base64.argtypes = [String, c_int, String]
    apr_sha1_base64.restype = None

# /usr/include/apr-util/apr_sha1.h: 88
if _libs["aprutil-1"].has("apr_sha1_init", "cdecl"):
    apr_sha1_init = _libs["aprutil-1"].get("apr_sha1_init", "cdecl")
    apr_sha1_init.argtypes = [POINTER(apr_sha1_ctx_t)]
    apr_sha1_init.restype = None

# /usr/include/apr-util/apr_sha1.h: 96
if _libs["aprutil-1"].has("apr_sha1_update", "cdecl"):
    apr_sha1_update = _libs["aprutil-1"].get("apr_sha1_update", "cdecl")
    apr_sha1_update.argtypes = [POINTER(apr_sha1_ctx_t), String, c_uint]
    apr_sha1_update.restype = None

# /usr/include/apr-util/apr_sha1.h: 105
if _libs["aprutil-1"].has("apr_sha1_update_binary", "cdecl"):
    apr_sha1_update_binary = _libs["aprutil-1"].get("apr_sha1_update_binary", "cdecl")
    apr_sha1_update_binary.argtypes = [POINTER(apr_sha1_ctx_t), POINTER(c_ubyte), c_uint]
    apr_sha1_update_binary.restype = None

# /usr/include/apr-util/apr_sha1.h: 114
if _libs["aprutil-1"].has("apr_sha1_final", "cdecl"):
    apr_sha1_final = _libs["aprutil-1"].get("apr_sha1_final", "cdecl")
    apr_sha1_final.argtypes = [c_ubyte * int(20), POINTER(apr_sha1_ctx_t)]
    apr_sha1_final.restype = None

# /usr/include/apr-util/apr_siphash.h: 70
if _libs["aprutil-1"].has("apr_siphash", "cdecl"):
    apr_siphash = _libs["aprutil-1"].get("apr_siphash", "cdecl")
    apr_siphash.argtypes = [POINTER(None), apr_size_t, c_ubyte * int(16), c_uint, c_uint]
    apr_siphash.restype = apr_uint64_t

# /usr/include/apr-util/apr_siphash.h: 87
if _libs["aprutil-1"].has("apr_siphash_auth", "cdecl"):
    apr_siphash_auth = _libs["aprutil-1"].get("apr_siphash_auth", "cdecl")
    apr_siphash_auth.argtypes = [c_ubyte * int(8), POINTER(None), apr_size_t, c_ubyte * int(16), c_uint, c_uint]
    apr_siphash_auth.restype = None

# /usr/include/apr-util/apr_siphash.h: 100
if _libs["aprutil-1"].has("apr_siphash24", "cdecl"):
    apr_siphash24 = _libs["aprutil-1"].get("apr_siphash24", "cdecl")
    apr_siphash24.argtypes = [POINTER(None), apr_size_t, c_ubyte * int(16)]
    apr_siphash24.restype = apr_uint64_t

# /usr/include/apr-util/apr_siphash.h: 114
if _libs["aprutil-1"].has("apr_siphash24_auth", "cdecl"):
    apr_siphash24_auth = _libs["aprutil-1"].get("apr_siphash24_auth", "cdecl")
    apr_siphash24_auth.argtypes = [c_ubyte * int(8), POINTER(None), apr_size_t, c_ubyte * int(16)]
    apr_siphash24_auth.restype = None

# /usr/include/apr-util/apr_siphash.h: 126
if _libs["aprutil-1"].has("apr_siphash48", "cdecl"):
    apr_siphash48 = _libs["aprutil-1"].get("apr_siphash48", "cdecl")
    apr_siphash48.argtypes = [POINTER(None), apr_size_t, c_ubyte * int(16)]
    apr_siphash48.restype = apr_uint64_t

# /usr/include/apr-util/apr_siphash.h: 140
if _libs["aprutil-1"].has("apr_siphash48_auth", "cdecl"):
    apr_siphash48_auth = _libs["aprutil-1"].get("apr_siphash48_auth", "cdecl")
    apr_siphash48_auth.argtypes = [c_ubyte * int(8), POINTER(None), apr_size_t, c_ubyte * int(16)]
    apr_siphash48_auth.restype = None

# /usr/include/apr-util/apr_strmatch.h: 43
class struct_apr_strmatch_pattern(Structure):
    pass

apr_strmatch_pattern = struct_apr_strmatch_pattern# /usr/include/apr-util/apr_strmatch.h: 38

struct_apr_strmatch_pattern.__slots__ = [
    'compare',
    'pattern',
    'length',
    'context',
]
struct_apr_strmatch_pattern._fields_ = [
    ('compare', CFUNCTYPE(UNCHECKED(c_char_p), POINTER(apr_strmatch_pattern), String, apr_size_t)),
    ('pattern', String),
    ('length', apr_size_t),
    ('context', POINTER(None)),
]

# /usr/include/apr-util/apr_strmatch.h: 74
if _libs["aprutil-1"].has("apr_strmatch_precompile", "cdecl"):
    apr_strmatch_precompile = _libs["aprutil-1"].get("apr_strmatch_precompile", "cdecl")
    apr_strmatch_precompile.argtypes = [POINTER(apr_pool_t), String, c_int]
    apr_strmatch_precompile.restype = POINTER(apr_strmatch_pattern)

# /usr/include/apr-util/apr_thread_pool.h: 58
class struct_apr_thread_pool(Structure):
    pass

apr_thread_pool_t = struct_apr_thread_pool# /usr/include/apr-util/apr_thread_pool.h: 58

# /usr/include/apr-util/apr_thread_pool.h: 77
if _libs["aprutil-1"].has("apr_thread_pool_create", "cdecl"):
    apr_thread_pool_create = _libs["aprutil-1"].get("apr_thread_pool_create", "cdecl")
    apr_thread_pool_create.argtypes = [POINTER(POINTER(apr_thread_pool_t)), apr_size_t, apr_size_t, POINTER(apr_pool_t)]
    apr_thread_pool_create.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 86
if _libs["aprutil-1"].has("apr_thread_pool_destroy", "cdecl"):
    apr_thread_pool_destroy = _libs["aprutil-1"].get("apr_thread_pool_destroy", "cdecl")
    apr_thread_pool_destroy.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_destroy.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 97
if _libs["aprutil-1"].has("apr_thread_pool_push", "cdecl"):
    apr_thread_pool_push = _libs["aprutil-1"].get("apr_thread_pool_push", "cdecl")
    apr_thread_pool_push.argtypes = [POINTER(apr_thread_pool_t), apr_thread_start_t, POINTER(None), apr_byte_t, POINTER(None)]
    apr_thread_pool_push.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 111
if _libs["aprutil-1"].has("apr_thread_pool_schedule", "cdecl"):
    apr_thread_pool_schedule = _libs["aprutil-1"].get("apr_thread_pool_schedule", "cdecl")
    apr_thread_pool_schedule.argtypes = [POINTER(apr_thread_pool_t), apr_thread_start_t, POINTER(None), apr_interval_time_t, POINTER(None)]
    apr_thread_pool_schedule.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 126
if _libs["aprutil-1"].has("apr_thread_pool_top", "cdecl"):
    apr_thread_pool_top = _libs["aprutil-1"].get("apr_thread_pool_top", "cdecl")
    apr_thread_pool_top.argtypes = [POINTER(apr_thread_pool_t), apr_thread_start_t, POINTER(None), apr_byte_t, POINTER(None)]
    apr_thread_pool_top.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 141
if _libs["aprutil-1"].has("apr_thread_pool_tasks_cancel", "cdecl"):
    apr_thread_pool_tasks_cancel = _libs["aprutil-1"].get("apr_thread_pool_tasks_cancel", "cdecl")
    apr_thread_pool_tasks_cancel.argtypes = [POINTER(apr_thread_pool_t), POINTER(None)]
    apr_thread_pool_tasks_cancel.restype = apr_status_t

# /usr/include/apr-util/apr_thread_pool.h: 149
if _libs["aprutil-1"].has("apr_thread_pool_tasks_count", "cdecl"):
    apr_thread_pool_tasks_count = _libs["aprutil-1"].get("apr_thread_pool_tasks_count", "cdecl")
    apr_thread_pool_tasks_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_tasks_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 156
if _libs["aprutil-1"].has("apr_thread_pool_scheduled_tasks_count", "cdecl"):
    apr_thread_pool_scheduled_tasks_count = _libs["aprutil-1"].get("apr_thread_pool_scheduled_tasks_count", "cdecl")
    apr_thread_pool_scheduled_tasks_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_scheduled_tasks_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 163
if _libs["aprutil-1"].has("apr_thread_pool_threads_count", "cdecl"):
    apr_thread_pool_threads_count = _libs["aprutil-1"].get("apr_thread_pool_threads_count", "cdecl")
    apr_thread_pool_threads_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_threads_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 170
if _libs["aprutil-1"].has("apr_thread_pool_busy_count", "cdecl"):
    apr_thread_pool_busy_count = _libs["aprutil-1"].get("apr_thread_pool_busy_count", "cdecl")
    apr_thread_pool_busy_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_busy_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 177
if _libs["aprutil-1"].has("apr_thread_pool_idle_count", "cdecl"):
    apr_thread_pool_idle_count = _libs["aprutil-1"].get("apr_thread_pool_idle_count", "cdecl")
    apr_thread_pool_idle_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_idle_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 186
if _libs["aprutil-1"].has("apr_thread_pool_idle_max_set", "cdecl"):
    apr_thread_pool_idle_max_set = _libs["aprutil-1"].get("apr_thread_pool_idle_max_set", "cdecl")
    apr_thread_pool_idle_max_set.argtypes = [POINTER(apr_thread_pool_t), apr_size_t]
    apr_thread_pool_idle_max_set.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 195
if _libs["aprutil-1"].has("apr_thread_pool_tasks_run_count", "cdecl"):
    apr_thread_pool_tasks_run_count = _libs["aprutil-1"].get("apr_thread_pool_tasks_run_count", "cdecl")
    apr_thread_pool_tasks_run_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_tasks_run_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 203
if _libs["aprutil-1"].has("apr_thread_pool_tasks_high_count", "cdecl"):
    apr_thread_pool_tasks_high_count = _libs["aprutil-1"].get("apr_thread_pool_tasks_high_count", "cdecl")
    apr_thread_pool_tasks_high_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_tasks_high_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 211
if _libs["aprutil-1"].has("apr_thread_pool_threads_high_count", "cdecl"):
    apr_thread_pool_threads_high_count = _libs["aprutil-1"].get("apr_thread_pool_threads_high_count", "cdecl")
    apr_thread_pool_threads_high_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_threads_high_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 219
if _libs["aprutil-1"].has("apr_thread_pool_threads_idle_timeout_count", "cdecl"):
    apr_thread_pool_threads_idle_timeout_count = _libs["aprutil-1"].get("apr_thread_pool_threads_idle_timeout_count", "cdecl")
    apr_thread_pool_threads_idle_timeout_count.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_threads_idle_timeout_count.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 226
if _libs["aprutil-1"].has("apr_thread_pool_idle_max_get", "cdecl"):
    apr_thread_pool_idle_max_get = _libs["aprutil-1"].get("apr_thread_pool_idle_max_get", "cdecl")
    apr_thread_pool_idle_max_get.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_idle_max_get.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 234
if _libs["aprutil-1"].has("apr_thread_pool_thread_max_set", "cdecl"):
    apr_thread_pool_thread_max_set = _libs["aprutil-1"].get("apr_thread_pool_thread_max_set", "cdecl")
    apr_thread_pool_thread_max_set.argtypes = [POINTER(apr_thread_pool_t), apr_size_t]
    apr_thread_pool_thread_max_set.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 248
if _libs["aprutil-1"].has("apr_thread_pool_idle_wait_set", "cdecl"):
    apr_thread_pool_idle_wait_set = _libs["aprutil-1"].get("apr_thread_pool_idle_wait_set", "cdecl")
    apr_thread_pool_idle_wait_set.argtypes = [POINTER(apr_thread_pool_t), apr_interval_time_t]
    apr_thread_pool_idle_wait_set.restype = apr_interval_time_t

# /usr/include/apr-util/apr_thread_pool.h: 258
if _libs["aprutil-1"].has("apr_thread_pool_idle_wait_get", "cdecl"):
    apr_thread_pool_idle_wait_get = _libs["aprutil-1"].get("apr_thread_pool_idle_wait_get", "cdecl")
    apr_thread_pool_idle_wait_get.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_idle_wait_get.restype = apr_interval_time_t

# /usr/include/apr-util/apr_thread_pool.h: 265
if _libs["aprutil-1"].has("apr_thread_pool_thread_max_get", "cdecl"):
    apr_thread_pool_thread_max_get = _libs["aprutil-1"].get("apr_thread_pool_thread_max_get", "cdecl")
    apr_thread_pool_thread_max_get.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_thread_max_get.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 273
if _libs["aprutil-1"].has("apr_thread_pool_threshold_set", "cdecl"):
    apr_thread_pool_threshold_set = _libs["aprutil-1"].get("apr_thread_pool_threshold_set", "cdecl")
    apr_thread_pool_threshold_set.argtypes = [POINTER(apr_thread_pool_t), apr_size_t]
    apr_thread_pool_threshold_set.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 281
if _libs["aprutil-1"].has("apr_thread_pool_threshold_get", "cdecl"):
    apr_thread_pool_threshold_get = _libs["aprutil-1"].get("apr_thread_pool_threshold_get", "cdecl")
    apr_thread_pool_threshold_get.argtypes = [POINTER(apr_thread_pool_t)]
    apr_thread_pool_threshold_get.restype = apr_size_t

# /usr/include/apr-util/apr_thread_pool.h: 289
if _libs["aprutil-1"].has("apr_thread_pool_task_owner_get", "cdecl"):
    apr_thread_pool_task_owner_get = _libs["aprutil-1"].get("apr_thread_pool_task_owner_get", "cdecl")
    apr_thread_pool_task_owner_get.argtypes = [POINTER(apr_thread_t), POINTER(POINTER(None))]
    apr_thread_pool_task_owner_get.restype = apr_status_t

# /usr/include/apr-util/apr_uri.h: 85
class struct_apr_uri_t(Structure):
    pass

apr_uri_t = struct_apr_uri_t# /usr/include/apr-util/apr_uri.h: 80

# /usr/include/apr-util/apr_uri.h: 106
class struct_hostent(Structure):
    pass

struct_apr_uri_t.__slots__ = [
    'scheme',
    'hostinfo',
    'user',
    'password',
    'hostname',
    'port_str',
    'path',
    'query',
    'fragment',
    'hostent',
    'port',
    'is_initialized',
    'dns_looked_up',
    'dns_resolved',
]
struct_apr_uri_t._fields_ = [
    ('scheme', String),
    ('hostinfo', String),
    ('user', String),
    ('password', String),
    ('hostname', String),
    ('port_str', String),
    ('path', String),
    ('query', String),
    ('fragment', String),
    ('hostent', POINTER(struct_hostent)),
    ('port', apr_port_t),
    ('is_initialized', c_uint, 1),
    ('dns_looked_up', c_uint, 1),
    ('dns_resolved', c_uint, 1),
]

# /usr/include/apr-util/apr_uri.h: 127
if _libs["aprutil-1"].has("apr_uri_port_of_scheme", "cdecl"):
    apr_uri_port_of_scheme = _libs["aprutil-1"].get("apr_uri_port_of_scheme", "cdecl")
    apr_uri_port_of_scheme.argtypes = [String]
    apr_uri_port_of_scheme.restype = apr_port_t

# /usr/include/apr-util/apr_uri.h: 146
if _libs["aprutil-1"].has("apr_uri_unparse", "cdecl"):
    apr_uri_unparse = _libs["aprutil-1"].get("apr_uri_unparse", "cdecl")
    apr_uri_unparse.argtypes = [POINTER(apr_pool_t), POINTER(apr_uri_t), c_uint]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_uri_unparse.restype = ReturnString
    else:
        apr_uri_unparse.restype = String
        apr_uri_unparse.errcheck = ReturnString

# /usr/include/apr-util/apr_uri.h: 159
if _libs["aprutil-1"].has("apr_uri_parse", "cdecl"):
    apr_uri_parse = _libs["aprutil-1"].get("apr_uri_parse", "cdecl")
    apr_uri_parse.argtypes = [POINTER(apr_pool_t), String, POINTER(apr_uri_t)]
    apr_uri_parse.restype = apr_status_t

# /usr/include/apr-util/apr_uri.h: 169
if _libs["aprutil-1"].has("apr_uri_parse_hostinfo", "cdecl"):
    apr_uri_parse_hostinfo = _libs["aprutil-1"].get("apr_uri_parse_hostinfo", "cdecl")
    apr_uri_parse_hostinfo.argtypes = [POINTER(apr_pool_t), String, POINTER(apr_uri_t)]
    apr_uri_parse_hostinfo.restype = apr_status_t

# /usr/include/apr-util/apr_uuid.h: 43
class struct_anon_128(Structure):
    pass

struct_anon_128.__slots__ = [
    'data',
]
struct_anon_128._fields_ = [
    ('data', c_ubyte * int(16)),
]

apr_uuid_t = struct_anon_128# /usr/include/apr-util/apr_uuid.h: 43

# /usr/include/apr-util/apr_uuid.h: 53
if _libs["aprutil-1"].has("apr_uuid_get", "cdecl"):
    apr_uuid_get = _libs["aprutil-1"].get("apr_uuid_get", "cdecl")
    apr_uuid_get.argtypes = [POINTER(apr_uuid_t)]
    apr_uuid_get.restype = None

# /usr/include/apr-util/apr_uuid.h: 62
if _libs["aprutil-1"].has("apr_uuid_format", "cdecl"):
    apr_uuid_format = _libs["aprutil-1"].get("apr_uuid_format", "cdecl")
    apr_uuid_format.argtypes = [String, POINTER(apr_uuid_t)]
    apr_uuid_format.restype = None

# /usr/include/apr-util/apr_uuid.h: 69
if _libs["aprutil-1"].has("apr_uuid_parse", "cdecl"):
    apr_uuid_parse = _libs["aprutil-1"].get("apr_uuid_parse", "cdecl")
    apr_uuid_parse.argtypes = [POINTER(apr_uuid_t), String]
    apr_uuid_parse.restype = apr_status_t

# /usr/include/apr-util/apr_xml.h: 53
class struct_apr_text(Structure):
    pass

apr_text = struct_apr_text# /usr/include/apr-util/apr_xml.h: 50

struct_apr_text.__slots__ = [
    'text',
    'next',
]
struct_apr_text._fields_ = [
    ('text', String),
    ('next', POINTER(struct_apr_text)),
]

# /usr/include/apr-util/apr_xml.h: 64
class struct_apr_text_header(Structure):
    pass

apr_text_header = struct_apr_text_header# /usr/include/apr-util/apr_xml.h: 61

struct_apr_text_header.__slots__ = [
    'first',
    'last',
]
struct_apr_text_header._fields_ = [
    ('first', POINTER(apr_text)),
    ('last', POINTER(apr_text)),
]

# /usr/include/apr-util/apr_xml.h: 77
if _libs["aprutil-1"].has("apr_text_append", "cdecl"):
    apr_text_append = _libs["aprutil-1"].get("apr_text_append", "cdecl")
    apr_text_append.argtypes = [POINTER(apr_pool_t), POINTER(apr_text_header), String]
    apr_text_append.restype = None

# /usr/include/apr-util/apr_xml.h: 148
class struct_apr_xml_attr(Structure):
    pass

apr_xml_attr = struct_apr_xml_attr# /usr/include/apr-util/apr_xml.h: 141

# /usr/include/apr-util/apr_xml.h: 162
class struct_apr_xml_elem(Structure):
    pass

apr_xml_elem = struct_apr_xml_elem# /usr/include/apr-util/apr_xml.h: 143

# /usr/include/apr-util/apr_xml.h: 200
class struct_apr_xml_doc(Structure):
    pass

apr_xml_doc = struct_apr_xml_doc# /usr/include/apr-util/apr_xml.h: 145

struct_apr_xml_attr.__slots__ = [
    'name',
    'ns',
    'value',
    'next',
]
struct_apr_xml_attr._fields_ = [
    ('name', String),
    ('ns', c_int),
    ('value', String),
    ('next', POINTER(struct_apr_xml_attr)),
]

# /usr/include/apr-util/apr_xml.h: 188
class struct_apr_xml_ns_scope(Structure):
    pass

struct_apr_xml_elem.__slots__ = [
    'name',
    'ns',
    'lang',
    'first_cdata',
    'following_cdata',
    'parent',
    'next',
    'first_child',
    'attr',
    'last_child',
    'ns_scope',
    'priv',
]
struct_apr_xml_elem._fields_ = [
    ('name', String),
    ('ns', c_int),
    ('lang', String),
    ('first_cdata', apr_text_header),
    ('following_cdata', apr_text_header),
    ('parent', POINTER(struct_apr_xml_elem)),
    ('next', POINTER(struct_apr_xml_elem)),
    ('first_child', POINTER(struct_apr_xml_elem)),
    ('attr', POINTER(struct_apr_xml_attr)),
    ('last_child', POINTER(struct_apr_xml_elem)),
    ('ns_scope', POINTER(struct_apr_xml_ns_scope)),
    ('priv', POINTER(None)),
]

struct_apr_xml_doc.__slots__ = [
    'root',
    'namespaces',
]
struct_apr_xml_doc._fields_ = [
    ('root', POINTER(apr_xml_elem)),
    ('namespaces', POINTER(apr_array_header_t)),
]

# /usr/include/apr-util/apr_xml.h: 208
class struct_apr_xml_parser(Structure):
    pass

apr_xml_parser = struct_apr_xml_parser# /usr/include/apr-util/apr_xml.h: 208

# /usr/include/apr-util/apr_xml.h: 215
if _libs["aprutil-1"].has("apr_xml_parser_create", "cdecl"):
    apr_xml_parser_create = _libs["aprutil-1"].get("apr_xml_parser_create", "cdecl")
    apr_xml_parser_create.argtypes = [POINTER(apr_pool_t)]
    apr_xml_parser_create.restype = POINTER(apr_xml_parser)

# /usr/include/apr-util/apr_xml.h: 227
if _libs["aprutil-1"].has("apr_xml_parse_file", "cdecl"):
    apr_xml_parse_file = _libs["aprutil-1"].get("apr_xml_parse_file", "cdecl")
    apr_xml_parse_file.argtypes = [POINTER(apr_pool_t), POINTER(POINTER(apr_xml_parser)), POINTER(POINTER(apr_xml_doc)), POINTER(apr_file_t), apr_size_t]
    apr_xml_parse_file.restype = apr_status_t

# /usr/include/apr-util/apr_xml.h: 242
if _libs["aprutil-1"].has("apr_xml_parser_feed", "cdecl"):
    apr_xml_parser_feed = _libs["aprutil-1"].get("apr_xml_parser_feed", "cdecl")
    apr_xml_parser_feed.argtypes = [POINTER(apr_xml_parser), String, apr_size_t]
    apr_xml_parser_feed.restype = apr_status_t

# /usr/include/apr-util/apr_xml.h: 254
if _libs["aprutil-1"].has("apr_xml_parser_done", "cdecl"):
    apr_xml_parser_done = _libs["aprutil-1"].get("apr_xml_parser_done", "cdecl")
    apr_xml_parser_done.argtypes = [POINTER(apr_xml_parser), POINTER(POINTER(apr_xml_doc))]
    apr_xml_parser_done.restype = apr_status_t

# /usr/include/apr-util/apr_xml.h: 264
if _libs["aprutil-1"].has("apr_xml_parser_geterror", "cdecl"):
    apr_xml_parser_geterror = _libs["aprutil-1"].get("apr_xml_parser_geterror", "cdecl")
    apr_xml_parser_geterror.argtypes = [POINTER(apr_xml_parser), String, apr_size_t]
    if sizeof(c_int) == sizeof(c_void_p):
        apr_xml_parser_geterror.restype = ReturnString
    else:
        apr_xml_parser_geterror.restype = String
        apr_xml_parser_geterror.errcheck = ReturnString

# /usr/include/apr-util/apr_xml.h: 286
if _libs["aprutil-1"].has("apr_xml_to_text", "cdecl"):
    apr_xml_to_text = _libs["aprutil-1"].get("apr_xml_to_text", "cdecl")
    apr_xml_to_text.argtypes = [POINTER(apr_pool_t), POINTER(apr_xml_elem), c_int, POINTER(apr_array_header_t), POINTER(c_int), POINTER(POINTER(c_char)), POINTER(apr_size_t)]
    apr_xml_to_text.restype = None

# /usr/include/apr-util/apr_xml.h: 304
if _libs["aprutil-1"].has("apr_xml_empty_elem", "cdecl"):
    apr_xml_empty_elem = _libs["aprutil-1"].get("apr_xml_empty_elem", "cdecl")
    apr_xml_empty_elem.argtypes = [POINTER(apr_pool_t), POINTER(apr_xml_elem)]
    apr_xml_empty_elem.restype = c_char_p

# /usr/include/apr-util/apr_xml.h: 317
if _libs["aprutil-1"].has("apr_xml_quote_string", "cdecl"):
    apr_xml_quote_string = _libs["aprutil-1"].get("apr_xml_quote_string", "cdecl")
    apr_xml_quote_string.argtypes = [POINTER(apr_pool_t), String, c_int]
    apr_xml_quote_string.restype = c_char_p

# /usr/include/apr-util/apr_xml.h: 325
if _libs["aprutil-1"].has("apr_xml_quote_elem", "cdecl"):
    apr_xml_quote_elem = _libs["aprutil-1"].get("apr_xml_quote_elem", "cdecl")
    apr_xml_quote_elem.argtypes = [POINTER(apr_pool_t), POINTER(apr_xml_elem)]
    apr_xml_quote_elem.restype = None

# /usr/include/apr-util/apr_xml.h: 335
if _libs["aprutil-1"].has("apr_xml_insert_uri", "cdecl"):
    apr_xml_insert_uri = _libs["aprutil-1"].get("apr_xml_insert_uri", "cdecl")
    apr_xml_insert_uri.argtypes = [POINTER(apr_array_header_t), String]
    apr_xml_insert_uri.restype = c_int

# /usr/include/apr-util/apu_version.h: 128
if _libs["aprutil-1"].has("apu_version", "cdecl"):
    apu_version = _libs["aprutil-1"].get("apu_version", "cdecl")
    apu_version.argtypes = [POINTER(apr_version_t)]
    apu_version.restype = None

# /usr/include/apr-util/apu_version.h: 131
if _libs["aprutil-1"].has("apu_version_string", "cdecl"):
    apu_version_string = _libs["aprutil-1"].get("apu_version_string", "cdecl")
    apu_version_string.argtypes = []
    apu_version_string.restype = c_char_p

# /usr/include/bits/socket.h: 41
try:
    PF_UNSPEC = 0
except:
    pass

# /usr/include/bits/socket.h: 42
try:
    PF_LOCAL = 1
except:
    pass

# /usr/include/bits/socket.h: 43
try:
    PF_UNIX = PF_LOCAL
except:
    pass

# /usr/include/bits/socket.h: 45
try:
    PF_INET = 2
except:
    pass

# /usr/include/bits/socket.h: 53
try:
    PF_INET6 = 10
except:
    pass

# /usr/include/bits/socket.h: 93
try:
    AF_UNSPEC = PF_UNSPEC
except:
    pass

# /usr/include/bits/socket.h: 95
try:
    AF_UNIX = PF_UNIX
except:
    pass

# /usr/include/bits/socket.h: 97
try:
    AF_INET = PF_INET
except:
    pass

# /usr/include/bits/socket.h: 105
try:
    AF_INET6 = PF_INET6
except:
    pass

# /usr/include/unistd.h: 316
try:
    SEEK_SET = 0
except:
    pass

# /usr/include/unistd.h: 317
try:
    SEEK_CUR = 1
except:
    pass

# /usr/include/unistd.h: 318
try:
    SEEK_END = 2
except:
    pass

# /usr/include/limits.h: 98
try:
    ULONG_MAX = 4294967295
except:
    pass

# /usr/include/bits/uio_lim.h: 30
try:
    __IOV_MAX = 1024
except:
    pass

# /usr/include/bits/xopen_lim.h: 66
try:
    IOV_MAX = __IOV_MAX
except:
    pass

# /usr/libx32/gcc/x86_64-pld-linux-gnux32/14.2.0/include/limits.h: 134
# #undef ULONG_MAX
try:
    del ULONG_MAX
except NameError:
    pass

# /usr/include/asm-generic/errno-base.h: 6
try:
    ENOENT = 2
except:
    pass

# /usr/include/asm-generic/errno-base.h: 8
try:
    EINTR = 4
except:
    pass

# /usr/include/asm-generic/errno-base.h: 13
try:
    EBADF = 9
except:
    pass

# /usr/include/asm-generic/errno-base.h: 15
try:
    EAGAIN = 11
except:
    pass

# /usr/include/asm-generic/errno-base.h: 16
try:
    ENOMEM = 12
except:
    pass

# /usr/include/asm-generic/errno-base.h: 17
try:
    EACCES = 13
except:
    pass

# /usr/include/asm-generic/errno-base.h: 21
try:
    EEXIST = 17
except:
    pass

# /usr/include/asm-generic/errno-base.h: 22
try:
    EXDEV = 18
except:
    pass

# /usr/include/asm-generic/errno-base.h: 24
try:
    ENOTDIR = 20
except:
    pass

# /usr/include/asm-generic/errno-base.h: 26
try:
    EINVAL = 22
except:
    pass

# /usr/include/asm-generic/errno-base.h: 27
try:
    ENFILE = 23
except:
    pass

# /usr/include/asm-generic/errno-base.h: 28
try:
    EMFILE = 24
except:
    pass

# /usr/include/asm-generic/errno-base.h: 32
try:
    ENOSPC = 28
except:
    pass

# /usr/include/asm-generic/errno-base.h: 33
try:
    ESPIPE = 29
except:
    pass

# /usr/include/asm-generic/errno-base.h: 36
try:
    EPIPE = 32
except:
    pass

# /usr/include/asm-generic/errno-base.h: 38
try:
    ERANGE = 34
except:
    pass

# /usr/include/asm-generic/errno.h: 8
try:
    ENAMETOOLONG = 36
except:
    pass

# /usr/include/asm-generic/errno.h: 20
try:
    ENOTEMPTY = 39
except:
    pass

# /usr/include/asm-generic/errno.h: 54
try:
    EPROTO = 71
except:
    pass

# /usr/include/asm-generic/errno.h: 71
try:
    ENOTSOCK = 88
except:
    pass

# /usr/include/asm-generic/errno.h: 78
try:
    EOPNOTSUPP = 95
except:
    pass

# /usr/include/asm-generic/errno.h: 80
try:
    EAFNOSUPPORT = 97
except:
    pass

# /usr/include/asm-generic/errno.h: 84
try:
    ENETUNREACH = 101
except:
    pass

# /usr/include/asm-generic/errno.h: 86
try:
    ECONNABORTED = 103
except:
    pass

# /usr/include/asm-generic/errno.h: 87
try:
    ECONNRESET = 104
except:
    pass

# /usr/include/asm-generic/errno.h: 93
try:
    ETIMEDOUT = 110
except:
    pass

# /usr/include/asm-generic/errno.h: 94
try:
    ECONNREFUSED = 111
except:
    pass

# /usr/include/asm-generic/errno.h: 96
try:
    EHOSTUNREACH = 113
except:
    pass

# /usr/include/asm-generic/errno.h: 98
try:
    EINPROGRESS = 115
except:
    pass

# /usr/include/asm-generic/errno.h: 105
try:
    EDQUOT = 122
except:
    pass

# /usr/include/errno.h: 38
try:
    errno = ((__errno_location ())[0])
except:
    pass

# /usr/include/apr/apr_errno.h: 117
try:
    APR_OS_START_ERROR = 20000
except:
    pass

# /usr/include/apr/apr_errno.h: 123
try:
    APR_OS_ERRSPACE_SIZE = 50000
except:
    pass

# /usr/include/apr/apr_errno.h: 132
try:
    APR_UTIL_ERRSPACE_SIZE = 20000
except:
    pass

# /usr/include/apr/apr_errno.h: 136
try:
    APR_OS_START_STATUS = (APR_OS_START_ERROR + APR_OS_ERRSPACE_SIZE)
except:
    pass

# /usr/include/apr/apr_errno.h: 141
try:
    APR_UTIL_START_STATUS = (APR_OS_START_STATUS + (APR_OS_ERRSPACE_SIZE - APR_UTIL_ERRSPACE_SIZE))
except:
    pass

# /usr/include/apr/apr_errno.h: 164
try:
    APR_OS_START_USERERR = (APR_OS_START_STATUS + APR_OS_ERRSPACE_SIZE)
except:
    pass

# /usr/include/apr/apr_errno.h: 169
try:
    APR_OS_START_USEERR = APR_OS_START_USERERR
except:
    pass

# /usr/include/apr/apr_errno.h: 174
try:
    APR_OS_START_CANONERR = (APR_OS_START_USERERR + (APR_OS_ERRSPACE_SIZE * 10))
except:
    pass

# /usr/include/apr/apr_errno.h: 180
try:
    APR_OS_START_EAIERR = (APR_OS_START_CANONERR + APR_OS_ERRSPACE_SIZE)
except:
    pass

# /usr/include/apr/apr_errno.h: 185
try:
    APR_OS_START_SYSERR = (APR_OS_START_EAIERR + APR_OS_ERRSPACE_SIZE)
except:
    pass

# /usr/include/apr/apr_errno.h: 225
try:
    APR_SUCCESS = 0
except:
    pass

# /usr/include/apr/apr_errno.h: 288
try:
    APR_ENOSTAT = (APR_OS_START_ERROR + 1)
except:
    pass

# /usr/include/apr/apr_errno.h: 290
try:
    APR_ENOPOOL = (APR_OS_START_ERROR + 2)
except:
    pass

# /usr/include/apr/apr_errno.h: 293
try:
    APR_EBADDATE = (APR_OS_START_ERROR + 4)
except:
    pass

# /usr/include/apr/apr_errno.h: 295
try:
    APR_EINVALSOCK = (APR_OS_START_ERROR + 5)
except:
    pass

# /usr/include/apr/apr_errno.h: 297
try:
    APR_ENOPROC = (APR_OS_START_ERROR + 6)
except:
    pass

# /usr/include/apr/apr_errno.h: 299
try:
    APR_ENOTIME = (APR_OS_START_ERROR + 7)
except:
    pass

# /usr/include/apr/apr_errno.h: 301
try:
    APR_ENODIR = (APR_OS_START_ERROR + 8)
except:
    pass

# /usr/include/apr/apr_errno.h: 303
try:
    APR_ENOLOCK = (APR_OS_START_ERROR + 9)
except:
    pass

# /usr/include/apr/apr_errno.h: 305
try:
    APR_ENOPOLL = (APR_OS_START_ERROR + 10)
except:
    pass

# /usr/include/apr/apr_errno.h: 307
try:
    APR_ENOSOCKET = (APR_OS_START_ERROR + 11)
except:
    pass

# /usr/include/apr/apr_errno.h: 309
try:
    APR_ENOTHREAD = (APR_OS_START_ERROR + 12)
except:
    pass

# /usr/include/apr/apr_errno.h: 311
try:
    APR_ENOTHDKEY = (APR_OS_START_ERROR + 13)
except:
    pass

# /usr/include/apr/apr_errno.h: 313
try:
    APR_EGENERAL = (APR_OS_START_ERROR + 14)
except:
    pass

# /usr/include/apr/apr_errno.h: 315
try:
    APR_ENOSHMAVAIL = (APR_OS_START_ERROR + 15)
except:
    pass

# /usr/include/apr/apr_errno.h: 317
try:
    APR_EBADIP = (APR_OS_START_ERROR + 16)
except:
    pass

# /usr/include/apr/apr_errno.h: 319
try:
    APR_EBADMASK = (APR_OS_START_ERROR + 17)
except:
    pass

# /usr/include/apr/apr_errno.h: 322
try:
    APR_EDSOOPEN = (APR_OS_START_ERROR + 19)
except:
    pass

# /usr/include/apr/apr_errno.h: 324
try:
    APR_EABSOLUTE = (APR_OS_START_ERROR + 20)
except:
    pass

# /usr/include/apr/apr_errno.h: 326
try:
    APR_ERELATIVE = (APR_OS_START_ERROR + 21)
except:
    pass

# /usr/include/apr/apr_errno.h: 328
try:
    APR_EINCOMPLETE = (APR_OS_START_ERROR + 22)
except:
    pass

# /usr/include/apr/apr_errno.h: 330
try:
    APR_EABOVEROOT = (APR_OS_START_ERROR + 23)
except:
    pass

# /usr/include/apr/apr_errno.h: 332
try:
    APR_EBADPATH = (APR_OS_START_ERROR + 24)
except:
    pass

# /usr/include/apr/apr_errno.h: 334
try:
    APR_EPATHWILD = (APR_OS_START_ERROR + 25)
except:
    pass

# /usr/include/apr/apr_errno.h: 336
try:
    APR_ESYMNOTFOUND = (APR_OS_START_ERROR + 26)
except:
    pass

# /usr/include/apr/apr_errno.h: 338
try:
    APR_EPROC_UNKNOWN = (APR_OS_START_ERROR + 27)
except:
    pass

# /usr/include/apr/apr_errno.h: 340
try:
    APR_ENOTENOUGHENTROPY = (APR_OS_START_ERROR + 28)
except:
    pass

# /usr/include/apr/apr_errno.h: 359
def APR_STATUS_IS_ENOSTAT(s):
    return (s == APR_ENOSTAT)

# /usr/include/apr/apr_errno.h: 365
def APR_STATUS_IS_ENOPOOL(s):
    return (s == APR_ENOPOOL)

# /usr/include/apr/apr_errno.h: 367
def APR_STATUS_IS_EBADDATE(s):
    return (s == APR_EBADDATE)

# /usr/include/apr/apr_errno.h: 369
def APR_STATUS_IS_EINVALSOCK(s):
    return (s == APR_EINVALSOCK)

# /usr/include/apr/apr_errno.h: 371
def APR_STATUS_IS_ENOPROC(s):
    return (s == APR_ENOPROC)

# /usr/include/apr/apr_errno.h: 373
def APR_STATUS_IS_ENOTIME(s):
    return (s == APR_ENOTIME)

# /usr/include/apr/apr_errno.h: 375
def APR_STATUS_IS_ENODIR(s):
    return (s == APR_ENODIR)

# /usr/include/apr/apr_errno.h: 377
def APR_STATUS_IS_ENOLOCK(s):
    return (s == APR_ENOLOCK)

# /usr/include/apr/apr_errno.h: 379
def APR_STATUS_IS_ENOPOLL(s):
    return (s == APR_ENOPOLL)

# /usr/include/apr/apr_errno.h: 381
def APR_STATUS_IS_ENOSOCKET(s):
    return (s == APR_ENOSOCKET)

# /usr/include/apr/apr_errno.h: 383
def APR_STATUS_IS_ENOTHREAD(s):
    return (s == APR_ENOTHREAD)

# /usr/include/apr/apr_errno.h: 385
def APR_STATUS_IS_ENOTHDKEY(s):
    return (s == APR_ENOTHDKEY)

# /usr/include/apr/apr_errno.h: 387
def APR_STATUS_IS_EGENERAL(s):
    return (s == APR_EGENERAL)

# /usr/include/apr/apr_errno.h: 389
def APR_STATUS_IS_ENOSHMAVAIL(s):
    return (s == APR_ENOSHMAVAIL)

# /usr/include/apr/apr_errno.h: 391
def APR_STATUS_IS_EBADIP(s):
    return (s == APR_EBADIP)

# /usr/include/apr/apr_errno.h: 393
def APR_STATUS_IS_EBADMASK(s):
    return (s == APR_EBADMASK)

# /usr/include/apr/apr_errno.h: 403
def APR_STATUS_IS_EDSOOPEN(s):
    return (s == APR_EDSOOPEN)

# /usr/include/apr/apr_errno.h: 406
def APR_STATUS_IS_EABSOLUTE(s):
    return (s == APR_EABSOLUTE)

# /usr/include/apr/apr_errno.h: 408
def APR_STATUS_IS_ERELATIVE(s):
    return (s == APR_ERELATIVE)

# /usr/include/apr/apr_errno.h: 410
def APR_STATUS_IS_EINCOMPLETE(s):
    return (s == APR_EINCOMPLETE)

# /usr/include/apr/apr_errno.h: 412
def APR_STATUS_IS_EABOVEROOT(s):
    return (s == APR_EABOVEROOT)

# /usr/include/apr/apr_errno.h: 414
def APR_STATUS_IS_EBADPATH(s):
    return (s == APR_EBADPATH)

# /usr/include/apr/apr_errno.h: 416
def APR_STATUS_IS_EPATHWILD(s):
    return (s == APR_EPATHWILD)

# /usr/include/apr/apr_errno.h: 424
def APR_STATUS_IS_ESYMNOTFOUND(s):
    return (s == APR_ESYMNOTFOUND)

# /usr/include/apr/apr_errno.h: 427
def APR_STATUS_IS_EPROC_UNKNOWN(s):
    return (s == APR_EPROC_UNKNOWN)

# /usr/include/apr/apr_errno.h: 429
def APR_STATUS_IS_ENOTENOUGHENTROPY(s):
    return (s == APR_ENOTENOUGHENTROPY)

# /usr/include/apr/apr_errno.h: 438
try:
    APR_INCHILD = (APR_OS_START_STATUS + 1)
except:
    pass

# /usr/include/apr/apr_errno.h: 440
try:
    APR_INPARENT = (APR_OS_START_STATUS + 2)
except:
    pass

# /usr/include/apr/apr_errno.h: 442
try:
    APR_DETACH = (APR_OS_START_STATUS + 3)
except:
    pass

# /usr/include/apr/apr_errno.h: 444
try:
    APR_NOTDETACH = (APR_OS_START_STATUS + 4)
except:
    pass

# /usr/include/apr/apr_errno.h: 446
try:
    APR_CHILD_DONE = (APR_OS_START_STATUS + 5)
except:
    pass

# /usr/include/apr/apr_errno.h: 448
try:
    APR_CHILD_NOTDONE = (APR_OS_START_STATUS + 6)
except:
    pass

# /usr/include/apr/apr_errno.h: 450
try:
    APR_TIMEUP = (APR_OS_START_STATUS + 7)
except:
    pass

# /usr/include/apr/apr_errno.h: 452
try:
    APR_INCOMPLETE = (APR_OS_START_STATUS + 8)
except:
    pass

# /usr/include/apr/apr_errno.h: 457
try:
    APR_BADCH = (APR_OS_START_STATUS + 12)
except:
    pass

# /usr/include/apr/apr_errno.h: 459
try:
    APR_BADARG = (APR_OS_START_STATUS + 13)
except:
    pass

# /usr/include/apr/apr_errno.h: 461
try:
    APR_EOF = (APR_OS_START_STATUS + 14)
except:
    pass

# /usr/include/apr/apr_errno.h: 463
try:
    APR_NOTFOUND = (APR_OS_START_STATUS + 15)
except:
    pass

# /usr/include/apr/apr_errno.h: 468
try:
    APR_ANONYMOUS = (APR_OS_START_STATUS + 19)
except:
    pass

# /usr/include/apr/apr_errno.h: 470
try:
    APR_FILEBASED = (APR_OS_START_STATUS + 20)
except:
    pass

# /usr/include/apr/apr_errno.h: 472
try:
    APR_KEYBASED = (APR_OS_START_STATUS + 21)
except:
    pass

# /usr/include/apr/apr_errno.h: 474
try:
    APR_EINIT = (APR_OS_START_STATUS + 22)
except:
    pass

# /usr/include/apr/apr_errno.h: 476
try:
    APR_ENOTIMPL = (APR_OS_START_STATUS + 23)
except:
    pass

# /usr/include/apr/apr_errno.h: 478
try:
    APR_EMISMATCH = (APR_OS_START_STATUS + 24)
except:
    pass

# /usr/include/apr/apr_errno.h: 480
try:
    APR_EBUSY = (APR_OS_START_STATUS + 25)
except:
    pass

# /usr/include/apr/apr_errno.h: 492
def APR_STATUS_IS_INCHILD(s):
    return (s == APR_INCHILD)

# /usr/include/apr/apr_errno.h: 499
def APR_STATUS_IS_INPARENT(s):
    return (s == APR_INPARENT)

# /usr/include/apr/apr_errno.h: 506
def APR_STATUS_IS_DETACH(s):
    return (s == APR_DETACH)

# /usr/include/apr/apr_errno.h: 513
def APR_STATUS_IS_NOTDETACH(s):
    return (s == APR_NOTDETACH)

# /usr/include/apr/apr_errno.h: 520
def APR_STATUS_IS_CHILD_DONE(s):
    return (s == APR_CHILD_DONE)

# /usr/include/apr/apr_errno.h: 527
def APR_STATUS_IS_CHILD_NOTDONE(s):
    return (s == APR_CHILD_NOTDONE)

# /usr/include/apr/apr_errno.h: 534
def APR_STATUS_IS_TIMEUP(s):
    return (s == APR_TIMEUP)

# /usr/include/apr/apr_errno.h: 542
def APR_STATUS_IS_INCOMPLETE(s):
    return (s == APR_INCOMPLETE)

# /usr/include/apr/apr_errno.h: 552
def APR_STATUS_IS_BADCH(s):
    return (s == APR_BADCH)

# /usr/include/apr/apr_errno.h: 560
def APR_STATUS_IS_BADARG(s):
    return (s == APR_BADARG)

# /usr/include/apr/apr_errno.h: 567
def APR_STATUS_IS_EOF(s):
    return (s == APR_EOF)

# /usr/include/apr/apr_errno.h: 574
def APR_STATUS_IS_NOTFOUND(s):
    return (s == APR_NOTFOUND)

# /usr/include/apr/apr_errno.h: 584
def APR_STATUS_IS_ANONYMOUS(s):
    return (s == APR_ANONYMOUS)

# /usr/include/apr/apr_errno.h: 591
def APR_STATUS_IS_FILEBASED(s):
    return (s == APR_FILEBASED)

# /usr/include/apr/apr_errno.h: 598
def APR_STATUS_IS_KEYBASED(s):
    return (s == APR_KEYBASED)

# /usr/include/apr/apr_errno.h: 606
def APR_STATUS_IS_EINIT(s):
    return (s == APR_EINIT)

# /usr/include/apr/apr_errno.h: 615
def APR_STATUS_IS_ENOTIMPL(s):
    return (s == APR_ENOTIMPL)

# /usr/include/apr/apr_errno.h: 622
def APR_STATUS_IS_EMISMATCH(s):
    return (s == APR_EMISMATCH)

# /usr/include/apr/apr_errno.h: 628
def APR_STATUS_IS_EBUSY(s):
    return (s == APR_EBUSY)

# /usr/include/apr/apr_errno.h: 639
try:
    APR_EACCES = EACCES
except:
    pass

# /usr/include/apr/apr_errno.h: 646
try:
    APR_EEXIST = EEXIST
except:
    pass

# /usr/include/apr/apr_errno.h: 653
try:
    APR_ENAMETOOLONG = ENAMETOOLONG
except:
    pass

# /usr/include/apr/apr_errno.h: 660
try:
    APR_ENOENT = ENOENT
except:
    pass

# /usr/include/apr/apr_errno.h: 667
try:
    APR_ENOTDIR = ENOTDIR
except:
    pass

# /usr/include/apr/apr_errno.h: 674
try:
    APR_ENOSPC = ENOSPC
except:
    pass

# /usr/include/apr/apr_errno.h: 681
try:
    APR_ENOMEM = ENOMEM
except:
    pass

# /usr/include/apr/apr_errno.h: 688
try:
    APR_EMFILE = EMFILE
except:
    pass

# /usr/include/apr/apr_errno.h: 695
try:
    APR_ENFILE = ENFILE
except:
    pass

# /usr/include/apr/apr_errno.h: 702
try:
    APR_EBADF = EBADF
except:
    pass

# /usr/include/apr/apr_errno.h: 709
try:
    APR_EINVAL = EINVAL
except:
    pass

# /usr/include/apr/apr_errno.h: 716
try:
    APR_ESPIPE = ESPIPE
except:
    pass

# /usr/include/apr/apr_errno.h: 726
try:
    APR_EAGAIN = EAGAIN
except:
    pass

# /usr/include/apr/apr_errno.h: 735
try:
    APR_EINTR = EINTR
except:
    pass

# /usr/include/apr/apr_errno.h: 742
try:
    APR_ENOTSOCK = ENOTSOCK
except:
    pass

# /usr/include/apr/apr_errno.h: 749
try:
    APR_ECONNREFUSED = ECONNREFUSED
except:
    pass

# /usr/include/apr/apr_errno.h: 756
try:
    APR_EINPROGRESS = EINPROGRESS
except:
    pass

# /usr/include/apr/apr_errno.h: 767
try:
    APR_ECONNABORTED = ECONNABORTED
except:
    pass

# /usr/include/apr/apr_errno.h: 774
try:
    APR_ECONNRESET = ECONNRESET
except:
    pass

# /usr/include/apr/apr_errno.h: 782
try:
    APR_ETIMEDOUT = ETIMEDOUT
except:
    pass

# /usr/include/apr/apr_errno.h: 789
try:
    APR_EHOSTUNREACH = EHOSTUNREACH
except:
    pass

# /usr/include/apr/apr_errno.h: 796
try:
    APR_ENETUNREACH = ENETUNREACH
except:
    pass

# /usr/include/apr/apr_errno.h: 805
try:
    APR_EFTYPE = (APR_OS_START_CANONERR + 23)
except:
    pass

# /usr/include/apr/apr_errno.h: 810
try:
    APR_EPIPE = EPIPE
except:
    pass

# /usr/include/apr/apr_errno.h: 817
try:
    APR_EXDEV = EXDEV
except:
    pass

# /usr/include/apr/apr_errno.h: 824
try:
    APR_ENOTEMPTY = ENOTEMPTY
except:
    pass

# /usr/include/apr/apr_errno.h: 831
try:
    APR_EAFNOSUPPORT = EAFNOSUPPORT
except:
    pass

# /usr/include/apr/apr_errno.h: 838
try:
    APR_EOPNOTSUPP = EOPNOTSUPP
except:
    pass

# /usr/include/apr/apr_errno.h: 845
try:
    APR_ERANGE = ERANGE
except:
    pass

# /usr/include/apr/apr_errno.h: 1214
def APR_FROM_OS_ERROR(e):
    return e

# /usr/include/apr/apr_errno.h: 1215
def APR_TO_OS_ERROR(e):
    return e

# /usr/include/apr/apr_errno.h: 1217
try:
    apr_get_os_error = errno
except:
    pass

# /usr/include/apr/apr_errno.h: 1218
def apr_set_os_error(e):
    return e

# /usr/include/apr/apr_errno.h: 1222
try:
    apr_get_netos_error = errno
except:
    pass

# /usr/include/apr/apr_errno.h: 1223
def apr_set_netos_error(e):
    return e

# /usr/include/apr/apr_errno.h: 1231
def APR_STATUS_IS_EACCES(s):
    return (s == APR_EACCES)

# /usr/include/apr/apr_errno.h: 1233
def APR_STATUS_IS_EEXIST(s):
    return (s == APR_EEXIST)

# /usr/include/apr/apr_errno.h: 1235
def APR_STATUS_IS_ENAMETOOLONG(s):
    return (s == APR_ENAMETOOLONG)

# /usr/include/apr/apr_errno.h: 1246
def APR_STATUS_IS_ENOENT(s):
    return (s == APR_ENOENT)

# /usr/include/apr/apr_errno.h: 1249
def APR_STATUS_IS_ENOTDIR(s):
    return (s == APR_ENOTDIR)

# /usr/include/apr/apr_errno.h: 1252
def APR_STATUS_IS_ENOSPC(s):
    return ((s == APR_ENOSPC) or (s == EDQUOT))

# /usr/include/apr/apr_errno.h: 1258
def APR_STATUS_IS_ENOMEM(s):
    return (s == APR_ENOMEM)

# /usr/include/apr/apr_errno.h: 1260
def APR_STATUS_IS_EMFILE(s):
    return (s == APR_EMFILE)

# /usr/include/apr/apr_errno.h: 1262
def APR_STATUS_IS_ENFILE(s):
    return (s == APR_ENFILE)

# /usr/include/apr/apr_errno.h: 1264
def APR_STATUS_IS_EBADF(s):
    return (s == APR_EBADF)

# /usr/include/apr/apr_errno.h: 1266
def APR_STATUS_IS_EINVAL(s):
    return (s == APR_EINVAL)

# /usr/include/apr/apr_errno.h: 1268
def APR_STATUS_IS_ESPIPE(s):
    return (s == APR_ESPIPE)

# /usr/include/apr/apr_errno.h: 1274
def APR_STATUS_IS_EAGAIN(s):
    return (s == APR_EAGAIN)

# /usr/include/apr/apr_errno.h: 1281
def APR_STATUS_IS_EINTR(s):
    return (s == APR_EINTR)

# /usr/include/apr/apr_errno.h: 1283
def APR_STATUS_IS_ENOTSOCK(s):
    return (s == APR_ENOTSOCK)

# /usr/include/apr/apr_errno.h: 1285
def APR_STATUS_IS_ECONNREFUSED(s):
    return (s == APR_ECONNREFUSED)

# /usr/include/apr/apr_errno.h: 1287
def APR_STATUS_IS_EINPROGRESS(s):
    return (s == APR_EINPROGRESS)

# /usr/include/apr/apr_errno.h: 1301
def APR_STATUS_IS_ECONNABORTED(s):
    return ((s == APR_ECONNABORTED) or (s == EPROTO))

# /usr/include/apr/apr_errno.h: 1308
def APR_STATUS_IS_ECONNRESET(s):
    return (s == APR_ECONNRESET)

# /usr/include/apr/apr_errno.h: 1311
def APR_STATUS_IS_ETIMEDOUT(s):
    return (s == APR_ETIMEDOUT)

# /usr/include/apr/apr_errno.h: 1313
def APR_STATUS_IS_EHOSTUNREACH(s):
    return (s == APR_EHOSTUNREACH)

# /usr/include/apr/apr_errno.h: 1315
def APR_STATUS_IS_ENETUNREACH(s):
    return (s == APR_ENETUNREACH)

# /usr/include/apr/apr_errno.h: 1317
def APR_STATUS_IS_EFTYPE(s):
    return (s == APR_EFTYPE)

# /usr/include/apr/apr_errno.h: 1319
def APR_STATUS_IS_EPIPE(s):
    return (s == APR_EPIPE)

# /usr/include/apr/apr_errno.h: 1321
def APR_STATUS_IS_EXDEV(s):
    return (s == APR_EXDEV)

# /usr/include/apr/apr_errno.h: 1323
def APR_STATUS_IS_ENOTEMPTY(s):
    return ((s == APR_ENOTEMPTY) or (s == APR_EEXIST))

# /usr/include/apr/apr_errno.h: 1326
def APR_STATUS_IS_EAFNOSUPPORT(s):
    return (s == APR_EAFNOSUPPORT)

# /usr/include/apr/apr_errno.h: 1328
def APR_STATUS_IS_EOPNOTSUPP(s):
    return (s == APR_EOPNOTSUPP)

# /usr/include/apr/apr_errno.h: 1331
def APR_STATUS_IS_ERANGE(s):
    return (s == APR_ERANGE)

# /usr/include/apr/apr_general.h: 51
try:
    FALSE = 0
except:
    pass

# /usr/include/apr/apr_general.h: 55
try:
    TRUE = (not FALSE)
except:
    pass

# /usr/include/apr/apr_general.h: 59
try:
    APR_ASCII_BLANK = '0'
except:
    pass

# /usr/include/apr/apr_general.h: 61
try:
    APR_ASCII_CR = '5'
except:
    pass

# /usr/include/apr/apr_general.h: 63
try:
    APR_ASCII_LF = '2'
except:
    pass

# /usr/include/apr/apr_general.h: 65
try:
    APR_ASCII_TAB = '1'
except:
    pass

# /usr/include/apr/apr_general.h: 143
def APR_ALIGN(size, boundary):
    return ((size + (boundary - 1)) & (~(boundary - 1)))

# /usr/include/apr/apr_general.h: 147
def APR_ALIGN_DEFAULT(size):
    return (APR_ALIGN (size, 8))

# /usr/include/apr/apr_general.h: 157
def APR_STRINGIFY(n):
    return (APR_STRINGIFY_HELPER (n))

# /usr/include/apr/apr_general.h: 159
def APR_STRINGIFY_HELPER(n):
    return n

# /usr/include/apr/apr_pools.h: 139
try:
    APR_POOL_DEBUG = 0
except:
    pass

# /usr/include/apr/apr_allocator.h: 64
try:
    APR_MEMNODE_T_SIZE = (APR_ALIGN_DEFAULT (sizeof(apr_memnode_t)))
except:
    pass

# /usr/include/apr/apr_allocator.h: 67
try:
    APR_ALLOCATOR_MAX_FREE_UNLIMITED = 0
except:
    pass

# /usr/include/apr/apr_thread_mutex.h: 43
try:
    APR_THREAD_MUTEX_DEFAULT = 0x0
except:
    pass

# /usr/include/apr/apr_thread_mutex.h: 44
try:
    APR_THREAD_MUTEX_NESTED = 0x1
except:
    pass

# /usr/include/apr/apr_thread_mutex.h: 45
try:
    APR_THREAD_MUTEX_UNNESTED = 0x2
except:
    pass

# /usr/include/apr/apr_thread_mutex.h: 46
try:
    APR_THREAD_MUTEX_TIMED = 0x4
except:
    pass

# /usr/include/apr/apr_time.h: 69
def apr_time_msec(time):
    return ((time / 1000) % 1000)

# /usr/include/apr/apr_time.h: 72
def apr_time_as_msec(time):
    return (time / 1000)

# /usr/include/apr/apr_time.h: 75
def apr_time_from_msec(msec):
    return ((apr_time_t (ord_if_char(msec))).value * 1000)

# /usr/include/apr/apr_time.h: 186
try:
    APR_RFC822_DATE_LEN = 30
except:
    pass

# /usr/include/apr/apr_time.h: 198
try:
    APR_CTIME_LEN = 25
except:
    pass

# /usr/include/apr/apr_pools.h: 465
def apr_pcalloc(p, size):
    return (memset ((apr_palloc (p, size)), 0, size))

# /usr/include/apr/apr_hash.h: 47
try:
    APR_HASH_KEY_STRING = (-1)
except:
    pass

# /usr/include/apr/apr_tables.h: 437
try:
    APR_OVERLAP_TABLES_SET = 0
except:
    pass

# /usr/include/apr/apr_tables.h: 439
try:
    APR_OVERLAP_TABLES_MERGE = 1
except:
    pass

# /usr/include/apr/apr_tables.h: 441
try:
    APR_OVERLAP_TABLES_ADD = 2
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types_impl.h: 99
try:
    SVN_INVALID_REVNUM = (svn_revnum_t (ord_if_char((-1)))).value
except:
    pass

# /usr/include/apr/apr_version.h: 41
try:
    APR_COPYRIGHT = 'Copyright 2024 The Apache Software Foundation.'
except:
    pass

# /usr/include/apr/apr_version.h: 52
try:
    APR_MAJOR_VERSION = 1
except:
    pass

# /usr/include/apr/apr_version.h: 58
try:
    APR_MINOR_VERSION = 7
except:
    pass

# /usr/include/apr/apr_version.h: 64
try:
    APR_PATCH_VERSION = 5
except:
    pass

# /usr/include/apr/apr_version.h: 85
def APR_VERSION_AT_LEAST(major, minor, patch):
    return (((major < APR_MAJOR_VERSION) or ((major == APR_MAJOR_VERSION) and (minor < APR_MINOR_VERSION))) or (((major == APR_MAJOR_VERSION) and (minor == APR_MINOR_VERSION)) and (patch <= APR_PATCH_VERSION)))

# /usr/include/apr/apr_version.h: 96
try:
    APR_IS_DEV_STRING = ''
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 132
try:
    SVN_UNALIGNED_ACCESS_IS_OK = 1
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 170
try:
    SVN_VA_NULL = cast(0, POINTER(struct_svn__null_pointer_constant_stdarg_sentinel_t))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 287
def SVN__APR_STATUS_IS_ENOTDIR(s):
    return (APR_STATUS_IS_ENOTDIR (s))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 298
def SVN__APR_STATUS_IS_EPIPE(s):
    return (APR_STATUS_IS_EPIPE (s))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 393
def SVN_IS_VALID_REVNUM(n):
    return (n >= 0)

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 399
try:
    SVN_IGNORED_REVNUM = (svn_revnum_t (ord_if_char((-1)))).value
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 402
def SVN_STR_TO_REV(str):
    return (svn_revnum_t (ord_if_char((atol (str))))).value

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 429
try:
    SVN_REVNUM_T_FMT = 'ld'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 437
try:
    SVN_INVALID_FILESIZE = (svn_filesize_t (ord_if_char((-1)))).value
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 446
def svn__atoui64(X):
    return (apr_uint64_t (ord_if_char((apr_atoi64 (X))))).value

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 486
def SVN_DEPTH_INFINITY_OR_FILES(recurse):
    return recurse and svn_depth_infinity or svn_depth_files

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 497
def SVN_DEPTH_INFINITY_OR_IMMEDIATES(recurse):
    return recurse and svn_depth_infinity or svn_depth_immediates

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 508
def SVN_DEPTH_INFINITY_OR_EMPTY(recurse):
    return recurse and svn_depth_infinity or svn_depth_empty

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 518
def SVN_DEPTH_IS_RECURSIVE(depth):
    return ((depth == svn_depth_infinity) or (depth == svn_depth_unknown))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 534
try:
    SVN_DIRENT_KIND = 0x00001
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 537
try:
    SVN_DIRENT_SIZE = 0x00002
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 540
try:
    SVN_DIRENT_HAS_PROPS = 0x00004
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 543
try:
    SVN_DIRENT_CREATED_REV = 0x00008
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 546
try:
    SVN_DIRENT_TIME = 0x00010
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 549
try:
    SVN_DIRENT_LAST_AUTHOR = 0x00020
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 552
try:
    SVN_DIRENT_ALL = (~(apr_uint32_t (ord_if_char(0))).value)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 641
try:
    SVN_KEYWORD_MAX_LEN = 255
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 644
try:
    SVN_KEYWORD_REVISION_LONG = 'LastChangedRevision'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 647
try:
    SVN_KEYWORD_REVISION_SHORT = 'Rev'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 651
try:
    SVN_KEYWORD_REVISION_MEDIUM = 'Revision'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 654
try:
    SVN_KEYWORD_DATE_LONG = 'LastChangedDate'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 657
try:
    SVN_KEYWORD_DATE_SHORT = 'Date'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 660
try:
    SVN_KEYWORD_AUTHOR_LONG = 'LastChangedBy'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 663
try:
    SVN_KEYWORD_AUTHOR_SHORT = 'Author'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 666
try:
    SVN_KEYWORD_URL_LONG = 'HeadURL'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 669
try:
    SVN_KEYWORD_URL_SHORT = 'URL'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 672
try:
    SVN_KEYWORD_ID = 'Id'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 676
try:
    SVN_KEYWORD_HEADER = 'Header'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1026
try:
    SVN_STREAM_CHUNK_SIZE = 102400
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1039
try:
    SVN__STREAM_CHUNK_SIZE = 16384
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1044
try:
    SVN_MAX_OBJECT_SIZE = ((apr_size_t (ord_if_char((-1)))).value / 2)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1251
try:
    SVN_LINENUM_MAX_VALUE = ULONG_MAX
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 54
try:
    SVN_NO_ERROR = 0
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 103
try:
    SVN_ERR_CATEGORY_SIZE = 5000
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 107
try:
    SVN_ERR_BAD_CATEGORY_START = (APR_OS_START_USERERR + (1 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 109
try:
    SVN_ERR_XML_CATEGORY_START = (APR_OS_START_USERERR + (2 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 111
try:
    SVN_ERR_IO_CATEGORY_START = (APR_OS_START_USERERR + (3 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 113
try:
    SVN_ERR_STREAM_CATEGORY_START = (APR_OS_START_USERERR + (4 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 115
try:
    SVN_ERR_NODE_CATEGORY_START = (APR_OS_START_USERERR + (5 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 117
try:
    SVN_ERR_ENTRY_CATEGORY_START = (APR_OS_START_USERERR + (6 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 119
try:
    SVN_ERR_WC_CATEGORY_START = (APR_OS_START_USERERR + (7 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 121
try:
    SVN_ERR_FS_CATEGORY_START = (APR_OS_START_USERERR + (8 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 123
try:
    SVN_ERR_REPOS_CATEGORY_START = (APR_OS_START_USERERR + (9 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 125
try:
    SVN_ERR_RA_CATEGORY_START = (APR_OS_START_USERERR + (10 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 127
try:
    SVN_ERR_RA_DAV_CATEGORY_START = (APR_OS_START_USERERR + (11 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 129
try:
    SVN_ERR_RA_LOCAL_CATEGORY_START = (APR_OS_START_USERERR + (12 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 131
try:
    SVN_ERR_SVNDIFF_CATEGORY_START = (APR_OS_START_USERERR + (13 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 133
try:
    SVN_ERR_APMOD_CATEGORY_START = (APR_OS_START_USERERR + (14 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 135
try:
    SVN_ERR_CLIENT_CATEGORY_START = (APR_OS_START_USERERR + (15 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 137
try:
    SVN_ERR_MISC_CATEGORY_START = (APR_OS_START_USERERR + (16 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 139
try:
    SVN_ERR_CL_CATEGORY_START = (APR_OS_START_USERERR + (17 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 141
try:
    SVN_ERR_RA_SVN_CATEGORY_START = (APR_OS_START_USERERR + (18 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 143
try:
    SVN_ERR_AUTHN_CATEGORY_START = (APR_OS_START_USERERR + (19 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 145
try:
    SVN_ERR_AUTHZ_CATEGORY_START = (APR_OS_START_USERERR + (20 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 147
try:
    SVN_ERR_DIFF_CATEGORY_START = (APR_OS_START_USERERR + (21 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 149
try:
    SVN_ERR_RA_SERF_CATEGORY_START = (APR_OS_START_USERERR + (22 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 151
try:
    SVN_ERR_MALFUNC_CATEGORY_START = (APR_OS_START_USERERR + (23 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error_codes.h: 153
try:
    SVN_ERR_X509_CATEGORY_START = (APR_OS_START_USERERR + (24 * SVN_ERR_CATEGORY_SIZE))
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 373
def svn_error_trace(expr):
    return expr

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 451
def SVN_ERR_IS_LOCK_ERROR(err):
    return ((((((((((err.contents.apr_err).value) == SVN_ERR_FS_PATH_ALREADY_LOCKED) or (((err.contents.apr_err).value) == SVN_ERR_FS_NOT_FOUND)) or (((err.contents.apr_err).value) == SVN_ERR_FS_OUT_OF_DATE)) or (((err.contents.apr_err).value) == SVN_ERR_FS_BAD_LOCK_TOKEN)) or (((err.contents.apr_err).value) == SVN_ERR_REPOS_HOOK_FAILURE)) or (((err.contents.apr_err).value) == SVN_ERR_FS_NO_SUCH_REVISION)) or (((err.contents.apr_err).value) == SVN_ERR_FS_OUT_OF_DATE)) or (((err.contents.apr_err).value) == SVN_ERR_FS_NOT_FILE))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 469
def SVN_ERR_IS_UNLOCK_ERROR(err):
    return (((((((((err.contents.apr_err).value) == SVN_ERR_FS_PATH_NOT_LOCKED) or (((err.contents.apr_err).value) == SVN_ERR_FS_BAD_LOCK_TOKEN)) or (((err.contents.apr_err).value) == SVN_ERR_FS_LOCK_OWNER_MISMATCH)) or (((err.contents.apr_err).value) == SVN_ERR_FS_NO_SUCH_LOCK)) or (((err.contents.apr_err).value) == SVN_ERR_RA_NOT_LOCKED)) or (((err.contents.apr_err).value) == SVN_ERR_FS_LOCK_EXPIRED)) or (((err.contents.apr_err).value) == SVN_ERR_REPOS_HOOK_FAILURE))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_error.h: 484
def SVN_ERROR_IN_CATEGORY(apr_err, category):
    return (category == ((apr_err / SVN_ERR_CATEGORY_SIZE) * SVN_ERR_CATEGORY_SIZE))

# /usr/include/apr/apr_user.h: 113
def apr_uid_compare(left, right):
    return (left == right) and APR_SUCCESS or APR_EMISMATCH

# /usr/include/apr/apr_user.h: 147
def apr_gid_compare(left, right):
    return (left == right) and APR_SUCCESS or APR_EMISMATCH

# /usr/include/apr/apr_file_info.h: 79
try:
    APR_FPROT_USETID = 0x8000
except:
    pass

# /usr/include/apr/apr_file_info.h: 80
try:
    APR_FPROT_UREAD = 0x0400
except:
    pass

# /usr/include/apr/apr_file_info.h: 81
try:
    APR_FPROT_UWRITE = 0x0200
except:
    pass

# /usr/include/apr/apr_file_info.h: 82
try:
    APR_FPROT_UEXECUTE = 0x0100
except:
    pass

# /usr/include/apr/apr_file_info.h: 84
try:
    APR_FPROT_GSETID = 0x4000
except:
    pass

# /usr/include/apr/apr_file_info.h: 85
try:
    APR_FPROT_GREAD = 0x0040
except:
    pass

# /usr/include/apr/apr_file_info.h: 86
try:
    APR_FPROT_GWRITE = 0x0020
except:
    pass

# /usr/include/apr/apr_file_info.h: 87
try:
    APR_FPROT_GEXECUTE = 0x0010
except:
    pass

# /usr/include/apr/apr_file_info.h: 89
try:
    APR_FPROT_WSTICKY = 0x2000
except:
    pass

# /usr/include/apr/apr_file_info.h: 90
try:
    APR_FPROT_WREAD = 0x0004
except:
    pass

# /usr/include/apr/apr_file_info.h: 91
try:
    APR_FPROT_WWRITE = 0x0002
except:
    pass

# /usr/include/apr/apr_file_info.h: 92
try:
    APR_FPROT_WEXECUTE = 0x0001
except:
    pass

# /usr/include/apr/apr_file_info.h: 94
try:
    APR_FPROT_OS_DEFAULT = 0x0FFF
except:
    pass

# /usr/include/apr/apr_file_info.h: 97
try:
    APR_FPROT_FILE_SOURCE_PERMS = 0x1000
except:
    pass

# /usr/include/apr/apr_file_info.h: 100
try:
    APR_USETID = APR_FPROT_USETID
except:
    pass

# /usr/include/apr/apr_file_info.h: 101
try:
    APR_UREAD = APR_FPROT_UREAD
except:
    pass

# /usr/include/apr/apr_file_info.h: 102
try:
    APR_UWRITE = APR_FPROT_UWRITE
except:
    pass

# /usr/include/apr/apr_file_info.h: 103
try:
    APR_UEXECUTE = APR_FPROT_UEXECUTE
except:
    pass

# /usr/include/apr/apr_file_info.h: 104
try:
    APR_GSETID = APR_FPROT_GSETID
except:
    pass

# /usr/include/apr/apr_file_info.h: 105
try:
    APR_GREAD = APR_FPROT_GREAD
except:
    pass

# /usr/include/apr/apr_file_info.h: 106
try:
    APR_GWRITE = APR_FPROT_GWRITE
except:
    pass

# /usr/include/apr/apr_file_info.h: 107
try:
    APR_GEXECUTE = APR_FPROT_GEXECUTE
except:
    pass

# /usr/include/apr/apr_file_info.h: 108
try:
    APR_WSTICKY = APR_FPROT_WSTICKY
except:
    pass

# /usr/include/apr/apr_file_info.h: 109
try:
    APR_WREAD = APR_FPROT_WREAD
except:
    pass

# /usr/include/apr/apr_file_info.h: 110
try:
    APR_WWRITE = APR_FPROT_WWRITE
except:
    pass

# /usr/include/apr/apr_file_info.h: 111
try:
    APR_WEXECUTE = APR_FPROT_WEXECUTE
except:
    pass

# /usr/include/apr/apr_file_info.h: 112
try:
    APR_OS_DEFAULT = APR_FPROT_OS_DEFAULT
except:
    pass

# /usr/include/apr/apr_file_info.h: 113
try:
    APR_FILE_SOURCE_PERMS = APR_FPROT_FILE_SOURCE_PERMS
except:
    pass

# /usr/include/apr/apr_file_info.h: 145
try:
    APR_FINFO_LINK = 0x00000001
except:
    pass

# /usr/include/apr/apr_file_info.h: 146
try:
    APR_FINFO_MTIME = 0x00000010
except:
    pass

# /usr/include/apr/apr_file_info.h: 147
try:
    APR_FINFO_CTIME = 0x00000020
except:
    pass

# /usr/include/apr/apr_file_info.h: 148
try:
    APR_FINFO_ATIME = 0x00000040
except:
    pass

# /usr/include/apr/apr_file_info.h: 149
try:
    APR_FINFO_SIZE = 0x00000100
except:
    pass

# /usr/include/apr/apr_file_info.h: 150
try:
    APR_FINFO_CSIZE = 0x00000200
except:
    pass

# /usr/include/apr/apr_file_info.h: 151
try:
    APR_FINFO_DEV = 0x00001000
except:
    pass

# /usr/include/apr/apr_file_info.h: 152
try:
    APR_FINFO_INODE = 0x00002000
except:
    pass

# /usr/include/apr/apr_file_info.h: 153
try:
    APR_FINFO_NLINK = 0x00004000
except:
    pass

# /usr/include/apr/apr_file_info.h: 154
try:
    APR_FINFO_TYPE = 0x00008000
except:
    pass

# /usr/include/apr/apr_file_info.h: 155
try:
    APR_FINFO_USER = 0x00010000
except:
    pass

# /usr/include/apr/apr_file_info.h: 156
try:
    APR_FINFO_GROUP = 0x00020000
except:
    pass

# /usr/include/apr/apr_file_info.h: 157
try:
    APR_FINFO_UPROT = 0x00100000
except:
    pass

# /usr/include/apr/apr_file_info.h: 158
try:
    APR_FINFO_GPROT = 0x00200000
except:
    pass

# /usr/include/apr/apr_file_info.h: 159
try:
    APR_FINFO_WPROT = 0x00400000
except:
    pass

# /usr/include/apr/apr_file_info.h: 160
try:
    APR_FINFO_ICASE = 0x01000000
except:
    pass

# /usr/include/apr/apr_file_info.h: 161
try:
    APR_FINFO_NAME = 0x02000000
except:
    pass

# /usr/include/apr/apr_file_info.h: 163
try:
    APR_FINFO_MIN = 0x00008170
except:
    pass

# /usr/include/apr/apr_file_info.h: 164
try:
    APR_FINFO_IDENT = 0x00003000
except:
    pass

# /usr/include/apr/apr_file_info.h: 165
try:
    APR_FINFO_OWNER = 0x00030000
except:
    pass

# /usr/include/apr/apr_file_info.h: 166
try:
    APR_FINFO_PROT = 0x00700000
except:
    pass

# /usr/include/apr/apr_file_info.h: 167
try:
    APR_FINFO_NORM = 0x0073b170
except:
    pass

# /usr/include/apr/apr_file_info.h: 168
try:
    APR_FINFO_DIRENT = 0x02000000
except:
    pass

# /usr/include/apr/apr_file_info.h: 287
try:
    APR_FILEPATH_NOTABOVEROOT = 0x01
except:
    pass

# /usr/include/apr/apr_file_info.h: 290
try:
    APR_FILEPATH_SECUREROOTTEST = 0x02
except:
    pass

# /usr/include/apr/apr_file_info.h: 295
try:
    APR_FILEPATH_SECUREROOT = 0x03
except:
    pass

# /usr/include/apr/apr_file_info.h: 298
try:
    APR_FILEPATH_NOTRELATIVE = 0x04
except:
    pass

# /usr/include/apr/apr_file_info.h: 301
try:
    APR_FILEPATH_NOTABSOLUTE = 0x08
except:
    pass

# /usr/include/apr/apr_file_info.h: 305
try:
    APR_FILEPATH_NATIVE = 0x10
except:
    pass

# /usr/include/apr/apr_file_info.h: 311
try:
    APR_FILEPATH_TRUENAME = 0x20
except:
    pass

# /usr/include/apr/apr_file_info.h: 404
try:
    APR_FILEPATH_ENCODING_UNKNOWN = 0
except:
    pass

# /usr/include/apr/apr_file_info.h: 407
try:
    APR_FILEPATH_ENCODING_LOCALE = 1
except:
    pass

# /usr/include/apr/apr_file_info.h: 410
try:
    APR_FILEPATH_ENCODING_UTF8 = 2
except:
    pass

# /usr/include/apr/apr_file_io.h: 54
try:
    APR_FOPEN_READ = 0x00001
except:
    pass

# /usr/include/apr/apr_file_io.h: 55
try:
    APR_FOPEN_WRITE = 0x00002
except:
    pass

# /usr/include/apr/apr_file_io.h: 56
try:
    APR_FOPEN_CREATE = 0x00004
except:
    pass

# /usr/include/apr/apr_file_io.h: 57
try:
    APR_FOPEN_APPEND = 0x00008
except:
    pass

# /usr/include/apr/apr_file_io.h: 58
try:
    APR_FOPEN_TRUNCATE = 0x00010
except:
    pass

# /usr/include/apr/apr_file_io.h: 60
try:
    APR_FOPEN_BINARY = 0x00020
except:
    pass

# /usr/include/apr/apr_file_io.h: 63
try:
    APR_FOPEN_EXCL = 0x00040
except:
    pass

# /usr/include/apr/apr_file_io.h: 65
try:
    APR_FOPEN_BUFFERED = 0x00080
except:
    pass

# /usr/include/apr/apr_file_io.h: 66
try:
    APR_FOPEN_DELONCLOSE = 0x00100
except:
    pass

# /usr/include/apr/apr_file_io.h: 67
try:
    APR_FOPEN_XTHREAD = 0x00200
except:
    pass

# /usr/include/apr/apr_file_io.h: 70
try:
    APR_FOPEN_SHARELOCK = 0x00400
except:
    pass

# /usr/include/apr/apr_file_io.h: 74
try:
    APR_FOPEN_NOCLEANUP = 0x00800
except:
    pass

# /usr/include/apr/apr_file_io.h: 79
try:
    APR_FOPEN_SENDFILE_ENABLED = 0x01000
except:
    pass

# /usr/include/apr/apr_file_io.h: 82
try:
    APR_FOPEN_LARGEFILE = 0x04000
except:
    pass

# /usr/include/apr/apr_file_io.h: 85
try:
    APR_FOPEN_SPARSE = 0x08000
except:
    pass

# /usr/include/apr/apr_file_io.h: 88
try:
    APR_FOPEN_NONBLOCK = 0x40000
except:
    pass

# /usr/include/apr/apr_file_io.h: 93
try:
    APR_READ = APR_FOPEN_READ
except:
    pass

# /usr/include/apr/apr_file_io.h: 94
try:
    APR_WRITE = APR_FOPEN_WRITE
except:
    pass

# /usr/include/apr/apr_file_io.h: 95
try:
    APR_CREATE = APR_FOPEN_CREATE
except:
    pass

# /usr/include/apr/apr_file_io.h: 96
try:
    APR_APPEND = APR_FOPEN_APPEND
except:
    pass

# /usr/include/apr/apr_file_io.h: 97
try:
    APR_TRUNCATE = APR_FOPEN_TRUNCATE
except:
    pass

# /usr/include/apr/apr_file_io.h: 98
try:
    APR_BINARY = APR_FOPEN_BINARY
except:
    pass

# /usr/include/apr/apr_file_io.h: 99
try:
    APR_EXCL = APR_FOPEN_EXCL
except:
    pass

# /usr/include/apr/apr_file_io.h: 100
try:
    APR_BUFFERED = APR_FOPEN_BUFFERED
except:
    pass

# /usr/include/apr/apr_file_io.h: 101
try:
    APR_DELONCLOSE = APR_FOPEN_DELONCLOSE
except:
    pass

# /usr/include/apr/apr_file_io.h: 102
try:
    APR_XTHREAD = APR_FOPEN_XTHREAD
except:
    pass

# /usr/include/apr/apr_file_io.h: 103
try:
    APR_SHARELOCK = APR_FOPEN_SHARELOCK
except:
    pass

# /usr/include/apr/apr_file_io.h: 104
try:
    APR_FILE_NOCLEANUP = APR_FOPEN_NOCLEANUP
except:
    pass

# /usr/include/apr/apr_file_io.h: 105
try:
    APR_SENDFILE_ENABLED = APR_FOPEN_SENDFILE_ENABLED
except:
    pass

# /usr/include/apr/apr_file_io.h: 106
try:
    APR_LARGEFILE = APR_FOPEN_LARGEFILE
except:
    pass

# /usr/include/apr/apr_file_io.h: 145
try:
    APR_SET = SEEK_SET
except:
    pass

# /usr/include/apr/apr_file_io.h: 147
try:
    APR_CUR = SEEK_CUR
except:
    pass

# /usr/include/apr/apr_file_io.h: 149
try:
    APR_END = SEEK_END
except:
    pass

# /usr/include/apr/apr_file_io.h: 158
try:
    APR_FILE_ATTR_READONLY = 0x01
except:
    pass

# /usr/include/apr/apr_file_io.h: 159
try:
    APR_FILE_ATTR_EXECUTABLE = 0x02
except:
    pass

# /usr/include/apr/apr_file_io.h: 160
try:
    APR_FILE_ATTR_HIDDEN = 0x04
except:
    pass

# /usr/include/apr/apr_file_io.h: 171
try:
    APR_MAX_IOVEC_SIZE = IOV_MAX
except:
    pass

# /usr/include/apr/apr_file_io.h: 196
try:
    APR_FLOCK_SHARED = 1
except:
    pass

# /usr/include/apr/apr_file_io.h: 202
try:
    APR_FLOCK_EXCLUSIVE = 2
except:
    pass

# /usr/include/apr/apr_file_io.h: 207
try:
    APR_FLOCK_TYPEMASK = 0x000F
except:
    pass

# /usr/include/apr/apr_file_io.h: 208
try:
    APR_FLOCK_NONBLOCK = 0x0010
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 73
def APR_PROC_CHECK_EXIT(x):
    return (x & APR_PROC_EXIT)

# /usr/include/apr/apr_thread_proc.h: 75
def APR_PROC_CHECK_SIGNALED(x):
    return (x & APR_PROC_SIGNAL)

# /usr/include/apr/apr_thread_proc.h: 77
def APR_PROC_CHECK_CORE_DUMP(x):
    return (x & APR_PROC_SIGNAL_CORE)

# /usr/include/apr/apr_thread_proc.h: 80
try:
    APR_NO_PIPE = 0
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 82
try:
    APR_FULL_BLOCK = 1
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 84
try:
    APR_FULL_NONBLOCK = 2
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 86
try:
    APR_PARENT_BLOCK = 3
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 88
try:
    APR_CHILD_BLOCK = 4
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 90
try:
    APR_NO_FILE = 8
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 93
try:
    APR_READ_BLOCK = 3
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 95
try:
    APR_WRITE_BLOCK = 4
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 100
try:
    APR_NO_FILE = 8
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 103
try:
    APR_LIMIT_CPU = 0
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 105
try:
    APR_LIMIT_MEM = 1
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 107
try:
    APR_LIMIT_NPROC = 2
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 109
try:
    APR_LIMIT_NOFILE = 3
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 115
try:
    APR_OC_REASON_DEATH = 0
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 117
try:
    APR_OC_REASON_UNWRITABLE = 1
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 118
try:
    APR_OC_REASON_RESTART = 2
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 122
try:
    APR_OC_REASON_UNREGISTER = 3
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 125
try:
    APR_OC_REASON_LOST = 4
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 127
try:
    APR_OC_REASON_RUNNING = 5
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 692
try:
    APR_PROC_DETACH_FOREGROUND = 0
except:
    pass

# /usr/include/apr/apr_thread_proc.h: 693
try:
    APR_PROC_DETACH_DAEMONIZE = 1
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 75
try:
    SVN_CONFIG_CATEGORY_SERVERS = 'servers'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 76
try:
    SVN_CONFIG_SECTION_GROUPS = 'groups'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 77
try:
    SVN_CONFIG_SECTION_GLOBAL = 'global'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 78
try:
    SVN_CONFIG_OPTION_HTTP_PROXY_HOST = 'http-proxy-host'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 79
try:
    SVN_CONFIG_OPTION_HTTP_PROXY_PORT = 'http-proxy-port'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 80
try:
    SVN_CONFIG_OPTION_HTTP_PROXY_USERNAME = 'http-proxy-username'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 81
try:
    SVN_CONFIG_OPTION_HTTP_PROXY_PASSWORD = 'http-proxy-password'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 82
try:
    SVN_CONFIG_OPTION_HTTP_PROXY_EXCEPTIONS = 'http-proxy-exceptions'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 83
try:
    SVN_CONFIG_OPTION_HTTP_TIMEOUT = 'http-timeout'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 84
try:
    SVN_CONFIG_OPTION_HTTP_COMPRESSION = 'http-compression'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 86
try:
    SVN_CONFIG_OPTION_NEON_DEBUG_MASK = 'neon-debug-mask'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 88
try:
    SVN_CONFIG_OPTION_HTTP_AUTH_TYPES = 'http-auth-types'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 89
try:
    SVN_CONFIG_OPTION_SSL_AUTHORITY_FILES = 'ssl-authority-files'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 90
try:
    SVN_CONFIG_OPTION_SSL_TRUST_DEFAULT_CA = 'ssl-trust-default-ca'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 91
try:
    SVN_CONFIG_OPTION_SSL_CLIENT_CERT_FILE = 'ssl-client-cert-file'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 92
try:
    SVN_CONFIG_OPTION_SSL_CLIENT_CERT_PASSWORD = 'ssl-client-cert-password'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 95
try:
    SVN_CONFIG_OPTION_SSL_PKCS11_PROVIDER = 'ssl-pkcs11-provider'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 97
try:
    SVN_CONFIG_OPTION_HTTP_LIBRARY = 'http-library'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 99
try:
    SVN_CONFIG_OPTION_STORE_PASSWORDS = 'store-passwords'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 101
try:
    SVN_CONFIG_OPTION_STORE_PLAINTEXT_PASSWORDS = 'store-plaintext-passwords'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 102
try:
    SVN_CONFIG_OPTION_STORE_AUTH_CREDS = 'store-auth-creds'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 104
try:
    SVN_CONFIG_OPTION_STORE_SSL_CLIENT_CERT_PP = 'store-ssl-client-cert-pp'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 106
try:
    SVN_CONFIG_OPTION_STORE_SSL_CLIENT_CERT_PP_PLAINTEXT = 'store-ssl-client-cert-pp-plaintext'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 108
try:
    SVN_CONFIG_OPTION_USERNAME = 'username'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 110
try:
    SVN_CONFIG_OPTION_HTTP_BULK_UPDATES = 'http-bulk-updates'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 112
try:
    SVN_CONFIG_OPTION_HTTP_MAX_CONNECTIONS = 'http-max-connections'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 114
try:
    SVN_CONFIG_OPTION_HTTP_CHUNKED_REQUESTS = 'http-chunked-requests'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 117
try:
    SVN_CONFIG_OPTION_SERF_LOG_COMPONENTS = 'serf-log-components'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 119
try:
    SVN_CONFIG_OPTION_SERF_LOG_LEVEL = 'serf-log-level'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 122
try:
    SVN_CONFIG_CATEGORY_CONFIG = 'config'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 123
try:
    SVN_CONFIG_SECTION_AUTH = 'auth'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 125
try:
    SVN_CONFIG_OPTION_PASSWORD_STORES = 'password-stores'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 127
try:
    SVN_CONFIG_OPTION_KWALLET_WALLET = 'kwallet-wallet'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 129
try:
    SVN_CONFIG_OPTION_KWALLET_SVN_APPLICATION_NAME_WITH_PID = 'kwallet-svn-application-name-with-pid'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 131
try:
    SVN_CONFIG_OPTION_SSL_CLIENT_CERT_FILE_PROMPT = 'ssl-client-cert-file-prompt'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 134
try:
    SVN_CONFIG_SECTION_HELPERS = 'helpers'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 135
try:
    SVN_CONFIG_OPTION_EDITOR_CMD = 'editor-cmd'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 136
try:
    SVN_CONFIG_OPTION_DIFF_CMD = 'diff-cmd'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 138
try:
    SVN_CONFIG_OPTION_DIFF_EXTENSIONS = 'diff-extensions'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 139
try:
    SVN_CONFIG_OPTION_DIFF3_CMD = 'diff3-cmd'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 140
try:
    SVN_CONFIG_OPTION_DIFF3_HAS_PROGRAM_ARG = 'diff3-has-program-arg'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 142
try:
    SVN_CONFIG_OPTION_MERGE_TOOL_CMD = 'merge-tool-cmd'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 143
try:
    SVN_CONFIG_SECTION_MISCELLANY = 'miscellany'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 144
try:
    SVN_CONFIG_OPTION_GLOBAL_IGNORES = 'global-ignores'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 145
try:
    SVN_CONFIG_OPTION_LOG_ENCODING = 'log-encoding'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 146
try:
    SVN_CONFIG_OPTION_USE_COMMIT_TIMES = 'use-commit-times'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 148
try:
    SVN_CONFIG_OPTION_TEMPLATE_ROOT = 'template-root'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 149
try:
    SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS = 'enable-auto-props'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 151
try:
    SVN_CONFIG_OPTION_ENABLE_MAGIC_FILE = 'enable-magic-file'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 153
try:
    SVN_CONFIG_OPTION_NO_UNLOCK = 'no-unlock'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 155
try:
    SVN_CONFIG_OPTION_MIMETYPES_FILE = 'mime-types-file'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 157
try:
    SVN_CONFIG_OPTION_PRESERVED_CF_EXTS = 'preserved-conflict-file-exts'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 159
try:
    SVN_CONFIG_OPTION_INTERACTIVE_CONFLICTS = 'interactive-conflicts'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 161
try:
    SVN_CONFIG_OPTION_MEMORY_CACHE_SIZE = 'memory-cache-size'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 163
try:
    SVN_CONFIG_OPTION_DIFF_IGNORE_CONTENT_TYPE = 'diff-ignore-content-type'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 164
try:
    SVN_CONFIG_SECTION_TUNNELS = 'tunnels'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 165
try:
    SVN_CONFIG_SECTION_AUTO_PROPS = 'auto-props'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 167
try:
    SVN_CONFIG_SECTION_WORKING_COPY = 'working-copy'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 169
try:
    SVN_CONFIG_OPTION_SQLITE_EXCLUSIVE = 'exclusive-locking'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 171
try:
    SVN_CONFIG_OPTION_SQLITE_EXCLUSIVE_CLIENTS = 'exclusive-locking-clients'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 173
try:
    SVN_CONFIG_OPTION_SQLITE_BUSY_TIMEOUT = 'busy-timeout'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 182
try:
    SVN_CONFIG_SECTION_GENERAL = 'general'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 183
try:
    SVN_CONFIG_OPTION_ANON_ACCESS = 'anon-access'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 184
try:
    SVN_CONFIG_OPTION_AUTH_ACCESS = 'auth-access'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 185
try:
    SVN_CONFIG_OPTION_PASSWORD_DB = 'password-db'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 186
try:
    SVN_CONFIG_OPTION_REALM = 'realm'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 187
try:
    SVN_CONFIG_OPTION_AUTHZ_DB = 'authz-db'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 189
try:
    SVN_CONFIG_OPTION_GROUPS_DB = 'groups-db'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 191
try:
    SVN_CONFIG_OPTION_FORCE_USERNAME_CASE = 'force-username-case'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 193
try:
    SVN_CONFIG_OPTION_HOOKS_ENV = 'hooks-env'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 195
try:
    SVN_CONFIG_SECTION_SASL = 'sasl'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 197
try:
    SVN_CONFIG_OPTION_USE_SASL = 'use-sasl'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 199
try:
    SVN_CONFIG_OPTION_MIN_SSF = 'min-encryption'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 201
try:
    SVN_CONFIG_OPTION_MAX_SSF = 'max-encryption'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 204
try:
    SVN_CONFIG_SECTION_USERS = 'users'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 214
try:
    SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_1 = '*.o *.lo *.la *.al .libs *.so *.so.[0-9]* *.a *.pyc *.pyo __pycache__'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 216
try:
    SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_2 = '*.rej *~ #*# .#* .*.swp .DS_Store [Tt]humbs.db'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 224
try:
    SVN_CONFIG_TRUE = 'TRUE'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 225
try:
    SVN_CONFIG_FALSE = 'FALSE'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 226
try:
    SVN_CONFIG_ASK = 'ASK'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 231
try:
    SVN_CONFIG_DEFAULT_OPTION_STORE_PASSWORDS = TRUE
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 232
try:
    SVN_CONFIG_DEFAULT_OPTION_STORE_PLAINTEXT_PASSWORDS = SVN_CONFIG_ASK
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 233
try:
    SVN_CONFIG_DEFAULT_OPTION_STORE_AUTH_CREDS = TRUE
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 234
try:
    SVN_CONFIG_DEFAULT_OPTION_STORE_SSL_CLIENT_CERT_PP = TRUE
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 235
try:
    SVN_CONFIG_DEFAULT_OPTION_STORE_SSL_CLIENT_CERT_PP_PLAINTEXT = SVN_CONFIG_ASK
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 237
try:
    SVN_CONFIG_DEFAULT_OPTION_HTTP_MAX_CONNECTIONS = 4
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 716
try:
    SVN_CONFIG_REALMSTRING_KEY = 'svn:realmstring'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 721
try:
    SVN_CONFIG_AUTHN_USERNAME_KEY = 'username'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 728
try:
    SVN_CONFIG_AUTHN_PASSWORD_KEY = 'password'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 735
try:
    SVN_CONFIG_AUTHN_PASSPHRASE_KEY = 'passphrase'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 741
try:
    SVN_CONFIG_AUTHN_PASSTYPE_KEY = 'passtype'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 748
try:
    SVN_CONFIG_AUTHN_ASCII_CERT_KEY = 'ascii_cert'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 755
try:
    SVN_CONFIG_AUTHN_FAILURES_KEY = 'failures'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 186
try:
    SVN_AUTH_CRED_SIMPLE = 'svn.simple'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 210
try:
    SVN_AUTH_CRED_USERNAME = 'svn.username'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 236
try:
    SVN_AUTH_CRED_SSL_CLIENT_CERT = 'svn.ssl.client-cert'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 271
try:
    SVN_AUTH_CRED_SSL_CLIENT_CERT_PW = 'svn.ssl.client-passphrase'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 300
try:
    SVN_AUTH_CRED_SSL_SERVER_TRUST = 'svn.ssl.server'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 412
try:
    SVN_AUTH_SSL_NOTYETVALID = 0x00000001
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 414
try:
    SVN_AUTH_SSL_EXPIRED = 0x00000002
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 416
try:
    SVN_AUTH_SSL_CNMISMATCH = 0x00000004
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 418
try:
    SVN_AUTH_SSL_UNKNOWNCA = 0x00000008
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 421
try:
    SVN_AUTH_SSL_OTHER = 0x40000000
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 568
try:
    SVN_AUTH_PARAM_PREFIX = 'svn:auth:'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1017
try:
    SVN_AUTH_PARAM_GNOME_KEYRING_UNLOCK_PROMPT_FUNC = 'gnome-keyring-unlock-prompt-func'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 1022
try:
    SVN_AUTH_PARAM_GNOME_KEYRING_UNLOCK_PROMPT_BATON = 'gnome-keyring-unlock-prompt-baton'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 56
try:
    SVN_DELTA_COMPRESSION_LEVEL_NONE = 0
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 62
try:
    SVN_DELTA_COMPRESSION_LEVEL_MAX = 9
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 70
try:
    SVN_DELTA_COMPRESSION_LEVEL_DEFAULT = 5
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 69
try:
    SVN_OPT_MAX_ALIASES = 3
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 72
try:
    SVN_OPT_MAX_OPTIONS = 50
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 76
try:
    SVN_OPT_MAX_PARAGRAPHS = 100
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 81
try:
    SVN_OPT_FIRST_LONGOPT_ID = 256
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_mergeinfo.h: 107
try:
    SVN_MERGEINFO_NONINHERITABLE_STR = '*'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2197
try:
    SVN_RA_CAPABILITY_DEPTH = 'depth'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2207
try:
    SVN_RA_CAPABILITY_MERGEINFO = 'mergeinfo'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2214
try:
    SVN_RA_CAPABILITY_LOG_REVPROPS = 'log-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2221
try:
    SVN_RA_CAPABILITY_PARTIAL_REPLAY = 'partial-replay'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2228
try:
    SVN_RA_CAPABILITY_COMMIT_REVPROPS = 'commit-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2236
try:
    SVN_RA_CAPABILITY_ATOMIC_REVPROPS = 'atomic-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2243
try:
    SVN_RA_CAPABILITY_INHERITED_PROPS = 'inherited-props'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2251
try:
    SVN_RA_CAPABILITY_EPHEMERAL_TXNPROPS = 'ephemeral-txnprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2259
try:
    SVN_RA_CAPABILITY_GET_FILE_REVS_REVERSE = 'get-file-revs-reversed'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2266
try:
    SVN_RA_CAPABILITY_LIST = 'list'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2584
try:
    SVN_RA_ABI_VERSION = 2
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 125
try:
    SVN_WC_TRANSLATE_FROM_NF = 0x00000000
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 132
try:
    SVN_WC_TRANSLATE_TO_NF = 0x00000001
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 139
try:
    SVN_WC_TRANSLATE_FORCE_EOL_REPAIR = 0x00000002
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 142
try:
    SVN_WC_TRANSLATE_NO_OUTPUT_CLEANUP = 0x00000004
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 148
try:
    SVN_WC_TRANSLATE_FORCE_COPY = 0x00000008
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 155
try:
    SVN_WC_TRANSLATE_USE_GLOBAL_TMP = 0x00000010
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 624
try:
    SVN_WC_ADM_DIR_NAME = '.svn'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2894
try:
    SVN_WC_ENTRY_WORKING_SIZE_UNKNOWN = (-1)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3140
try:
    SVN_WC_ENTRY_THIS_DIR = ''
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 437
try:
    SVN_CLIENT_COMMIT_ITEM_ADD = 0x01
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 438
try:
    SVN_CLIENT_COMMIT_ITEM_DELETE = 0x02
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 439
try:
    SVN_CLIENT_COMMIT_ITEM_TEXT_MODS = 0x04
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 440
try:
    SVN_CLIENT_COMMIT_ITEM_PROP_MODS = 0x08
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 441
try:
    SVN_CLIENT_COMMIT_ITEM_IS_COPY = 0x10
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 447
try:
    SVN_CLIENT_COMMIT_ITEM_LOCK_TOKEN = 0x20
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 453
try:
    SVN_CLIENT_COMMIT_ITEM_MOVED_HERE = 0x40
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1126
try:
    SVN_CLIENT_AUTH_USERNAME = 'username'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1131
try:
    SVN_CLIENT_AUTH_PASSWORD = 'password'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7181
try:
    SVN_INFO_SIZE_UNKNOWN = (apr_size_t (ord_if_char((-1)))).value
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 48
def svn_ctype_test(c, flags):
    return (0 != ((svn_ctype_table [(c_ubyte (ord_if_char(c))).value]) & flags))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 58
try:
    SVN_CTYPE_CNTRL = 0x0001
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 59
try:
    SVN_CTYPE_SPACE = 0x0002
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 60
try:
    SVN_CTYPE_DIGIT = 0x0004
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 61
try:
    SVN_CTYPE_UPPER = 0x0008
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 62
try:
    SVN_CTYPE_LOWER = 0x0010
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 63
try:
    SVN_CTYPE_PUNCT = 0x0020
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 64
try:
    SVN_CTYPE_XALPHA = 0x0040
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 65
try:
    SVN_CTYPE_ASCII = 0x0080
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 69
try:
    SVN_CTYPE_ALPHA = (SVN_CTYPE_LOWER | SVN_CTYPE_UPPER)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 71
try:
    SVN_CTYPE_ALNUM = (SVN_CTYPE_ALPHA | SVN_CTYPE_DIGIT)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 73
try:
    SVN_CTYPE_XDIGIT = (SVN_CTYPE_DIGIT | SVN_CTYPE_XALPHA)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 75
try:
    SVN_CTYPE_GRAPH = (SVN_CTYPE_PUNCT | SVN_CTYPE_ALNUM)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 77
try:
    SVN_CTYPE_PRINT = (SVN_CTYPE_GRAPH | SVN_CTYPE_SPACE)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 81
def svn_ctype_iscntrl(c):
    return (svn_ctype_test (c, SVN_CTYPE_CNTRL))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 84
def svn_ctype_isspace(c):
    return (svn_ctype_test (c, SVN_CTYPE_SPACE))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 87
def svn_ctype_isdigit(c):
    return (svn_ctype_test (c, SVN_CTYPE_DIGIT))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 90
def svn_ctype_isupper(c):
    return (svn_ctype_test (c, SVN_CTYPE_UPPER))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 93
def svn_ctype_islower(c):
    return (svn_ctype_test (c, SVN_CTYPE_LOWER))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 96
def svn_ctype_ispunct(c):
    return (svn_ctype_test (c, SVN_CTYPE_PUNCT))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 99
def svn_ctype_isascii(c):
    return (svn_ctype_test (c, SVN_CTYPE_ASCII))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 102
def svn_ctype_isalpha(c):
    return (svn_ctype_test (c, SVN_CTYPE_ALPHA))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 105
def svn_ctype_isalnum(c):
    return (svn_ctype_test (c, SVN_CTYPE_ALNUM))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 108
def svn_ctype_isxdigit(c):
    return (svn_ctype_test (c, SVN_CTYPE_XDIGIT))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 111
def svn_ctype_isgraph(c):
    return (svn_ctype_test (c, SVN_CTYPE_GRAPH))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 114
def svn_ctype_isprint(c):
    return (svn_ctype_test (c, SVN_CTYPE_PRINT))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 124
try:
    SVN_CTYPE_UTF8LEAD = 0x0100
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 125
try:
    SVN_CTYPE_UTF8CONT = 0x0200
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 133
try:
    SVN_CTYPE_UTF8MBC = (SVN_CTYPE_UTF8LEAD | SVN_CTYPE_UTF8CONT)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 135
try:
    SVN_CTYPE_UTF8 = (SVN_CTYPE_ASCII | SVN_CTYPE_UTF8MBC)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 138
def svn_ctype_isutf8lead(c):
    return (svn_ctype_test (c, SVN_CTYPE_UTF8LEAD))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 144
def svn_ctype_isutf8mbc(c):
    return (svn_ctype_test (c, SVN_CTYPE_UTF8MBC))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 147
def svn_ctype_isutf8(c):
    return (svn_ctype_test (c, SVN_CTYPE_UTF8))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 156
try:
    SVN_CTYPE_ASCII_MINUS = 45
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 157
try:
    SVN_CTYPE_ASCII_DOT = 46
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 158
try:
    SVN_CTYPE_ASCII_COLON = 58
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 159
try:
    SVN_CTYPE_ASCII_UNDERSCORE = 95
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 160
try:
    SVN_CTYPE_ASCII_TAB = 9
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 161
try:
    SVN_CTYPE_ASCII_LINEFEED = 10
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 162
try:
    SVN_CTYPE_ASCII_CARRIAGERETURN = 13
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ctype.h: 164
try:
    SVN_CTYPE_ASCII_DELETE = 127
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 44
try:
    SVN_SVNDIFF_MIME_TYPE = 'application/vnd.svn-svndiff'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 52
try:
    SVN_SKEL_MIME_TYPE = 'application/vnd.svn-skel'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 66
try:
    SVN_DAV_DELTA_BASE_HEADER = 'X-SVN-VR-Base'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 71
try:
    SVN_DAV_OPTIONS_HEADER = 'X-SVN-Options'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 78
try:
    SVN_DAV_OPTION_NO_MERGE_RESPONSE = 'no-merge-response'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 79
try:
    SVN_DAV_OPTION_LOCK_BREAK = 'lock-break'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 80
try:
    SVN_DAV_OPTION_LOCK_STEAL = 'lock-steal'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 81
try:
    SVN_DAV_OPTION_RELEASE_LOCKS = 'release-locks'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 82
try:
    SVN_DAV_OPTION_KEEP_LOCKS = 'keep-locks'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 90
try:
    SVN_DAV_VERSION_NAME_HEADER = 'X-SVN-Version-Name'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 95
try:
    SVN_DAV_CREATIONDATE_HEADER = 'X-SVN-Creation-Date'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 103
try:
    SVN_DAV_LOCK_OWNER_HEADER = 'X-SVN-Lock-Owner'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 109
try:
    SVN_DAV_YOUNGEST_REV_HEADER = 'SVN-Youngest-Rev'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 115
try:
    SVN_DAV_REPOS_UUID_HEADER = 'SVN-Repository-UUID'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 122
try:
    SVN_DAV_ME_RESOURCE_HEADER = 'SVN-Me-Resource'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 128
try:
    SVN_DAV_ROOT_URI_HEADER = 'SVN-Repository-Root'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 136
try:
    SVN_DAV_REV_STUB_HEADER = 'SVN-Rev-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 143
try:
    SVN_DAV_REV_ROOT_STUB_HEADER = 'SVN-Rev-Root-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 151
try:
    SVN_DAV_TXN_STUB_HEADER = 'SVN-Txn-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 157
try:
    SVN_DAV_VTXN_STUB_HEADER = 'SVN-VTxn-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 166
try:
    SVN_DAV_TXN_ROOT_STUB_HEADER = 'SVN-Txn-Root-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 172
try:
    SVN_DAV_VTXN_ROOT_STUB_HEADER = 'SVN-VTxn-Root-Stub'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 180
try:
    SVN_DAV_TXN_NAME_HEADER = 'SVN-Txn-Name'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 187
try:
    SVN_DAV_VTXN_NAME_HEADER = 'SVN-VTxn-Name'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 193
try:
    SVN_DAV_SUPPORTED_POSTS_HEADER = 'SVN-Supported-Posts'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 199
try:
    SVN_DAV_ALLOW_BULK_UPDATES = 'SVN-Allow-Bulk-Updates'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 206
try:
    SVN_DAV_REPOSITORY_MERGEINFO = 'SVN-Repository-MergeInfo'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 229
try:
    SVN_DAV_BASE_FULLTEXT_MD5_HEADER = 'X-SVN-Base-Fulltext-MD5'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 230
try:
    SVN_DAV_RESULT_FULLTEXT_MD5_HEADER = 'X-SVN-Result-Fulltext-MD5'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 243
try:
    SVN_DAV_ERROR_NAMESPACE = 'svn:'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 246
try:
    SVN_DAV_ERROR_TAG = 'error'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 261
try:
    SVN_DAV_PROP_NS_SVN = 'http://subversion.tigris.org/xmlns/svn/'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 268
try:
    SVN_DAV_PROP_NS_CUSTOM = 'http://subversion.tigris.org/xmlns/custom/'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_dav.h: 273
try:
    SVN_DAV_PROP_NS_DAV = 'http://subversion.tigris.org/xmlns/dav/'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 76
try:
    SVN_FS_TYPE_BDB = 'bdb'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 78
try:
    SVN_FS_TYPE_FSFS = 'fsfs'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 88
try:
    SVN_FS_TYPE_FSX = 'fsx'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 97
try:
    SVN_FS_CONFIG_BDB_TXN_NOSYNC = 'bdb-txn-nosync'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 98
try:
    SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE = 'bdb-log-autoremove'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 104
try:
    SVN_FS_CONFIG_FSFS_CACHE_DELTAS = 'fsfs-cache-deltas'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 110
try:
    SVN_FS_CONFIG_FSFS_CACHE_FULLTEXTS = 'fsfs-cache-fulltexts'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 120
try:
    SVN_FS_CONFIG_FSFS_CACHE_REVPROPS = 'fsfs-cache-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 135
try:
    SVN_FS_CONFIG_FSFS_CACHE_NS = 'fsfs-cache-namespace'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 141
try:
    SVN_FS_CONFIG_FSFS_CACHE_NODEPROPS = 'fsfs-cache-nodeprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 147
try:
    SVN_FS_CONFIG_FSFS_BLOCK_READ = 'fsfs-block-read'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 157
try:
    SVN_FS_CONFIG_FSFS_SHARD_SIZE = 'fsfs-shard-size'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 167
try:
    SVN_FS_CONFIG_FSFS_LOG_ADDRESSING = 'fsfs-log-addressing'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 175
try:
    SVN_FS_CONFIG_FS_TYPE = 'fs-type'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 182
try:
    SVN_FS_CONFIG_PRE_1_4_COMPATIBLE = 'pre-1.4-compatible'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 189
try:
    SVN_FS_CONFIG_PRE_1_5_COMPATIBLE = 'pre-1.5-compatible'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 196
try:
    SVN_FS_CONFIG_PRE_1_6_COMPATIBLE = 'pre-1.6-compatible'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 203
try:
    SVN_FS_CONFIG_PRE_1_8_COMPATIBLE = 'pre-1.8-compatible'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 215
try:
    SVN_FS_CONFIG_COMPATIBLE_VERSION = 'compatible-version'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 228
try:
    SVN_FS_CONFIG_NO_FLUSH_TO_DISK = 'no-flush-to-disk'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1124
try:
    SVN_FS_TXN_CHECK_OOD = 0x00001
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1129
try:
    SVN_FS_TXN_CHECK_LOCKS = 0x00002
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1137
try:
    SVN_FS_TXN_CLIENT_DATE = 0x00004
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 46
try:
    SVN_KEYLINE_MAXLEN = 100
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 66
try:
    SVN_HASH_TERMINATOR = 'END'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 262
def svn_hash_gets(ht, key):
    return (apr_hash_get (ht, key, APR_HASH_KEY_STRING))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_hash.h: 277
def svn_hash_sets(ht, key, val):
    return (apr_hash_set (ht, key, APR_HASH_KEY_STRING, val))

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 47
try:
    SVN_ALLOCATOR_RECOMMENDED_MAX_FREE = (4096 * 1024)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 79
try:
    svn_pool_clear = apr_pool_clear
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_pools.h: 87
try:
    svn_pool_destroy = apr_pool_destroy
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 344
try:
    SVN_PROP_PREFIX = 'svn:'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 370
try:
    SVN_PROP_BOOLEAN_TRUE = '*'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 392
try:
    SVN_PROP_EXECUTABLE_VALUE = SVN_PROP_BOOLEAN_TRUE
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 403
try:
    SVN_PROP_NEEDS_LOCK_VALUE = SVN_PROP_BOOLEAN_TRUE
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 413
try:
    SVN_PROP_SPECIAL_VALUE = SVN_PROP_BOOLEAN_TRUE
except:
    pass

# /usr/include/netinet/in.h: 202
try:
    INADDR_NONE = (in_addr_t (ord_if_char(0xffffffff))).value
except:
    pass

# /usr/include/apr/apr_network_io.h: 50
try:
    APR_MAX_SECS_TO_LINGER = 30
except:
    pass

# /usr/include/apr/apr_network_io.h: 55
try:
    APRMAXHOSTLEN = 256
except:
    pass

# /usr/include/apr/apr_network_io.h: 60
try:
    APR_ANYADDR = '0.0.0.0'
except:
    pass

# /usr/include/apr/apr_network_io.h: 67
try:
    APR_SO_LINGER = 1
except:
    pass

# /usr/include/apr/apr_network_io.h: 68
try:
    APR_SO_KEEPALIVE = 2
except:
    pass

# /usr/include/apr/apr_network_io.h: 69
try:
    APR_SO_DEBUG = 4
except:
    pass

# /usr/include/apr/apr_network_io.h: 70
try:
    APR_SO_NONBLOCK = 8
except:
    pass

# /usr/include/apr/apr_network_io.h: 71
try:
    APR_SO_REUSEADDR = 16
except:
    pass

# /usr/include/apr/apr_network_io.h: 72
try:
    APR_SO_SNDBUF = 64
except:
    pass

# /usr/include/apr/apr_network_io.h: 73
try:
    APR_SO_RCVBUF = 128
except:
    pass

# /usr/include/apr/apr_network_io.h: 74
try:
    APR_SO_DISCONNECTED = 256
except:
    pass

# /usr/include/apr/apr_network_io.h: 75
try:
    APR_TCP_NODELAY = 512
except:
    pass

# /usr/include/apr/apr_network_io.h: 78
try:
    APR_TCP_NOPUSH = 1024
except:
    pass

# /usr/include/apr/apr_network_io.h: 79
try:
    APR_RESET_NODELAY = 2048
except:
    pass

# /usr/include/apr/apr_network_io.h: 85
try:
    APR_INCOMPLETE_READ = 4096
except:
    pass

# /usr/include/apr/apr_network_io.h: 96
try:
    APR_INCOMPLETE_WRITE = 8192
except:
    pass

# /usr/include/apr/apr_network_io.h: 99
try:
    APR_IPV6_V6ONLY = 16384
except:
    pass

# /usr/include/apr/apr_network_io.h: 102
try:
    APR_TCP_DEFER_ACCEPT = 32768
except:
    pass

# /usr/include/apr/apr_network_io.h: 106
try:
    APR_SO_BROADCAST = 65536
except:
    pass

# /usr/include/apr/apr_network_io.h: 108
try:
    APR_SO_FREEBIND = 131072
except:
    pass

# /usr/include/apr/apr_network_io.h: 121
try:
    APR_IPV4_ADDR_OK = 0x01
except:
    pass

# /usr/include/apr/apr_network_io.h: 122
try:
    APR_IPV6_ADDR_OK = 0x02
except:
    pass

# /usr/include/apr/apr_network_io.h: 139
try:
    APR_INADDR_NONE = INADDR_NONE
except:
    pass

# /usr/include/apr/apr_network_io.h: 149
try:
    APR_INET = AF_INET
except:
    pass

# /usr/include/apr/apr_network_io.h: 154
try:
    APR_UNSPEC = AF_UNSPEC
except:
    pass

# /usr/include/apr/apr_network_io.h: 163
try:
    APR_INET6 = AF_INET6
except:
    pass

# /usr/include/apr/apr_network_io.h: 168
try:
    APR_UNIX = AF_UNIX
except:
    pass

# /usr/include/apr/apr_network_io.h: 189
try:
    APR_PROTO_TCP = 6
except:
    pass

# /usr/include/apr/apr_network_io.h: 190
try:
    APR_PROTO_UDP = 17
except:
    pass

# /usr/include/apr/apr_network_io.h: 191
try:
    APR_PROTO_SCTP = 132
except:
    pass

# /usr/include/apr/apr_network_io.h: 289
try:
    APR_SENDFILE_DISCONNECT_SOCKET = 1
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 47
try:
    SVN_RA_SVN_PORT = 3690
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 50
try:
    SVN_RA_SVN_CAP_EDIT_PIPELINE = 'edit-pipeline'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 51
try:
    SVN_RA_SVN_CAP_SVNDIFF1 = 'svndiff1'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 52
try:
    SVN_RA_SVN_CAP_SVNDIFF2_ACCEPTED = 'accepts-svndiff2'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 53
try:
    SVN_RA_SVN_CAP_ABSENT_ENTRIES = 'absent-entries'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 55
try:
    SVN_RA_SVN_CAP_COMMIT_REVPROPS = 'commit-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 57
try:
    SVN_RA_SVN_CAP_MERGEINFO = 'mergeinfo'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 59
try:
    SVN_RA_SVN_CAP_DEPTH = 'depth'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 61
try:
    SVN_RA_SVN_CAP_LOG_REVPROPS = 'log-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 63
try:
    SVN_RA_SVN_CAP_PARTIAL_REPLAY = 'partial-replay'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 65
try:
    SVN_RA_SVN_CAP_ATOMIC_REVPROPS = 'atomic-revprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 67
try:
    SVN_RA_SVN_CAP_INHERITED_PROPS = 'inherited-props'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 69
try:
    SVN_RA_SVN_CAP_EPHEMERAL_TXNPROPS = 'ephemeral-txnprops'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 71
try:
    SVN_RA_SVN_CAP_GET_FILE_REVS_REVERSE = 'file-revs-reverse'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 73
try:
    SVN_RA_SVN_CAP_LIST = 'list'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 84
try:
    SVN_RA_SVN_DIRENT_KIND = 'kind'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 87
try:
    SVN_RA_SVN_DIRENT_SIZE = 'size'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 90
try:
    SVN_RA_SVN_DIRENT_HAS_PROPS = 'has-props'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 93
try:
    SVN_RA_SVN_DIRENT_CREATED_REV = 'created-rev'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 96
try:
    SVN_RA_SVN_DIRENT_TIME = 'time'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 99
try:
    SVN_RA_SVN_DIRENT_LAST_AUTHOR = 'last-author'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 106
try:
    SVN_RA_SVN_UNSPECIFIED_NUMBER = (~(apr_uint64_t (ord_if_char(0))).value)
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 605
try:
    SVN_REPOS_CAPABILITY_MERGEINFO = 'mergeinfo'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3085
try:
    SVN_REPOS_DUMPFILE_MAGIC_HEADER = 'SVN-fs-dump-format-version'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3086
try:
    SVN_REPOS_DUMPFILE_FORMAT_VERSION = 3
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3087
try:
    SVN_REPOS_DUMPFILE_FORMAT_VERSION_DELTAS = 3
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3088
try:
    SVN_REPOS_DUMPFILE_UUID = 'UUID'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3089
try:
    SVN_REPOS_DUMPFILE_CONTENT_LENGTH = 'Content-length'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3091
try:
    SVN_REPOS_DUMPFILE_REVISION_NUMBER = 'Revision-number'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3093
try:
    SVN_REPOS_DUMPFILE_NODE_PATH = 'Node-path'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3094
try:
    SVN_REPOS_DUMPFILE_NODE_KIND = 'Node-kind'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3095
try:
    SVN_REPOS_DUMPFILE_NODE_ACTION = 'Node-action'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3096
try:
    SVN_REPOS_DUMPFILE_NODE_COPYFROM_PATH = 'Node-copyfrom-path'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3097
try:
    SVN_REPOS_DUMPFILE_NODE_COPYFROM_REV = 'Node-copyfrom-rev'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3099
try:
    SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_MD5 = 'Text-copy-source-md5'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3101
try:
    SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_SHA1 = 'Text-copy-source-sha1'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3102
try:
    SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_CHECKSUM = SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_MD5
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3105
try:
    SVN_REPOS_DUMPFILE_TEXT_CONTENT_MD5 = 'Text-content-md5'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3107
try:
    SVN_REPOS_DUMPFILE_TEXT_CONTENT_SHA1 = 'Text-content-sha1'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3108
try:
    SVN_REPOS_DUMPFILE_TEXT_CONTENT_CHECKSUM = SVN_REPOS_DUMPFILE_TEXT_CONTENT_MD5
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3111
try:
    SVN_REPOS_DUMPFILE_PROP_CONTENT_LENGTH = 'Prop-content-length'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3112
try:
    SVN_REPOS_DUMPFILE_TEXT_CONTENT_LENGTH = 'Text-content-length'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3115
try:
    SVN_REPOS_DUMPFILE_PROP_DELTA = 'Prop-delta'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3117
try:
    SVN_REPOS_DUMPFILE_TEXT_DELTA = 'Text-delta'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3119
try:
    SVN_REPOS_DUMPFILE_TEXT_DELTA_BASE_MD5 = 'Text-delta-base-md5'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3121
try:
    SVN_REPOS_DUMPFILE_TEXT_DELTA_BASE_SHA1 = 'Text-delta-base-sha1'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3123
try:
    SVN_REPOS_DUMPFILE_TEXT_DELTA_BASE_CHECKSUM = SVN_REPOS_DUMPFILE_TEXT_DELTA_BASE_MD5
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 38
def MAX(a, b):
    return (a < b) and b or a

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 43
def MIN(a, b):
    return (a < b) and a or b

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 47
try:
    SVN_SUBST_NATIVE_EOL_STR = '\\n'
except:
    pass

# /usr/include/apr-util/apu.h: 53
def APU_DECLARE(type):
    return type

# /usr/include/apr-util/apr_xlate.h: 78
try:
    APR_DEFAULT_CHARSET = (String (ord_if_char(0))).value
except:
    pass

# /usr/include/apr-util/apr_xlate.h: 82
try:
    APR_LOCALE_CHARSET = (String (ord_if_char(1))).value
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 45
try:
    SVN_APR_LOCALE_CHARSET = APR_LOCALE_CHARSET
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_utf.h: 46
try:
    SVN_APR_DEFAULT_CHARSET = APR_DEFAULT_CHARSET
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 57
try:
    SVN_VER_MAJOR = 1
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 64
try:
    SVN_VER_MINOR = 14
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 73
try:
    SVN_VER_PATCH = 5
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 77
try:
    SVN_VER_MICRO = SVN_VER_PATCH
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 80
try:
    SVN_VER_LIBRARY = SVN_VER_MAJOR
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 96
try:
    SVN_VER_TAG = ' (r1922182)'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 111
try:
    SVN_VER_NUMTAG = ''
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 120
try:
    SVN_VER_REVISION = 1922182
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 41
try:
    SVN_X509_OID_COMMON_NAME = '\\x55\\x04\\x03'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 42
try:
    SVN_X509_OID_COUNTRY = '\\x55\\x04\\x06'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 43
try:
    SVN_X509_OID_LOCALITY = '\\x55\\x04\\x07'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 44
try:
    SVN_X509_OID_STATE = '\\x55\\x04\\x08'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 45
try:
    SVN_X509_OID_ORGANIZATION = '\\x55\\x04\\x0A'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 46
try:
    SVN_X509_OID_ORG_UNIT = '\\x55\\x04\\x0B'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 47
try:
    SVN_X509_OID_EMAIL = '\\x2A\\x86\\x48\\x86\\xF7\\x0D\\x01\\x09\\x01'
except:
    pass

# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 42
try:
    SVN_XML_NAMESPACE = 'svn:'
except:
    pass

# /usr/include/apr/apr_encode.h: 105
try:
    APR_ENCODE_STRING = (-1)
except:
    pass

# /usr/include/apr/apr_encode.h: 110
try:
    APR_ENCODE_NONE = 0
except:
    pass

# /usr/include/apr/apr_encode.h: 115
try:
    APR_ENCODE_RELAXED = 1
except:
    pass

# /usr/include/apr/apr_encode.h: 120
try:
    APR_ENCODE_NOPADDING = 2
except:
    pass

# /usr/include/apr/apr_encode.h: 125
try:
    APR_ENCODE_URL = 4
except:
    pass

# /usr/include/apr/apr_encode.h: 130
try:
    APR_ENCODE_BASE64URL = (APR_ENCODE_NOPADDING | APR_ENCODE_URL)
except:
    pass

# /usr/include/apr/apr_encode.h: 135
try:
    APR_ENCODE_BASE32HEX = 8
except:
    pass

# /usr/include/apr/apr_encode.h: 140
try:
    APR_ENCODE_COLON = 16
except:
    pass

# /usr/include/apr/apr_encode.h: 145
try:
    APR_ENCODE_LOWER = 32
except:
    pass

# /usr/include/apr/apr_escape.h: 56
try:
    APR_ESCAPE_STRING = (-1)
except:
    pass

# /usr/include/apr/apr_escape.h: 61
try:
    APR_ESCAPE_LDAP_DN = 0x01
except:
    pass

# /usr/include/apr/apr_escape.h: 66
try:
    APR_ESCAPE_LDAP_FILTER = 0x02
except:
    pass

# /usr/include/apr/apr_escape.h: 71
try:
    APR_ESCAPE_LDAP_ALL = 0x03
except:
    pass

# /usr/include/apr/apr_fnmatch.h: 58
try:
    APR_FNM_NOMATCH = 1
except:
    pass

# /usr/include/apr/apr_fnmatch.h: 60
try:
    APR_FNM_NOESCAPE = 0x01
except:
    pass

# /usr/include/apr/apr_fnmatch.h: 61
try:
    APR_FNM_PATHNAME = 0x02
except:
    pass

# /usr/include/apr/apr_fnmatch.h: 62
try:
    APR_FNM_PERIOD = 0x04
except:
    pass

# /usr/include/apr/apr_fnmatch.h: 63
try:
    APR_FNM_CASE_BLIND = 0x08
except:
    pass

# /usr/include/apr/apr_lib.h: 52
try:
    HUGE_STRING_LEN = 8192
except:
    pass

# /usr/include/apr/apr_lib.h: 98
def apr_killpg(x, y):
    return (killpg (x, y))

# /usr/include/apr/apr_lib.h: 203
def apr_isalnum(c):
    return (isalnum ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 205
def apr_isalpha(c):
    return (isalpha ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 207
def apr_iscntrl(c):
    return (iscntrl ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 209
def apr_isdigit(c):
    return (isdigit ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 211
def apr_isgraph(c):
    return (isgraph ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 213
def apr_islower(c):
    return (islower ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 216
def apr_isascii(c):
    return (isascii ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 221
def apr_isprint(c):
    return (isprint ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 223
def apr_ispunct(c):
    return (ispunct ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 225
def apr_isspace(c):
    return (isspace ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 227
def apr_isupper(c):
    return (isupper ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 229
def apr_isxdigit(c):
    return (isxdigit ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 231
def apr_tolower(c):
    return (tolower ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_lib.h: 233
def apr_toupper(c):
    return (toupper ((c_ubyte (ord_if_char(c))).value))

# /usr/include/apr/apr_ring.h: 166
def APR_RING_FIRST(hp):
    return (hp.contents.next)

# /usr/include/apr/apr_ring.h: 171
def APR_RING_LAST(hp):
    return (hp.contents.prev)

# /usr/include/apr/apr_mmap.h: 46
try:
    APR_MMAP_READ = 1
except:
    pass

# /usr/include/apr/apr_mmap.h: 48
try:
    APR_MMAP_WRITE = 2
except:
    pass

# /usr/include/apr/apr_mmap.h: 101
try:
    APR_MMAP_THRESHOLD = 1
except:
    pass

# /usr/include/apr/apr_mmap.h: 111
try:
    APR_MMAP_LIMIT = ((4 * 1024) * 1024)
except:
    pass

# /usr/include/apr/apr_mmap.h: 115
def APR_MMAP_CANDIDATE(filelength):
    return ((filelength >= APR_MMAP_THRESHOLD) and (filelength < APR_MMAP_LIMIT))

# /usr/include/apr/apr_poll.h: 49
try:
    APR_POLLIN = 0x001
except:
    pass

# /usr/include/apr/apr_poll.h: 50
try:
    APR_POLLPRI = 0x002
except:
    pass

# /usr/include/apr/apr_poll.h: 51
try:
    APR_POLLOUT = 0x004
except:
    pass

# /usr/include/apr/apr_poll.h: 52
try:
    APR_POLLERR = 0x010
except:
    pass

# /usr/include/apr/apr_poll.h: 53
try:
    APR_POLLHUP = 0x020
except:
    pass

# /usr/include/apr/apr_poll.h: 54
try:
    APR_POLLNVAL = 0x040
except:
    pass

# /usr/include/apr/apr_poll.h: 62
try:
    APR_POLLSET_THREADSAFE = 0x001
except:
    pass

# /usr/include/apr/apr_poll.h: 65
try:
    APR_POLLSET_NOCOPY = 0x002
except:
    pass

# /usr/include/apr/apr_poll.h: 68
try:
    APR_POLLSET_WAKEABLE = 0x004
except:
    pass

# /usr/include/apr/apr_poll.h: 71
try:
    APR_POLLSET_NODEFAULT = 0x010
except:
    pass

# /usr/include/apr/apr_shm.h: 78
try:
    APR_SHM_NS_LOCAL = 1
except:
    pass

# /usr/include/apr/apr_shm.h: 85
try:
    APR_SHM_NS_GLOBAL = 2
except:
    pass

# /usr/include/apr-util/apr_anylock.h: 51
def APR_ANYLOCK_LOCK(lck):
    return (((lck.contents.type).value) == apr_anylock_none) and APR_SUCCESS or (((lck.contents.type).value) == apr_anylock_threadmutex) and (apr_thread_mutex_lock (((lck.contents.lock).tm))) or (((lck.contents.type).value) == apr_anylock_procmutex) and (apr_proc_mutex_lock (((lck.contents.lock).pm))) or (((lck.contents.type).value) == apr_anylock_readlock) and (apr_thread_rwlock_rdlock (((lck.contents.lock).rw))) or (((lck.contents.type).value) == apr_anylock_writelock) and (apr_thread_rwlock_wrlock (((lck.contents.lock).rw))) or APR_EINVAL

# /usr/include/apr-util/apr_anylock.h: 78
def APR_ANYLOCK_TRYLOCK(lck):
    return (((lck.contents.type).value) == apr_anylock_none) and APR_SUCCESS or (((lck.contents.type).value) == apr_anylock_threadmutex) and (apr_thread_mutex_trylock (((lck.contents.lock).tm))) or (((lck.contents.type).value) == apr_anylock_procmutex) and (apr_proc_mutex_trylock (((lck.contents.lock).pm))) or (((lck.contents.type).value) == apr_anylock_readlock) and (apr_thread_rwlock_tryrdlock (((lck.contents.lock).rw))) or (((lck.contents.type).value) == apr_anylock_writelock) and (apr_thread_rwlock_trywrlock (((lck.contents.lock).rw))) or APR_EINVAL

# /usr/include/apr-util/apr_anylock.h: 105
def APR_ANYLOCK_UNLOCK(lck):
    return (((lck.contents.type).value) == apr_anylock_none) and APR_SUCCESS or (((lck.contents.type).value) == apr_anylock_threadmutex) and (apr_thread_mutex_unlock (((lck.contents.lock).tm))) or (((lck.contents.type).value) == apr_anylock_procmutex) and (apr_proc_mutex_unlock (((lck.contents.lock).pm))) or ((((lck.contents.type).value) == apr_anylock_readlock) or (((lck.contents.type).value) == apr_anylock_writelock)) and (apr_thread_rwlock_unlock (((lck.contents.lock).rw))) or APR_EINVAL

# /usr/include/apr-util/apr_buckets.h: 54
try:
    APR_BUCKET_BUFF_SIZE = 8000
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 345
def APR_BRIGADE_FIRST(b):
    return (APR_RING_FIRST (pointer((b.contents.list))))

# /usr/include/apr-util/apr_buckets.h: 351
def APR_BRIGADE_LAST(b):
    return (APR_RING_LAST (pointer((b.contents.list))))

# /usr/include/apr-util/apr_buckets.h: 448
def APR_BUCKET_IS_METADATA(e):
    return ((e.contents.type).contents.is_metadata)

# /usr/include/apr-util/apr_buckets.h: 455
def APR_BUCKET_IS_FLUSH(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_flush))

# /usr/include/apr-util/apr_buckets.h: 461
def APR_BUCKET_IS_EOS(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_eos))

# /usr/include/apr-util/apr_buckets.h: 467
def APR_BUCKET_IS_FILE(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_file))

# /usr/include/apr-util/apr_buckets.h: 473
def APR_BUCKET_IS_PIPE(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_pipe))

# /usr/include/apr-util/apr_buckets.h: 479
def APR_BUCKET_IS_SOCKET(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_socket))

# /usr/include/apr-util/apr_buckets.h: 485
def APR_BUCKET_IS_HEAP(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_heap))

# /usr/include/apr-util/apr_buckets.h: 491
def APR_BUCKET_IS_TRANSIENT(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_transient))

# /usr/include/apr-util/apr_buckets.h: 497
def APR_BUCKET_IS_IMMORTAL(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_immortal))

# /usr/include/apr-util/apr_buckets.h: 504
def APR_BUCKET_IS_MMAP(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_mmap))

# /usr/include/apr-util/apr_buckets.h: 511
def APR_BUCKET_IS_POOL(e):
    return (((e.contents.type).value) == pointer(apr_bucket_type_pool))

# /usr/include/apr-util/apr_buckets.h: 650
try:
    APR_BUCKET_ALLOC_SIZE = (APR_ALIGN_DEFAULT ((2 * sizeof(apr_bucket_structs))))
except:
    pass

# /usr/include/apr-util/apr_buckets.h: 1089
def apr_bucket_read(e, str, len, block):
    return (((e.contents.type).contents.read) (e, str, len, block))

# /usr/include/apr-util/apr_buckets.h: 1097
def apr_bucket_setaside(e, p):
    return (((e.contents.type).contents.setaside) (e, p))

# /usr/include/apr-util/apr_buckets.h: 1109
def apr_bucket_split(e, point):
    return (((e.contents.type).contents.split) (e, point))

# /usr/include/apr-util/apr_buckets.h: 1116
def apr_bucket_copy(e, c):
    return (((e.contents.type).contents.copy) (e, c))

# /usr/include/apr-util/apu_errno.h: 63
try:
    APR_ENOKEY = (APR_UTIL_START_STATUS + 1)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 65
try:
    APR_ENOIV = (APR_UTIL_START_STATUS + 2)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 67
try:
    APR_EKEYTYPE = (APR_UTIL_START_STATUS + 3)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 69
try:
    APR_ENOSPACE = (APR_UTIL_START_STATUS + 4)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 71
try:
    APR_ECRYPT = (APR_UTIL_START_STATUS + 5)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 73
try:
    APR_EPADDING = (APR_UTIL_START_STATUS + 6)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 75
try:
    APR_EKEYLENGTH = (APR_UTIL_START_STATUS + 7)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 77
try:
    APR_ENOCIPHER = (APR_UTIL_START_STATUS + 8)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 79
try:
    APR_ENODIGEST = (APR_UTIL_START_STATUS + 9)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 81
try:
    APR_ENOENGINE = (APR_UTIL_START_STATUS + 10)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 83
try:
    APR_EINITENGINE = (APR_UTIL_START_STATUS + 11)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 85
try:
    APR_EREINIT = (APR_UTIL_START_STATUS + 12)
except:
    pass

# /usr/include/apr-util/apu_errno.h: 109
def APR_STATUS_IS_ENOKEY(s):
    return (s == APR_ENOKEY)

# /usr/include/apr-util/apu_errno.h: 113
def APR_STATUS_IS_ENOIV(s):
    return (s == APR_ENOIV)

# /usr/include/apr-util/apu_errno.h: 117
def APR_STATUS_IS_EKEYTYPE(s):
    return (s == APR_EKEYTYPE)

# /usr/include/apr-util/apu_errno.h: 121
def APR_STATUS_IS_ENOSPACE(s):
    return (s == APR_ENOSPACE)

# /usr/include/apr-util/apu_errno.h: 125
def APR_STATUS_IS_ECRYPT(s):
    return (s == APR_ECRYPT)

# /usr/include/apr-util/apu_errno.h: 129
def APR_STATUS_IS_EPADDING(s):
    return (s == APR_EPADDING)

# /usr/include/apr-util/apu_errno.h: 133
def APR_STATUS_IS_EKEYLENGTH(s):
    return (s == APR_EKEYLENGTH)

# /usr/include/apr-util/apu_errno.h: 137
def APR_STATUS_IS_ENOCIPHER(s):
    return (s == APR_ENOCIPHER)

# /usr/include/apr-util/apu_errno.h: 141
def APR_STATUS_IS_ENODIGEST(s):
    return (s == APR_ENODIGEST)

# /usr/include/apr-util/apu_errno.h: 145
def APR_STATUS_IS_ENOENGINE(s):
    return (s == APR_ENOENGINE)

# /usr/include/apr-util/apu_errno.h: 149
def APR_STATUS_IS_EINITENGINE(s):
    return (s == APR_EINITENGINE)

# /usr/include/apr-util/apu_errno.h: 153
def APR_STATUS_IS_EREINIT(s):
    return (s == APR_EREINIT)

# /usr/include/apr-util/apr_crypto.h: 47
try:
    APU_CRYPTO_RECOMMENDED_DRIVER = 'openssl'
except:
    pass

# /usr/include/apr-util/apr_date.h: 43
try:
    APR_DATE_BAD = (apr_time_t (ord_if_char(0))).value
except:
    pass

# /usr/include/apr-util/apr_dbd.h: 239
try:
    APR_DBD_TRANSACTION_COMMIT = 0x00
except:
    pass

# /usr/include/apr-util/apr_dbd.h: 240
try:
    APR_DBD_TRANSACTION_ROLLBACK = 0x01
except:
    pass

# /usr/include/apr-util/apr_dbd.h: 241
try:
    APR_DBD_TRANSACTION_IGNORE_ERRORS = 0x02
except:
    pass

# /usr/include/apr-util/apr_dbm.h: 56
try:
    APR_DBM_READONLY = 1
except:
    pass

# /usr/include/apr-util/apr_dbm.h: 57
try:
    APR_DBM_READWRITE = 2
except:
    pass

# /usr/include/apr-util/apr_dbm.h: 58
try:
    APR_DBM_RWCREATE = 3
except:
    pass

# /usr/include/apr-util/apr_dbm.h: 59
try:
    APR_DBM_RWTRUNC = 4
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 299
try:
    APR_HOOK_REALLY_FIRST = (-10)
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 301
try:
    APR_HOOK_FIRST = 0
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 303
try:
    APR_HOOK_MIDDLE = 10
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 305
try:
    APR_HOOK_LAST = 20
except:
    pass

# /usr/include/apr-util/apr_hooks.h: 307
try:
    APR_HOOK_REALLY_LAST = 30
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 34
try:
    APR_HAS_LDAP = 1
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 37
try:
    APR_HAS_NETSCAPE_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 38
try:
    APR_HAS_SOLARIS_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 39
try:
    APR_HAS_NOVELL_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 40
try:
    APR_HAS_MOZILLA_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 41
try:
    APR_HAS_OPENLDAP_LDAPSDK = 1
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 42
try:
    APR_HAS_MICROSOFT_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 43
try:
    APR_HAS_TIVOLI_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 44
try:
    APR_HAS_ZOS_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 45
try:
    APR_HAS_OTHER_LDAPSDK = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 64
try:
    APR_HAS_LDAP_SSL = 1
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 66
try:
    APR_HAS_LDAP_URL_PARSE = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 72
try:
    LDAP_DEPRECATED = 1
except:
    pass

# /usr/include/ldap.h: 576
def LDAP_RANGE(n, x, y):
    return ((x <= n) and (n <= y))

# /usr/include/ldap.h: 613
def LDAP_SECURITY_ERROR(n):
    return (LDAP_RANGE (n, 0x2F, 0x32))

# /usr/include/ldap.h: 618
try:
    LDAP_INSUFFICIENT_ACCESS = 0x32
except:
    pass

# /usr/include/ldap.h: 702
try:
    LDAP_SERVER_DOWN = (-1)
except:
    pass

# /usr/include/ldap.h: 766
try:
    LDAP_NO_LIMIT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 87
try:
    APR_HAS_LDAPSSL_CLIENT_INIT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 88
try:
    APR_HAS_LDAPSSL_CLIENT_DEINIT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 89
try:
    APR_HAS_LDAPSSL_ADD_TRUSTED_CERT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 90
try:
    APR_HAS_LDAP_START_TLS_S = 1
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 91
try:
    APR_HAS_LDAP_SSLINIT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 92
try:
    APR_HAS_LDAPSSL_INIT = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 93
try:
    APR_HAS_LDAPSSL_INSTALL_ROUTINES = 0
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 112
try:
    APR_LDAP_SIZELIMIT = LDAP_NO_LIMIT
except:
    pass

# /usr/include/apr-util/apr_ldap.h: 166
def APR_LDAP_IS_SERVER_DOWN(s):
    return (s == LDAP_SERVER_DOWN)

# /usr/include/apr-util/apr_ldap.h: 187
def APU_DECLARE_LDAP(type):
    return (APU_DECLARE (type))

# /usr/include/apr-util/apr_ldap_url.h: 57
try:
    APR_LDAP_URL_SUCCESS = 0x00
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 58
try:
    APR_LDAP_URL_ERR_MEM = 0x01
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 59
try:
    APR_LDAP_URL_ERR_PARAM = 0x02
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 60
try:
    APR_LDAP_URL_ERR_BADSCHEME = 0x03
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 61
try:
    APR_LDAP_URL_ERR_BADENCLOSURE = 0x04
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 62
try:
    APR_LDAP_URL_ERR_BADURL = 0x05
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 63
try:
    APR_LDAP_URL_ERR_BADHOST = 0x06
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 64
try:
    APR_LDAP_URL_ERR_BADATTRS = 0x07
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 65
try:
    APR_LDAP_URL_ERR_BADSCOPE = 0x08
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 66
try:
    APR_LDAP_URL_ERR_BADFILTER = 0x09
except:
    pass

# /usr/include/apr-util/apr_ldap_url.h: 67
try:
    APR_LDAP_URL_ERR_BADEXTS = 0x0a
except:
    pass

# /usr/include/apr-util/apr_ldap_init.h: 42
try:
    APU_LDAP_INSUFFICIENT_ACCESS = LDAP_INSUFFICIENT_ACCESS
except:
    pass

# /usr/include/apr-util/apr_ldap_init.h: 56
try:
    APU_LDAP_SECURITY_ERROR = LDAP_SECURITY_ERROR
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 47
try:
    APR_LDAP_OPT_TLS = 0x6fff
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 52
try:
    APR_LDAP_OPT_TLS_CERT = 0x6ffe
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 57
try:
    APR_LDAP_OPT_VERIFY_CERT = 0x6ffd
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 62
try:
    APR_LDAP_OPT_REFERRALS = 0x6ffc
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 67
try:
    APR_LDAP_OPT_REFHOPLIMIT = 0x6ffb
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 120
try:
    APR_LDAP_CA_TYPE_UNKNOWN = 0
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 122
try:
    APR_LDAP_CA_TYPE_DER = 1
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 124
try:
    APR_LDAP_CA_TYPE_BASE64 = 2
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 126
try:
    APR_LDAP_CA_TYPE_CERT7_DB = 3
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 128
try:
    APR_LDAP_CA_TYPE_SECMOD = 4
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 130
try:
    APR_LDAP_CERT_TYPE_UNKNOWN = 5
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 132
try:
    APR_LDAP_CERT_TYPE_DER = 6
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 134
try:
    APR_LDAP_CERT_TYPE_BASE64 = 7
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 136
try:
    APR_LDAP_CERT_TYPE_KEY3_DB = 8
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 138
try:
    APR_LDAP_CERT_TYPE_NICKNAME = 9
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 140
try:
    APR_LDAP_KEY_TYPE_UNKNOWN = 10
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 142
try:
    APR_LDAP_KEY_TYPE_DER = 11
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 144
try:
    APR_LDAP_KEY_TYPE_BASE64 = 12
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 146
try:
    APR_LDAP_CERT_TYPE_PFX = 13
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 148
try:
    APR_LDAP_KEY_TYPE_PFX = 14
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 152
try:
    APR_LDAP_CA_TYPE_CACERTDIR_BASE64 = 15
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 197
try:
    APR_LDAP_NONE = 0
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 199
try:
    APR_LDAP_SSL = 1
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 201
try:
    APR_LDAP_STARTTLS = 2
except:
    pass

# /usr/include/apr-util/apr_ldap_option.h: 203
try:
    APR_LDAP_STOPTLS = 3
except:
    pass

# /usr/include/apr-util/apr_md4.h: 61
try:
    APR_MD4_DIGESTSIZE = 16
except:
    pass

# /usr/include/apr-util/apr_md5.h: 68
try:
    APR_MD5_DIGESTSIZE = 16
except:
    pass

# /usr/include/apr-util/apr_reslist.h: 63
try:
    APR_RESLIST_CLEANUP_DEFAULT = 0
except:
    pass

# /usr/include/apr-util/apr_reslist.h: 64
try:
    APR_RESLIST_CLEANUP_FIRST = 1
except:
    pass

# /usr/include/apr-util/apr_redis.h: 42
try:
    RC_DEFAULT_SERVER_PORT = 6379
except:
    pass

# /usr/include/apr-util/apr_redis.h: 46
try:
    RC_DEFAULT_SERVER_MIN = 0
except:
    pass

# /usr/include/apr-util/apr_redis.h: 50
try:
    RC_DEFAULT_SERVER_SMAX = 1
except:
    pass

# /usr/include/apr-util/apr_redis.h: 54
try:
    RC_DEFAULT_SERVER_TTL = 600
except:
    pass

# /usr/include/apr-util/apr_sdbm.h: 59
try:
    APR_SDBM_DIRFEXT = '.dir'
except:
    pass

# /usr/include/apr-util/apr_sdbm.h: 61
try:
    APR_SDBM_PAGFEXT = '.pag'
except:
    pass

# /usr/include/apr-util/apr_sdbm.h: 64
try:
    APR_SDBM_INSERT = 0
except:
    pass

# /usr/include/apr-util/apr_sdbm.h: 65
try:
    APR_SDBM_REPLACE = 1
except:
    pass

# /usr/include/apr-util/apr_sdbm.h: 66
try:
    APR_SDBM_INSERTDUP = 2
except:
    pass

# /usr/include/apr-util/apr_sha1.h: 39
try:
    APR_SHA1_DIGESTSIZE = 20
except:
    pass

# /usr/include/apr-util/apr_sha1.h: 45
try:
    APR_SHA1PW_ID = '{SHA}'
except:
    pass

# /usr/include/apr-util/apr_sha1.h: 48
try:
    APR_SHA1PW_IDLEN = 5
except:
    pass

# /usr/include/apr-util/apr_siphash.h: 54
try:
    APR_SIPHASH_DSIZE = 8
except:
    pass

# /usr/include/apr-util/apr_siphash.h: 57
try:
    APR_SIPHASH_KSIZE = 16
except:
    pass

# /usr/include/apr-util/apr_strmatch.h: 64
def apr_strmatch(pattern, s, slen):
    return (((pattern.contents.compare)[0]) (pattern, s, slen))

# /usr/include/apr-util/apr_thread_pool.h: 60
try:
    APR_THREAD_TASK_PRIORITY_LOWEST = 0
except:
    pass

# /usr/include/apr-util/apr_thread_pool.h: 61
try:
    APR_THREAD_TASK_PRIORITY_LOW = 63
except:
    pass

# /usr/include/apr-util/apr_thread_pool.h: 62
try:
    APR_THREAD_TASK_PRIORITY_NORMAL = 127
except:
    pass

# /usr/include/apr-util/apr_thread_pool.h: 63
try:
    APR_THREAD_TASK_PRIORITY_HIGH = 191
except:
    pass

# /usr/include/apr-util/apr_thread_pool.h: 64
try:
    APR_THREAD_TASK_PRIORITY_HIGHEST = 255
except:
    pass

# /usr/include/apr-util/apr_uri.h: 43
try:
    APR_URI_FTP_DEFAULT_PORT = 21
except:
    pass

# /usr/include/apr-util/apr_uri.h: 44
try:
    APR_URI_SSH_DEFAULT_PORT = 22
except:
    pass

# /usr/include/apr-util/apr_uri.h: 45
try:
    APR_URI_TELNET_DEFAULT_PORT = 23
except:
    pass

# /usr/include/apr-util/apr_uri.h: 46
try:
    APR_URI_GOPHER_DEFAULT_PORT = 70
except:
    pass

# /usr/include/apr-util/apr_uri.h: 47
try:
    APR_URI_HTTP_DEFAULT_PORT = 80
except:
    pass

# /usr/include/apr-util/apr_uri.h: 48
try:
    APR_URI_POP_DEFAULT_PORT = 110
except:
    pass

# /usr/include/apr-util/apr_uri.h: 49
try:
    APR_URI_NNTP_DEFAULT_PORT = 119
except:
    pass

# /usr/include/apr-util/apr_uri.h: 50
try:
    APR_URI_IMAP_DEFAULT_PORT = 143
except:
    pass

# /usr/include/apr-util/apr_uri.h: 51
try:
    APR_URI_PROSPERO_DEFAULT_PORT = 191
except:
    pass

# /usr/include/apr-util/apr_uri.h: 52
try:
    APR_URI_WAIS_DEFAULT_PORT = 210
except:
    pass

# /usr/include/apr-util/apr_uri.h: 53
try:
    APR_URI_LDAP_DEFAULT_PORT = 389
except:
    pass

# /usr/include/apr-util/apr_uri.h: 54
try:
    APR_URI_HTTPS_DEFAULT_PORT = 443
except:
    pass

# /usr/include/apr-util/apr_uri.h: 55
try:
    APR_URI_RTSP_DEFAULT_PORT = 554
except:
    pass

# /usr/include/apr-util/apr_uri.h: 56
try:
    APR_URI_SNEWS_DEFAULT_PORT = 563
except:
    pass

# /usr/include/apr-util/apr_uri.h: 57
try:
    APR_URI_ACAP_DEFAULT_PORT = 674
except:
    pass

# /usr/include/apr-util/apr_uri.h: 58
try:
    APR_URI_NFS_DEFAULT_PORT = 2049
except:
    pass

# /usr/include/apr-util/apr_uri.h: 59
try:
    APR_URI_TIP_DEFAULT_PORT = 3372
except:
    pass

# /usr/include/apr-util/apr_uri.h: 60
try:
    APR_URI_SIP_DEFAULT_PORT = 5060
except:
    pass

# /usr/include/apr-util/apr_uri.h: 64
try:
    APR_URI_UNP_OMITSITEPART = (1 << 0)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 66
try:
    APR_URI_UNP_OMITUSER = (1 << 1)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 68
try:
    APR_URI_UNP_OMITPASSWORD = (1 << 2)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 70
try:
    APR_URI_UNP_OMITUSERINFO = (APR_URI_UNP_OMITUSER | APR_URI_UNP_OMITPASSWORD)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 73
try:
    APR_URI_UNP_REVEALPASSWORD = (1 << 3)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 75
try:
    APR_URI_UNP_OMITPATHINFO = (1 << 4)
except:
    pass

# /usr/include/apr-util/apr_uri.h: 77
try:
    APR_URI_UNP_OMITQUERY = (1 << 5)
except:
    pass

# /usr/include/apr-util/apr_uuid.h: 46
try:
    APR_UUID_FORMATTED_LENGTH = 36
except:
    pass

# /usr/include/apr-util/apr_xml.h: 133
try:
    APR_XML_NS_DAV_ID = 0
except:
    pass

# /usr/include/apr-util/apr_xml.h: 134
try:
    APR_XML_NS_NONE = (-10)
except:
    pass

# /usr/include/apr-util/apr_xml.h: 136
try:
    APR_XML_NS_ERROR_BASE = (-100)
except:
    pass

# /usr/include/apr-util/apr_xml.h: 138
def APR_XML_NS_IS_ERROR(e):
    return (e <= APR_XML_NS_ERROR_BASE)

# /usr/include/apr-util/apr_xml.h: 292
try:
    APR_XML_X2T_FULL = 0
except:
    pass

# /usr/include/apr-util/apr_xml.h: 293
try:
    APR_XML_X2T_INNER = 1
except:
    pass

# /usr/include/apr-util/apr_xml.h: 294
try:
    APR_XML_X2T_LANG_INNER = 2
except:
    pass

# /usr/include/apr-util/apr_xml.h: 295
try:
    APR_XML_X2T_FULL_NS_LANG = 3
except:
    pass

# /usr/include/apr-util/apr_xml.h: 296
try:
    APR_XML_X2T_PARSED = 4
except:
    pass

# /usr/include/apr-util/apr_xml.h: 339
def APR_XML_GET_URI_ITEM(ary, i):
    return (cast((ary.contents.elts), POINTER(POINTER(c_char))) [i])

# /usr/include/apr-util/apu_version.h: 41
try:
    APU_COPYRIGHT = ('Copyright (c) 2000-2023 The Apache Software ' + 'Foundation or its licensors, as applicable.')
except:
    pass

# /usr/include/apr-util/apu_version.h: 53
try:
    APU_MAJOR_VERSION = 1
except:
    pass

# /usr/include/apr-util/apu_version.h: 59
try:
    APU_MINOR_VERSION = 6
except:
    pass

# /usr/include/apr-util/apu_version.h: 65
try:
    APU_PATCH_VERSION = 3
except:
    pass

# /usr/include/apr-util/apu_version.h: 81
try:
    APU_IS_DEV_STRING = ''
except:
    pass

# /usr/include/apr-util/apu_version.h: 87
def APU_STRINGIFY(n):
    return (APU_STRINGIFY_HELPER (n))

# /usr/include/apr-util/apu_version.h: 89
def APU_STRINGIFY_HELPER(n):
    return n

apr_pool_t = struct_apr_pool_t# /usr/include/apr/apr_pools.h: 60

apr_allocator_t = struct_apr_allocator_t# /usr/include/apr/apr_allocator.h: 41

apr_memnode_t = struct_apr_memnode_t# /usr/include/apr/apr_allocator.h: 54

apr_thread_mutex_t = struct_apr_thread_mutex_t# /usr/include/apr/apr_thread_mutex.h: 41

apr_time_exp_t = struct_apr_time_exp_t# /usr/include/apr/apr_time.h: 97

apr_hash_t = struct_apr_hash_t# /usr/include/apr/apr_hash.h: 52

apr_hash_index_t = struct_apr_hash_index_t# /usr/include/apr/apr_hash.h: 57

apr_table_t = struct_apr_table_t# /usr/include/apr/apr_tables.h: 56

apr_array_header_t = struct_apr_array_header_t# /usr/include/apr/apr_tables.h: 62

apr_table_entry_t = struct_apr_table_entry_t# /usr/include/apr/apr_tables.h: 81

svn_error_t = struct_svn_error_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 180

svn__null_pointer_constant_stdarg_sentinel_t = struct_svn__null_pointer_constant_stdarg_sentinel_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 159

svn_version_t = struct_svn_version_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 147

svn_dirent_t = struct_svn_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 584

svn_commit_info_t = struct_svn_commit_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 707

svn_log_changed_path2_t = struct_svn_log_changed_path2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 771

svn_log_changed_path_t = struct_svn_log_changed_path_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 812

svn_log_entry_t = struct_svn_log_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 910

svn_lock_t = struct_svn_lock_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1118

svn_merge_range_t = struct_svn_merge_range_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1173

svn_location_segment_t = struct_svn_location_segment_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_types.h: 1215

apr_dir_t = struct_apr_dir_t# /usr/include/apr/apr_file_info.h: 121

apr_finfo_t = struct_apr_finfo_t# /usr/include/apr/apr_file_info.h: 174

apr_file_t = struct_apr_file_t# /usr/include/apr/apr_file_info.h: 212

apr_proc_t = struct_apr_proc_t# /usr/include/apr/apr_thread_proc.h: 162

apr_thread_t = struct_apr_thread_t# /usr/include/apr/apr_thread_proc.h: 178

apr_threadattr_t = struct_apr_threadattr_t# /usr/include/apr/apr_thread_proc.h: 181

apr_procattr_t = struct_apr_procattr_t# /usr/include/apr/apr_thread_proc.h: 184

apr_thread_once_t = struct_apr_thread_once_t# /usr/include/apr/apr_thread_proc.h: 187

apr_threadkey_t = struct_apr_threadkey_t# /usr/include/apr/apr_thread_proc.h: 190

apr_other_child_rec_t = struct_apr_other_child_rec_t# /usr/include/apr/apr_thread_proc.h: 193

svn_string_t = struct_svn_string_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 100

svn_stringbuf_t = struct_svn_stringbuf_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_string.h: 120

svn_checksum_t = struct_svn_checksum_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 77

svn_checksum_ctx_t = struct_svn_checksum_ctx_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_checksum.h: 82

svn_io_dirent2_t = struct_svn_io_dirent2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 98

svn_io_dirent_t = struct_svn_io_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 132

svn_stream_t = struct_svn_stream_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 863

svn_stream_mark_t = struct_svn_stream_mark_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_io.h: 894

svn_config_t = struct_svn_config_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_config.h: 54

svn_auth_baton_t = struct_svn_auth_baton_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 87

svn_auth_iterstate_t = struct_svn_auth_iterstate_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 90

svn_auth_provider_t = struct_svn_auth_provider_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 153

svn_auth_provider_object_t = struct_svn_auth_provider_object_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 163

svn_auth_cred_simple_t = struct_svn_auth_cred_simple_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 200

svn_auth_cred_username_t = struct_svn_auth_cred_username_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 222

svn_auth_cred_ssl_client_cert_t = struct_svn_auth_cred_ssl_client_cert_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 248

svn_auth_cred_ssl_client_cert_pw_t = struct_svn_auth_cred_ssl_client_cert_pw_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 283

svn_auth_ssl_server_cert_info_t = struct_svn_auth_ssl_server_cert_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 319

svn_auth_cred_ssl_server_trust_t = struct_svn_auth_cred_ssl_server_trust_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_auth.h: 340

svn_cache_config_t = struct_svn_cache_config_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cache_config.h: 64

apr_getopt_t = struct_apr_getopt_t# /usr/include/apr/apr_getopt.h: 50

apr_getopt_option_t = struct_apr_getopt_option_t# /usr/include/apr/apr_getopt.h: 83

svn_txdelta_op_t = struct_svn_txdelta_op_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 167

svn_txdelta_window_t = struct_svn_txdelta_window_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 216

svn_txdelta_stream_t = struct_svn_txdelta_stream_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 305

svn_delta_editor_t = struct_svn_delta_editor_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 883

svn_delta_path_driver_state_t = struct_svn_delta_path_driver_state_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_delta.h: 1422

svn_opt_subcommand_desc3_t = struct_svn_opt_subcommand_desc3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 112

svn_opt_subcommand_desc2_t = struct_svn_opt_subcommand_desc2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 144

svn_opt_subcommand_desc_t = struct_svn_opt_subcommand_desc_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 173

svn_opt_revision_value_t = union_svn_opt_revision_value_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 466

svn_opt_revision_t = struct_svn_opt_revision_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 473

svn_opt_revision_range_t = struct_svn_opt_revision_range_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_opt.h: 483

svn_ra_reporter3_t = struct_svn_ra_reporter3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 438

svn_ra_reporter2_t = struct_svn_ra_reporter2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 479

svn_ra_reporter_t = struct_svn_ra_reporter_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 517

svn_ra_callbacks2_t = struct_svn_ra_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 624

svn_ra_callbacks_t = struct_svn_ra_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 647

svn_ra_session_t = struct_svn_ra_session_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 685

svn_ra_plugin_t = struct_svn_ra_plugin_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra.h: 2536

svn_wc_context_t = struct_svn_wc_context_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 179

svn_wc_adm_access_t = struct_svn_wc_adm_access_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 237

svn_wc_traversal_info_t = struct_svn_wc_traversal_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 707

svn_wc_external_item2_t = struct_svn_wc_external_item2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 812

svn_wc_external_item_t = struct_svn_wc_external_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 872

svn_wc_notify_t = struct_svn_wc_notify_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1495

svn_wc_conflict_version_t = struct_svn_wc_conflict_version_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1735

svn_wc_conflict_description2_t = struct_svn_wc_conflict_description2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 1930

svn_wc_conflict_description_t = struct_svn_wc_conflict_description_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2023

svn_wc_conflict_result_t = struct_svn_wc_conflict_result_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2230

svn_wc_diff_callbacks4_t = struct_svn_wc_diff_callbacks4_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2509

svn_wc_diff_callbacks3_t = struct_svn_wc_diff_callbacks3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2606

svn_wc_diff_callbacks2_t = struct_svn_wc_diff_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2679

svn_wc_diff_callbacks_t = struct_svn_wc_diff_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 2749

svn_wc_entry_t = struct_svn_wc_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3135

svn_wc_info_t = struct_svn_wc_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3291

svn_wc_entry_callbacks2_t = struct_svn_wc_entry_callbacks2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3412

svn_wc_entry_callbacks_t = struct_svn_wc_entry_callbacks_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3423

svn_wc_status3_t = struct_svn_wc_status3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3880

svn_wc_status2_t = struct_svn_wc_status2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 3996

svn_wc_status_t = struct_svn_wc_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 4035

svn_wc_committed_queue_t = struct_svn_wc_committed_queue_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 5199

svn_wc_revision_status_t = struct_svn_wc_revision_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_wc.h: 8158

svn_diff_t = struct_svn_diff_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 82

svn_diff_fns2_t = struct_svn_diff_fns2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 148

svn_diff_fns_t = struct_svn_diff_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 177

svn_diff_output_fns_t = struct_svn_diff_output_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 377

svn_diff_file_options_t = struct_svn_diff_file_options_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 490

svn_diff_hunk_t = struct_svn_diff_hunk_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1077

svn_prop_patch_t = struct_svn_prop_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1212

svn_diff_binary_patch_t = struct_svn_diff_binary_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1219

svn_patch_t = struct_svn_patch_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1329

svn_patch_file_t = struct_svn_patch_file_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_diff.h: 1334

svn_client_proplist_item_t = struct_svn_client_proplist_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 355

svn_client_commit_info_t = struct_svn_client_commit_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 427

svn_client_commit_item3_t = struct_svn_client_commit_item3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 537

svn_client_commit_item2_t = struct_svn_client_commit_item2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 570

svn_client_commit_item_t = struct_svn_client_commit_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 601

svn_client_diff_summarize_t = struct_svn_client_diff_summarize_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 911

svn_client_ctx_t = struct_svn_client_ctx_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 1086

svn_client_status_t = struct_svn_client_status_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 2540

svn_client_conflict_t = struct_svn_client_conflict_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4572

svn_client_conflict_option_t = struct_svn_client_conflict_option_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 4579

svn_client_copy_source_t = struct_svn_client_copy_source_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 5507

svn_info_t = struct_svn_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7295

svn_client_info2_t = struct_svn_client_info2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_client.h: 7377

svn_cmdline_prompt_baton2_t = struct_svn_cmdline_prompt_baton2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 172

svn_cmdline_prompt_baton_t = struct_svn_cmdline_prompt_baton_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_cmdline.h: 183

apr_dso_handle_t = struct_apr_dso_handle_t# /usr/include/apr/apr_dso.h: 44

svn_fs_t = struct_svn_fs_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 66

svn_fs_access_t = struct_svn_fs_access_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 813

svn_fs_id_t = struct_svn_fs_id_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 966

svn_fs_txn_t = struct_svn_fs_txn_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1111

svn_fs_root_t = struct_svn_fs_root_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1380

svn_fs_path_change3_t = struct_svn_fs_path_change3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1560

svn_fs_path_change2_t = struct_svn_fs_path_change2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1627

svn_fs_path_change_t = struct_svn_fs_path_change_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1650

svn_fs_path_change_iterator_t = struct_svn_fs_path_change_iterator_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1694

svn_fs_history_t = struct_svn_fs_history_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 1789

svn_fs_dirent_t = struct_svn_fs_dirent_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2311

svn_fs_lock_target_t = struct_svn_fs_lock_target_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 2983

svn_fs_fsfs_info_t = struct_svn_fs_fsfs_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3435

svn_fs_fsx_info_t = struct_svn_fs_fsx_info_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3461

svn_fs_info_placeholder_t = struct_svn_fs_info_placeholder_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3471

svn_fs_ioctl_code_t = struct_svn_fs_ioctl_code_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_fs.h: 3517

svn_prop_t = struct_svn_prop_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 64

svn_prop_inherited_item_t = struct_svn_prop_inherited_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_props.h: 105

apr_socket_t = struct_apr_socket_t# /usr/include/apr/apr_network_io.h: 219

apr_hdtr_t = struct_apr_hdtr_t# /usr/include/apr/apr_network_io.h: 293

apr_ipsubnet_t = struct_apr_ipsubnet_t# /usr/include/apr/apr_network_io.h: 227

apr_sockaddr_t = struct_apr_sockaddr_t# /usr/include/apr/apr_network_io.h: 239

svn_ra_svn_conn_st = struct_svn_ra_svn_conn_st# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 124

svn_ra_svn_cmd_entry_t = struct_svn_ra_svn_cmd_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 145

svn_ra_svn_item_t = struct_svn_ra_svn_item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_ra_svn.h: 173

svn_repos_notify_t = struct_svn_repos_notify_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 367

svn_repos_t = struct_svn_repos_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 410

svn_repos_log_entry_t = struct_svn_repos_log_entry_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2066

svn_repos_node_t = struct_svn_repos_node_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 2966

svn_repos_parse_fns3_t = struct_svn_repos_parse_fns3_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3765

svn_repos_parse_fns2_t = struct_svn_repos_parse_fns2_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 3993

svn_repos_parse_fns_t = struct_svn_repos_parse_fns_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4039

svn_authz_t = struct_svn_authz_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_repos.h: 4136

svn_sort__item_t = struct_svn_sort__item_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_sorts.h: 55

svn_subst_keywords_t = struct_svn_subst_keywords_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_subst.h: 123

apr_xlate_t = struct_apr_xlate_t# /usr/include/apr-util/apr_xlate.h: 39

svn_version_checklist_t = struct_svn_version_checklist_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 240

svn_version_extended_t = struct_svn_version_extended_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 301

svn_version_ext_linked_lib_t = struct_svn_version_ext_linked_lib_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 405

svn_version_ext_loaded_lib_t = struct_svn_version_ext_loaded_lib_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_version.h: 430

svn_x509_certinfo_t = struct_svn_x509_certinfo_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 54

svn_x509_name_attr_t = struct_svn_x509_name_attr_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_x509.h: 61

svn_xml_parser_t = struct_svn_xml_parser_t# /tmp/B.i2dfn62w/BUILD/subversion-1.14.5-build/subversion-1.14.5/subversion/include/svn_xml.h: 158

apr_proc_mutex_t = struct_apr_proc_mutex_t# /usr/include/apr/apr_proc_mutex.h: 57

apr_global_mutex_t = struct_apr_global_mutex_t# /usr/include/apr/apr_global_mutex.h: 47

apr_vformatter_buff_t = struct_apr_vformatter_buff_t# /usr/include/apr/apr_lib.h: 64

apr_mmap_t = struct_apr_mmap_t# /usr/include/apr/apr_mmap.h: 62

apr_pollfd_t = struct_apr_pollfd_t# /usr/include/apr/apr_poll.h: 108

apr_pollset_t = struct_apr_pollset_t# /usr/include/apr/apr_poll.h: 123

apr_pollcb_t = struct_apr_pollcb_t# /usr/include/apr/apr_poll.h: 317

apr_shm_t = struct_apr_shm_t# /usr/include/apr/apr_shm.h: 44

apr_os_proc_mutex_t = struct_apr_os_proc_mutex_t# /usr/include/apr/apr_portable.h: 130

apr_os_sock_info_t = struct_apr_os_sock_info_t# /usr/include/apr/apr_portable.h: 190

apr_os_global_mutex_t = struct_apr_os_global_mutex_t# /usr/include/apr/apr_portable.h: 210

apr_crypto_hash_t = struct_apr_crypto_hash_t# /usr/include/apr/apr_random.h: 48

apr_random_t = struct_apr_random_t# /usr/include/apr/apr_random.h: 63

apr_skiplist = struct_apr_skiplist# /usr/include/apr/apr_skiplist.h: 54

apr_skiplistnode = struct_apr_skiplistnode# /usr/include/apr/apr_skiplist.h: 63

apr_thread_cond_t = struct_apr_thread_cond_t# /usr/include/apr/apr_thread_cond.h: 44

apr_thread_rwlock_t = struct_apr_thread_rwlock_t# /usr/include/apr/apr_thread_rwlock.h: 42

apr_anylock_u_t = union_apr_anylock_u_t# /usr/include/apr-util/apr_anylock.h: 39

apr_anylock_t = struct_apr_anylock_t# /usr/include/apr-util/apr_anylock.h: 46

apr_bucket_brigade = struct_apr_bucket_brigade# /usr/include/apr-util/apr_buckets.h: 258

apr_bucket = struct_apr_bucket# /usr/include/apr-util/apr_buckets.h: 224

apr_bucket_alloc_t = struct_apr_bucket_alloc_t# /usr/include/apr-util/apr_buckets.h: 123

apr_bucket_type_t = struct_apr_bucket_type_t# /usr/include/apr-util/apr_buckets.h: 131

apr_bucket_list = struct_apr_bucket_list# /usr/include/apr-util/apr_buckets.h: 273

apr_bucket_refcount = struct_apr_bucket_refcount# /usr/include/apr-util/apr_buckets.h: 531

apr_bucket_heap = struct_apr_bucket_heap# /usr/include/apr-util/apr_buckets.h: 543

apr_bucket_pool = struct_apr_bucket_pool# /usr/include/apr-util/apr_buckets.h: 561

apr_bucket_mmap = struct_apr_bucket_mmap# /usr/include/apr-util/apr_buckets.h: 599

apr_bucket_file = struct_apr_bucket_file# /usr/include/apr-util/apr_buckets.h: 612

apr_bucket_structs = union_apr_bucket_structs# /usr/include/apr-util/apr_buckets.h: 635

apu_err_t = struct_apu_err_t# /usr/include/apr-util/apu_errno.h: 165

apr_crypto_driver_t = struct_apr_crypto_driver_t# /usr/include/apr-util/apr_crypto.h: 124

apr_crypto_t = struct_apr_crypto_t# /usr/include/apr-util/apr_crypto.h: 125

apr_crypto_config_t = struct_apr_crypto_config_t# /usr/include/apr-util/apr_crypto.h: 126

apr_crypto_key_t = struct_apr_crypto_key_t# /usr/include/apr-util/apr_crypto.h: 127

apr_crypto_block_t = struct_apr_crypto_block_t# /usr/include/apr-util/apr_crypto.h: 128

apr_crypto_block_key_type_t = struct_apr_crypto_block_key_type_t# /usr/include/apr-util/apr_crypto.h: 135

apr_crypto_block_key_mode_t = struct_apr_crypto_block_key_mode_t# /usr/include/apr-util/apr_crypto.h: 139

apr_crypto_passphrase_t = struct_apr_crypto_passphrase_t# /usr/include/apr-util/apr_crypto.h: 147

apr_crypto_secret_t = struct_apr_crypto_secret_t# /usr/include/apr-util/apr_crypto.h: 152

apr_crypto_key_rec_t = struct_apr_crypto_key_rec_t# /usr/include/apr-util/apr_crypto.h: 170

apr_dbd_driver_t = struct_apr_dbd_driver_t# /usr/include/apr-util/apr_dbd.h: 82

apr_dbd_t = struct_apr_dbd_t# /usr/include/apr-util/apr_dbd.h: 83

apr_dbd_transaction_t = struct_apr_dbd_transaction_t# /usr/include/apr-util/apr_dbd.h: 84

apr_dbd_results_t = struct_apr_dbd_results_t# /usr/include/apr-util/apr_dbd.h: 85

apr_dbd_row_t = struct_apr_dbd_row_t# /usr/include/apr-util/apr_dbd.h: 86

apr_dbd_prepared_t = struct_apr_dbd_prepared_t# /usr/include/apr-util/apr_dbd.h: 87

apr_dbm_t = struct_apr_dbm_t# /usr/include/apr-util/apr_dbm.h: 42

apr_ldap_err_t = struct_apr_ldap_err_t# /usr/include/apr-util/apr_ldap.h: 152

apr_ldap_url_desc_t = struct_apr_ldap_url_desc_t# /usr/include/apr-util/apr_ldap_url.h: 43

apr_ldap_opt_tls_cert_t = struct_apr_ldap_opt_tls_cert_t# /usr/include/apr-util/apr_ldap_option.h: 166

apr_md4_ctx_t = struct_apr_md4_ctx_t# /usr/include/apr-util/apr_md4.h: 67

apr_md5_ctx_t = struct_apr_md5_ctx_t# /usr/include/apr-util/apr_md5.h: 74

apr_reslist_t = struct_apr_reslist_t# /usr/include/apr-util/apr_reslist.h: 42

apr_memcache_conn_t = struct_apr_memcache_conn_t# /usr/include/apr-util/apr_memcache.h: 56

apr_memcache_server_t = struct_apr_memcache_server_t# /usr/include/apr-util/apr_memcache.h: 60

apr_memcache_t = struct_apr_memcache_t# /usr/include/apr-util/apr_memcache.h: 98

apr_queue_t = struct_apr_queue_t# /usr/include/apr-util/apr_queue.h: 47

apr_redis_conn_t = struct_apr_redis_conn_t# /usr/include/apr-util/apr_redis.h: 71

apr_redis_server_t = struct_apr_redis_server_t# /usr/include/apr-util/apr_redis.h: 75

apr_redis_t = struct_apr_redis_t# /usr/include/apr-util/apr_redis.h: 120

apr_rmm_t = struct_apr_rmm_t# /usr/include/apr-util/apr_rmm.h: 40

apr_sdbm_t = struct_apr_sdbm_t# /usr/include/apr-util/apr_sdbm.h: 44

apr_sha1_ctx_t = struct_apr_sha1_ctx_t# /usr/include/apr-util/apr_sha1.h: 56

apr_strmatch_pattern = struct_apr_strmatch_pattern# /usr/include/apr-util/apr_strmatch.h: 43

apr_thread_pool = struct_apr_thread_pool# /usr/include/apr-util/apr_thread_pool.h: 58

apr_uri_t = struct_apr_uri_t# /usr/include/apr-util/apr_uri.h: 85

hostent = struct_hostent# /usr/include/apr-util/apr_uri.h: 106

apr_text = struct_apr_text# /usr/include/apr-util/apr_xml.h: 53

apr_text_header = struct_apr_text_header# /usr/include/apr-util/apr_xml.h: 64

apr_xml_attr = struct_apr_xml_attr# /usr/include/apr-util/apr_xml.h: 148

apr_xml_elem = struct_apr_xml_elem# /usr/include/apr-util/apr_xml.h: 162

apr_xml_doc = struct_apr_xml_doc# /usr/include/apr-util/apr_xml.h: 200

apr_xml_ns_scope = struct_apr_xml_ns_scope# /usr/include/apr-util/apr_xml.h: 188

apr_xml_parser = struct_apr_xml_parser# /usr/include/apr-util/apr_xml.h: 208

# No inserted files

# No prefix-stripping

